const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-11-01";
pub const sdk_id: []const u8 = "AccessAnalyzer";
pub const arn_namespace: ?[]const u8 = "access-analyzer";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "access-analyzer";
pub const name: []const u8 = "AccessAnalyzer";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-11-01",
    sdk_id: []const u8 = "AccessAnalyzer",
    arn_namespace: ?[]const u8 = "access-analyzer",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "access-analyzer",
    name: []const u8 = "AccessAnalyzer",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const apply_archive_rule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/archive-rule",
        .success_code = 200,
    };

    action_name: []const u8 = "ApplyArchiveRule",
    Request: type = struct {
        analyzer_arn: []const u8,
        rule_name: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .rule_name = "ruleName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_archive_rule) } {
            return .{ .service_metadata = service_metadata, .action = apply_archive_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_policy_generation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/policy/generation/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelPolicyGeneration",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_policy_generation) } {
            return .{ .service_metadata = service_metadata, .action = cancel_policy_generation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const check_access_not_granted: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policy/check-access-not-granted",
        .success_code = 200,
    };

    action_name: []const u8 = "CheckAccessNotGranted",
    Request: type = struct {
        policy_document: []const u8,
        access: []struct {
            actions: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .actions = "actions",
                };
                return @field(mappings, field_name);
            }
        },
        policy_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_document = "policyDocument",
                .access = "access",
                .policy_type = "policyType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_access_not_granted) } {
            return .{ .service_metadata = service_metadata, .action = check_access_not_granted };
        }
    },
    Response: type = struct {
        result: ?[]const u8 = null,
        message: ?[]const u8 = null,
        reasons: ?[]ReasonSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "result",
                .message = "message",
                .reasons = "reasons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameter,
        Throttling,
        UnprocessableEntity,
        Validation,
    },
} = .{};
pub const check_no_new_access: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policy/check-no-new-access",
        .success_code = 200,
    };

    action_name: []const u8 = "CheckNoNewAccess",
    Request: type = struct {
        new_policy_document: []const u8,
        existing_policy_document: []const u8,
        policy_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .new_policy_document = "newPolicyDocument",
                .existing_policy_document = "existingPolicyDocument",
                .policy_type = "policyType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_no_new_access) } {
            return .{ .service_metadata = service_metadata, .action = check_no_new_access };
        }
    },
    Response: type = struct {
        result: ?[]const u8 = null,
        message: ?[]const u8 = null,
        reasons: ?[]ReasonSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "result",
                .message = "message",
                .reasons = "reasons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameter,
        Throttling,
        UnprocessableEntity,
        Validation,
    },
} = .{};
pub const create_access_preview: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/access-preview",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessPreview",
    Request: type = struct {
        analyzer_arn: []const u8,
        configurations: []struct {
            key: ?[]const u8 = null,
            value: ?Configuration = null,
        },
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .configurations = "configurations",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "configurations", field_name))
                return try serializeMap(self.configurations, self.fieldNameFor("configurations"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_preview) } {
            return .{ .service_metadata = service_metadata, .action = create_access_preview };
        }
    },
    Response: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_access_preview: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/access-preview/{accessPreviewId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPreview",
    Request: type = struct {
        access_preview_id: []const u8,
        analyzer_arn: []const u8,

        pub const http_query = .{
            .analyzer_arn = "analyzerArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_preview_id = "accessPreviewId",
                .analyzer_arn = "analyzerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_preview) } {
            return .{ .service_metadata = service_metadata, .action = get_access_preview };
        }
    },
    Response: type = struct {
        access_preview: struct {
            id: []const u8,
            analyzer_arn: []const u8,
            configurations: []struct {
                key: ?[]const u8 = null,
                value: ?Configuration = null,
            },
            created_at: i64,
            status: []const u8,
            status_reason: ?AccessPreviewStatusReason = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .analyzer_arn = "analyzerArn",
                    .configurations = "configurations",
                    .created_at = "createdAt",
                    .status = "status",
                    .status_reason = "statusReason",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "configurations", field_name))
                    return try serializeMap(self.configurations, self.fieldNameFor("configurations"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_preview = "accessPreview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_analyzed_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/analyzed-resource",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAnalyzedResource",
    Request: type = struct {
        analyzer_arn: []const u8,
        resource_arn: []const u8,

        pub const http_query = .{
            .analyzer_arn = "analyzerArn",
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_analyzed_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_analyzed_resource };
        }
    },
    Response: type = struct {
        resource: ?struct {
            resource_arn: []const u8,
            resource_type: []const u8,
            created_at: i64,
            analyzed_at: i64,
            updated_at: i64,
            is_public: bool,
            actions: ?[][]const u8 = null,
            shared_via: ?[][]const u8 = null,
            status: ?[]const u8 = null,
            resource_owner_account: []const u8,
            @"error": ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "resourceArn",
                    .resource_type = "resourceType",
                    .created_at = "createdAt",
                    .analyzed_at = "analyzedAt",
                    .updated_at = "updatedAt",
                    .is_public = "isPublic",
                    .actions = "actions",
                    .shared_via = "sharedVia",
                    .status = "status",
                    .resource_owner_account = "resourceOwnerAccount",
                    .@"error" = "error",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "resource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_finding: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/finding/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFinding",
    Request: type = struct {
        analyzer_arn: []const u8,
        id: []const u8,

        pub const http_query = .{
            .analyzer_arn = "analyzerArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_finding) } {
            return .{ .service_metadata = service_metadata, .action = get_finding };
        }
    },
    Response: type = struct {
        finding: ?struct {
            id: []const u8,
            principal: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            action: ?[][]const u8 = null,
            resource: ?[]const u8 = null,
            is_public: ?bool = null,
            resource_type: []const u8,
            condition: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            created_at: i64,
            analyzed_at: i64,
            updated_at: i64,
            status: []const u8,
            resource_owner_account: []const u8,
            @"error": ?[]const u8 = null,
            sources: ?[]FindingSource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .principal = "principal",
                    .action = "action",
                    .resource = "resource",
                    .is_public = "isPublic",
                    .resource_type = "resourceType",
                    .condition = "condition",
                    .created_at = "createdAt",
                    .analyzed_at = "analyzedAt",
                    .updated_at = "updatedAt",
                    .status = "status",
                    .resource_owner_account = "resourceOwnerAccount",
                    .@"error" = "error",
                    .sources = "sources",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "principal", field_name))
                    return try serializeMap(self.principal, self.fieldNameFor("principal"), options, out_stream);
                if (std.mem.eql(u8, "condition", field_name))
                    return try serializeMap(self.condition, self.fieldNameFor("condition"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding = "finding",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_finding_v2: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findingv2/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindingV2",
    Request: type = struct {
        analyzer_arn: []const u8,
        id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .analyzer_arn = "analyzerArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .id = "id",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_finding_v2) } {
            return .{ .service_metadata = service_metadata, .action = get_finding_v2 };
        }
    },
    Response: type = struct {
        analyzed_at: i64,
        created_at: i64,
        @"error": ?[]const u8 = null,
        id: []const u8,
        next_token: ?[]const u8 = null,
        resource: ?[]const u8 = null,
        resource_type: []const u8,
        resource_owner_account: []const u8,
        status: []const u8,
        updated_at: i64,
        finding_details: []union {
            external_access_details: ?struct {
                action: ?[][]const u8 = null,
                condition: []struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                },
                is_public: ?bool = null,
                principal: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                sources: ?[]FindingSource = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action = "action",
                        .condition = "condition",
                        .is_public = "isPublic",
                        .principal = "principal",
                        .sources = "sources",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "condition", field_name))
                        return try serializeMap(self.condition, self.fieldNameFor("condition"), options, out_stream);
                    if (std.mem.eql(u8, "principal", field_name))
                        return try serializeMap(self.principal, self.fieldNameFor("principal"), options, out_stream);
                    return false;
                }
            },
            unused_permission_details: ?struct {
                actions: ?[]struct {
                    action: []const u8,
                    last_accessed: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .action = "action",
                            .last_accessed = "lastAccessed",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                service_namespace: []const u8,
                last_accessed: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .actions = "actions",
                        .service_namespace = "serviceNamespace",
                        .last_accessed = "lastAccessed",
                    };
                    return @field(mappings, field_name);
                }
            },
            unused_iam_user_access_key_details: ?struct {
                access_key_id: []const u8,
                last_accessed: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .access_key_id = "accessKeyId",
                        .last_accessed = "lastAccessed",
                    };
                    return @field(mappings, field_name);
                }
            },
            unused_iam_role_details: ?struct {
                last_accessed: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .last_accessed = "lastAccessed",
                    };
                    return @field(mappings, field_name);
                }
            },
            unused_iam_user_password_details: ?struct {
                last_accessed: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .last_accessed = "lastAccessed",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .external_access_details = "externalAccessDetails",
                    .unused_permission_details = "unusedPermissionDetails",
                    .unused_iam_user_access_key_details = "unusedIamUserAccessKeyDetails",
                    .unused_iam_role_details = "unusedIamRoleDetails",
                    .unused_iam_user_password_details = "unusedIamUserPasswordDetails",
                };
                return @field(mappings, field_name);
            }
        },
        finding_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzed_at = "analyzedAt",
                .created_at = "createdAt",
                .@"error" = "error",
                .id = "id",
                .next_token = "nextToken",
                .resource = "resource",
                .resource_type = "resourceType",
                .resource_owner_account = "resourceOwnerAccount",
                .status = "status",
                .updated_at = "updatedAt",
                .finding_details = "findingDetails",
                .finding_type = "findingType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_generated_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policy/generation/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGeneratedPolicy",
    Request: type = struct {
        job_id: []const u8,
        include_resource_placeholders: ?bool = null,
        include_service_level_template: ?bool = null,

        pub const http_query = .{
            .include_resource_placeholders = "includeResourcePlaceholders",
            .include_service_level_template = "includeServiceLevelTemplate",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .include_resource_placeholders = "includeResourcePlaceholders",
                .include_service_level_template = "includeServiceLevelTemplate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_generated_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_generated_policy };
        }
    },
    Response: type = struct {
        job_details: struct {
            job_id: []const u8,
            status: []const u8,
            started_on: i64,
            completed_on: ?i64 = null,
            job_error: ?struct {
                code: []const u8,
                message: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .status = "status",
                    .started_on = "startedOn",
                    .completed_on = "completedOn",
                    .job_error = "jobError",
                };
                return @field(mappings, field_name);
            }
        },
        generated_policy_result: struct {
            properties: struct {
                is_complete: ?bool = null,
                principal_arn: []const u8,
                cloud_trail_properties: ?struct {
                    trail_properties: []struct {
                        cloud_trail_arn: []const u8,
                        regions: ?[][]const u8 = null,
                        all_regions: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .cloud_trail_arn = "cloudTrailArn",
                                .regions = "regions",
                                .all_regions = "allRegions",
                            };
                            return @field(mappings, field_name);
                        }
                    },
                    start_time: i64,
                    end_time: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .trail_properties = "trailProperties",
                            .start_time = "startTime",
                            .end_time = "endTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .is_complete = "isComplete",
                        .principal_arn = "principalArn",
                        .cloud_trail_properties = "cloudTrailProperties",
                    };
                    return @field(mappings, field_name);
                }
            },
            generated_policies: ?[]struct {
                policy: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .policy = "policy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .properties = "properties",
                    .generated_policies = "generatedPolicies",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_details = "jobDetails",
                .generated_policy_result = "generatedPolicyResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_access_preview_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/access-preview/{accessPreviewId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessPreviewFindings",
    Request: type = struct {
        access_preview_id: []const u8,
        analyzer_arn: []const u8,
        filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Criterion = null,
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_preview_id = "accessPreviewId",
                .analyzer_arn = "analyzerArn",
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter", field_name))
                return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_preview_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_access_preview_findings };
        }
    },
    Response: type = struct {
        findings: []struct {
            id: []const u8,
            existing_finding_id: ?[]const u8 = null,
            existing_finding_status: ?[]const u8 = null,
            principal: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            action: ?[][]const u8 = null,
            condition: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            resource: ?[]const u8 = null,
            is_public: ?bool = null,
            resource_type: []const u8,
            created_at: i64,
            change_type: []const u8,
            status: []const u8,
            resource_owner_account: []const u8,
            @"error": ?[]const u8 = null,
            sources: ?[]FindingSource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .existing_finding_id = "existingFindingId",
                    .existing_finding_status = "existingFindingStatus",
                    .principal = "principal",
                    .action = "action",
                    .condition = "condition",
                    .resource = "resource",
                    .is_public = "isPublic",
                    .resource_type = "resourceType",
                    .created_at = "createdAt",
                    .change_type = "changeType",
                    .status = "status",
                    .resource_owner_account = "resourceOwnerAccount",
                    .@"error" = "error",
                    .sources = "sources",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "principal", field_name))
                    return try serializeMap(self.principal, self.fieldNameFor("principal"), options, out_stream);
                if (std.mem.eql(u8, "condition", field_name))
                    return try serializeMap(self.condition, self.fieldNameFor("condition"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_access_previews: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/access-preview",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessPreviews",
    Request: type = struct {
        analyzer_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .analyzer_arn = "analyzerArn",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_previews) } {
            return .{ .service_metadata = service_metadata, .action = list_access_previews };
        }
    },
    Response: type = struct {
        access_previews: []struct {
            id: []const u8,
            analyzer_arn: []const u8,
            created_at: i64,
            status: []const u8,
            status_reason: ?AccessPreviewStatusReason = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .analyzer_arn = "analyzerArn",
                    .created_at = "createdAt",
                    .status = "status",
                    .status_reason = "statusReason",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_previews = "accessPreviews",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_analyzed_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/analyzed-resource",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnalyzedResources",
    Request: type = struct {
        analyzer_arn: []const u8,
        resource_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .resource_type = "resourceType",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_analyzed_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_analyzed_resources };
        }
    },
    Response: type = struct {
        analyzed_resources: []struct {
            resource_arn: []const u8,
            resource_owner_account: []const u8,
            resource_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "resourceArn",
                    .resource_owner_account = "resourceOwnerAccount",
                    .resource_type = "resourceType",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzed_resources = "analyzedResources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/finding",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindings",
    Request: type = struct {
        analyzer_arn: []const u8,
        filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Criterion = null,
        } = null,
        sort: ?SortCriteria = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .filter = "filter",
                .sort = "sort",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter", field_name))
                return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_findings };
        }
    },
    Response: type = struct {
        findings: []struct {
            id: []const u8,
            principal: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            action: ?[][]const u8 = null,
            resource: ?[]const u8 = null,
            is_public: ?bool = null,
            resource_type: []const u8,
            condition: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            created_at: i64,
            analyzed_at: i64,
            updated_at: i64,
            status: []const u8,
            resource_owner_account: []const u8,
            @"error": ?[]const u8 = null,
            sources: ?[]FindingSource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .principal = "principal",
                    .action = "action",
                    .resource = "resource",
                    .is_public = "isPublic",
                    .resource_type = "resourceType",
                    .condition = "condition",
                    .created_at = "createdAt",
                    .analyzed_at = "analyzedAt",
                    .updated_at = "updatedAt",
                    .status = "status",
                    .resource_owner_account = "resourceOwnerAccount",
                    .@"error" = "error",
                    .sources = "sources",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "principal", field_name))
                    return try serializeMap(self.principal, self.fieldNameFor("principal"), options, out_stream);
                if (std.mem.eql(u8, "condition", field_name))
                    return try serializeMap(self.condition, self.fieldNameFor("condition"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_findings_v2: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findingv2",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindingsV2",
    Request: type = struct {
        analyzer_arn: []const u8,
        filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Criterion = null,
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort: ?SortCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .filter = "filter",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .sort = "sort",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter", field_name))
                return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_findings_v2) } {
            return .{ .service_metadata = service_metadata, .action = list_findings_v2 };
        }
    },
    Response: type = struct {
        findings: []struct {
            analyzed_at: i64,
            created_at: i64,
            @"error": ?[]const u8 = null,
            id: []const u8,
            resource: ?[]const u8 = null,
            resource_type: []const u8,
            resource_owner_account: []const u8,
            status: []const u8,
            updated_at: i64,
            finding_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .analyzed_at = "analyzedAt",
                    .created_at = "createdAt",
                    .@"error" = "error",
                    .id = "id",
                    .resource = "resource",
                    .resource_type = "resourceType",
                    .resource_owner_account = "resourceOwnerAccount",
                    .status = "status",
                    .updated_at = "updatedAt",
                    .finding_type = "findingType",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_policy_generations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policy/generation",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPolicyGenerations",
    Request: type = struct {
        principal_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .principal_arn = "principalArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_arn = "principalArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_policy_generations) } {
            return .{ .service_metadata = service_metadata, .action = list_policy_generations };
        }
    },
    Response: type = struct {
        policy_generations: []struct {
            job_id: []const u8,
            principal_arn: []const u8,
            status: []const u8,
            started_on: i64,
            completed_on: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .principal_arn = "principalArn",
                    .status = "status",
                    .started_on = "startedOn",
                    .completed_on = "completedOn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_generations = "policyGenerations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_policy_generation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/policy/generation",
        .success_code = 200,
    };

    action_name: []const u8 = "StartPolicyGeneration",
    Request: type = struct {
        policy_generation_details: struct {
            principal_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .principal_arn = "principalArn",
                };
                return @field(mappings, field_name);
            }
        },
        cloud_trail_details: ?struct {
            trails: []struct {
                cloud_trail_arn: []const u8,
                regions: ?[][]const u8 = null,
                all_regions: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cloud_trail_arn = "cloudTrailArn",
                        .regions = "regions",
                        .all_regions = "allRegions",
                    };
                    return @field(mappings, field_name);
                }
            },
            access_role: []const u8,
            start_time: i64,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trails = "trails",
                    .access_role = "accessRole",
                    .start_time = "startTime",
                    .end_time = "endTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_generation_details = "policyGenerationDetails",
                .cloud_trail_details = "cloudTrailDetails",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_policy_generation) } {
            return .{ .service_metadata = service_metadata, .action = start_policy_generation };
        }
    },
    Response: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_resource_scan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/resource/scan",
        .success_code = 200,
    };

    action_name: []const u8 = "StartResourceScan",
    Request: type = struct {
        analyzer_arn: []const u8,
        resource_arn: []const u8,
        resource_owner_account: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .resource_arn = "resourceArn",
                .resource_owner_account = "resourceOwnerAccount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_resource_scan) } {
            return .{ .service_metadata = service_metadata, .action = start_resource_scan };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_findings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/finding",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFindings",
    Request: type = struct {
        analyzer_arn: []const u8,
        status: []const u8,
        ids: ?[][]const u8 = null,
        resource_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzer_arn = "analyzerArn",
                .status = "status",
                .ids = "ids",
                .resource_arn = "resourceArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_findings) } {
            return .{ .service_metadata = service_metadata, .action = update_findings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const validate_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policy/validation",
        .success_code = 200,
    };

    action_name: []const u8 = "ValidatePolicy",
    Request: type = struct {
        locale: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        policy_document: []const u8,
        policy_type: []const u8,
        validate_policy_resource_type: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locale = "locale",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .policy_document = "policyDocument",
                .policy_type = "policyType",
                .validate_policy_resource_type = "validatePolicyResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_policy) } {
            return .{ .service_metadata = service_metadata, .action = validate_policy };
        }
    },
    Response: type = struct {
        findings: []struct {
            finding_details: []const u8,
            finding_type: []const u8,
            issue_code: []const u8,
            learn_more_link: []const u8,
            locations: []struct {
                path: []union {
                    index: ?i64,
                    key: ?[]const u8,
                    substring: ?struct {
                        start: i64,
                        length: i64,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .start = "start",
                                .length = "length",
                            };
                            return @field(mappings, field_name);
                        }
                    },
                    value: ?[]const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .index = "index",
                            .key = "key",
                            .substring = "substring",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                },
                span: struct {
                    start: Position,
                    end: Position,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .start = "start",
                            .end = "end",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .path = "path",
                        .span = "span",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_details = "findingDetails",
                    .finding_type = "findingType",
                    .issue_code = "issueCode",
                    .learn_more_link = "learnMoreLink",
                    .locations = "locations",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const Position = struct {
    line: i64,
    column: i64,
    offset: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line = "line",
            .column = "column",
            .offset = "offset",
        };
        return @field(mappings, field_name);
    }
};

pub const SortCriteria = struct {
    attribute_name: ?[]const u8 = null,
    order_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "attributeName",
            .order_by = "orderBy",
        };
        return @field(mappings, field_name);
    }
};

pub const Criterion = struct {
    eq: ?[][]const u8 = null,
    neq: ?[][]const u8 = null,
    contains: ?[][]const u8 = null,
    exists: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eq = "eq",
            .neq = "neq",
            .contains = "contains",
            .exists = "exists",
        };
        return @field(mappings, field_name);
    }
};

pub const FindingSource = struct {
    type: []const u8,
    detail: ?FindingSourceDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .detail = "detail",
        };
        return @field(mappings, field_name);
    }
};

pub const FindingSourceDetail = struct {
    access_point_arn: ?[]const u8 = null,
    access_point_account: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_point_arn = "accessPointArn",
            .access_point_account = "accessPointAccount",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessPreviewStatusReason = struct {
    code: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
        };
        return @field(mappings, field_name);
    }
};

pub const Configuration = union {
    ebs_snapshot: ?EbsSnapshotConfiguration,
    ecr_repository: ?EcrRepositoryConfiguration,
    iam_role: ?IamRoleConfiguration,
    efs_file_system: ?EfsFileSystemConfiguration,
    kms_key: ?KmsKeyConfiguration,
    rds_db_cluster_snapshot: ?RdsDbClusterSnapshotConfiguration,
    rds_db_snapshot: ?RdsDbSnapshotConfiguration,
    secrets_manager_secret: ?SecretsManagerSecretConfiguration,
    s3_bucket: ?S3BucketConfiguration,
    sns_topic: ?SnsTopicConfiguration,
    sqs_queue: ?SqsQueueConfiguration,
    s3_express_directory_bucket: ?S3ExpressDirectoryBucketConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_snapshot = "ebsSnapshot",
            .ecr_repository = "ecrRepository",
            .iam_role = "iamRole",
            .efs_file_system = "efsFileSystem",
            .kms_key = "kmsKey",
            .rds_db_cluster_snapshot = "rdsDbClusterSnapshot",
            .rds_db_snapshot = "rdsDbSnapshot",
            .secrets_manager_secret = "secretsManagerSecret",
            .s3_bucket = "s3Bucket",
            .sns_topic = "snsTopic",
            .sqs_queue = "sqsQueue",
            .s3_express_directory_bucket = "s3ExpressDirectoryBucket",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ExpressDirectoryBucketConfiguration = struct {
    bucket_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_policy = "bucketPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const SqsQueueConfiguration = struct {
    queue_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue_policy = "queuePolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsTopicConfiguration = struct {
    topic_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_policy = "topicPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketConfiguration = struct {
    bucket_policy: ?[]const u8 = null,
    bucket_acl_grants: ?[]S3BucketAclGrantConfiguration = null,
    bucket_public_access_block: ?S3PublicAccessBlockConfiguration = null,
    access_points: ?[]struct {
        key: ?[]const u8 = null,
        value: ?S3AccessPointConfiguration = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_policy = "bucketPolicy",
            .bucket_acl_grants = "bucketAclGrants",
            .bucket_public_access_block = "bucketPublicAccessBlock",
            .access_points = "accessPoints",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "access_points", field_name))
            return try serializeMap(self.access_points, self.fieldNameFor("access_points"), options, out_stream);
        return false;
    }
};

pub const S3AccessPointConfiguration = struct {
    access_point_policy: ?[]const u8 = null,
    public_access_block: ?S3PublicAccessBlockConfiguration = null,
    network_origin: ?NetworkOriginConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_point_policy = "accessPointPolicy",
            .public_access_block = "publicAccessBlock",
            .network_origin = "networkOrigin",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkOriginConfiguration = union {
    vpc_configuration: ?VpcConfiguration,
    internet_configuration: ?InternetConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_configuration = "vpcConfiguration",
            .internet_configuration = "internetConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const InternetConfiguration = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const VpcConfiguration = struct {
    vpc_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "vpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const S3PublicAccessBlockConfiguration = struct {
    ignore_public_acls: bool,
    restrict_public_buckets: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ignore_public_acls = "ignorePublicAcls",
            .restrict_public_buckets = "restrictPublicBuckets",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketAclGrantConfiguration = struct {
    permission: []const u8,
    grantee: AclGrantee,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .permission = "permission",
            .grantee = "grantee",
        };
        return @field(mappings, field_name);
    }
};

pub const AclGrantee = union {
    id: ?[]const u8,
    uri: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .uri = "uri",
        };
        return @field(mappings, field_name);
    }
};

pub const SecretsManagerSecretConfiguration = struct {
    kms_key_id: ?[]const u8 = null,
    secret_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "kmsKeyId",
            .secret_policy = "secretPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const RdsDbSnapshotConfiguration = struct {
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?RdsDbSnapshotAttributeValue = null,
    } = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "attributes",
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const RdsDbSnapshotAttributeValue = union {
    account_ids: ?[][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_ids = "accountIds",
        };
        return @field(mappings, field_name);
    }
};

pub const RdsDbClusterSnapshotConfiguration = struct {
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?RdsDbClusterSnapshotAttributeValue = null,
    } = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "attributes",
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const RdsDbClusterSnapshotAttributeValue = union {
    account_ids: ?[][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_ids = "accountIds",
        };
        return @field(mappings, field_name);
    }
};

pub const KmsKeyConfiguration = struct {
    key_policies: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    grants: ?[]KmsGrantConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_policies = "keyPolicies",
            .grants = "grants",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "key_policies", field_name))
            return try serializeMap(self.key_policies, self.fieldNameFor("key_policies"), options, out_stream);
        return false;
    }
};

pub const KmsGrantConfiguration = struct {
    operations: [][]const u8,
    grantee_principal: []const u8,
    retiring_principal: ?[]const u8 = null,
    constraints: ?KmsGrantConstraints = null,
    issuing_account: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .operations = "operations",
            .grantee_principal = "granteePrincipal",
            .retiring_principal = "retiringPrincipal",
            .constraints = "constraints",
            .issuing_account = "issuingAccount",
        };
        return @field(mappings, field_name);
    }
};

pub const KmsGrantConstraints = struct {
    encryption_context_equals: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    encryption_context_subset: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_context_equals = "encryptionContextEquals",
            .encryption_context_subset = "encryptionContextSubset",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "encryption_context_equals", field_name))
            return try serializeMap(self.encryption_context_equals, self.fieldNameFor("encryption_context_equals"), options, out_stream);
        if (std.mem.eql(u8, "encryption_context_subset", field_name))
            return try serializeMap(self.encryption_context_subset, self.fieldNameFor("encryption_context_subset"), options, out_stream);
        return false;
    }
};

pub const EfsFileSystemConfiguration = struct {
    file_system_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_system_policy = "fileSystemPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const IamRoleConfiguration = struct {
    trust_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trust_policy = "trustPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const EcrRepositoryConfiguration = struct {
    repository_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_policy = "repositoryPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsSnapshotConfiguration = struct {
    user_ids: ?[][]const u8 = null,
    groups: ?[][]const u8 = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_ids = "userIds",
            .groups = "groups",
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ReasonSummary = struct {
    description: ?[]const u8 = null,
    statement_index: ?i64 = null,
    statement_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .statement_index = "statementIndex",
            .statement_id = "statementId",
        };
        return @field(mappings, field_name);
    }
};
