const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-12-08";
pub const sdk_id: []const u8 = "ACM";
pub const arn_namespace: ?[]const u8 = "acm";
pub const endpoint_prefix: []const u8 = "acm";
pub const sigv4_name: []const u8 = "acm";
pub const name: []const u8 = "CertificateManager";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-12-08",
    sdk_id: []const u8 = "ACM",
    arn_namespace: ?[]const u8 = "acm",
    endpoint_prefix: []const u8 = "acm",
    sigv4_name: []const u8 = "acm",
    name: []const u8 = "CertificateManager",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags_to_certificate: struct {
    action_name: []const u8 = "AddTagsToCertificate",
    Request: type = struct {
        certificate_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_certificate) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidParameter,
        InvalidTag,
        ResourceNotFound,
        TagPolicy,
        Throttling,
        TooManyTags,
    },
} = .{};
pub const delete_certificate: struct {
    action_name: []const u8 = "DeleteCertificate",
    Request: type = struct {
        certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_certificate) } {
            return .{ .service_metadata = service_metadata, .action = delete_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InvalidArn,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_certificate: struct {
    action_name: []const u8 = "DescribeCertificate",
    Request: type = struct {
        certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificate) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificate };
        }
    },
    Response: type = struct {
        certificate: ?struct {
            certificate_arn: ?[]const u8 = null,
            domain_name: ?[]const u8 = null,
            subject_alternative_names: ?[][]const u8 = null,
            domain_validation_options: ?[]DomainValidation = null,
            serial: ?[]const u8 = null,
            subject: ?[]const u8 = null,
            issuer: ?[]const u8 = null,
            created_at: ?i64 = null,
            issued_at: ?i64 = null,
            imported_at: ?i64 = null,
            status: ?[]const u8 = null,
            revoked_at: ?i64 = null,
            revocation_reason: ?[]const u8 = null,
            not_before: ?i64 = null,
            not_after: ?i64 = null,
            key_algorithm: ?[]const u8 = null,
            signature_algorithm: ?[]const u8 = null,
            in_use_by: ?[][]const u8 = null,
            failure_reason: ?[]const u8 = null,
            type: ?[]const u8 = null,
            renewal_summary: ?struct {
                renewal_status: []const u8,
                domain_validation_options: []DomainValidation,
                renewal_status_reason: ?[]const u8 = null,
                updated_at: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .renewal_status = "RenewalStatus",
                        .domain_validation_options = "DomainValidationOptions",
                        .renewal_status_reason = "RenewalStatusReason",
                        .updated_at = "UpdatedAt",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            key_usages: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            extended_key_usages: ?[]struct {
                name: ?[]const u8 = null,
                oid: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .oid = "OID",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            certificate_authority_arn: ?[]const u8 = null,
            renewal_eligibility: ?[]const u8 = null,
            options: ?CertificateOptions = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_arn = "CertificateArn",
                    .domain_name = "DomainName",
                    .subject_alternative_names = "SubjectAlternativeNames",
                    .domain_validation_options = "DomainValidationOptions",
                    .serial = "Serial",
                    .subject = "Subject",
                    .issuer = "Issuer",
                    .created_at = "CreatedAt",
                    .issued_at = "IssuedAt",
                    .imported_at = "ImportedAt",
                    .status = "Status",
                    .revoked_at = "RevokedAt",
                    .revocation_reason = "RevocationReason",
                    .not_before = "NotBefore",
                    .not_after = "NotAfter",
                    .key_algorithm = "KeyAlgorithm",
                    .signature_algorithm = "SignatureAlgorithm",
                    .in_use_by = "InUseBy",
                    .failure_reason = "FailureReason",
                    .type = "Type",
                    .renewal_summary = "RenewalSummary",
                    .key_usages = "KeyUsages",
                    .extended_key_usages = "ExtendedKeyUsages",
                    .certificate_authority_arn = "CertificateAuthorityArn",
                    .renewal_eligibility = "RenewalEligibility",
                    .options = "Options",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        ResourceNotFound,
    },
} = .{};
pub const export_certificate: struct {
    action_name: []const u8 = "ExportCertificate",
    Request: type = struct {
        certificate_arn: []const u8,
        passphrase: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .passphrase = "Passphrase",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_certificate) } {
            return .{ .service_metadata = service_metadata, .action = export_certificate };
        }
    },
    Response: type = struct {
        certificate: ?[]const u8 = null,
        certificate_chain: ?[]const u8 = null,
        private_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .certificate_chain = "CertificateChain",
                .private_key = "PrivateKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        RequestInProgress,
        ResourceNotFound,
    },
} = .{};
pub const get_account_configuration: struct {
    action_name: []const u8 = "GetAccountConfiguration",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_account_configuration };
        }
    },
    Response: type = struct {
        expiry_events: ?ExpiryEventsConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .expiry_events = "ExpiryEvents",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Throttling,
    },
} = .{};
pub const get_certificate: struct {
    action_name: []const u8 = "GetCertificate",
    Request: type = struct {
        certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_certificate) } {
            return .{ .service_metadata = service_metadata, .action = get_certificate };
        }
    },
    Response: type = struct {
        certificate: ?[]const u8 = null,
        certificate_chain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .certificate_chain = "CertificateChain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        RequestInProgress,
        ResourceNotFound,
    },
} = .{};
pub const import_certificate: struct {
    action_name: []const u8 = "ImportCertificate",
    Request: type = struct {
        certificate_arn: ?[]const u8 = null,
        certificate: []const u8,
        private_key: []const u8,
        certificate_chain: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .certificate = "Certificate",
                .private_key = "PrivateKey",
                .certificate_chain = "CertificateChain",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_certificate) } {
            return .{ .service_metadata = service_metadata, .action = import_certificate };
        }
    },
    Response: type = struct {
        certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidParameter,
        InvalidTag,
        LimitExceeded,
        ResourceNotFound,
        TagPolicy,
        TooManyTags,
    },
} = .{};
pub const list_certificates: struct {
    action_name: []const u8 = "ListCertificates",
    Request: type = struct {
        certificate_statuses: ?[][]const u8 = null,
        includes: ?struct {
            extended_key_usage: ?[][]const u8 = null,
            key_usage: ?[][]const u8 = null,
            key_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .extended_key_usage = "extendedKeyUsage",
                    .key_usage = "keyUsage",
                    .key_types = "keyTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_items: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_statuses = "CertificateStatuses",
                .includes = "Includes",
                .next_token = "NextToken",
                .max_items = "MaxItems",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_certificates) } {
            return .{ .service_metadata = service_metadata, .action = list_certificates };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        certificate_summary_list: ?[]struct {
            certificate_arn: ?[]const u8 = null,
            domain_name: ?[]const u8 = null,
            subject_alternative_name_summaries: ?[][]const u8 = null,
            has_additional_subject_alternative_names: ?bool = null,
            status: ?[]const u8 = null,
            type: ?[]const u8 = null,
            key_algorithm: ?[]const u8 = null,
            key_usages: ?[][]const u8 = null,
            extended_key_usages: ?[][]const u8 = null,
            in_use: ?bool = null,
            exported: ?bool = null,
            renewal_eligibility: ?[]const u8 = null,
            not_before: ?i64 = null,
            not_after: ?i64 = null,
            created_at: ?i64 = null,
            issued_at: ?i64 = null,
            imported_at: ?i64 = null,
            revoked_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_arn = "CertificateArn",
                    .domain_name = "DomainName",
                    .subject_alternative_name_summaries = "SubjectAlternativeNameSummaries",
                    .has_additional_subject_alternative_names = "HasAdditionalSubjectAlternativeNames",
                    .status = "Status",
                    .type = "Type",
                    .key_algorithm = "KeyAlgorithm",
                    .key_usages = "KeyUsages",
                    .extended_key_usages = "ExtendedKeyUsages",
                    .in_use = "InUse",
                    .exported = "Exported",
                    .renewal_eligibility = "RenewalEligibility",
                    .not_before = "NotBefore",
                    .not_after = "NotAfter",
                    .created_at = "CreatedAt",
                    .issued_at = "IssuedAt",
                    .imported_at = "ImportedAt",
                    .revoked_at = "RevokedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .certificate_summary_list = "CertificateSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgs,
        Validation,
    },
} = .{};
pub const list_tags_for_certificate: struct {
    action_name: []const u8 = "ListTagsForCertificate",
    Request: type = struct {
        certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_certificate) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_certificate };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        ResourceNotFound,
    },
} = .{};
pub const put_account_configuration: struct {
    action_name: []const u8 = "PutAccountConfiguration",
    Request: type = struct {
        expiry_events: ?ExpiryEventsConfiguration = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .expiry_events = "ExpiryEvents",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_account_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        Throttling,
        Validation,
    },
} = .{};
pub const remove_tags_from_certificate: struct {
    action_name: []const u8 = "RemoveTagsFromCertificate",
    Request: type = struct {
        certificate_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_certificate) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidParameter,
        InvalidTag,
        ResourceNotFound,
        TagPolicy,
        Throttling,
    },
} = .{};
pub const renew_certificate: struct {
    action_name: []const u8 = "RenewCertificate",
    Request: type = struct {
        certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(renew_certificate) } {
            return .{ .service_metadata = service_metadata, .action = renew_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        ResourceNotFound,
    },
} = .{};
pub const request_certificate: struct {
    action_name: []const u8 = "RequestCertificate",
    Request: type = struct {
        domain_name: []const u8,
        validation_method: ?[]const u8 = null,
        subject_alternative_names: ?[][]const u8 = null,
        idempotency_token: ?[]const u8 = null,
        domain_validation_options: ?[]struct {
            domain_name: []const u8,
            validation_domain: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .validation_domain = "ValidationDomain",
                };
                return @field(mappings, field_name);
            }
        } = null,
        options: ?CertificateOptions = null,
        certificate_authority_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        key_algorithm: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .validation_method = "ValidationMethod",
                .subject_alternative_names = "SubjectAlternativeNames",
                .idempotency_token = "IdempotencyToken",
                .domain_validation_options = "DomainValidationOptions",
                .options = "Options",
                .certificate_authority_arn = "CertificateAuthorityArn",
                .tags = "Tags",
                .key_algorithm = "KeyAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(request_certificate) } {
            return .{ .service_metadata = service_metadata, .action = request_certificate };
        }
    },
    Response: type = struct {
        certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidDomainValidationOptions,
        InvalidParameter,
        InvalidTag,
        LimitExceeded,
        TagPolicy,
        TooManyTags,
    },
} = .{};
pub const resend_validation_email: struct {
    action_name: []const u8 = "ResendValidationEmail",
    Request: type = struct {
        certificate_arn: []const u8,
        domain: []const u8,
        validation_domain: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .domain = "Domain",
                .validation_domain = "ValidationDomain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resend_validation_email) } {
            return .{ .service_metadata = service_metadata, .action = resend_validation_email };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidDomainValidationOptions,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const update_certificate_options: struct {
    action_name: []const u8 = "UpdateCertificateOptions",
    Request: type = struct {
        certificate_arn: []const u8,
        options: CertificateOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_certificate_options) } {
            return .{ .service_metadata = service_metadata, .action = update_certificate_options };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};

pub const CertificateOptions = struct {
    certificate_transparency_logging_preference: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_transparency_logging_preference = "CertificateTransparencyLoggingPreference",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpiryEventsConfiguration = struct {
    days_before_expiry: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days_before_expiry = "DaysBeforeExpiry",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainValidation = struct {
    domain_name: []const u8,
    validation_emails: ?[][]const u8 = null,
    validation_domain: ?[]const u8 = null,
    validation_status: ?[]const u8 = null,
    resource_record: ?ResourceRecord = null,
    validation_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .validation_emails = "ValidationEmails",
            .validation_domain = "ValidationDomain",
            .validation_status = "ValidationStatus",
            .resource_record = "ResourceRecord",
            .validation_method = "ValidationMethod",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceRecord = struct {
    name: []const u8,
    type: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
