const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-08-22";
pub const sdk_id: []const u8 = "ACM PCA";
pub const arn_namespace: ?[]const u8 = "acm-pca";
pub const endpoint_prefix: []const u8 = "acm-pca";
pub const sigv4_name: []const u8 = "acm-pca";
pub const name: []const u8 = "ACMPrivateCA";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-08-22",
    sdk_id: []const u8 = "ACM PCA",
    arn_namespace: ?[]const u8 = "acm-pca",
    endpoint_prefix: []const u8 = "acm-pca",
    sigv4_name: []const u8 = "acm-pca",
    name: []const u8 = "ACMPrivateCA",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_certificate_authority: struct {
    action_name: []const u8 = "CreateCertificateAuthority",
    Request: type = struct {
        certificate_authority_configuration: CertificateAuthorityConfiguration,
        revocation_configuration: ?RevocationConfiguration = null,
        certificate_authority_type: []const u8,
        idempotency_token: ?[]const u8 = null,
        key_storage_security_standard: ?[]const u8 = null,
        tags: ?[]Tag = null,
        usage_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_configuration = "CertificateAuthorityConfiguration",
                .revocation_configuration = "RevocationConfiguration",
                .certificate_authority_type = "CertificateAuthorityType",
                .idempotency_token = "IdempotencyToken",
                .key_storage_security_standard = "KeyStorageSecurityStandard",
                .tags = "Tags",
                .usage_mode = "UsageMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = create_certificate_authority };
        }
    },
    Response: type = struct {
        certificate_authority_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgs,
        InvalidPolicy,
        InvalidTag,
        LimitExceeded,
    },
} = .{};
pub const create_certificate_authority_audit_report: struct {
    action_name: []const u8 = "CreateCertificateAuthorityAuditReport",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        s3_bucket_name: []const u8,
        audit_report_response_format: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .s3_bucket_name = "S3BucketName",
                .audit_report_response_format = "AuditReportResponseFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_certificate_authority_audit_report) } {
            return .{ .service_metadata = service_metadata, .action = create_certificate_authority_audit_report };
        }
    },
    Response: type = struct {
        audit_report_id: ?[]const u8 = null,
        s3_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .audit_report_id = "AuditReportId",
                .s3_key = "S3Key",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgs,
        InvalidArn,
        InvalidState,
        RequestFailed,
        RequestInProgress,
        ResourceNotFound,
    },
} = .{};
pub const create_permission: struct {
    action_name: []const u8 = "CreatePermission",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        principal: []const u8,
        source_account: ?[]const u8 = null,
        actions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .principal = "Principal",
                .source_account = "SourceAccount",
                .actions = "Actions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_permission) } {
            return .{ .service_metadata = service_metadata, .action = create_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        LimitExceeded,
        PermissionAlreadyExists,
        RequestFailed,
        ResourceNotFound,
    },
} = .{};
pub const delete_certificate_authority: struct {
    action_name: []const u8 = "DeleteCertificateAuthority",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        permanent_deletion_time_in_days: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .permanent_deletion_time_in_days = "PermanentDeletionTimeInDays",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = delete_certificate_authority };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        InvalidArn,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const delete_permission: struct {
    action_name: []const u8 = "DeletePermission",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        principal: []const u8,
        source_account: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .principal = "Principal",
                .source_account = "SourceAccount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        RequestFailed,
        ResourceNotFound,
    },
} = .{};
pub const delete_policy: struct {
    action_name: []const u8 = "DeletePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        InvalidArn,
        InvalidState,
        LockoutPrevented,
        RequestFailed,
        ResourceNotFound,
    },
} = .{};
pub const describe_certificate_authority: struct {
    action_name: []const u8 = "DescribeCertificateAuthority",
    Request: type = struct {
        certificate_authority_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificate_authority };
        }
    },
    Response: type = struct {
        certificate_authority: ?CertificateAuthority = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority = "CertificateAuthority",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        ResourceNotFound,
    },
} = .{};
pub const describe_certificate_authority_audit_report: struct {
    action_name: []const u8 = "DescribeCertificateAuthorityAuditReport",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        audit_report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .audit_report_id = "AuditReportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificate_authority_audit_report) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificate_authority_audit_report };
        }
    },
    Response: type = struct {
        audit_report_status: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,
        s3_key: ?[]const u8 = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .audit_report_status = "AuditReportStatus",
                .s3_bucket_name = "S3BucketName",
                .s3_key = "S3Key",
                .created_at = "CreatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgs,
        InvalidArn,
        ResourceNotFound,
    },
} = .{};
pub const get_certificate: struct {
    action_name: []const u8 = "GetCertificate",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_certificate) } {
            return .{ .service_metadata = service_metadata, .action = get_certificate };
        }
    },
    Response: type = struct {
        certificate: ?[]const u8 = null,
        certificate_chain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .certificate_chain = "CertificateChain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        RequestFailed,
        RequestInProgress,
        ResourceNotFound,
    },
} = .{};
pub const get_certificate_authority_certificate: struct {
    action_name: []const u8 = "GetCertificateAuthorityCertificate",
    Request: type = struct {
        certificate_authority_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_certificate_authority_certificate) } {
            return .{ .service_metadata = service_metadata, .action = get_certificate_authority_certificate };
        }
    },
    Response: type = struct {
        certificate: ?[]const u8 = null,
        certificate_chain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .certificate_chain = "CertificateChain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const get_certificate_authority_csr: struct {
    action_name: []const u8 = "GetCertificateAuthorityCsr",
    Request: type = struct {
        certificate_authority_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_certificate_authority_csr) } {
            return .{ .service_metadata = service_metadata, .action = get_certificate_authority_csr };
        }
    },
    Response: type = struct {
        csr: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .csr = "Csr",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        RequestFailed,
        RequestInProgress,
        ResourceNotFound,
    },
} = .{};
pub const get_policy: struct {
    action_name: []const u8 = "GetPolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        RequestFailed,
        ResourceNotFound,
    },
} = .{};
pub const import_certificate_authority_certificate: struct {
    action_name: []const u8 = "ImportCertificateAuthorityCertificate",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        certificate: []const u8,
        certificate_chain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .certificate = "Certificate",
                .certificate_chain = "CertificateChain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_certificate_authority_certificate) } {
            return .{ .service_metadata = service_metadata, .action = import_certificate_authority_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CertificateMismatch,
        ConcurrentModification,
        InvalidArn,
        InvalidRequest,
        InvalidState,
        MalformedCertificate,
        RequestFailed,
        RequestInProgress,
        ResourceNotFound,
    },
} = .{};
pub const issue_certificate: struct {
    action_name: []const u8 = "IssueCertificate",
    Request: type = struct {
        api_passthrough: ?struct {
            extensions: ?struct {
                certificate_policies: ?[]struct {
                    cert_policy_id: []const u8,
                    policy_qualifiers: ?[]struct {
                        policy_qualifier_id: []const u8,
                        qualifier: struct {
                            cps_uri: []const u8,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .cps_uri = "CpsUri",
                                };
                                return @field(mappings, field_name);
                            }
                        },

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .policy_qualifier_id = "PolicyQualifierId",
                                .qualifier = "Qualifier",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cert_policy_id = "CertPolicyId",
                            .policy_qualifiers = "PolicyQualifiers",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                extended_key_usage: ?[]struct {
                    extended_key_usage_type: ?[]const u8 = null,
                    extended_key_usage_object_identifier: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .extended_key_usage_type = "ExtendedKeyUsageType",
                            .extended_key_usage_object_identifier = "ExtendedKeyUsageObjectIdentifier",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                key_usage: ?KeyUsage = null,
                subject_alternative_names: ?[]GeneralName = null,
                custom_extensions: ?[]struct {
                    object_identifier: []const u8,
                    value: []const u8,
                    critical: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .object_identifier = "ObjectIdentifier",
                            .value = "Value",
                            .critical = "Critical",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .certificate_policies = "CertificatePolicies",
                        .extended_key_usage = "ExtendedKeyUsage",
                        .key_usage = "KeyUsage",
                        .subject_alternative_names = "SubjectAlternativeNames",
                        .custom_extensions = "CustomExtensions",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            subject: ?ASN1Subject = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .extensions = "Extensions",
                    .subject = "Subject",
                };
                return @field(mappings, field_name);
            }
        } = null,
        certificate_authority_arn: []const u8,
        csr: []const u8,
        signing_algorithm: []const u8,
        template_arn: ?[]const u8 = null,
        validity: Validity,
        validity_not_before: ?Validity = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_passthrough = "ApiPassthrough",
                .certificate_authority_arn = "CertificateAuthorityArn",
                .csr = "Csr",
                .signing_algorithm = "SigningAlgorithm",
                .template_arn = "TemplateArn",
                .validity = "Validity",
                .validity_not_before = "ValidityNotBefore",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(issue_certificate) } {
            return .{ .service_metadata = service_metadata, .action = issue_certificate };
        }
    },
    Response: type = struct {
        certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgs,
        InvalidArn,
        InvalidState,
        LimitExceeded,
        MalformedCSR,
        ResourceNotFound,
    },
} = .{};
pub const list_certificate_authorities: struct {
    action_name: []const u8 = "ListCertificateAuthorities",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_owner: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .resource_owner = "ResourceOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_certificate_authorities) } {
            return .{ .service_metadata = service_metadata, .action = list_certificate_authorities };
        }
    },
    Response: type = struct {
        certificate_authorities: ?[]CertificateAuthority = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authorities = "CertificateAuthorities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
    },
} = .{};
pub const list_permissions: struct {
    action_name: []const u8 = "ListPermissions",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_permissions };
        }
    },
    Response: type = struct {
        permissions: ?[]struct {
            certificate_authority_arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            principal: ?[]const u8 = null,
            source_account: ?[]const u8 = null,
            actions: ?[][]const u8 = null,
            policy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_authority_arn = "CertificateAuthorityArn",
                    .created_at = "CreatedAt",
                    .principal = "Principal",
                    .source_account = "SourceAccount",
                    .actions = "Actions",
                    .policy = "Policy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "Permissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidNextToken,
        InvalidState,
        RequestFailed,
        ResourceNotFound,
    },
} = .{};
pub const list_tags: struct {
    action_name: []const u8 = "ListTags",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const put_policy: struct {
    action_name: []const u8 = "PutPolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        InvalidArn,
        InvalidPolicy,
        InvalidState,
        LockoutPrevented,
        RequestFailed,
        ResourceNotFound,
    },
} = .{};
pub const restore_certificate_authority: struct {
    action_name: []const u8 = "RestoreCertificateAuthority",
    Request: type = struct {
        certificate_authority_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = restore_certificate_authority };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const revoke_certificate: struct {
    action_name: []const u8 = "RevokeCertificate",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        certificate_serial: []const u8,
        revocation_reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .certificate_serial = "CertificateSerial",
                .revocation_reason = "RevocationReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_certificate) } {
            return .{ .service_metadata = service_metadata, .action = revoke_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        InvalidArn,
        InvalidRequest,
        InvalidState,
        LimitExceeded,
        RequestAlreadyProcessed,
        RequestFailed,
        RequestInProgress,
        ResourceNotFound,
    },
} = .{};
pub const tag_certificate_authority: struct {
    action_name: []const u8 = "TagCertificateAuthority",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = tag_certificate_authority };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        InvalidTag,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const untag_certificate_authority: struct {
    action_name: []const u8 = "UntagCertificateAuthority",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = untag_certificate_authority };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        InvalidState,
        InvalidTag,
        ResourceNotFound,
    },
} = .{};
pub const update_certificate_authority: struct {
    action_name: []const u8 = "UpdateCertificateAuthority",
    Request: type = struct {
        certificate_authority_arn: []const u8,
        revocation_configuration: ?RevocationConfiguration = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_arn = "CertificateAuthorityArn",
                .revocation_configuration = "RevocationConfiguration",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = update_certificate_authority };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        InvalidArgs,
        InvalidArn,
        InvalidPolicy,
        InvalidState,
        ResourceNotFound,
    },
} = .{};

pub const RevocationConfiguration = struct {
    crl_configuration: ?CrlConfiguration = null,
    ocsp_configuration: ?OcspConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crl_configuration = "CrlConfiguration",
            .ocsp_configuration = "OcspConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const OcspConfiguration = struct {
    enabled: bool,
    ocsp_custom_cname: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .ocsp_custom_cname = "OcspCustomCname",
        };
        return @field(mappings, field_name);
    }
};

pub const CrlConfiguration = struct {
    enabled: bool,
    expiration_in_days: ?i64 = null,
    custom_cname: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_object_acl: ?[]const u8 = null,
    crl_distribution_point_extension_configuration: ?CrlDistributionPointExtensionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .expiration_in_days = "ExpirationInDays",
            .custom_cname = "CustomCname",
            .s3_bucket_name = "S3BucketName",
            .s3_object_acl = "S3ObjectAcl",
            .crl_distribution_point_extension_configuration = "CrlDistributionPointExtensionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CrlDistributionPointExtensionConfiguration = struct {
    omit_extension: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .omit_extension = "OmitExtension",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateAuthority = struct {
    arn: ?[]const u8 = null,
    owner_account: ?[]const u8 = null,
    created_at: ?i64 = null,
    last_state_change_at: ?i64 = null,
    type: ?[]const u8 = null,
    serial: ?[]const u8 = null,
    status: ?[]const u8 = null,
    not_before: ?i64 = null,
    not_after: ?i64 = null,
    failure_reason: ?[]const u8 = null,
    certificate_authority_configuration: ?CertificateAuthorityConfiguration = null,
    revocation_configuration: ?RevocationConfiguration = null,
    restorable_until: ?i64 = null,
    key_storage_security_standard: ?[]const u8 = null,
    usage_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .owner_account = "OwnerAccount",
            .created_at = "CreatedAt",
            .last_state_change_at = "LastStateChangeAt",
            .type = "Type",
            .serial = "Serial",
            .status = "Status",
            .not_before = "NotBefore",
            .not_after = "NotAfter",
            .failure_reason = "FailureReason",
            .certificate_authority_configuration = "CertificateAuthorityConfiguration",
            .revocation_configuration = "RevocationConfiguration",
            .restorable_until = "RestorableUntil",
            .key_storage_security_standard = "KeyStorageSecurityStandard",
            .usage_mode = "UsageMode",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateAuthorityConfiguration = struct {
    key_algorithm: []const u8,
    signing_algorithm: []const u8,
    subject: ASN1Subject,
    csr_extensions: ?CsrExtensions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_algorithm = "KeyAlgorithm",
            .signing_algorithm = "SigningAlgorithm",
            .subject = "Subject",
            .csr_extensions = "CsrExtensions",
        };
        return @field(mappings, field_name);
    }
};

pub const CsrExtensions = struct {
    key_usage: ?KeyUsage = null,
    subject_information_access: ?[]AccessDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_usage = "KeyUsage",
            .subject_information_access = "SubjectInformationAccess",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessDescription = struct {
    access_method: AccessMethod,
    access_location: GeneralName,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_method = "AccessMethod",
            .access_location = "AccessLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const GeneralName = struct {
    other_name: ?OtherName = null,
    rfc822_name: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    directory_name: ?ASN1Subject = null,
    edi_party_name: ?EdiPartyName = null,
    uniform_resource_identifier: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    registered_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .other_name = "OtherName",
            .rfc822_name = "Rfc822Name",
            .dns_name = "DnsName",
            .directory_name = "DirectoryName",
            .edi_party_name = "EdiPartyName",
            .uniform_resource_identifier = "UniformResourceIdentifier",
            .ip_address = "IpAddress",
            .registered_id = "RegisteredId",
        };
        return @field(mappings, field_name);
    }
};

pub const EdiPartyName = struct {
    party_name: []const u8,
    name_assigner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .party_name = "PartyName",
            .name_assigner = "NameAssigner",
        };
        return @field(mappings, field_name);
    }
};

pub const ASN1Subject = struct {
    country: ?[]const u8 = null,
    organization: ?[]const u8 = null,
    organizational_unit: ?[]const u8 = null,
    distinguished_name_qualifier: ?[]const u8 = null,
    state: ?[]const u8 = null,
    common_name: ?[]const u8 = null,
    serial_number: ?[]const u8 = null,
    locality: ?[]const u8 = null,
    title: ?[]const u8 = null,
    surname: ?[]const u8 = null,
    given_name: ?[]const u8 = null,
    initials: ?[]const u8 = null,
    pseudonym: ?[]const u8 = null,
    generation_qualifier: ?[]const u8 = null,
    custom_attributes: ?[]CustomAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country = "Country",
            .organization = "Organization",
            .organizational_unit = "OrganizationalUnit",
            .distinguished_name_qualifier = "DistinguishedNameQualifier",
            .state = "State",
            .common_name = "CommonName",
            .serial_number = "SerialNumber",
            .locality = "Locality",
            .title = "Title",
            .surname = "Surname",
            .given_name = "GivenName",
            .initials = "Initials",
            .pseudonym = "Pseudonym",
            .generation_qualifier = "GenerationQualifier",
            .custom_attributes = "CustomAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomAttribute = struct {
    object_identifier: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_identifier = "ObjectIdentifier",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const OtherName = struct {
    type_id: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type_id = "TypeId",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessMethod = struct {
    custom_object_identifier: ?[]const u8 = null,
    access_method_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_object_identifier = "CustomObjectIdentifier",
            .access_method_type = "AccessMethodType",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyUsage = struct {
    digital_signature: ?bool = null,
    non_repudiation: ?bool = null,
    key_encipherment: ?bool = null,
    data_encipherment: ?bool = null,
    key_agreement: ?bool = null,
    key_cert_sign: ?bool = null,
    crl_sign: ?bool = null,
    encipher_only: ?bool = null,
    decipher_only: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .digital_signature = "DigitalSignature",
            .non_repudiation = "NonRepudiation",
            .key_encipherment = "KeyEncipherment",
            .data_encipherment = "DataEncipherment",
            .key_agreement = "KeyAgreement",
            .key_cert_sign = "KeyCertSign",
            .crl_sign = "CRLSign",
            .encipher_only = "EncipherOnly",
            .decipher_only = "DecipherOnly",
        };
        return @field(mappings, field_name);
    }
};

pub const Validity = struct {
    value: i64,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};
