const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "Amplify";
pub const arn_namespace: ?[]const u8 = "amplify";
pub const endpoint_prefix: []const u8 = "amplify";
pub const sigv4_name: []const u8 = "amplify";
pub const name: []const u8 = "Amplify";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "Amplify",
    arn_namespace: ?[]const u8 = "amplify",
    endpoint_prefix: []const u8 = "amplify",
    sigv4_name: []const u8 = "amplify",
    name: []const u8 = "Amplify",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_app: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateApp",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        repository: ?[]const u8 = null,
        platform: ?[]const u8 = null,
        iam_service_role_arn: ?[]const u8 = null,
        oauth_token: ?[]const u8 = null,
        access_token: ?[]const u8 = null,
        environment_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        enable_branch_auto_build: ?bool = null,
        enable_branch_auto_deletion: ?bool = null,
        enable_basic_auth: ?bool = null,
        basic_auth_credentials: ?[]const u8 = null,
        custom_rules: ?[]CustomRule = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        build_spec: ?[]const u8 = null,
        custom_headers: ?[]const u8 = null,
        enable_auto_branch_creation: ?bool = null,
        auto_branch_creation_patterns: ?[][]const u8 = null,
        auto_branch_creation_config: ?AutoBranchCreationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .repository = "repository",
                .platform = "platform",
                .iam_service_role_arn = "iamServiceRoleArn",
                .oauth_token = "oauthToken",
                .access_token = "accessToken",
                .environment_variables = "environmentVariables",
                .enable_branch_auto_build = "enableBranchAutoBuild",
                .enable_branch_auto_deletion = "enableBranchAutoDeletion",
                .enable_basic_auth = "enableBasicAuth",
                .basic_auth_credentials = "basicAuthCredentials",
                .custom_rules = "customRules",
                .tags = "tags",
                .build_spec = "buildSpec",
                .custom_headers = "customHeaders",
                .enable_auto_branch_creation = "enableAutoBranchCreation",
                .auto_branch_creation_patterns = "autoBranchCreationPatterns",
                .auto_branch_creation_config = "autoBranchCreationConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment_variables", field_name))
                return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app) } {
            return .{ .service_metadata = service_metadata, .action = create_app };
        }
    },
    Response: type = struct {
        app: App,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app = "app",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const create_backend_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/backendenvironments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackendEnvironment",
    Request: type = struct {
        app_id: []const u8,
        environment_name: []const u8,
        stack_name: ?[]const u8 = null,
        deployment_artifacts: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .environment_name = "environmentName",
                .stack_name = "stackName",
                .deployment_artifacts = "deploymentArtifacts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backend_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_backend_environment };
        }
    },
    Response: type = struct {
        backend_environment: BackendEnvironment,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backend_environment = "backendEnvironment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_branch: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/branches",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBranch",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        description: ?[]const u8 = null,
        stage: ?[]const u8 = null,
        framework: ?[]const u8 = null,
        enable_notification: ?bool = null,
        enable_auto_build: ?bool = null,
        environment_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        basic_auth_credentials: ?[]const u8 = null,
        enable_basic_auth: ?bool = null,
        enable_performance_mode: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        build_spec: ?[]const u8 = null,
        ttl: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        enable_pull_request_preview: ?bool = null,
        pull_request_environment_name: ?[]const u8 = null,
        backend_environment_arn: ?[]const u8 = null,
        backend: ?Backend = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .description = "description",
                .stage = "stage",
                .framework = "framework",
                .enable_notification = "enableNotification",
                .enable_auto_build = "enableAutoBuild",
                .environment_variables = "environmentVariables",
                .basic_auth_credentials = "basicAuthCredentials",
                .enable_basic_auth = "enableBasicAuth",
                .enable_performance_mode = "enablePerformanceMode",
                .tags = "tags",
                .build_spec = "buildSpec",
                .ttl = "ttl",
                .display_name = "displayName",
                .enable_pull_request_preview = "enablePullRequestPreview",
                .pull_request_environment_name = "pullRequestEnvironmentName",
                .backend_environment_arn = "backendEnvironmentArn",
                .backend = "backend",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment_variables", field_name))
                return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_branch) } {
            return .{ .service_metadata = service_metadata, .action = create_branch };
        }
    },
    Response: type = struct {
        branch: Branch,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch = "branch",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/branches/{branchName}/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDeployment",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        file_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .file_map = "fileMap",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "file_map", field_name))
                return try serializeMap(self.file_map, self.fieldNameFor("file_map"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deployment) } {
            return .{ .service_metadata = service_metadata, .action = create_deployment };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        file_upload_urls: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        zip_upload_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .file_upload_urls = "fileUploadUrls",
                .zip_upload_url = "zipUploadUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "file_upload_urls", field_name))
                return try serializeMap(self.file_upload_urls, self.fieldNameFor("file_upload_urls"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const create_domain_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/domains",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDomainAssociation",
    Request: type = struct {
        app_id: []const u8,
        domain_name: []const u8,
        enable_auto_sub_domain: ?bool = null,
        sub_domain_settings: []SubDomainSetting,
        auto_sub_domain_creation_patterns: ?[][]const u8 = null,
        auto_sub_domain_iam_role: ?[]const u8 = null,
        certificate_settings: ?CertificateSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .domain_name = "domainName",
                .enable_auto_sub_domain = "enableAutoSubDomain",
                .sub_domain_settings = "subDomainSettings",
                .auto_sub_domain_creation_patterns = "autoSubDomainCreationPatterns",
                .auto_sub_domain_iam_role = "autoSubDomainIAMRole",
                .certificate_settings = "certificateSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = create_domain_association };
        }
    },
    Response: type = struct {
        domain_association: DomainAssociation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_association = "domainAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_webhook: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/webhooks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWebhook",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_webhook) } {
            return .{ .service_metadata = service_metadata, .action = create_webhook };
        }
    },
    Response: type = struct {
        webhook: Webhook,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook = "webhook",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_app: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/apps/{appId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApp",
    Request: type = struct {
        app_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app) } {
            return .{ .service_metadata = service_metadata, .action = delete_app };
        }
    },
    Response: type = struct {
        app: App,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app = "app",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_backend_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/apps/{appId}/backendenvironments/{environmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackendEnvironment",
    Request: type = struct {
        app_id: []const u8,
        environment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .environment_name = "environmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backend_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_backend_environment };
        }
    },
    Response: type = struct {
        backend_environment: BackendEnvironment,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backend_environment = "backendEnvironment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_branch: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/apps/{appId}/branches/{branchName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBranch",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_branch) } {
            return .{ .service_metadata = service_metadata, .action = delete_branch };
        }
    },
    Response: type = struct {
        branch: Branch,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch = "branch",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_domain_association: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/apps/{appId}/domains/{domainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDomainAssociation",
    Request: type = struct {
        app_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .domain_name = "domainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain_association };
        }
    },
    Response: type = struct {
        domain_association: DomainAssociation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_association = "domainAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/apps/{appId}/branches/{branchName}/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJob",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_job };
        }
    },
    Response: type = struct {
        job_summary: JobSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summary = "jobSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_webhook: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/webhooks/{webhookId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWebhook",
    Request: type = struct {
        webhook_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook_id = "webhookId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_webhook) } {
            return .{ .service_metadata = service_metadata, .action = delete_webhook };
        }
    },
    Response: type = struct {
        webhook: Webhook,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook = "webhook",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const generate_access_logs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/accesslogs",
        .success_code = 200,
    };

    action_name: []const u8 = "GenerateAccessLogs",
    Request: type = struct {
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        domain_name: []const u8,
        app_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "startTime",
                .end_time = "endTime",
                .domain_name = "domainName",
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_access_logs) } {
            return .{ .service_metadata = service_metadata, .action = generate_access_logs };
        }
    },
    Response: type = struct {
        log_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_url = "logUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_app: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApp",
    Request: type = struct {
        app_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app) } {
            return .{ .service_metadata = service_metadata, .action = get_app };
        }
    },
    Response: type = struct {
        app: App,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app = "app",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_artifact_url: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/artifacts/{artifactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetArtifactUrl",
    Request: type = struct {
        artifact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_id = "artifactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_artifact_url) } {
            return .{ .service_metadata = service_metadata, .action = get_artifact_url };
        }
    },
    Response: type = struct {
        artifact_id: []const u8,
        artifact_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_id = "artifactId",
                .artifact_url = "artifactUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_backend_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/backendenvironments/{environmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackendEnvironment",
    Request: type = struct {
        app_id: []const u8,
        environment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .environment_name = "environmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backend_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_backend_environment };
        }
    },
    Response: type = struct {
        backend_environment: BackendEnvironment,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backend_environment = "backendEnvironment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_branch: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/branches/{branchName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBranch",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_branch) } {
            return .{ .service_metadata = service_metadata, .action = get_branch };
        }
    },
    Response: type = struct {
        branch: Branch,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch = "branch",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_domain_association: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/domains/{domainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainAssociation",
    Request: type = struct {
        app_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .domain_name = "domainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_association };
        }
    },
    Response: type = struct {
        domain_association: DomainAssociation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_association = "domainAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/branches/{branchName}/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJob",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job) } {
            return .{ .service_metadata = service_metadata, .action = get_job };
        }
    },
    Response: type = struct {
        job: struct {
            summary: JobSummary,
            steps: []struct {
                step_name: []const u8,
                start_time: i64,
                status: []const u8,
                end_time: i64,
                log_url: ?[]const u8 = null,
                artifacts_url: ?[]const u8 = null,
                test_artifacts_url: ?[]const u8 = null,
                test_config_url: ?[]const u8 = null,
                screenshots: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                status_reason: ?[]const u8 = null,
                context: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .step_name = "stepName",
                        .start_time = "startTime",
                        .status = "status",
                        .end_time = "endTime",
                        .log_url = "logUrl",
                        .artifacts_url = "artifactsUrl",
                        .test_artifacts_url = "testArtifactsUrl",
                        .test_config_url = "testConfigUrl",
                        .screenshots = "screenshots",
                        .status_reason = "statusReason",
                        .context = "context",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "screenshots", field_name))
                        return try serializeMap(self.screenshots, self.fieldNameFor("screenshots"), options, out_stream);
                    return false;
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .summary = "summary",
                    .steps = "steps",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_webhook: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/webhooks/{webhookId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWebhook",
    Request: type = struct {
        webhook_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook_id = "webhookId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_webhook) } {
            return .{ .service_metadata = service_metadata, .action = get_webhook };
        }
    },
    Response: type = struct {
        webhook: Webhook,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook = "webhook",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_apps: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApps",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_apps) } {
            return .{ .service_metadata = service_metadata, .action = list_apps };
        }
    },
    Response: type = struct {
        apps: []App,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apps = "apps",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        Unauthorized,
    },
} = .{};
pub const list_artifacts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/branches/{branchName}/jobs/{jobId}/artifacts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListArtifacts",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        job_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .job_id = "jobId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_artifacts) } {
            return .{ .service_metadata = service_metadata, .action = list_artifacts };
        }
    },
    Response: type = struct {
        artifacts: []struct {
            artifact_file_name: []const u8,
            artifact_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .artifact_file_name = "artifactFileName",
                    .artifact_id = "artifactId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifacts = "artifacts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const list_backend_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/backendenvironments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackendEnvironments",
    Request: type = struct {
        app_id: []const u8,
        environment_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .environment_name = "environmentName",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .environment_name = "environmentName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backend_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_backend_environments };
        }
    },
    Response: type = struct {
        backend_environments: []BackendEnvironment,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backend_environments = "backendEnvironments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        Unauthorized,
    },
} = .{};
pub const list_branches: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/branches",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBranches",
    Request: type = struct {
        app_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_branches) } {
            return .{ .service_metadata = service_metadata, .action = list_branches };
        }
    },
    Response: type = struct {
        branches: []Branch,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branches = "branches",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        Unauthorized,
    },
} = .{};
pub const list_domain_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/domains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainAssociations",
    Request: type = struct {
        app_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domain_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_domain_associations };
        }
    },
    Response: type = struct {
        domain_associations: []DomainAssociation,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_associations = "domainAssociations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        Unauthorized,
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/branches/{branchName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        job_summaries: []JobSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summaries = "jobSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        ResourceNotFound,
    },
} = .{};
pub const list_webhooks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apps/{appId}/webhooks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWebhooks",
    Request: type = struct {
        app_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_webhooks) } {
            return .{ .service_metadata = service_metadata, .action = list_webhooks };
        }
    },
    Response: type = struct {
        webhooks: []Webhook,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhooks = "webhooks",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const start_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/branches/{branchName}/deployments/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDeployment",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        job_id: ?[]const u8 = null,
        source_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .job_id = "jobId",
                .source_url = "sourceUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_deployment) } {
            return .{ .service_metadata = service_metadata, .action = start_deployment };
        }
    },
    Response: type = struct {
        job_summary: JobSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summary = "jobSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const start_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/branches/{branchName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartJob",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        job_id: ?[]const u8 = null,
        job_type: []const u8,
        job_reason: ?[]const u8 = null,
        commit_id: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,
        commit_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .job_id = "jobId",
                .job_type = "jobType",
                .job_reason = "jobReason",
                .commit_id = "commitId",
                .commit_message = "commitMessage",
                .commit_time = "commitTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_job) } {
            return .{ .service_metadata = service_metadata, .action = start_job };
        }
    },
    Response: type = struct {
        job_summary: JobSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summary = "jobSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const stop_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/apps/{appId}/branches/{branchName}/jobs/{jobId}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopJob",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_job };
        }
    },
    Response: type = struct {
        job_summary: JobSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summary = "jobSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        ResourceNotFound,
    },
} = .{};
pub const update_app: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApp",
    Request: type = struct {
        app_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        platform: ?[]const u8 = null,
        iam_service_role_arn: ?[]const u8 = null,
        environment_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        enable_branch_auto_build: ?bool = null,
        enable_branch_auto_deletion: ?bool = null,
        enable_basic_auth: ?bool = null,
        basic_auth_credentials: ?[]const u8 = null,
        custom_rules: ?[]CustomRule = null,
        build_spec: ?[]const u8 = null,
        custom_headers: ?[]const u8 = null,
        enable_auto_branch_creation: ?bool = null,
        auto_branch_creation_patterns: ?[][]const u8 = null,
        auto_branch_creation_config: ?AutoBranchCreationConfig = null,
        repository: ?[]const u8 = null,
        oauth_token: ?[]const u8 = null,
        access_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .name = "name",
                .description = "description",
                .platform = "platform",
                .iam_service_role_arn = "iamServiceRoleArn",
                .environment_variables = "environmentVariables",
                .enable_branch_auto_build = "enableBranchAutoBuild",
                .enable_branch_auto_deletion = "enableBranchAutoDeletion",
                .enable_basic_auth = "enableBasicAuth",
                .basic_auth_credentials = "basicAuthCredentials",
                .custom_rules = "customRules",
                .build_spec = "buildSpec",
                .custom_headers = "customHeaders",
                .enable_auto_branch_creation = "enableAutoBranchCreation",
                .auto_branch_creation_patterns = "autoBranchCreationPatterns",
                .auto_branch_creation_config = "autoBranchCreationConfig",
                .repository = "repository",
                .oauth_token = "oauthToken",
                .access_token = "accessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment_variables", field_name))
                return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app) } {
            return .{ .service_metadata = service_metadata, .action = update_app };
        }
    },
    Response: type = struct {
        app: App,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app = "app",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_branch: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/branches/{branchName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBranch",
    Request: type = struct {
        app_id: []const u8,
        branch_name: []const u8,
        description: ?[]const u8 = null,
        framework: ?[]const u8 = null,
        stage: ?[]const u8 = null,
        enable_notification: ?bool = null,
        enable_auto_build: ?bool = null,
        environment_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        basic_auth_credentials: ?[]const u8 = null,
        enable_basic_auth: ?bool = null,
        enable_performance_mode: ?bool = null,
        build_spec: ?[]const u8 = null,
        ttl: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        enable_pull_request_preview: ?bool = null,
        pull_request_environment_name: ?[]const u8 = null,
        backend_environment_arn: ?[]const u8 = null,
        backend: ?Backend = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .branch_name = "branchName",
                .description = "description",
                .framework = "framework",
                .stage = "stage",
                .enable_notification = "enableNotification",
                .enable_auto_build = "enableAutoBuild",
                .environment_variables = "environmentVariables",
                .basic_auth_credentials = "basicAuthCredentials",
                .enable_basic_auth = "enableBasicAuth",
                .enable_performance_mode = "enablePerformanceMode",
                .build_spec = "buildSpec",
                .ttl = "ttl",
                .display_name = "displayName",
                .enable_pull_request_preview = "enablePullRequestPreview",
                .pull_request_environment_name = "pullRequestEnvironmentName",
                .backend_environment_arn = "backendEnvironmentArn",
                .backend = "backend",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment_variables", field_name))
                return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_branch) } {
            return .{ .service_metadata = service_metadata, .action = update_branch };
        }
    },
    Response: type = struct {
        branch: Branch,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch = "branch",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_domain_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apps/{appId}/domains/{domainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDomainAssociation",
    Request: type = struct {
        app_id: []const u8,
        domain_name: []const u8,
        enable_auto_sub_domain: ?bool = null,
        sub_domain_settings: ?[]SubDomainSetting = null,
        auto_sub_domain_creation_patterns: ?[][]const u8 = null,
        auto_sub_domain_iam_role: ?[]const u8 = null,
        certificate_settings: ?CertificateSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .domain_name = "domainName",
                .enable_auto_sub_domain = "enableAutoSubDomain",
                .sub_domain_settings = "subDomainSettings",
                .auto_sub_domain_creation_patterns = "autoSubDomainCreationPatterns",
                .auto_sub_domain_iam_role = "autoSubDomainIAMRole",
                .certificate_settings = "certificateSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = update_domain_association };
        }
    },
    Response: type = struct {
        domain_association: DomainAssociation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_association = "domainAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_webhook: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/webhooks/{webhookId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWebhook",
    Request: type = struct {
        webhook_id: []const u8,
        branch_name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook_id = "webhookId",
                .branch_name = "branchName",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_webhook) } {
            return .{ .service_metadata = service_metadata, .action = update_webhook };
        }
    },
    Response: type = struct {
        webhook: Webhook,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook = "webhook",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DependentServiceFailure,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};

pub const Webhook = struct {
    webhook_arn: []const u8,
    webhook_id: []const u8,
    webhook_url: []const u8,
    branch_name: []const u8,
    description: []const u8,
    create_time: i64,
    update_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .webhook_arn = "webhookArn",
            .webhook_id = "webhookId",
            .webhook_url = "webhookUrl",
            .branch_name = "branchName",
            .description = "description",
            .create_time = "createTime",
            .update_time = "updateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainAssociation = struct {
    domain_association_arn: []const u8,
    domain_name: []const u8,
    enable_auto_sub_domain: bool,
    auto_sub_domain_creation_patterns: ?[][]const u8 = null,
    auto_sub_domain_iam_role: ?[]const u8 = null,
    domain_status: []const u8,
    update_status: ?[]const u8 = null,
    status_reason: []const u8,
    certificate_verification_dns_record: ?[]const u8 = null,
    sub_domains: []SubDomain,
    certificate: ?Certificate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_association_arn = "domainAssociationArn",
            .domain_name = "domainName",
            .enable_auto_sub_domain = "enableAutoSubDomain",
            .auto_sub_domain_creation_patterns = "autoSubDomainCreationPatterns",
            .auto_sub_domain_iam_role = "autoSubDomainIAMRole",
            .domain_status = "domainStatus",
            .update_status = "updateStatus",
            .status_reason = "statusReason",
            .certificate_verification_dns_record = "certificateVerificationDNSRecord",
            .sub_domains = "subDomains",
            .certificate = "certificate",
        };
        return @field(mappings, field_name);
    }
};

pub const Certificate = struct {
    type: []const u8,
    custom_certificate_arn: ?[]const u8 = null,
    certificate_verification_dns_record: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .custom_certificate_arn = "customCertificateArn",
            .certificate_verification_dns_record = "certificateVerificationDNSRecord",
        };
        return @field(mappings, field_name);
    }
};

pub const SubDomain = struct {
    sub_domain_setting: SubDomainSetting,
    verified: bool,
    dns_record: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sub_domain_setting = "subDomainSetting",
            .verified = "verified",
            .dns_record = "dnsRecord",
        };
        return @field(mappings, field_name);
    }
};

pub const SubDomainSetting = struct {
    prefix: []const u8,
    branch_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "prefix",
            .branch_name = "branchName",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateSettings = struct {
    type: []const u8,
    custom_certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .custom_certificate_arn = "customCertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Branch = struct {
    branch_arn: []const u8,
    branch_name: []const u8,
    description: []const u8,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    stage: []const u8,
    display_name: []const u8,
    enable_notification: bool,
    create_time: i64,
    update_time: i64,
    environment_variables: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    enable_auto_build: bool,
    custom_domains: [][]const u8,
    framework: []const u8,
    active_job_id: []const u8,
    total_number_of_jobs: []const u8,
    enable_basic_auth: bool,
    enable_performance_mode: ?bool = null,
    thumbnail_url: ?[]const u8 = null,
    basic_auth_credentials: ?[]const u8 = null,
    build_spec: ?[]const u8 = null,
    ttl: []const u8,
    associated_resources: ?[][]const u8 = null,
    enable_pull_request_preview: bool,
    pull_request_environment_name: ?[]const u8 = null,
    destination_branch: ?[]const u8 = null,
    source_branch: ?[]const u8 = null,
    backend_environment_arn: ?[]const u8 = null,
    backend: ?Backend = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .branch_arn = "branchArn",
            .branch_name = "branchName",
            .description = "description",
            .tags = "tags",
            .stage = "stage",
            .display_name = "displayName",
            .enable_notification = "enableNotification",
            .create_time = "createTime",
            .update_time = "updateTime",
            .environment_variables = "environmentVariables",
            .enable_auto_build = "enableAutoBuild",
            .custom_domains = "customDomains",
            .framework = "framework",
            .active_job_id = "activeJobId",
            .total_number_of_jobs = "totalNumberOfJobs",
            .enable_basic_auth = "enableBasicAuth",
            .enable_performance_mode = "enablePerformanceMode",
            .thumbnail_url = "thumbnailUrl",
            .basic_auth_credentials = "basicAuthCredentials",
            .build_spec = "buildSpec",
            .ttl = "ttl",
            .associated_resources = "associatedResources",
            .enable_pull_request_preview = "enablePullRequestPreview",
            .pull_request_environment_name = "pullRequestEnvironmentName",
            .destination_branch = "destinationBranch",
            .source_branch = "sourceBranch",
            .backend_environment_arn = "backendEnvironmentArn",
            .backend = "backend",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        if (std.mem.eql(u8, "environment_variables", field_name))
            return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
        return false;
    }
};

pub const Backend = struct {
    stack_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stack_arn = "stackArn",
        };
        return @field(mappings, field_name);
    }
};

pub const App = struct {
    app_id: []const u8,
    app_arn: []const u8,
    name: []const u8,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    description: []const u8,
    repository: []const u8,
    platform: []const u8,
    create_time: i64,
    update_time: i64,
    iam_service_role_arn: ?[]const u8 = null,
    environment_variables: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    default_domain: []const u8,
    enable_branch_auto_build: bool,
    enable_branch_auto_deletion: ?bool = null,
    enable_basic_auth: bool,
    basic_auth_credentials: ?[]const u8 = null,
    custom_rules: ?[]CustomRule = null,
    production_branch: ?ProductionBranch = null,
    build_spec: ?[]const u8 = null,
    custom_headers: ?[]const u8 = null,
    enable_auto_branch_creation: ?bool = null,
    auto_branch_creation_patterns: ?[][]const u8 = null,
    auto_branch_creation_config: ?AutoBranchCreationConfig = null,
    repository_clone_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_id = "appId",
            .app_arn = "appArn",
            .name = "name",
            .tags = "tags",
            .description = "description",
            .repository = "repository",
            .platform = "platform",
            .create_time = "createTime",
            .update_time = "updateTime",
            .iam_service_role_arn = "iamServiceRoleArn",
            .environment_variables = "environmentVariables",
            .default_domain = "defaultDomain",
            .enable_branch_auto_build = "enableBranchAutoBuild",
            .enable_branch_auto_deletion = "enableBranchAutoDeletion",
            .enable_basic_auth = "enableBasicAuth",
            .basic_auth_credentials = "basicAuthCredentials",
            .custom_rules = "customRules",
            .production_branch = "productionBranch",
            .build_spec = "buildSpec",
            .custom_headers = "customHeaders",
            .enable_auto_branch_creation = "enableAutoBranchCreation",
            .auto_branch_creation_patterns = "autoBranchCreationPatterns",
            .auto_branch_creation_config = "autoBranchCreationConfig",
            .repository_clone_method = "repositoryCloneMethod",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        if (std.mem.eql(u8, "environment_variables", field_name))
            return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
        return false;
    }
};

pub const AutoBranchCreationConfig = struct {
    stage: ?[]const u8 = null,
    framework: ?[]const u8 = null,
    enable_auto_build: ?bool = null,
    environment_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    basic_auth_credentials: ?[]const u8 = null,
    enable_basic_auth: ?bool = null,
    enable_performance_mode: ?bool = null,
    build_spec: ?[]const u8 = null,
    enable_pull_request_preview: ?bool = null,
    pull_request_environment_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stage = "stage",
            .framework = "framework",
            .enable_auto_build = "enableAutoBuild",
            .environment_variables = "environmentVariables",
            .basic_auth_credentials = "basicAuthCredentials",
            .enable_basic_auth = "enableBasicAuth",
            .enable_performance_mode = "enablePerformanceMode",
            .build_spec = "buildSpec",
            .enable_pull_request_preview = "enablePullRequestPreview",
            .pull_request_environment_name = "pullRequestEnvironmentName",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment_variables", field_name))
            return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
        return false;
    }
};

pub const ProductionBranch = struct {
    last_deploy_time: ?i64 = null,
    status: ?[]const u8 = null,
    thumbnail_url: ?[]const u8 = null,
    branch_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_deploy_time = "lastDeployTime",
            .status = "status",
            .thumbnail_url = "thumbnailUrl",
            .branch_name = "branchName",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRule = struct {
    source: []const u8,
    target: []const u8,
    status: ?[]const u8 = null,
    condition: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .target = "target",
            .status = "status",
            .condition = "condition",
        };
        return @field(mappings, field_name);
    }
};

pub const JobSummary = struct {
    job_arn: []const u8,
    job_id: []const u8,
    commit_id: []const u8,
    commit_message: []const u8,
    commit_time: i64,
    start_time: i64,
    status: []const u8,
    end_time: ?i64 = null,
    job_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_arn = "jobArn",
            .job_id = "jobId",
            .commit_id = "commitId",
            .commit_message = "commitMessage",
            .commit_time = "commitTime",
            .start_time = "startTime",
            .status = "status",
            .end_time = "endTime",
            .job_type = "jobType",
        };
        return @field(mappings, field_name);
    }
};

pub const BackendEnvironment = struct {
    backend_environment_arn: []const u8,
    environment_name: []const u8,
    stack_name: ?[]const u8 = null,
    deployment_artifacts: ?[]const u8 = null,
    create_time: i64,
    update_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backend_environment_arn = "backendEnvironmentArn",
            .environment_name = "environmentName",
            .stack_name = "stackName",
            .deployment_artifacts = "deploymentArtifacts",
            .create_time = "createTime",
            .update_time = "updateTime",
        };
        return @field(mappings, field_name);
    }
};
