const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-11";
pub const sdk_id: []const u8 = "AmplifyBackend";
pub const arn_namespace: ?[]const u8 = "amplifybackend";
pub const endpoint_prefix: []const u8 = "amplifybackend";
pub const sigv4_name: []const u8 = "amplifybackend";
pub const name: []const u8 = "AmplifyBackend";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-11",
    sdk_id: []const u8 = "AmplifyBackend",
    arn_namespace: ?[]const u8 = "amplifybackend",
    endpoint_prefix: []const u8 = "amplifybackend",
    sigv4_name: []const u8 = "amplifybackend",
    name: []const u8 = "AmplifyBackend",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const clone_backend: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/environments/{BackendEnvironmentName}/clone",
        .success_code = 200,
    };

    action_name: []const u8 = "CloneBackend",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        target_environment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .target_environment_name = "targetEnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(clone_backend) } {
            return .{ .service_metadata = service_metadata, .action = clone_backend };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_backend: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackend",
    Request: type = struct {
        app_id: []const u8,
        app_name: []const u8,
        backend_environment_name: []const u8,
        resource_config: ?struct {

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{};
                return @field(mappings, field_name);
            }
        } = null,
        resource_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .app_name = "appName",
                .backend_environment_name = "backendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backend) } {
            return .{ .service_metadata = service_metadata, .action = create_backend };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_backend_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/api",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackendAPI",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_config: BackendAPIResourceConfig,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "backendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backend_api) } {
            return .{ .service_metadata = service_metadata, .action = create_backend_api };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_backend_auth: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/auth",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackendAuth",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_config: CreateBackendAuthResourceConfig,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "backendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backend_auth) } {
            return .{ .service_metadata = service_metadata, .action = create_backend_auth };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_backend_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackendConfig",
    Request: type = struct {
        app_id: []const u8,
        backend_manager_app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_manager_app_id = "backendManagerAppId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backend_config) } {
            return .{ .service_metadata = service_metadata, .action = create_backend_config };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .job_id = "jobId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_backend_storage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/storage",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackendStorage",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_config: struct {
            bucket_name: ?[]const u8 = null,
            permissions: BackendStoragePermissions,
            service_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket_name = "bucketName",
                    .permissions = "permissions",
                    .service_name = "serviceName",
                };
                return @field(mappings, field_name);
            }
        },
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "backendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backend_storage) } {
            return .{ .service_metadata = service_metadata, .action = create_backend_storage };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .job_id = "jobId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/challenge",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateToken",
    Request: type = struct {
        app_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_token) } {
            return .{ .service_metadata = service_metadata, .action = create_token };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        challenge_code: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        ttl: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .challenge_code = "challengeCode",
                .session_id = "sessionId",
                .ttl = "ttl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_backend: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/environments/{BackendEnvironmentName}/remove",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackend",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backend) } {
            return .{ .service_metadata = service_metadata, .action = delete_backend };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_backend_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/api/{BackendEnvironmentName}/remove",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackendAPI",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_config: ?BackendAPIResourceConfig = null,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backend_api) } {
            return .{ .service_metadata = service_metadata, .action = delete_backend_api };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_backend_auth: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/auth/{BackendEnvironmentName}/remove",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackendAuth",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backend_auth) } {
            return .{ .service_metadata = service_metadata, .action = delete_backend_auth };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_backend_storage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/storage/{BackendEnvironmentName}/remove",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackendStorage",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_name: []const u8,
        service_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_name = "resourceName",
                .service_name = "serviceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backend_storage) } {
            return .{ .service_metadata = service_metadata, .action = delete_backend_storage };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .job_id = "jobId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/challenge/{SessionId}/remove",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteToken",
    Request: type = struct {
        app_id: []const u8,
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_token) } {
            return .{ .service_metadata = service_metadata, .action = delete_token };
        }
    },
    Response: type = struct {
        is_success: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_success = "isSuccess",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const generate_backend_api_models: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/api/{BackendEnvironmentName}/generateModels",
        .success_code = 200,
    };

    action_name: []const u8 = "GenerateBackendAPIModels",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_backend_api_models) } {
            return .{ .service_metadata = service_metadata, .action = generate_backend_api_models };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_backend: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/details",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackend",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "backendEnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backend) } {
            return .{ .service_metadata = service_metadata, .action = get_backend };
        }
    },
    Response: type = struct {
        amplify_feature_flags: ?[]const u8 = null,
        amplify_meta_config: ?[]const u8 = null,
        app_id: ?[]const u8 = null,
        app_name: ?[]const u8 = null,
        backend_environment_list: ?[][]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amplify_feature_flags = "amplifyFeatureFlags",
                .amplify_meta_config = "amplifyMetaConfig",
                .app_id = "appId",
                .app_name = "appName",
                .backend_environment_list = "backendEnvironmentList",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_backend_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/api/{BackendEnvironmentName}/details",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackendAPI",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_config: ?BackendAPIResourceConfig = null,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backend_api) } {
            return .{ .service_metadata = service_metadata, .action = get_backend_api };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        resource_config: ?BackendAPIResourceConfig = null,
        resource_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_backend_api_models: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/api/{BackendEnvironmentName}/getModels",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackendAPIModels",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backend_api_models) } {
            return .{ .service_metadata = service_metadata, .action = get_backend_api_models };
        }
    },
    Response: type = struct {
        models: ?[]const u8 = null,
        status: ?[]const u8 = null,
        model_introspection_schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .models = "models",
                .status = "status",
                .model_introspection_schema = "modelIntrospectionSchema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_backend_auth: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/auth/{BackendEnvironmentName}/details",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackendAuth",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backend_auth) } {
            return .{ .service_metadata = service_metadata, .action = get_backend_auth };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        resource_config: ?CreateBackendAuthResourceConfig = null,
        resource_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_backend_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backend/{AppId}/job/{BackendEnvironmentName}/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackendJob",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backend_job) } {
            return .{ .service_metadata = service_metadata, .action = get_backend_job };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        create_time: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,
        update_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .create_time = "createTime",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
                .update_time = "updateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_backend_storage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/storage/{BackendEnvironmentName}/details",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackendStorage",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backend_storage) } {
            return .{ .service_metadata = service_metadata, .action = get_backend_storage };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        resource_config: ?struct {
            bucket_name: ?[]const u8 = null,
            imported: bool,
            permissions: ?BackendStoragePermissions = null,
            service_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket_name = "bucketName",
                    .imported = "imported",
                    .permissions = "permissions",
                    .service_name = "serviceName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        resource_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_token: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backend/{AppId}/challenge/{SessionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetToken",
    Request: type = struct {
        app_id: []const u8,
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_token) } {
            return .{ .service_metadata = service_metadata, .action = get_token };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        challenge_code: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        ttl: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .challenge_code = "challengeCode",
                .session_id = "sessionId",
                .ttl = "ttl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const import_backend_auth: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/auth/{BackendEnvironmentName}/import",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportBackendAuth",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        identity_pool_id: ?[]const u8 = null,
        native_client_id: []const u8,
        user_pool_id: []const u8,
        web_client_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .identity_pool_id = "identityPoolId",
                .native_client_id = "nativeClientId",
                .user_pool_id = "userPoolId",
                .web_client_id = "webClientId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_backend_auth) } {
            return .{ .service_metadata = service_metadata, .action = import_backend_auth };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const import_backend_storage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/storage/{BackendEnvironmentName}/import",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportBackendStorage",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        bucket_name: ?[]const u8 = null,
        service_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .bucket_name = "bucketName",
                .service_name = "serviceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_backend_storage) } {
            return .{ .service_metadata = service_metadata, .action = import_backend_storage };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .job_id = "jobId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_backend_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/job/{BackendEnvironmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackendJobs",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        job_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .job_id = "jobId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backend_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_backend_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            app_id: []const u8,
            backend_environment_name: []const u8,
            create_time: ?[]const u8 = null,
            @"error": ?[]const u8 = null,
            job_id: ?[]const u8 = null,
            operation: ?[]const u8 = null,
            status: ?[]const u8 = null,
            update_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_id = "appId",
                    .backend_environment_name = "backendEnvironmentName",
                    .create_time = "createTime",
                    .@"error" = "error",
                    .job_id = "jobId",
                    .operation = "operation",
                    .status = "status",
                    .update_time = "updateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_s3_buckets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/s3Buckets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListS3Buckets",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_s3_buckets) } {
            return .{ .service_metadata = service_metadata, .action = list_s3_buckets };
        }
    },
    Response: type = struct {
        buckets: ?[]struct {
            creation_date: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_date = "creationDate",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .buckets = "buckets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const remove_all_backends: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/remove",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveAllBackends",
    Request: type = struct {
        app_id: []const u8,
        clean_amplify_app: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .clean_amplify_app = "cleanAmplifyApp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_all_backends) } {
            return .{ .service_metadata = service_metadata, .action = remove_all_backends };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const remove_backend_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/config/remove",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveBackendConfig",
    Request: type = struct {
        app_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_backend_config) } {
            return .{ .service_metadata = service_metadata, .action = remove_backend_config };
        }
    },
    Response: type = struct {
        @"error": ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"error" = "error",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_backend_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/api/{BackendEnvironmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBackendAPI",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_config: ?BackendAPIResourceConfig = null,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_backend_api) } {
            return .{ .service_metadata = service_metadata, .action = update_backend_api };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_backend_auth: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/auth/{BackendEnvironmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBackendAuth",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_config: struct {
            auth_resources: []const u8,
            identity_pool_configs: ?struct {
                unauthenticated_login: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .unauthenticated_login = "unauthenticatedLogin",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            service: []const u8,
            user_pool_configs: struct {
                forgot_password: ?struct {
                    delivery_method: ?[]const u8 = null,
                    email_settings: ?EmailSettings = null,
                    sms_settings: ?SmsSettings = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .delivery_method = "deliveryMethod",
                            .email_settings = "emailSettings",
                            .sms_settings = "smsSettings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                mfa: ?struct {
                    mfa_mode: ?[]const u8 = null,
                    settings: ?Settings = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .mfa_mode = "MFAMode",
                            .settings = "settings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                o_auth: ?struct {
                    domain_prefix: ?[]const u8 = null,
                    o_auth_grant_type: ?[]const u8 = null,
                    o_auth_scopes: ?[][]const u8 = null,
                    redirect_sign_in_ur_is: ?[][]const u8 = null,
                    redirect_sign_out_ur_is: ?[][]const u8 = null,
                    social_provider_settings: ?SocialProviderSettings = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .domain_prefix = "domainPrefix",
                            .o_auth_grant_type = "oAuthGrantType",
                            .o_auth_scopes = "oAuthScopes",
                            .redirect_sign_in_ur_is = "redirectSignInURIs",
                            .redirect_sign_out_ur_is = "redirectSignOutURIs",
                            .social_provider_settings = "socialProviderSettings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                password_policy: ?struct {
                    additional_constraints: ?[][]const u8 = null,
                    minimum_length: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .additional_constraints = "additionalConstraints",
                            .minimum_length = "minimumLength",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                verification_message: ?struct {
                    delivery_method: []const u8,
                    email_settings: ?EmailSettings = null,
                    sms_settings: ?SmsSettings = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .delivery_method = "deliveryMethod",
                            .email_settings = "emailSettings",
                            .sms_settings = "smsSettings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .forgot_password = "forgotPassword",
                        .mfa = "mfa",
                        .o_auth = "oAuth",
                        .password_policy = "passwordPolicy",
                        .verification_message = "verificationMessage",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auth_resources = "authResources",
                    .identity_pool_configs = "identityPoolConfigs",
                    .service = "service",
                    .user_pool_configs = "userPoolConfigs",
                };
                return @field(mappings, field_name);
            }
        },
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_backend_auth) } {
            return .{ .service_metadata = service_metadata, .action = update_backend_auth };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_backend_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/config/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBackendConfig",
    Request: type = struct {
        app_id: []const u8,
        login_auth_config: ?LoginAuthConfigReqObj = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .login_auth_config = "loginAuthConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_backend_config) } {
            return .{ .service_metadata = service_metadata, .action = update_backend_config };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_manager_app_id: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        login_auth_config: ?LoginAuthConfigReqObj = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_manager_app_id = "backendManagerAppId",
                .@"error" = "error",
                .login_auth_config = "loginAuthConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_backend_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/job/{BackendEnvironmentName}/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBackendJob",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        job_id: []const u8,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .job_id = "JobId",
                .operation = "operation",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_backend_job) } {
            return .{ .service_metadata = service_metadata, .action = update_backend_job };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        create_time: ?[]const u8 = null,
        @"error": ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        operation: ?[]const u8 = null,
        status: ?[]const u8 = null,
        update_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .create_time = "createTime",
                .@"error" = "error",
                .job_id = "jobId",
                .operation = "operation",
                .status = "status",
                .update_time = "updateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_backend_storage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backend/{AppId}/storage/{BackendEnvironmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBackendStorage",
    Request: type = struct {
        app_id: []const u8,
        backend_environment_name: []const u8,
        resource_config: struct {
            permissions: BackendStoragePermissions,
            service_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .permissions = "permissions",
                    .service_name = "serviceName",
                };
                return @field(mappings, field_name);
            }
        },
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "AppId",
                .backend_environment_name = "BackendEnvironmentName",
                .resource_config = "resourceConfig",
                .resource_name = "resourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_backend_storage) } {
            return .{ .service_metadata = service_metadata, .action = update_backend_storage };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        backend_environment_name: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .backend_environment_name = "backendEnvironmentName",
                .job_id = "jobId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        GatewayTimeout,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const BackendStoragePermissions = struct {
    authenticated: [][]const u8,
    un_authenticated: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authenticated = "authenticated",
            .un_authenticated = "unAuthenticated",
        };
        return @field(mappings, field_name);
    }
};

pub const LoginAuthConfigReqObj = struct {
    aws_cognito_identity_pool_id: ?[]const u8 = null,
    aws_cognito_region: ?[]const u8 = null,
    aws_user_pools_id: ?[]const u8 = null,
    aws_user_pools_web_client_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_cognito_identity_pool_id = "aws_cognito_identity_pool_id",
            .aws_cognito_region = "aws_cognito_region",
            .aws_user_pools_id = "aws_user_pools_id",
            .aws_user_pools_web_client_id = "aws_user_pools_web_client_id",
        };
        return @field(mappings, field_name);
    }
};

pub const SmsSettings = struct {
    sms_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sms_message = "smsMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailSettings = struct {
    email_message: ?[]const u8 = null,
    email_subject: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .email_message = "emailMessage",
            .email_subject = "emailSubject",
        };
        return @field(mappings, field_name);
    }
};

pub const SocialProviderSettings = struct {
    facebook: ?BackendAuthSocialProviderConfig = null,
    google: ?BackendAuthSocialProviderConfig = null,
    login_with_amazon: ?BackendAuthSocialProviderConfig = null,
    sign_in_with_apple: ?BackendAuthAppleProviderConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .facebook = "Facebook",
            .google = "Google",
            .login_with_amazon = "LoginWithAmazon",
            .sign_in_with_apple = "SignInWithApple",
        };
        return @field(mappings, field_name);
    }
};

pub const BackendAuthAppleProviderConfig = struct {
    client_id: ?[]const u8 = null,
    key_id: ?[]const u8 = null,
    private_key: ?[]const u8 = null,
    team_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "client_id",
            .key_id = "key_id",
            .private_key = "private_key",
            .team_id = "team_id",
        };
        return @field(mappings, field_name);
    }
};

pub const BackendAuthSocialProviderConfig = struct {
    client_id: ?[]const u8 = null,
    client_secret: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "client_id",
            .client_secret = "client_secret",
        };
        return @field(mappings, field_name);
    }
};

pub const Settings = struct {
    mfa_types: ?[][]const u8 = null,
    sms_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mfa_types = "mfaTypes",
            .sms_message = "smsMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const BackendAPIResourceConfig = struct {
    additional_auth_types: ?[]BackendAPIAuthType = null,
    api_name: ?[]const u8 = null,
    conflict_resolution: ?BackendAPIConflictResolution = null,
    default_auth_type: ?BackendAPIAuthType = null,
    service: ?[]const u8 = null,
    transform_schema: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_auth_types = "additionalAuthTypes",
            .api_name = "apiName",
            .conflict_resolution = "conflictResolution",
            .default_auth_type = "defaultAuthType",
            .service = "service",
            .transform_schema = "transformSchema",
        };
        return @field(mappings, field_name);
    }
};

pub const BackendAPIAuthType = struct {
    mode: ?[]const u8 = null,
    settings: ?BackendAPIAppSyncAuthSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "mode",
            .settings = "settings",
        };
        return @field(mappings, field_name);
    }
};

pub const BackendAPIAppSyncAuthSettings = struct {
    cognito_user_pool_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    expiration_time: ?f64 = null,
    open_id_auth_ttl: ?[]const u8 = null,
    open_id_client_id: ?[]const u8 = null,
    open_id_iat_ttl: ?[]const u8 = null,
    open_id_issue_url: ?[]const u8 = null,
    open_id_provider_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cognito_user_pool_id = "cognitoUserPoolId",
            .description = "description",
            .expiration_time = "expirationTime",
            .open_id_auth_ttl = "openIDAuthTTL",
            .open_id_client_id = "openIDClientId",
            .open_id_iat_ttl = "openIDIatTTL",
            .open_id_issue_url = "openIDIssueURL",
            .open_id_provider_name = "openIDProviderName",
        };
        return @field(mappings, field_name);
    }
};

pub const BackendAPIConflictResolution = struct {
    resolution_strategy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resolution_strategy = "resolutionStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateBackendAuthResourceConfig = struct {
    auth_resources: []const u8,
    identity_pool_configs: ?CreateBackendAuthIdentityPoolConfig = null,
    service: []const u8,
    user_pool_configs: CreateBackendAuthUserPoolConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auth_resources = "authResources",
            .identity_pool_configs = "identityPoolConfigs",
            .service = "service",
            .user_pool_configs = "userPoolConfigs",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateBackendAuthUserPoolConfig = struct {
    forgot_password: ?CreateBackendAuthForgotPasswordConfig = null,
    mfa: ?CreateBackendAuthMFAConfig = null,
    o_auth: ?CreateBackendAuthOAuthConfig = null,
    password_policy: ?CreateBackendAuthPasswordPolicyConfig = null,
    required_sign_up_attributes: [][]const u8,
    sign_in_method: []const u8,
    user_pool_name: []const u8,
    verification_message: ?CreateBackendAuthVerificationMessageConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .forgot_password = "forgotPassword",
            .mfa = "mfa",
            .o_auth = "oAuth",
            .password_policy = "passwordPolicy",
            .required_sign_up_attributes = "requiredSignUpAttributes",
            .sign_in_method = "signInMethod",
            .user_pool_name = "userPoolName",
            .verification_message = "verificationMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateBackendAuthVerificationMessageConfig = struct {
    delivery_method: []const u8,
    email_settings: ?EmailSettings = null,
    sms_settings: ?SmsSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_method = "deliveryMethod",
            .email_settings = "emailSettings",
            .sms_settings = "smsSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateBackendAuthPasswordPolicyConfig = struct {
    additional_constraints: ?[][]const u8 = null,
    minimum_length: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_constraints = "additionalConstraints",
            .minimum_length = "minimumLength",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateBackendAuthOAuthConfig = struct {
    domain_prefix: ?[]const u8 = null,
    o_auth_grant_type: []const u8,
    o_auth_scopes: [][]const u8,
    redirect_sign_in_ur_is: [][]const u8,
    redirect_sign_out_ur_is: [][]const u8,
    social_provider_settings: ?SocialProviderSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_prefix = "domainPrefix",
            .o_auth_grant_type = "oAuthGrantType",
            .o_auth_scopes = "oAuthScopes",
            .redirect_sign_in_ur_is = "redirectSignInURIs",
            .redirect_sign_out_ur_is = "redirectSignOutURIs",
            .social_provider_settings = "socialProviderSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateBackendAuthMFAConfig = struct {
    mfa_mode: []const u8,
    settings: ?Settings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mfa_mode = "MFAMode",
            .settings = "settings",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateBackendAuthForgotPasswordConfig = struct {
    delivery_method: []const u8,
    email_settings: ?EmailSettings = null,
    sms_settings: ?SmsSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_method = "deliveryMethod",
            .email_settings = "emailSettings",
            .sms_settings = "smsSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateBackendAuthIdentityPoolConfig = struct {
    identity_pool_name: []const u8,
    unauthenticated_login: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_pool_name = "identityPoolName",
            .unauthenticated_login = "unauthenticatedLogin",
        };
        return @field(mappings, field_name);
    }
};
