const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-08-11";
pub const sdk_id: []const u8 = "AmplifyUIBuilder";
pub const arn_namespace: ?[]const u8 = "amplifyuibuilder";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "amplifyuibuilder";
pub const name: []const u8 = "AmplifyUIBuilder";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-08-11",
    sdk_id: []const u8 = "AmplifyUIBuilder",
    arn_namespace: ?[]const u8 = "amplifyuibuilder",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "amplifyuibuilder",
    name: []const u8 = "AmplifyUIBuilder",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const exchange_code_for_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tokens/{provider}",
        .success_code = 200,
    };

    action_name: []const u8 = "ExchangeCodeForToken",
    Request: type = struct {
        provider: []const u8,
        request: struct {
            code: []const u8,
            redirect_uri: []const u8,
            client_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "code",
                    .redirect_uri = "redirectUri",
                    .client_id = "clientId",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider = "provider",
                .request = "request",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(exchange_code_for_token) } {
            return .{ .service_metadata = service_metadata, .action = exchange_code_for_token };
        }
    },
    Response: type = struct {
        access_token: []const u8,
        expires_in: i64,
        refresh_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "accessToken",
                .expires_in = "expiresIn",
                .refresh_token = "refreshToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
    },
} = .{};
pub const get_metadata: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app/{appId}/environment/{environmentName}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMetadata",
    Request: type = struct {
        app_id: []const u8,
        environment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .environment_name = "environmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_metadata };
        }
    },
    Response: type = struct {
        features: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .features = "features",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "features", field_name))
                return try serializeMap(self.features, self.fieldNameFor("features"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const put_metadata_flag: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app/{appId}/environment/{environmentName}/metadata/features/{featureName}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutMetadataFlag",
    Request: type = struct {
        app_id: []const u8,
        environment_name: []const u8,
        feature_name: []const u8,
        body: struct {
            new_value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .new_value = "newValue",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .environment_name = "environmentName",
                .feature_name = "featureName",
                .body = "body",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_metadata_flag) } {
            return .{ .service_metadata = service_metadata, .action = put_metadata_flag };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameter,
        Unauthorized,
    },
} = .{};
pub const refresh_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tokens/{provider}/refresh",
        .success_code = 200,
    };

    action_name: []const u8 = "RefreshToken",
    Request: type = struct {
        provider: []const u8,
        refresh_token_body: struct {
            token: []const u8,
            client_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .token = "token",
                    .client_id = "clientId",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "refresh_token_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider = "provider",
                .refresh_token_body = "refreshTokenBody",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(refresh_token) } {
            return .{ .service_metadata = service_metadata, .action = refresh_token };
        }
    },
    Response: type = struct {
        access_token: []const u8,
        expires_in: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "accessToken",
                .expires_in = "expiresIn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
