const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-29";
pub const sdk_id: []const u8 = "ApiGatewayManagementApi";
pub const arn_namespace: ?[]const u8 = "apigateway";
pub const endpoint_prefix: []const u8 = "execute-api";
pub const sigv4_name: []const u8 = "execute-api";
pub const name: []const u8 = "ApiGatewayManagementApi";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-29",
    sdk_id: []const u8 = "ApiGatewayManagementApi",
    arn_namespace: ?[]const u8 = "apigateway",
    endpoint_prefix: []const u8 = "execute-api",
    sigv4_name: []const u8 = "execute-api",
    name: []const u8 = "ApiGatewayManagementApi",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/@connections/{ConnectionId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Forbidden,
        Gone,
        LimitExceeded,
    },
} = .{};
pub const get_connection: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/@connections/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connection) } {
            return .{ .service_metadata = service_metadata, .action = get_connection };
        }
    },
    Response: type = struct {
        connected_at: ?i64 = null,
        identity: ?struct {
            source_ip: []const u8,
            user_agent: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_ip = "sourceIp",
                    .user_agent = "userAgent",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_active_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connected_at = "connectedAt",
                .identity = "identity",
                .last_active_at = "lastActiveAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        Gone,
        LimitExceeded,
    },
} = .{};
pub const post_to_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/@connections/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "PostToConnection",
    Request: type = struct {
        data: []const u8,
        connection_id: []const u8,

        pub const http_payload: []const u8 = "data";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data = "Data",
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(post_to_connection) } {
            return .{ .service_metadata = service_metadata, .action = post_to_connection };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Forbidden,
        Gone,
        LimitExceeded,
        PayloadTooLarge,
    },
} = .{};
