const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-29";
pub const sdk_id: []const u8 = "ApiGatewayV2";
pub const arn_namespace: ?[]const u8 = "apigateway";
pub const endpoint_prefix: []const u8 = "apigateway";
pub const sigv4_name: []const u8 = "apigateway";
pub const name: []const u8 = "ApiGatewayV2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-29",
    sdk_id: []const u8 = "ApiGatewayV2",
    arn_namespace: ?[]const u8 = "apigateway",
    endpoint_prefix: []const u8 = "apigateway",
    sigv4_name: []const u8 = "apigateway",
    name: []const u8 = "ApiGatewayV2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApi",
    Request: type = struct {
        api_key_selection_expression: ?[]const u8 = null,
        cors_configuration: ?Cors = null,
        credentials_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        disable_schema_validation: ?bool = null,
        disable_execute_api_endpoint: ?bool = null,
        name: []const u8,
        protocol_type: []const u8,
        route_key: ?[]const u8 = null,
        route_selection_expression: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        target: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_key_selection_expression = "apiKeySelectionExpression",
                .cors_configuration = "corsConfiguration",
                .credentials_arn = "credentialsArn",
                .description = "description",
                .disable_schema_validation = "disableSchemaValidation",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .name = "name",
                .protocol_type = "protocolType",
                .route_key = "routeKey",
                .route_selection_expression = "routeSelectionExpression",
                .tags = "tags",
                .target = "target",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_api) } {
            return .{ .service_metadata = service_metadata, .action = create_api };
        }
    },
    Response: type = struct {
        api_endpoint: ?[]const u8 = null,
        api_gateway_managed: ?bool = null,
        api_id: ?[]const u8 = null,
        api_key_selection_expression: ?[]const u8 = null,
        cors_configuration: ?Cors = null,
        created_date: ?i64 = null,
        description: ?[]const u8 = null,
        disable_schema_validation: ?bool = null,
        disable_execute_api_endpoint: ?bool = null,
        import_info: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        protocol_type: ?[]const u8 = null,
        route_selection_expression: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_endpoint = "apiEndpoint",
                .api_gateway_managed = "apiGatewayManaged",
                .api_id = "apiId",
                .api_key_selection_expression = "apiKeySelectionExpression",
                .cors_configuration = "corsConfiguration",
                .created_date = "createdDate",
                .description = "description",
                .disable_schema_validation = "disableSchemaValidation",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .import_info = "importInfo",
                .name = "name",
                .protocol_type = "protocolType",
                .route_selection_expression = "routeSelectionExpression",
                .tags = "tags",
                .version = "version",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_api_mapping: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domainnames/{DomainName}/apimappings",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApiMapping",
    Request: type = struct {
        api_id: []const u8,
        api_mapping_key: ?[]const u8 = null,
        domain_name: []const u8,
        stage: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .api_mapping_key = "apiMappingKey",
                .domain_name = "DomainName",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_api_mapping) } {
            return .{ .service_metadata = service_metadata, .action = create_api_mapping };
        }
    },
    Response: type = struct {
        api_id: ?[]const u8 = null,
        api_mapping_id: ?[]const u8 = null,
        api_mapping_key: ?[]const u8 = null,
        stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .api_mapping_id = "apiMappingId",
                .api_mapping_key = "apiMappingKey",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_authorizer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis/{ApiId}/authorizers",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAuthorizer",
    Request: type = struct {
        api_id: []const u8,
        authorizer_credentials_arn: ?[]const u8 = null,
        authorizer_payload_format_version: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,
        authorizer_type: []const u8,
        authorizer_uri: ?[]const u8 = null,
        enable_simple_responses: ?bool = null,
        identity_source: [][]const u8,
        identity_validation_expression: ?[]const u8 = null,
        jwt_configuration: ?JWTConfiguration = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .authorizer_credentials_arn = "authorizerCredentialsArn",
                .authorizer_payload_format_version = "authorizerPayloadFormatVersion",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
                .authorizer_type = "authorizerType",
                .authorizer_uri = "authorizerUri",
                .enable_simple_responses = "enableSimpleResponses",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .jwt_configuration = "jwtConfiguration",
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = create_authorizer };
        }
    },
    Response: type = struct {
        authorizer_credentials_arn: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        authorizer_payload_format_version: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,
        authorizer_type: ?[]const u8 = null,
        authorizer_uri: ?[]const u8 = null,
        enable_simple_responses: ?bool = null,
        identity_source: ?[][]const u8 = null,
        identity_validation_expression: ?[]const u8 = null,
        jwt_configuration: ?JWTConfiguration = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_credentials_arn = "authorizerCredentialsArn",
                .authorizer_id = "authorizerId",
                .authorizer_payload_format_version = "authorizerPayloadFormatVersion",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
                .authorizer_type = "authorizerType",
                .authorizer_uri = "authorizerUri",
                .enable_simple_responses = "enableSimpleResponses",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .jwt_configuration = "jwtConfiguration",
                .name = "name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis/{ApiId}/deployments",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDeployment",
    Request: type = struct {
        api_id: []const u8,
        description: ?[]const u8 = null,
        stage_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .description = "description",
                .stage_name = "stageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deployment) } {
            return .{ .service_metadata = service_metadata, .action = create_deployment };
        }
    },
    Response: type = struct {
        auto_deployed: ?bool = null,
        created_date: ?i64 = null,
        deployment_id: ?[]const u8 = null,
        deployment_status: ?[]const u8 = null,
        deployment_status_message: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_deployed = "autoDeployed",
                .created_date = "createdDate",
                .deployment_id = "deploymentId",
                .deployment_status = "deploymentStatus",
                .deployment_status_message = "deploymentStatusMessage",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_domain_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domainnames",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDomainName",
    Request: type = struct {
        domain_name: []const u8,
        domain_name_configurations: ?[]DomainNameConfiguration = null,
        mutual_tls_authentication: ?MutualTlsAuthenticationInput = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .domain_name_configurations = "domainNameConfigurations",
                .mutual_tls_authentication = "mutualTlsAuthentication",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain_name) } {
            return .{ .service_metadata = service_metadata, .action = create_domain_name };
        }
    },
    Response: type = struct {
        api_mapping_selection_expression: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        domain_name_configurations: ?[]DomainNameConfiguration = null,
        mutual_tls_authentication: ?MutualTlsAuthentication = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_mapping_selection_expression = "apiMappingSelectionExpression",
                .domain_name = "domainName",
                .domain_name_configurations = "domainNameConfigurations",
                .mutual_tls_authentication = "mutualTlsAuthentication",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_integration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis/{ApiId}/integrations",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateIntegration",
    Request: type = struct {
        api_id: []const u8,
        connection_id: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        content_handling_strategy: ?[]const u8 = null,
        credentials_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        integration_method: ?[]const u8 = null,
        integration_subtype: ?[]const u8 = null,
        integration_type: []const u8,
        integration_uri: ?[]const u8 = null,
        passthrough_behavior: ?[]const u8 = null,
        payload_format_version: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        template_selection_expression: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        tls_config: ?TlsConfigInput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .connection_id = "connectionId",
                .connection_type = "connectionType",
                .content_handling_strategy = "contentHandlingStrategy",
                .credentials_arn = "credentialsArn",
                .description = "description",
                .integration_method = "integrationMethod",
                .integration_subtype = "integrationSubtype",
                .integration_type = "integrationType",
                .integration_uri = "integrationUri",
                .passthrough_behavior = "passthroughBehavior",
                .payload_format_version = "payloadFormatVersion",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .response_parameters = "responseParameters",
                .template_selection_expression = "templateSelectionExpression",
                .timeout_in_millis = "timeoutInMillis",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_integration) } {
            return .{ .service_metadata = service_metadata, .action = create_integration };
        }
    },
    Response: type = struct {
        api_gateway_managed: ?bool = null,
        connection_id: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        content_handling_strategy: ?[]const u8 = null,
        credentials_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        integration_id: ?[]const u8 = null,
        integration_method: ?[]const u8 = null,
        integration_response_selection_expression: ?[]const u8 = null,
        integration_subtype: ?[]const u8 = null,
        integration_type: ?[]const u8 = null,
        integration_uri: ?[]const u8 = null,
        passthrough_behavior: ?[]const u8 = null,
        payload_format_version: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        template_selection_expression: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        tls_config: ?TlsConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_gateway_managed = "apiGatewayManaged",
                .connection_id = "connectionId",
                .connection_type = "connectionType",
                .content_handling_strategy = "contentHandlingStrategy",
                .credentials_arn = "credentialsArn",
                .description = "description",
                .integration_id = "integrationId",
                .integration_method = "integrationMethod",
                .integration_response_selection_expression = "integrationResponseSelectionExpression",
                .integration_subtype = "integrationSubtype",
                .integration_type = "integrationType",
                .integration_uri = "integrationUri",
                .passthrough_behavior = "passthroughBehavior",
                .payload_format_version = "payloadFormatVersion",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .response_parameters = "responseParameters",
                .template_selection_expression = "templateSelectionExpression",
                .timeout_in_millis = "timeoutInMillis",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_integration_response: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis/{ApiId}/integrations/{IntegrationId}/integrationresponses",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateIntegrationResponse",
    Request: type = struct {
        api_id: []const u8,
        content_handling_strategy: ?[]const u8 = null,
        integration_id: []const u8,
        integration_response_key: []const u8,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        template_selection_expression: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .content_handling_strategy = "contentHandlingStrategy",
                .integration_id = "IntegrationId",
                .integration_response_key = "integrationResponseKey",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .template_selection_expression = "templateSelectionExpression",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_integration_response) } {
            return .{ .service_metadata = service_metadata, .action = create_integration_response };
        }
    },
    Response: type = struct {
        content_handling_strategy: ?[]const u8 = null,
        integration_response_id: ?[]const u8 = null,
        integration_response_key: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        template_selection_expression: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_handling_strategy = "contentHandlingStrategy",
                .integration_response_id = "integrationResponseId",
                .integration_response_key = "integrationResponseKey",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .template_selection_expression = "templateSelectionExpression",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis/{ApiId}/models",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateModel",
    Request: type = struct {
        api_id: []const u8,
        content_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        name: []const u8,
        schema: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .content_type = "contentType",
                .description = "description",
                .name = "name",
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model) } {
            return .{ .service_metadata = service_metadata, .action = create_model };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        model_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .description = "description",
                .model_id = "modelId",
                .name = "name",
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_route: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis/{ApiId}/routes",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRoute",
    Request: type = struct {
        api_id: []const u8,
        api_key_required: ?bool = null,
        authorization_scopes: ?[][]const u8 = null,
        authorization_type: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        model_selection_expression: ?[]const u8 = null,
        operation_name: ?[]const u8 = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_key: []const u8,
        route_response_selection_expression: ?[]const u8 = null,
        target: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .api_key_required = "apiKeyRequired",
                .authorization_scopes = "authorizationScopes",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .model_selection_expression = "modelSelectionExpression",
                .operation_name = "operationName",
                .request_models = "requestModels",
                .request_parameters = "requestParameters",
                .route_key = "routeKey",
                .route_response_selection_expression = "routeResponseSelectionExpression",
                .target = "target",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_route) } {
            return .{ .service_metadata = service_metadata, .action = create_route };
        }
    },
    Response: type = struct {
        api_gateway_managed: ?bool = null,
        api_key_required: ?bool = null,
        authorization_scopes: ?[][]const u8 = null,
        authorization_type: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        model_selection_expression: ?[]const u8 = null,
        operation_name: ?[]const u8 = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_id: ?[]const u8 = null,
        route_key: ?[]const u8 = null,
        route_response_selection_expression: ?[]const u8 = null,
        target: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_gateway_managed = "apiGatewayManaged",
                .api_key_required = "apiKeyRequired",
                .authorization_scopes = "authorizationScopes",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .model_selection_expression = "modelSelectionExpression",
                .operation_name = "operationName",
                .request_models = "requestModels",
                .request_parameters = "requestParameters",
                .route_id = "routeId",
                .route_key = "routeKey",
                .route_response_selection_expression = "routeResponseSelectionExpression",
                .target = "target",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_route_response: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}/routeresponses",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRouteResponse",
    Request: type = struct {
        api_id: []const u8,
        model_selection_expression: ?[]const u8 = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_id: []const u8,
        route_response_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .model_selection_expression = "modelSelectionExpression",
                .response_models = "responseModels",
                .response_parameters = "responseParameters",
                .route_id = "RouteId",
                .route_response_key = "routeResponseKey",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_route_response) } {
            return .{ .service_metadata = service_metadata, .action = create_route_response };
        }
    },
    Response: type = struct {
        model_selection_expression: ?[]const u8 = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_response_id: ?[]const u8 = null,
        route_response_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_selection_expression = "modelSelectionExpression",
                .response_models = "responseModels",
                .response_parameters = "responseParameters",
                .route_response_id = "routeResponseId",
                .route_response_key = "routeResponseKey",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_stage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/apis/{ApiId}/stages",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateStage",
    Request: type = struct {
        access_log_settings: ?AccessLogSettings = null,
        api_id: []const u8,
        auto_deploy: ?bool = null,
        client_certificate_id: ?[]const u8 = null,
        default_route_settings: ?RouteSettings = null,
        deployment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        route_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RouteSettings = null,
        } = null,
        stage_name: []const u8,
        stage_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_log_settings = "accessLogSettings",
                .api_id = "ApiId",
                .auto_deploy = "autoDeploy",
                .client_certificate_id = "clientCertificateId",
                .default_route_settings = "defaultRouteSettings",
                .deployment_id = "deploymentId",
                .description = "description",
                .route_settings = "routeSettings",
                .stage_name = "stageName",
                .stage_variables = "stageVariables",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "route_settings", field_name))
                return try serializeMap(self.route_settings, self.fieldNameFor("route_settings"), options, out_stream);
            if (std.mem.eql(u8, "stage_variables", field_name))
                return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stage) } {
            return .{ .service_metadata = service_metadata, .action = create_stage };
        }
    },
    Response: type = struct {
        access_log_settings: ?AccessLogSettings = null,
        api_gateway_managed: ?bool = null,
        auto_deploy: ?bool = null,
        client_certificate_id: ?[]const u8 = null,
        created_date: ?i64 = null,
        default_route_settings: ?RouteSettings = null,
        deployment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        last_deployment_status_message: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        route_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RouteSettings = null,
        } = null,
        stage_name: ?[]const u8 = null,
        stage_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_log_settings = "accessLogSettings",
                .api_gateway_managed = "apiGatewayManaged",
                .auto_deploy = "autoDeploy",
                .client_certificate_id = "clientCertificateId",
                .created_date = "createdDate",
                .default_route_settings = "defaultRouteSettings",
                .deployment_id = "deploymentId",
                .description = "description",
                .last_deployment_status_message = "lastDeploymentStatusMessage",
                .last_updated_date = "lastUpdatedDate",
                .route_settings = "routeSettings",
                .stage_name = "stageName",
                .stage_variables = "stageVariables",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "route_settings", field_name))
                return try serializeMap(self.route_settings, self.fieldNameFor("route_settings"), options, out_stream);
            if (std.mem.eql(u8, "stage_variables", field_name))
                return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_vpc_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/vpclinks",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVpcLink",
    Request: type = struct {
        name: []const u8,
        security_group_ids: ?[][]const u8 = null,
        subnet_ids: [][]const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .security_group_ids = "securityGroupIds",
                .subnet_ids = "subnetIds",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_link) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_link };
        }
    },
    Response: type = struct {
        created_date: ?i64 = null,
        name: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc_link_id: ?[]const u8 = null,
        vpc_link_status: ?[]const u8 = null,
        vpc_link_status_message: ?[]const u8 = null,
        vpc_link_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_date = "createdDate",
                .name = "name",
                .security_group_ids = "securityGroupIds",
                .subnet_ids = "subnetIds",
                .tags = "tags",
                .vpc_link_id = "vpcLinkId",
                .vpc_link_status = "vpcLinkStatus",
                .vpc_link_status_message = "vpcLinkStatusMessage",
                .vpc_link_version = "vpcLinkVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const delete_access_log_settings: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/stages/{StageName}/accesslogsettings",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAccessLogSettings",
    Request: type = struct {
        api_id: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .stage_name = "StageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_log_settings) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_log_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_api: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteApi",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_api) } {
            return .{ .service_metadata = service_metadata, .action = delete_api };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_api_mapping: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/domainnames/{DomainName}/apimappings/{ApiMappingId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteApiMapping",
    Request: type = struct {
        api_mapping_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_mapping_id = "ApiMappingId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_api_mapping) } {
            return .{ .service_metadata = service_metadata, .action = delete_api_mapping };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_authorizer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/authorizers/{AuthorizerId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAuthorizer",
    Request: type = struct {
        api_id: []const u8,
        authorizer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .authorizer_id = "AuthorizerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = delete_authorizer };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_cors_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/cors",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteCorsConfiguration",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cors_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_cors_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_deployment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/deployments/{DeploymentId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDeployment",
    Request: type = struct {
        api_id: []const u8,
        deployment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .deployment_id = "DeploymentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_deployment) } {
            return .{ .service_metadata = service_metadata, .action = delete_deployment };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_domain_name: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/domainnames/{DomainName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDomainName",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain_name) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_integration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/integrations/{IntegrationId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIntegration",
    Request: type = struct {
        api_id: []const u8,
        integration_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .integration_id = "IntegrationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_integration) } {
            return .{ .service_metadata = service_metadata, .action = delete_integration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_integration_response: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/integrations/{IntegrationId}/integrationresponses/{IntegrationResponseId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIntegrationResponse",
    Request: type = struct {
        api_id: []const u8,
        integration_id: []const u8,
        integration_response_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .integration_id = "IntegrationId",
                .integration_response_id = "IntegrationResponseId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_integration_response) } {
            return .{ .service_metadata = service_metadata, .action = delete_integration_response };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_model: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/models/{ModelId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteModel",
    Request: type = struct {
        api_id: []const u8,
        model_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .model_id = "ModelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_model };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_route: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRoute",
    Request: type = struct {
        api_id: []const u8,
        route_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .route_id = "RouteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_route) } {
            return .{ .service_metadata = service_metadata, .action = delete_route };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_route_request_parameter: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}/requestparameters/{RequestParameterKey}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRouteRequestParameter",
    Request: type = struct {
        api_id: []const u8,
        request_parameter_key: []const u8,
        route_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .request_parameter_key = "RequestParameterKey",
                .route_id = "RouteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_route_request_parameter) } {
            return .{ .service_metadata = service_metadata, .action = delete_route_request_parameter };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_route_response: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}/routeresponses/{RouteResponseId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRouteResponse",
    Request: type = struct {
        api_id: []const u8,
        route_id: []const u8,
        route_response_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .route_id = "RouteId",
                .route_response_id = "RouteResponseId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_route_response) } {
            return .{ .service_metadata = service_metadata, .action = delete_route_response };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_route_settings: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/stages/{StageName}/routesettings/{RouteKey}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRouteSettings",
    Request: type = struct {
        api_id: []const u8,
        route_key: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .route_key = "RouteKey",
                .stage_name = "StageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_route_settings) } {
            return .{ .service_metadata = service_metadata, .action = delete_route_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_stage: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/stages/{StageName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteStage",
    Request: type = struct {
        api_id: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .stage_name = "StageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stage) } {
            return .{ .service_metadata = service_metadata, .action = delete_stage };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_vpc_link: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/vpclinks/{VpcLinkId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteVpcLink",
    Request: type = struct {
        vpc_link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_link_id = "VpcLinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_link) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_link };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const export_api: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/exports/{Specification}",
        .success_code = 200,
    };

    action_name: []const u8 = "ExportApi",
    Request: type = struct {
        api_id: []const u8,
        export_version: ?[]const u8 = null,
        include_extensions: ?bool = null,
        output_type: []const u8,
        specification: []const u8,
        stage_name: ?[]const u8 = null,

        pub const http_query = .{
            .export_version = "exportVersion",
            .include_extensions = "includeExtensions",
            .output_type = "outputType",
            .stage_name = "stageName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .export_version = "ExportVersion",
                .include_extensions = "IncludeExtensions",
                .output_type = "OutputType",
                .specification = "Specification",
                .stage_name = "StageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_api) } {
            return .{ .service_metadata = service_metadata, .action = export_api };
        }
    },
    Response: type = struct {
        body: ?[]const u8 = null,

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "body",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_api: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApi",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_api) } {
            return .{ .service_metadata = service_metadata, .action = get_api };
        }
    },
    Response: type = struct {
        api_endpoint: ?[]const u8 = null,
        api_gateway_managed: ?bool = null,
        api_id: ?[]const u8 = null,
        api_key_selection_expression: ?[]const u8 = null,
        cors_configuration: ?Cors = null,
        created_date: ?i64 = null,
        description: ?[]const u8 = null,
        disable_schema_validation: ?bool = null,
        disable_execute_api_endpoint: ?bool = null,
        import_info: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        protocol_type: ?[]const u8 = null,
        route_selection_expression: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_endpoint = "apiEndpoint",
                .api_gateway_managed = "apiGatewayManaged",
                .api_id = "apiId",
                .api_key_selection_expression = "apiKeySelectionExpression",
                .cors_configuration = "corsConfiguration",
                .created_date = "createdDate",
                .description = "description",
                .disable_schema_validation = "disableSchemaValidation",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .import_info = "importInfo",
                .name = "name",
                .protocol_type = "protocolType",
                .route_selection_expression = "routeSelectionExpression",
                .tags = "tags",
                .version = "version",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_api_mapping: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domainnames/{DomainName}/apimappings/{ApiMappingId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApiMapping",
    Request: type = struct {
        api_mapping_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_mapping_id = "ApiMappingId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_api_mapping) } {
            return .{ .service_metadata = service_metadata, .action = get_api_mapping };
        }
    },
    Response: type = struct {
        api_id: ?[]const u8 = null,
        api_mapping_id: ?[]const u8 = null,
        api_mapping_key: ?[]const u8 = null,
        stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .api_mapping_id = "apiMappingId",
                .api_mapping_key = "apiMappingKey",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_api_mappings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domainnames/{DomainName}/apimappings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApiMappings",
    Request: type = struct {
        domain_name: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_api_mappings) } {
            return .{ .service_metadata = service_metadata, .action = get_api_mappings };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            api_id: []const u8,
            api_mapping_id: ?[]const u8 = null,
            api_mapping_key: ?[]const u8 = null,
            stage: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .api_id = "apiId",
                    .api_mapping_id = "apiMappingId",
                    .api_mapping_key = "apiMappingKey",
                    .stage = "stage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_apis: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApis",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_apis) } {
            return .{ .service_metadata = service_metadata, .action = get_apis };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            api_endpoint: ?[]const u8 = null,
            api_gateway_managed: ?bool = null,
            api_id: ?[]const u8 = null,
            api_key_selection_expression: ?[]const u8 = null,
            cors_configuration: ?Cors = null,
            created_date: ?i64 = null,
            description: ?[]const u8 = null,
            disable_schema_validation: ?bool = null,
            disable_execute_api_endpoint: ?bool = null,
            import_info: ?[][]const u8 = null,
            name: []const u8,
            protocol_type: []const u8,
            route_selection_expression: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            version: ?[]const u8 = null,
            warnings: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .api_endpoint = "apiEndpoint",
                    .api_gateway_managed = "apiGatewayManaged",
                    .api_id = "apiId",
                    .api_key_selection_expression = "apiKeySelectionExpression",
                    .cors_configuration = "corsConfiguration",
                    .created_date = "createdDate",
                    .description = "description",
                    .disable_schema_validation = "disableSchemaValidation",
                    .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                    .import_info = "importInfo",
                    .name = "name",
                    .protocol_type = "protocolType",
                    .route_selection_expression = "routeSelectionExpression",
                    .tags = "tags",
                    .version = "version",
                    .warnings = "warnings",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_authorizer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/authorizers/{AuthorizerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAuthorizer",
    Request: type = struct {
        api_id: []const u8,
        authorizer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .authorizer_id = "AuthorizerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = get_authorizer };
        }
    },
    Response: type = struct {
        authorizer_credentials_arn: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        authorizer_payload_format_version: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,
        authorizer_type: ?[]const u8 = null,
        authorizer_uri: ?[]const u8 = null,
        enable_simple_responses: ?bool = null,
        identity_source: ?[][]const u8 = null,
        identity_validation_expression: ?[]const u8 = null,
        jwt_configuration: ?JWTConfiguration = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_credentials_arn = "authorizerCredentialsArn",
                .authorizer_id = "authorizerId",
                .authorizer_payload_format_version = "authorizerPayloadFormatVersion",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
                .authorizer_type = "authorizerType",
                .authorizer_uri = "authorizerUri",
                .enable_simple_responses = "enableSimpleResponses",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .jwt_configuration = "jwtConfiguration",
                .name = "name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_authorizers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/authorizers",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAuthorizers",
    Request: type = struct {
        api_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_authorizers) } {
            return .{ .service_metadata = service_metadata, .action = get_authorizers };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            authorizer_credentials_arn: ?[]const u8 = null,
            authorizer_id: ?[]const u8 = null,
            authorizer_payload_format_version: ?[]const u8 = null,
            authorizer_result_ttl_in_seconds: ?i64 = null,
            authorizer_type: ?[]const u8 = null,
            authorizer_uri: ?[]const u8 = null,
            enable_simple_responses: ?bool = null,
            identity_source: ?[][]const u8 = null,
            identity_validation_expression: ?[]const u8 = null,
            jwt_configuration: ?JWTConfiguration = null,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authorizer_credentials_arn = "authorizerCredentialsArn",
                    .authorizer_id = "authorizerId",
                    .authorizer_payload_format_version = "authorizerPayloadFormatVersion",
                    .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
                    .authorizer_type = "authorizerType",
                    .authorizer_uri = "authorizerUri",
                    .enable_simple_responses = "enableSimpleResponses",
                    .identity_source = "identitySource",
                    .identity_validation_expression = "identityValidationExpression",
                    .jwt_configuration = "jwtConfiguration",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_deployment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/deployments/{DeploymentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeployment",
    Request: type = struct {
        api_id: []const u8,
        deployment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .deployment_id = "DeploymentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployment) } {
            return .{ .service_metadata = service_metadata, .action = get_deployment };
        }
    },
    Response: type = struct {
        auto_deployed: ?bool = null,
        created_date: ?i64 = null,
        deployment_id: ?[]const u8 = null,
        deployment_status: ?[]const u8 = null,
        deployment_status_message: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_deployed = "autoDeployed",
                .created_date = "createdDate",
                .deployment_id = "deploymentId",
                .deployment_status = "deploymentStatus",
                .deployment_status_message = "deploymentStatusMessage",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_deployments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeployments",
    Request: type = struct {
        api_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployments) } {
            return .{ .service_metadata = service_metadata, .action = get_deployments };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            auto_deployed: ?bool = null,
            created_date: ?i64 = null,
            deployment_id: ?[]const u8 = null,
            deployment_status: ?[]const u8 = null,
            deployment_status_message: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_deployed = "autoDeployed",
                    .created_date = "createdDate",
                    .deployment_id = "deploymentId",
                    .deployment_status = "deploymentStatus",
                    .deployment_status_message = "deploymentStatusMessage",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_domain_name: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domainnames/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainName",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_name) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_name };
        }
    },
    Response: type = struct {
        api_mapping_selection_expression: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        domain_name_configurations: ?[]DomainNameConfiguration = null,
        mutual_tls_authentication: ?MutualTlsAuthentication = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_mapping_selection_expression = "apiMappingSelectionExpression",
                .domain_name = "domainName",
                .domain_name_configurations = "domainNameConfigurations",
                .mutual_tls_authentication = "mutualTlsAuthentication",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_domain_names: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domainnames",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainNames",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_names) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_names };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            api_mapping_selection_expression: ?[]const u8 = null,
            domain_name: []const u8,
            domain_name_configurations: ?[]DomainNameConfiguration = null,
            mutual_tls_authentication: ?MutualTlsAuthentication = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .api_mapping_selection_expression = "apiMappingSelectionExpression",
                    .domain_name = "domainName",
                    .domain_name_configurations = "domainNameConfigurations",
                    .mutual_tls_authentication = "mutualTlsAuthentication",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_integration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/integrations/{IntegrationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntegration",
    Request: type = struct {
        api_id: []const u8,
        integration_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .integration_id = "IntegrationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_integration) } {
            return .{ .service_metadata = service_metadata, .action = get_integration };
        }
    },
    Response: type = struct {
        api_gateway_managed: ?bool = null,
        connection_id: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        content_handling_strategy: ?[]const u8 = null,
        credentials_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        integration_id: ?[]const u8 = null,
        integration_method: ?[]const u8 = null,
        integration_response_selection_expression: ?[]const u8 = null,
        integration_subtype: ?[]const u8 = null,
        integration_type: ?[]const u8 = null,
        integration_uri: ?[]const u8 = null,
        passthrough_behavior: ?[]const u8 = null,
        payload_format_version: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        template_selection_expression: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        tls_config: ?TlsConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_gateway_managed = "apiGatewayManaged",
                .connection_id = "connectionId",
                .connection_type = "connectionType",
                .content_handling_strategy = "contentHandlingStrategy",
                .credentials_arn = "credentialsArn",
                .description = "description",
                .integration_id = "integrationId",
                .integration_method = "integrationMethod",
                .integration_response_selection_expression = "integrationResponseSelectionExpression",
                .integration_subtype = "integrationSubtype",
                .integration_type = "integrationType",
                .integration_uri = "integrationUri",
                .passthrough_behavior = "passthroughBehavior",
                .payload_format_version = "payloadFormatVersion",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .response_parameters = "responseParameters",
                .template_selection_expression = "templateSelectionExpression",
                .timeout_in_millis = "timeoutInMillis",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_integration_response: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/integrations/{IntegrationId}/integrationresponses/{IntegrationResponseId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntegrationResponse",
    Request: type = struct {
        api_id: []const u8,
        integration_id: []const u8,
        integration_response_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .integration_id = "IntegrationId",
                .integration_response_id = "IntegrationResponseId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_integration_response) } {
            return .{ .service_metadata = service_metadata, .action = get_integration_response };
        }
    },
    Response: type = struct {
        content_handling_strategy: ?[]const u8 = null,
        integration_response_id: ?[]const u8 = null,
        integration_response_key: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        template_selection_expression: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_handling_strategy = "contentHandlingStrategy",
                .integration_response_id = "integrationResponseId",
                .integration_response_key = "integrationResponseKey",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .template_selection_expression = "templateSelectionExpression",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_integration_responses: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/integrations/{IntegrationId}/integrationresponses",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntegrationResponses",
    Request: type = struct {
        api_id: []const u8,
        integration_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .integration_id = "IntegrationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_integration_responses) } {
            return .{ .service_metadata = service_metadata, .action = get_integration_responses };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            content_handling_strategy: ?[]const u8 = null,
            integration_response_id: ?[]const u8 = null,
            integration_response_key: []const u8,
            response_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            response_templates: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            template_selection_expression: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .content_handling_strategy = "contentHandlingStrategy",
                    .integration_response_id = "integrationResponseId",
                    .integration_response_key = "integrationResponseKey",
                    .response_parameters = "responseParameters",
                    .response_templates = "responseTemplates",
                    .template_selection_expression = "templateSelectionExpression",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "response_parameters", field_name))
                    return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
                if (std.mem.eql(u8, "response_templates", field_name))
                    return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_integrations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntegrations",
    Request: type = struct {
        api_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_integrations) } {
            return .{ .service_metadata = service_metadata, .action = get_integrations };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            api_gateway_managed: ?bool = null,
            connection_id: ?[]const u8 = null,
            connection_type: ?[]const u8 = null,
            content_handling_strategy: ?[]const u8 = null,
            credentials_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            integration_id: ?[]const u8 = null,
            integration_method: ?[]const u8 = null,
            integration_response_selection_expression: ?[]const u8 = null,
            integration_subtype: ?[]const u8 = null,
            integration_type: ?[]const u8 = null,
            integration_uri: ?[]const u8 = null,
            passthrough_behavior: ?[]const u8 = null,
            payload_format_version: ?[]const u8 = null,
            request_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            request_templates: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            response_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,


            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "value", field_name))
                    return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
                return false;
            }
            } = null,
            template_selection_expression: ?[]const u8 = null,
            timeout_in_millis: ?i64 = null,
            tls_config: ?TlsConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .api_gateway_managed = "apiGatewayManaged",
                    .connection_id = "connectionId",
                    .connection_type = "connectionType",
                    .content_handling_strategy = "contentHandlingStrategy",
                    .credentials_arn = "credentialsArn",
                    .description = "description",
                    .integration_id = "integrationId",
                    .integration_method = "integrationMethod",
                    .integration_response_selection_expression = "integrationResponseSelectionExpression",
                    .integration_subtype = "integrationSubtype",
                    .integration_type = "integrationType",
                    .integration_uri = "integrationUri",
                    .passthrough_behavior = "passthroughBehavior",
                    .payload_format_version = "payloadFormatVersion",
                    .request_parameters = "requestParameters",
                    .request_templates = "requestTemplates",
                    .response_parameters = "responseParameters",
                    .template_selection_expression = "templateSelectionExpression",
                    .timeout_in_millis = "timeoutInMillis",
                    .tls_config = "tlsConfig",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "request_parameters", field_name))
                    return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
                if (std.mem.eql(u8, "request_templates", field_name))
                    return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
                if (std.mem.eql(u8, "response_parameters", field_name))
                    return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/models/{ModelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetModel",
    Request: type = struct {
        api_id: []const u8,
        model_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .model_id = "ModelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_model) } {
            return .{ .service_metadata = service_metadata, .action = get_model };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        model_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .description = "description",
                .model_id = "modelId",
                .name = "name",
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_models: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/models",
        .success_code = 200,
    };

    action_name: []const u8 = "GetModels",
    Request: type = struct {
        api_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_models) } {
            return .{ .service_metadata = service_metadata, .action = get_models };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            content_type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            model_id: ?[]const u8 = null,
            name: []const u8,
            schema: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .content_type = "contentType",
                    .description = "description",
                    .model_id = "modelId",
                    .name = "name",
                    .schema = "schema",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_model_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/models/{ModelId}/template",
        .success_code = 200,
    };

    action_name: []const u8 = "GetModelTemplate",
    Request: type = struct {
        api_id: []const u8,
        model_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .model_id = "ModelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_model_template) } {
            return .{ .service_metadata = service_metadata, .action = get_model_template };
        }
    },
    Response: type = struct {
        value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .value = "value",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_route: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRoute",
    Request: type = struct {
        api_id: []const u8,
        route_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .route_id = "RouteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_route) } {
            return .{ .service_metadata = service_metadata, .action = get_route };
        }
    },
    Response: type = struct {
        api_gateway_managed: ?bool = null,
        api_key_required: ?bool = null,
        authorization_scopes: ?[][]const u8 = null,
        authorization_type: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        model_selection_expression: ?[]const u8 = null,
        operation_name: ?[]const u8 = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_id: ?[]const u8 = null,
        route_key: ?[]const u8 = null,
        route_response_selection_expression: ?[]const u8 = null,
        target: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_gateway_managed = "apiGatewayManaged",
                .api_key_required = "apiKeyRequired",
                .authorization_scopes = "authorizationScopes",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .model_selection_expression = "modelSelectionExpression",
                .operation_name = "operationName",
                .request_models = "requestModels",
                .request_parameters = "requestParameters",
                .route_id = "routeId",
                .route_key = "routeKey",
                .route_response_selection_expression = "routeResponseSelectionExpression",
                .target = "target",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_route_response: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}/routeresponses/{RouteResponseId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRouteResponse",
    Request: type = struct {
        api_id: []const u8,
        route_id: []const u8,
        route_response_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .route_id = "RouteId",
                .route_response_id = "RouteResponseId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_route_response) } {
            return .{ .service_metadata = service_metadata, .action = get_route_response };
        }
    },
    Response: type = struct {
        model_selection_expression: ?[]const u8 = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_response_id: ?[]const u8 = null,
        route_response_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_selection_expression = "modelSelectionExpression",
                .response_models = "responseModels",
                .response_parameters = "responseParameters",
                .route_response_id = "routeResponseId",
                .route_response_key = "routeResponseKey",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_route_responses: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}/routeresponses",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRouteResponses",
    Request: type = struct {
        api_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        route_id: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .route_id = "RouteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_route_responses) } {
            return .{ .service_metadata = service_metadata, .action = get_route_responses };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            model_selection_expression: ?[]const u8 = null,
            response_models: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            response_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?ParameterConstraints = null,
            } = null,
            route_response_id: ?[]const u8 = null,
            route_response_key: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_selection_expression = "modelSelectionExpression",
                    .response_models = "responseModels",
                    .response_parameters = "responseParameters",
                    .route_response_id = "routeResponseId",
                    .route_response_key = "routeResponseKey",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "response_models", field_name))
                    return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
                if (std.mem.eql(u8, "response_parameters", field_name))
                    return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_routes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/routes",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRoutes",
    Request: type = struct {
        api_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_routes) } {
            return .{ .service_metadata = service_metadata, .action = get_routes };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            api_gateway_managed: ?bool = null,
            api_key_required: ?bool = null,
            authorization_scopes: ?[][]const u8 = null,
            authorization_type: ?[]const u8 = null,
            authorizer_id: ?[]const u8 = null,
            model_selection_expression: ?[]const u8 = null,
            operation_name: ?[]const u8 = null,
            request_models: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            request_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?ParameterConstraints = null,
            } = null,
            route_id: ?[]const u8 = null,
            route_key: []const u8,
            route_response_selection_expression: ?[]const u8 = null,
            target: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .api_gateway_managed = "apiGatewayManaged",
                    .api_key_required = "apiKeyRequired",
                    .authorization_scopes = "authorizationScopes",
                    .authorization_type = "authorizationType",
                    .authorizer_id = "authorizerId",
                    .model_selection_expression = "modelSelectionExpression",
                    .operation_name = "operationName",
                    .request_models = "requestModels",
                    .request_parameters = "requestParameters",
                    .route_id = "routeId",
                    .route_key = "routeKey",
                    .route_response_selection_expression = "routeResponseSelectionExpression",
                    .target = "target",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "request_models", field_name))
                    return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
                if (std.mem.eql(u8, "request_parameters", field_name))
                    return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_stage: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/stages/{StageName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStage",
    Request: type = struct {
        api_id: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .stage_name = "StageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stage) } {
            return .{ .service_metadata = service_metadata, .action = get_stage };
        }
    },
    Response: type = struct {
        access_log_settings: ?AccessLogSettings = null,
        api_gateway_managed: ?bool = null,
        auto_deploy: ?bool = null,
        client_certificate_id: ?[]const u8 = null,
        created_date: ?i64 = null,
        default_route_settings: ?RouteSettings = null,
        deployment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        last_deployment_status_message: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        route_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RouteSettings = null,
        } = null,
        stage_name: ?[]const u8 = null,
        stage_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_log_settings = "accessLogSettings",
                .api_gateway_managed = "apiGatewayManaged",
                .auto_deploy = "autoDeploy",
                .client_certificate_id = "clientCertificateId",
                .created_date = "createdDate",
                .default_route_settings = "defaultRouteSettings",
                .deployment_id = "deploymentId",
                .description = "description",
                .last_deployment_status_message = "lastDeploymentStatusMessage",
                .last_updated_date = "lastUpdatedDate",
                .route_settings = "routeSettings",
                .stage_name = "stageName",
                .stage_variables = "stageVariables",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "route_settings", field_name))
                return try serializeMap(self.route_settings, self.fieldNameFor("route_settings"), options, out_stream);
            if (std.mem.eql(u8, "stage_variables", field_name))
                return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_stages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/apis/{ApiId}/stages",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStages",
    Request: type = struct {
        api_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stages) } {
            return .{ .service_metadata = service_metadata, .action = get_stages };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            access_log_settings: ?AccessLogSettings = null,
            api_gateway_managed: ?bool = null,
            auto_deploy: ?bool = null,
            client_certificate_id: ?[]const u8 = null,
            created_date: ?i64 = null,
            default_route_settings: ?RouteSettings = null,
            deployment_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            last_deployment_status_message: ?[]const u8 = null,
            last_updated_date: ?i64 = null,
            route_settings: ?[]struct {
                key: ?[]const u8 = null,
                value: ?RouteSettings = null,
            } = null,
            stage_name: []const u8,
            stage_variables: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_log_settings = "accessLogSettings",
                    .api_gateway_managed = "apiGatewayManaged",
                    .auto_deploy = "autoDeploy",
                    .client_certificate_id = "clientCertificateId",
                    .created_date = "createdDate",
                    .default_route_settings = "defaultRouteSettings",
                    .deployment_id = "deploymentId",
                    .description = "description",
                    .last_deployment_status_message = "lastDeploymentStatusMessage",
                    .last_updated_date = "lastUpdatedDate",
                    .route_settings = "routeSettings",
                    .stage_name = "stageName",
                    .stage_variables = "stageVariables",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "route_settings", field_name))
                    return try serializeMap(self.route_settings, self.fieldNameFor("route_settings"), options, out_stream);
                if (std.mem.eql(u8, "stage_variables", field_name))
                    return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTags",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_tags) } {
            return .{ .service_metadata = service_metadata, .action = get_tags };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_vpc_link: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/vpclinks/{VpcLinkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVpcLink",
    Request: type = struct {
        vpc_link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_link_id = "VpcLinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpc_link) } {
            return .{ .service_metadata = service_metadata, .action = get_vpc_link };
        }
    },
    Response: type = struct {
        created_date: ?i64 = null,
        name: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc_link_id: ?[]const u8 = null,
        vpc_link_status: ?[]const u8 = null,
        vpc_link_status_message: ?[]const u8 = null,
        vpc_link_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_date = "createdDate",
                .name = "name",
                .security_group_ids = "securityGroupIds",
                .subnet_ids = "subnetIds",
                .tags = "tags",
                .vpc_link_id = "vpcLinkId",
                .vpc_link_status = "vpcLinkStatus",
                .vpc_link_status_message = "vpcLinkStatusMessage",
                .vpc_link_version = "vpcLinkVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_vpc_links: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/vpclinks",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVpcLinks",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpc_links) } {
            return .{ .service_metadata = service_metadata, .action = get_vpc_links };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            created_date: ?i64 = null,
            name: []const u8,
            security_group_ids: [][]const u8,
            subnet_ids: [][]const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            vpc_link_id: []const u8,
            vpc_link_status: ?[]const u8 = null,
            vpc_link_status_message: ?[]const u8 = null,
            vpc_link_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_date = "createdDate",
                    .name = "name",
                    .security_group_ids = "securityGroupIds",
                    .subnet_ids = "subnetIds",
                    .tags = "tags",
                    .vpc_link_id = "vpcLinkId",
                    .vpc_link_status = "vpcLinkStatus",
                    .vpc_link_status_message = "vpcLinkStatusMessage",
                    .vpc_link_version = "vpcLinkVersion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const import_api: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/apis",
        .success_code = 201,
    };

    action_name: []const u8 = "ImportApi",
    Request: type = struct {
        basepath: ?[]const u8 = null,
        body: []const u8,
        fail_on_warnings: ?bool = null,

        pub const http_query = .{
            .basepath = "basepath",
            .fail_on_warnings = "failOnWarnings",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .basepath = "Basepath",
                .body = "body",
                .fail_on_warnings = "FailOnWarnings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_api) } {
            return .{ .service_metadata = service_metadata, .action = import_api };
        }
    },
    Response: type = struct {
        api_endpoint: ?[]const u8 = null,
        api_gateway_managed: ?bool = null,
        api_id: ?[]const u8 = null,
        api_key_selection_expression: ?[]const u8 = null,
        cors_configuration: ?Cors = null,
        created_date: ?i64 = null,
        description: ?[]const u8 = null,
        disable_schema_validation: ?bool = null,
        disable_execute_api_endpoint: ?bool = null,
        import_info: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        protocol_type: ?[]const u8 = null,
        route_selection_expression: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_endpoint = "apiEndpoint",
                .api_gateway_managed = "apiGatewayManaged",
                .api_id = "apiId",
                .api_key_selection_expression = "apiKeySelectionExpression",
                .cors_configuration = "corsConfiguration",
                .created_date = "createdDate",
                .description = "description",
                .disable_schema_validation = "disableSchemaValidation",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .import_info = "importInfo",
                .name = "name",
                .protocol_type = "protocolType",
                .route_selection_expression = "routeSelectionExpression",
                .tags = "tags",
                .version = "version",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const reimport_api: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/apis/{ApiId}",
        .success_code = 201,
    };

    action_name: []const u8 = "ReimportApi",
    Request: type = struct {
        api_id: []const u8,
        basepath: ?[]const u8 = null,
        body: []const u8,
        fail_on_warnings: ?bool = null,

        pub const http_query = .{
            .basepath = "basepath",
            .fail_on_warnings = "failOnWarnings",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .basepath = "Basepath",
                .body = "body",
                .fail_on_warnings = "FailOnWarnings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reimport_api) } {
            return .{ .service_metadata = service_metadata, .action = reimport_api };
        }
    },
    Response: type = struct {
        api_endpoint: ?[]const u8 = null,
        api_gateway_managed: ?bool = null,
        api_id: ?[]const u8 = null,
        api_key_selection_expression: ?[]const u8 = null,
        cors_configuration: ?Cors = null,
        created_date: ?i64 = null,
        description: ?[]const u8 = null,
        disable_schema_validation: ?bool = null,
        disable_execute_api_endpoint: ?bool = null,
        import_info: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        protocol_type: ?[]const u8 = null,
        route_selection_expression: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_endpoint = "apiEndpoint",
                .api_gateway_managed = "apiGatewayManaged",
                .api_id = "apiId",
                .api_key_selection_expression = "apiKeySelectionExpression",
                .cors_configuration = "corsConfiguration",
                .created_date = "createdDate",
                .description = "description",
                .disable_schema_validation = "disableSchemaValidation",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .import_info = "importInfo",
                .name = "name",
                .protocol_type = "protocolType",
                .route_selection_expression = "routeSelectionExpression",
                .tags = "tags",
                .version = "version",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const reset_authorizers_cache: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/apis/{ApiId}/stages/{StageName}/cache/authorizers",
        .success_code = 204,
    };

    action_name: []const u8 = "ResetAuthorizersCache",
    Request: type = struct {
        api_id: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .stage_name = "StageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_authorizers_cache) } {
            return .{ .service_metadata = service_metadata, .action = reset_authorizers_cache };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/tags/{ResourceArn}",
        .success_code = 201,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_api: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApi",
    Request: type = struct {
        api_id: []const u8,
        api_key_selection_expression: ?[]const u8 = null,
        cors_configuration: ?Cors = null,
        credentials_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        disable_schema_validation: ?bool = null,
        disable_execute_api_endpoint: ?bool = null,
        name: ?[]const u8 = null,
        route_key: ?[]const u8 = null,
        route_selection_expression: ?[]const u8 = null,
        target: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .api_key_selection_expression = "apiKeySelectionExpression",
                .cors_configuration = "corsConfiguration",
                .credentials_arn = "credentialsArn",
                .description = "description",
                .disable_schema_validation = "disableSchemaValidation",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .name = "name",
                .route_key = "routeKey",
                .route_selection_expression = "routeSelectionExpression",
                .target = "target",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_api) } {
            return .{ .service_metadata = service_metadata, .action = update_api };
        }
    },
    Response: type = struct {
        api_endpoint: ?[]const u8 = null,
        api_gateway_managed: ?bool = null,
        api_id: ?[]const u8 = null,
        api_key_selection_expression: ?[]const u8 = null,
        cors_configuration: ?Cors = null,
        created_date: ?i64 = null,
        description: ?[]const u8 = null,
        disable_schema_validation: ?bool = null,
        disable_execute_api_endpoint: ?bool = null,
        import_info: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        protocol_type: ?[]const u8 = null,
        route_selection_expression: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_endpoint = "apiEndpoint",
                .api_gateway_managed = "apiGatewayManaged",
                .api_id = "apiId",
                .api_key_selection_expression = "apiKeySelectionExpression",
                .cors_configuration = "corsConfiguration",
                .created_date = "createdDate",
                .description = "description",
                .disable_schema_validation = "disableSchemaValidation",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .import_info = "importInfo",
                .name = "name",
                .protocol_type = "protocolType",
                .route_selection_expression = "routeSelectionExpression",
                .tags = "tags",
                .version = "version",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_api_mapping: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/domainnames/{DomainName}/apimappings/{ApiMappingId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApiMapping",
    Request: type = struct {
        api_id: []const u8,
        api_mapping_id: []const u8,
        api_mapping_key: ?[]const u8 = null,
        domain_name: []const u8,
        stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .api_mapping_id = "ApiMappingId",
                .api_mapping_key = "apiMappingKey",
                .domain_name = "DomainName",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_api_mapping) } {
            return .{ .service_metadata = service_metadata, .action = update_api_mapping };
        }
    },
    Response: type = struct {
        api_id: ?[]const u8 = null,
        api_mapping_id: ?[]const u8 = null,
        api_mapping_key: ?[]const u8 = null,
        stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .api_mapping_id = "apiMappingId",
                .api_mapping_key = "apiMappingKey",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_authorizer: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}/authorizers/{AuthorizerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAuthorizer",
    Request: type = struct {
        api_id: []const u8,
        authorizer_credentials_arn: ?[]const u8 = null,
        authorizer_id: []const u8,
        authorizer_payload_format_version: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,
        authorizer_type: ?[]const u8 = null,
        authorizer_uri: ?[]const u8 = null,
        enable_simple_responses: ?bool = null,
        identity_source: ?[][]const u8 = null,
        identity_validation_expression: ?[]const u8 = null,
        jwt_configuration: ?JWTConfiguration = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .authorizer_credentials_arn = "authorizerCredentialsArn",
                .authorizer_id = "AuthorizerId",
                .authorizer_payload_format_version = "authorizerPayloadFormatVersion",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
                .authorizer_type = "authorizerType",
                .authorizer_uri = "authorizerUri",
                .enable_simple_responses = "enableSimpleResponses",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .jwt_configuration = "jwtConfiguration",
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = update_authorizer };
        }
    },
    Response: type = struct {
        authorizer_credentials_arn: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        authorizer_payload_format_version: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,
        authorizer_type: ?[]const u8 = null,
        authorizer_uri: ?[]const u8 = null,
        enable_simple_responses: ?bool = null,
        identity_source: ?[][]const u8 = null,
        identity_validation_expression: ?[]const u8 = null,
        jwt_configuration: ?JWTConfiguration = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_credentials_arn = "authorizerCredentialsArn",
                .authorizer_id = "authorizerId",
                .authorizer_payload_format_version = "authorizerPayloadFormatVersion",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
                .authorizer_type = "authorizerType",
                .authorizer_uri = "authorizerUri",
                .enable_simple_responses = "enableSimpleResponses",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .jwt_configuration = "jwtConfiguration",
                .name = "name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_deployment: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}/deployments/{DeploymentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDeployment",
    Request: type = struct {
        api_id: []const u8,
        deployment_id: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .deployment_id = "DeploymentId",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_deployment) } {
            return .{ .service_metadata = service_metadata, .action = update_deployment };
        }
    },
    Response: type = struct {
        auto_deployed: ?bool = null,
        created_date: ?i64 = null,
        deployment_id: ?[]const u8 = null,
        deployment_status: ?[]const u8 = null,
        deployment_status_message: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_deployed = "autoDeployed",
                .created_date = "createdDate",
                .deployment_id = "deploymentId",
                .deployment_status = "deploymentStatus",
                .deployment_status_message = "deploymentStatusMessage",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_domain_name: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/domainnames/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDomainName",
    Request: type = struct {
        domain_name: []const u8,
        domain_name_configurations: ?[]DomainNameConfiguration = null,
        mutual_tls_authentication: ?MutualTlsAuthenticationInput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .domain_name_configurations = "domainNameConfigurations",
                .mutual_tls_authentication = "mutualTlsAuthentication",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain_name) } {
            return .{ .service_metadata = service_metadata, .action = update_domain_name };
        }
    },
    Response: type = struct {
        api_mapping_selection_expression: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        domain_name_configurations: ?[]DomainNameConfiguration = null,
        mutual_tls_authentication: ?MutualTlsAuthentication = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_mapping_selection_expression = "apiMappingSelectionExpression",
                .domain_name = "domainName",
                .domain_name_configurations = "domainNameConfigurations",
                .mutual_tls_authentication = "mutualTlsAuthentication",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_integration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}/integrations/{IntegrationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIntegration",
    Request: type = struct {
        api_id: []const u8,
        connection_id: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        content_handling_strategy: ?[]const u8 = null,
        credentials_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        integration_id: []const u8,
        integration_method: ?[]const u8 = null,
        integration_subtype: ?[]const u8 = null,
        integration_type: ?[]const u8 = null,
        integration_uri: ?[]const u8 = null,
        passthrough_behavior: ?[]const u8 = null,
        payload_format_version: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        template_selection_expression: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        tls_config: ?TlsConfigInput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .connection_id = "connectionId",
                .connection_type = "connectionType",
                .content_handling_strategy = "contentHandlingStrategy",
                .credentials_arn = "credentialsArn",
                .description = "description",
                .integration_id = "IntegrationId",
                .integration_method = "integrationMethod",
                .integration_subtype = "integrationSubtype",
                .integration_type = "integrationType",
                .integration_uri = "integrationUri",
                .passthrough_behavior = "passthroughBehavior",
                .payload_format_version = "payloadFormatVersion",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .response_parameters = "responseParameters",
                .template_selection_expression = "templateSelectionExpression",
                .timeout_in_millis = "timeoutInMillis",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_integration) } {
            return .{ .service_metadata = service_metadata, .action = update_integration };
        }
    },
    Response: type = struct {
        api_gateway_managed: ?bool = null,
        connection_id: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        content_handling_strategy: ?[]const u8 = null,
        credentials_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        integration_id: ?[]const u8 = null,
        integration_method: ?[]const u8 = null,
        integration_response_selection_expression: ?[]const u8 = null,
        integration_subtype: ?[]const u8 = null,
        integration_type: ?[]const u8 = null,
        integration_uri: ?[]const u8 = null,
        passthrough_behavior: ?[]const u8 = null,
        payload_format_version: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        template_selection_expression: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        tls_config: ?TlsConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_gateway_managed = "apiGatewayManaged",
                .connection_id = "connectionId",
                .connection_type = "connectionType",
                .content_handling_strategy = "contentHandlingStrategy",
                .credentials_arn = "credentialsArn",
                .description = "description",
                .integration_id = "integrationId",
                .integration_method = "integrationMethod",
                .integration_response_selection_expression = "integrationResponseSelectionExpression",
                .integration_subtype = "integrationSubtype",
                .integration_type = "integrationType",
                .integration_uri = "integrationUri",
                .passthrough_behavior = "passthroughBehavior",
                .payload_format_version = "payloadFormatVersion",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .response_parameters = "responseParameters",
                .template_selection_expression = "templateSelectionExpression",
                .timeout_in_millis = "timeoutInMillis",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_integration_response: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}/integrations/{IntegrationId}/integrationresponses/{IntegrationResponseId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIntegrationResponse",
    Request: type = struct {
        api_id: []const u8,
        content_handling_strategy: ?[]const u8 = null,
        integration_id: []const u8,
        integration_response_id: []const u8,
        integration_response_key: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        template_selection_expression: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .content_handling_strategy = "contentHandlingStrategy",
                .integration_id = "IntegrationId",
                .integration_response_id = "IntegrationResponseId",
                .integration_response_key = "integrationResponseKey",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .template_selection_expression = "templateSelectionExpression",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_integration_response) } {
            return .{ .service_metadata = service_metadata, .action = update_integration_response };
        }
    },
    Response: type = struct {
        content_handling_strategy: ?[]const u8 = null,
        integration_response_id: ?[]const u8 = null,
        integration_response_key: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        template_selection_expression: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_handling_strategy = "contentHandlingStrategy",
                .integration_response_id = "integrationResponseId",
                .integration_response_key = "integrationResponseKey",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .template_selection_expression = "templateSelectionExpression",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_model: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}/models/{ModelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateModel",
    Request: type = struct {
        api_id: []const u8,
        content_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        model_id: []const u8,
        name: ?[]const u8 = null,
        schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .content_type = "contentType",
                .description = "description",
                .model_id = "ModelId",
                .name = "name",
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_model) } {
            return .{ .service_metadata = service_metadata, .action = update_model };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        model_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .description = "description",
                .model_id = "modelId",
                .name = "name",
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_route: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoute",
    Request: type = struct {
        api_id: []const u8,
        api_key_required: ?bool = null,
        authorization_scopes: ?[][]const u8 = null,
        authorization_type: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        model_selection_expression: ?[]const u8 = null,
        operation_name: ?[]const u8 = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_id: []const u8,
        route_key: ?[]const u8 = null,
        route_response_selection_expression: ?[]const u8 = null,
        target: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .api_key_required = "apiKeyRequired",
                .authorization_scopes = "authorizationScopes",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .model_selection_expression = "modelSelectionExpression",
                .operation_name = "operationName",
                .request_models = "requestModels",
                .request_parameters = "requestParameters",
                .route_id = "RouteId",
                .route_key = "routeKey",
                .route_response_selection_expression = "routeResponseSelectionExpression",
                .target = "target",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_route) } {
            return .{ .service_metadata = service_metadata, .action = update_route };
        }
    },
    Response: type = struct {
        api_gateway_managed: ?bool = null,
        api_key_required: ?bool = null,
        authorization_scopes: ?[][]const u8 = null,
        authorization_type: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        model_selection_expression: ?[]const u8 = null,
        operation_name: ?[]const u8 = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_id: ?[]const u8 = null,
        route_key: ?[]const u8 = null,
        route_response_selection_expression: ?[]const u8 = null,
        target: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_gateway_managed = "apiGatewayManaged",
                .api_key_required = "apiKeyRequired",
                .authorization_scopes = "authorizationScopes",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .model_selection_expression = "modelSelectionExpression",
                .operation_name = "operationName",
                .request_models = "requestModels",
                .request_parameters = "requestParameters",
                .route_id = "routeId",
                .route_key = "routeKey",
                .route_response_selection_expression = "routeResponseSelectionExpression",
                .target = "target",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_route_response: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}/routes/{RouteId}/routeresponses/{RouteResponseId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRouteResponse",
    Request: type = struct {
        api_id: []const u8,
        model_selection_expression: ?[]const u8 = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_id: []const u8,
        route_response_id: []const u8,
        route_response_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "ApiId",
                .model_selection_expression = "modelSelectionExpression",
                .response_models = "responseModels",
                .response_parameters = "responseParameters",
                .route_id = "RouteId",
                .route_response_id = "RouteResponseId",
                .route_response_key = "routeResponseKey",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_route_response) } {
            return .{ .service_metadata = service_metadata, .action = update_route_response };
        }
    },
    Response: type = struct {
        model_selection_expression: ?[]const u8 = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ParameterConstraints = null,
        } = null,
        route_response_id: ?[]const u8 = null,
        route_response_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_selection_expression = "modelSelectionExpression",
                .response_models = "responseModels",
                .response_parameters = "responseParameters",
                .route_response_id = "routeResponseId",
                .route_response_key = "routeResponseKey",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_stage: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/apis/{ApiId}/stages/{StageName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStage",
    Request: type = struct {
        access_log_settings: ?AccessLogSettings = null,
        api_id: []const u8,
        auto_deploy: ?bool = null,
        client_certificate_id: ?[]const u8 = null,
        default_route_settings: ?RouteSettings = null,
        deployment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        route_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RouteSettings = null,
        } = null,
        stage_name: []const u8,
        stage_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_log_settings = "accessLogSettings",
                .api_id = "ApiId",
                .auto_deploy = "autoDeploy",
                .client_certificate_id = "clientCertificateId",
                .default_route_settings = "defaultRouteSettings",
                .deployment_id = "deploymentId",
                .description = "description",
                .route_settings = "routeSettings",
                .stage_name = "StageName",
                .stage_variables = "stageVariables",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "route_settings", field_name))
                return try serializeMap(self.route_settings, self.fieldNameFor("route_settings"), options, out_stream);
            if (std.mem.eql(u8, "stage_variables", field_name))
                return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_stage) } {
            return .{ .service_metadata = service_metadata, .action = update_stage };
        }
    },
    Response: type = struct {
        access_log_settings: ?AccessLogSettings = null,
        api_gateway_managed: ?bool = null,
        auto_deploy: ?bool = null,
        client_certificate_id: ?[]const u8 = null,
        created_date: ?i64 = null,
        default_route_settings: ?RouteSettings = null,
        deployment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        last_deployment_status_message: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        route_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RouteSettings = null,
        } = null,
        stage_name: ?[]const u8 = null,
        stage_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_log_settings = "accessLogSettings",
                .api_gateway_managed = "apiGatewayManaged",
                .auto_deploy = "autoDeploy",
                .client_certificate_id = "clientCertificateId",
                .created_date = "createdDate",
                .default_route_settings = "defaultRouteSettings",
                .deployment_id = "deploymentId",
                .description = "description",
                .last_deployment_status_message = "lastDeploymentStatusMessage",
                .last_updated_date = "lastUpdatedDate",
                .route_settings = "routeSettings",
                .stage_name = "stageName",
                .stage_variables = "stageVariables",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "route_settings", field_name))
                return try serializeMap(self.route_settings, self.fieldNameFor("route_settings"), options, out_stream);
            if (std.mem.eql(u8, "stage_variables", field_name))
                return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_vpc_link: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/vpclinks/{VpcLinkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVpcLink",
    Request: type = struct {
        name: ?[]const u8 = null,
        vpc_link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .vpc_link_id = "VpcLinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpc_link) } {
            return .{ .service_metadata = service_metadata, .action = update_vpc_link };
        }
    },
    Response: type = struct {
        created_date: ?i64 = null,
        name: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc_link_id: ?[]const u8 = null,
        vpc_link_status: ?[]const u8 = null,
        vpc_link_status_message: ?[]const u8 = null,
        vpc_link_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_date = "createdDate",
                .name = "name",
                .security_group_ids = "securityGroupIds",
                .subnet_ids = "subnetIds",
                .tags = "tags",
                .vpc_link_id = "vpcLinkId",
                .vpc_link_status = "vpcLinkStatus",
                .vpc_link_status_message = "vpcLinkStatusMessage",
                .vpc_link_version = "vpcLinkVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const RouteSettings = struct {
    data_trace_enabled: ?bool = null,
    detailed_metrics_enabled: ?bool = null,
    logging_level: ?[]const u8 = null,
    throttling_burst_limit: ?i64 = null,
    throttling_rate_limit: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_trace_enabled = "dataTraceEnabled",
            .detailed_metrics_enabled = "detailedMetricsEnabled",
            .logging_level = "loggingLevel",
            .throttling_burst_limit = "throttlingBurstLimit",
            .throttling_rate_limit = "throttlingRateLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessLogSettings = struct {
    destination_arn: ?[]const u8 = null,
    format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_arn = "destinationArn",
            .format = "format",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterConstraints = struct {
    required: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .required = "required",
        };
        return @field(mappings, field_name);
    }
};

pub const TlsConfig = struct {
    server_name_to_verify: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name_to_verify = "serverNameToVerify",
        };
        return @field(mappings, field_name);
    }
};

pub const TlsConfigInput = struct {
    server_name_to_verify: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name_to_verify = "serverNameToVerify",
        };
        return @field(mappings, field_name);
    }
};

pub const MutualTlsAuthentication = struct {
    truststore_uri: ?[]const u8 = null,
    truststore_version: ?[]const u8 = null,
    truststore_warnings: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .truststore_uri = "truststoreUri",
            .truststore_version = "truststoreVersion",
            .truststore_warnings = "truststoreWarnings",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainNameConfiguration = struct {
    api_gateway_domain_name: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    certificate_name: ?[]const u8 = null,
    certificate_upload_date: ?i64 = null,
    domain_name_status: ?[]const u8 = null,
    domain_name_status_message: ?[]const u8 = null,
    endpoint_type: ?[]const u8 = null,
    hosted_zone_id: ?[]const u8 = null,
    security_policy: ?[]const u8 = null,
    ownership_verification_certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_gateway_domain_name = "apiGatewayDomainName",
            .certificate_arn = "certificateArn",
            .certificate_name = "certificateName",
            .certificate_upload_date = "certificateUploadDate",
            .domain_name_status = "domainNameStatus",
            .domain_name_status_message = "domainNameStatusMessage",
            .endpoint_type = "endpointType",
            .hosted_zone_id = "hostedZoneId",
            .security_policy = "securityPolicy",
            .ownership_verification_certificate_arn = "ownershipVerificationCertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MutualTlsAuthenticationInput = struct {
    truststore_uri: ?[]const u8 = null,
    truststore_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .truststore_uri = "truststoreUri",
            .truststore_version = "truststoreVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const JWTConfiguration = struct {
    audience: ?[][]const u8 = null,
    issuer: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audience = "audience",
            .issuer = "issuer",
        };
        return @field(mappings, field_name);
    }
};

pub const Cors = struct {
    allow_credentials: ?bool = null,
    allow_headers: ?[][]const u8 = null,
    allow_methods: ?[][]const u8 = null,
    allow_origins: ?[][]const u8 = null,
    expose_headers: ?[][]const u8 = null,
    max_age: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_credentials = "allowCredentials",
            .allow_headers = "allowHeaders",
            .allow_methods = "allowMethods",
            .allow_origins = "allowOrigins",
            .expose_headers = "exposeHeaders",
            .max_age = "maxAge",
        };
        return @field(mappings, field_name);
    }
};
