const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-10-09";
pub const sdk_id: []const u8 = "AppConfig";
pub const arn_namespace: ?[]const u8 = "appconfig";
pub const endpoint_prefix: []const u8 = "appconfig";
pub const sigv4_name: []const u8 = "appconfig";
pub const name: []const u8 = "AmazonAppConfig";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-10-09",
    sdk_id: []const u8 = "AppConfig",
    arn_namespace: ?[]const u8 = "appconfig",
    endpoint_prefix: []const u8 = "appconfig",
    sigv4_name: []const u8 = "appconfig",
    name: []const u8 = "AmazonAppConfig",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_configuration_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{ApplicationId}/configurationprofiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateConfigurationProfile",
    Request: type = struct {
        application_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        location_uri: []const u8,
        retrieval_role_arn: ?[]const u8 = null,
        validators: ?[]Validator = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        type: ?[]const u8 = null,
        kms_key_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .name = "Name",
                .description = "Description",
                .location_uri = "LocationUri",
                .retrieval_role_arn = "RetrievalRoleArn",
                .validators = "Validators",
                .tags = "Tags",
                .type = "Type",
                .kms_key_identifier = "KmsKeyIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_profile };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        retrieval_role_arn: ?[]const u8 = null,
        validators: ?[]Validator = null,
        type: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        kms_key_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .location_uri = "LocationUri",
                .retrieval_role_arn = "RetrievalRoleArn",
                .validators = "Validators",
                .type = "Type",
                .kms_key_arn = "KmsKeyArn",
                .kms_key_identifier = "KmsKeyIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_deployment_strategy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deploymentstrategies",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDeploymentStrategy",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        deployment_duration_in_minutes: i64,
        final_bake_time_in_minutes: ?i64 = null,
        growth_factor: f32,
        growth_type: ?[]const u8 = null,
        replicate_to: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                .growth_factor = "GrowthFactor",
                .growth_type = "GrowthType",
                .replicate_to = "ReplicateTo",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deployment_strategy) } {
            return .{ .service_metadata = service_metadata, .action = create_deployment_strategy };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        deployment_duration_in_minutes: ?i64 = null,
        growth_type: ?[]const u8 = null,
        growth_factor: ?f32 = null,
        final_bake_time_in_minutes: ?i64 = null,
        replicate_to: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                .growth_type = "GrowthType",
                .growth_factor = "GrowthFactor",
                .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                .replicate_to = "ReplicateTo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{ApplicationId}/environments",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateEnvironment",
    Request: type = struct {
        application_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        monitors: ?[]Monitor = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .name = "Name",
                .description = "Description",
                .monitors = "Monitors",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_environment };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        state: ?[]const u8 = null,
        monitors: ?[]Monitor = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .state = "State",
                .monitors = "Monitors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_extension: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/extensions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateExtension",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        actions: []struct {
            key: ?[]const u8 = null,
            value: ?[]Action = null,
        },
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Parameter = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        latest_version_number: ?i64 = null,
        pub const http_header = .{
            .latest_version_number = "Latest-Version-Number",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .actions = "Actions",
                .parameters = "Parameters",
                .tags = "Tags",
                .latest_version_number = "LatestVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "actions", field_name))
                return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_extension) } {
            return .{ .service_metadata = service_metadata, .action = create_extension };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_number: ?i64 = null,
        arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        actions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]Action = null,
        } = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Parameter = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .version_number = "VersionNumber",
                .arn = "Arn",
                .description = "Description",
                .actions = "Actions",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "actions", field_name))
                return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_extension_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/extensionassociations",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateExtensionAssociation",
    Request: type = struct {
        extension_identifier: []const u8,
        extension_version_number: ?i64 = null,
        resource_identifier: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .extension_identifier = "ExtensionIdentifier",
                .extension_version_number = "ExtensionVersionNumber",
                .resource_identifier = "ResourceIdentifier",
                .parameters = "Parameters",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_extension_association) } {
            return .{ .service_metadata = service_metadata, .action = create_extension_association };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        extension_arn: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        extension_version_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .extension_arn = "ExtensionArn",
                .resource_arn = "ResourceArn",
                .arn = "Arn",
                .parameters = "Parameters",
                .extension_version_number = "ExtensionVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_hosted_configuration_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{ApplicationId}/configurationprofiles/{ConfigurationProfileId}/hostedconfigurationversions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateHostedConfigurationVersion",
    Request: type = struct {
        application_id: []const u8,
        configuration_profile_id: []const u8,
        description: ?[]const u8 = null,
        content: []const u8,
        content_type: []const u8,
        latest_version_number: ?i64 = null,
        version_label: ?[]const u8 = null,
        pub const http_header = .{
            .description = "Description",
            .content_type = "Content-Type",
            .latest_version_number = "Latest-Version-Number",
            .version_label = "VersionLabel",
        };

        pub const http_payload: []const u8 = "content";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
                .description = "Description",
                .content = "Content",
                .content_type = "ContentType",
                .latest_version_number = "LatestVersionNumber",
                .version_label = "VersionLabel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hosted_configuration_version) } {
            return .{ .service_metadata = service_metadata, .action = create_hosted_configuration_version };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        configuration_profile_id: ?[]const u8 = null,
        version_number: ?i64 = null,
        description: ?[]const u8 = null,
        content: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        version_label: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        pub const http_header = .{
            .application_id = "Application-Id",
            .configuration_profile_id = "Configuration-Profile-Id",
            .version_number = "Version-Number",
            .description = "Description",
            .content_type = "Content-Type",
            .version_label = "VersionLabel",
            .kms_key_arn = "KmsKeyArn",
        };

        pub const http_payload: []const u8 = "content";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
                .version_number = "VersionNumber",
                .description = "Description",
                .content = "Content",
                .content_type = "ContentType",
                .version_label = "VersionLabel",
                .kms_key_arn = "KmsKeyArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServer,
        PayloadTooLarge,
        ResourceNotFound,
        ServiceQuotaExceeded,
    },
} = .{};
pub const delete_application: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{ApplicationId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const delete_configuration_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{ApplicationId}/configurationprofiles/{ConfigurationProfileId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteConfigurationProfile",
    Request: type = struct {
        application_id: []const u8,
        configuration_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const delete_deployment_strategy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/deployementstrategies/{DeploymentStrategyId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDeploymentStrategy",
    Request: type = struct {
        deployment_strategy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_strategy_id = "DeploymentStrategyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_deployment_strategy) } {
            return .{ .service_metadata = service_metadata, .action = delete_deployment_strategy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const delete_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{ApplicationId}/environments/{EnvironmentId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteEnvironment",
    Request: type = struct {
        application_id: []const u8,
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const delete_extension: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/extensions/{ExtensionIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteExtension",
    Request: type = struct {
        extension_identifier: []const u8,
        version_number: ?i64 = null,

        pub const http_query = .{
            .version_number = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .extension_identifier = "ExtensionIdentifier",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_extension) } {
            return .{ .service_metadata = service_metadata, .action = delete_extension };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const delete_extension_association: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/extensionassociations/{ExtensionAssociationId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteExtensionAssociation",
    Request: type = struct {
        extension_association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .extension_association_id = "ExtensionAssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_extension_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_extension_association };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const delete_hosted_configuration_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{ApplicationId}/configurationprofiles/{ConfigurationProfileId}/hostedconfigurationversions/{VersionNumber}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteHostedConfigurationVersion",
    Request: type = struct {
        application_id: []const u8,
        configuration_profile_id: []const u8,
        version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_hosted_configuration_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_hosted_configuration_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplication",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application) } {
            return .{ .service_metadata = service_metadata, .action = get_application };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{Application}/environments/{Environment}/configurations/{Configuration}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfiguration",
    Request: type = struct {
        application: []const u8,
        environment: []const u8,
        configuration: []const u8,
        client_id: []const u8,
        client_configuration_version: ?[]const u8 = null,

        pub const http_query = .{
            .client_id = "client_id",
            .client_configuration_version = "client_configuration_version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "Application",
                .environment = "Environment",
                .configuration = "Configuration",
                .client_id = "ClientId",
                .client_configuration_version = "ClientConfigurationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration };
        }
    },
    Response: type = struct {
        content: ?[]const u8 = null,
        configuration_version: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        pub const http_header = .{
            .configuration_version = "Configuration-Version",
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "content";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .configuration_version = "ConfigurationVersion",
                .content_type = "ContentType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_configuration_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/configurationprofiles/{ConfigurationProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfigurationProfile",
    Request: type = struct {
        application_id: []const u8,
        configuration_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration_profile };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        retrieval_role_arn: ?[]const u8 = null,
        validators: ?[]Validator = null,
        type: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        kms_key_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .location_uri = "LocationUri",
                .retrieval_role_arn = "RetrievalRoleArn",
                .validators = "Validators",
                .type = "Type",
                .kms_key_arn = "KmsKeyArn",
                .kms_key_identifier = "KmsKeyIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_deployment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/environments/{EnvironmentId}/deployments/{DeploymentNumber}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeployment",
    Request: type = struct {
        application_id: []const u8,
        environment_id: []const u8,
        deployment_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .deployment_number = "DeploymentNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployment) } {
            return .{ .service_metadata = service_metadata, .action = get_deployment };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        deployment_strategy_id: ?[]const u8 = null,
        configuration_profile_id: ?[]const u8 = null,
        deployment_number: ?i64 = null,
        configuration_name: ?[]const u8 = null,
        configuration_location_uri: ?[]const u8 = null,
        configuration_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        deployment_duration_in_minutes: ?i64 = null,
        growth_type: ?[]const u8 = null,
        growth_factor: ?f32 = null,
        final_bake_time_in_minutes: ?i64 = null,
        state: ?[]const u8 = null,
        event_log: ?[]DeploymentEvent = null,
        percentage_complete: ?f32 = null,
        started_at: ?i64 = null,
        completed_at: ?i64 = null,
        applied_extensions: ?[]AppliedExtension = null,
        kms_key_arn: ?[]const u8 = null,
        kms_key_identifier: ?[]const u8 = null,
        version_label: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .deployment_strategy_id = "DeploymentStrategyId",
                .configuration_profile_id = "ConfigurationProfileId",
                .deployment_number = "DeploymentNumber",
                .configuration_name = "ConfigurationName",
                .configuration_location_uri = "ConfigurationLocationUri",
                .configuration_version = "ConfigurationVersion",
                .description = "Description",
                .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                .growth_type = "GrowthType",
                .growth_factor = "GrowthFactor",
                .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                .state = "State",
                .event_log = "EventLog",
                .percentage_complete = "PercentageComplete",
                .started_at = "StartedAt",
                .completed_at = "CompletedAt",
                .applied_extensions = "AppliedExtensions",
                .kms_key_arn = "KmsKeyArn",
                .kms_key_identifier = "KmsKeyIdentifier",
                .version_label = "VersionLabel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_deployment_strategy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/deploymentstrategies/{DeploymentStrategyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeploymentStrategy",
    Request: type = struct {
        deployment_strategy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_strategy_id = "DeploymentStrategyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployment_strategy) } {
            return .{ .service_metadata = service_metadata, .action = get_deployment_strategy };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        deployment_duration_in_minutes: ?i64 = null,
        growth_type: ?[]const u8 = null,
        growth_factor: ?f32 = null,
        final_bake_time_in_minutes: ?i64 = null,
        replicate_to: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                .growth_type = "GrowthType",
                .growth_factor = "GrowthFactor",
                .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                .replicate_to = "ReplicateTo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/environments/{EnvironmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironment",
    Request: type = struct {
        application_id: []const u8,
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_environment };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        state: ?[]const u8 = null,
        monitors: ?[]Monitor = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .state = "State",
                .monitors = "Monitors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_extension: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/extensions/{ExtensionIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExtension",
    Request: type = struct {
        extension_identifier: []const u8,
        version_number: ?i64 = null,

        pub const http_query = .{
            .version_number = "version_number",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .extension_identifier = "ExtensionIdentifier",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_extension) } {
            return .{ .service_metadata = service_metadata, .action = get_extension };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_number: ?i64 = null,
        arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        actions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]Action = null,
        } = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Parameter = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .version_number = "VersionNumber",
                .arn = "Arn",
                .description = "Description",
                .actions = "Actions",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "actions", field_name))
                return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_extension_association: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/extensionassociations/{ExtensionAssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExtensionAssociation",
    Request: type = struct {
        extension_association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .extension_association_id = "ExtensionAssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_extension_association) } {
            return .{ .service_metadata = service_metadata, .action = get_extension_association };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        extension_arn: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        extension_version_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .extension_arn = "ExtensionArn",
                .resource_arn = "ResourceArn",
                .arn = "Arn",
                .parameters = "Parameters",
                .extension_version_number = "ExtensionVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_hosted_configuration_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/configurationprofiles/{ConfigurationProfileId}/hostedconfigurationversions/{VersionNumber}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHostedConfigurationVersion",
    Request: type = struct {
        application_id: []const u8,
        configuration_profile_id: []const u8,
        version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_hosted_configuration_version) } {
            return .{ .service_metadata = service_metadata, .action = get_hosted_configuration_version };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        configuration_profile_id: ?[]const u8 = null,
        version_number: ?i64 = null,
        description: ?[]const u8 = null,
        content: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        version_label: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        pub const http_header = .{
            .application_id = "Application-Id",
            .configuration_profile_id = "Configuration-Profile-Id",
            .version_number = "Version-Number",
            .description = "Description",
            .content_type = "Content-Type",
            .version_label = "VersionLabel",
            .kms_key_arn = "KmsKeyArn",
        };

        pub const http_payload: []const u8 = "content";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
                .version_number = "VersionNumber",
                .description = "Description",
                .content = "Content",
                .content_type = "ContentType",
                .version_label = "VersionLabel",
                .kms_key_arn = "KmsKeyArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        items: ?[]Application = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
    },
} = .{};
pub const list_configuration_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/configurationprofiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurationProfiles",
    Request: type = struct {
        application_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        type: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
            .type = "type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_profiles };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            application_id: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            location_uri: ?[]const u8 = null,
            validator_types: ?[][]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .id = "Id",
                    .name = "Name",
                    .location_uri = "LocationUri",
                    .validator_types = "ValidatorTypes",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_deployments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/environments/{EnvironmentId}/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeployments",
    Request: type = struct {
        application_id: []const u8,
        environment_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_deployments) } {
            return .{ .service_metadata = service_metadata, .action = list_deployments };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            deployment_number: ?i64 = null,
            configuration_name: ?[]const u8 = null,
            configuration_version: ?[]const u8 = null,
            deployment_duration_in_minutes: ?i64 = null,
            growth_type: ?[]const u8 = null,
            growth_factor: ?f32 = null,
            final_bake_time_in_minutes: ?i64 = null,
            state: ?[]const u8 = null,
            percentage_complete: ?f32 = null,
            started_at: ?i64 = null,
            completed_at: ?i64 = null,
            version_label: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .deployment_number = "DeploymentNumber",
                    .configuration_name = "ConfigurationName",
                    .configuration_version = "ConfigurationVersion",
                    .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                    .growth_type = "GrowthType",
                    .growth_factor = "GrowthFactor",
                    .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                    .state = "State",
                    .percentage_complete = "PercentageComplete",
                    .started_at = "StartedAt",
                    .completed_at = "CompletedAt",
                    .version_label = "VersionLabel",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_deployment_strategies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/deploymentstrategies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeploymentStrategies",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_deployment_strategies) } {
            return .{ .service_metadata = service_metadata, .action = list_deployment_strategies };
        }
    },
    Response: type = struct {
        items: ?[]DeploymentStrategy = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
    },
} = .{};
pub const list_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/environments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironments",
    Request: type = struct {
        application_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_environments };
        }
    },
    Response: type = struct {
        items: ?[]Environment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_extension_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/extensionassociations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListExtensionAssociations",
    Request: type = struct {
        resource_identifier: ?[]const u8 = null,
        extension_identifier: ?[]const u8 = null,
        extension_version_number: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .resource_identifier = "resource_identifier",
            .extension_identifier = "extension_identifier",
            .extension_version_number = "extension_version_number",
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .extension_identifier = "ExtensionIdentifier",
                .extension_version_number = "ExtensionVersionNumber",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_extension_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_extension_associations };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            id: ?[]const u8 = null,
            extension_arn: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .extension_arn = "ExtensionArn",
                    .resource_arn = "ResourceArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
    },
} = .{};
pub const list_extensions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/extensions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListExtensions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
            .name = "name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_extensions) } {
            return .{ .service_metadata = service_metadata, .action = list_extensions };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version_number: ?i64 = null,
            arn: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .version_number = "VersionNumber",
                    .arn = "Arn",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
    },
} = .{};
pub const list_hosted_configuration_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/configurationprofiles/{ConfigurationProfileId}/hostedconfigurationversions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHostedConfigurationVersions",
    Request: type = struct {
        application_id: []const u8,
        configuration_profile_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        version_label: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
            .version_label = "version_label",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .version_label = "VersionLabel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hosted_configuration_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_hosted_configuration_versions };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            application_id: ?[]const u8 = null,
            configuration_profile_id: ?[]const u8 = null,
            version_number: ?i64 = null,
            description: ?[]const u8 = null,
            content_type: ?[]const u8 = null,
            version_label: ?[]const u8 = null,
            kms_key_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .configuration_profile_id = "ConfigurationProfileId",
                    .version_number = "VersionNumber",
                    .description = "Description",
                    .content_type = "ContentType",
                    .version_label = "VersionLabel",
                    .kms_key_arn = "KmsKeyArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const start_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{ApplicationId}/environments/{EnvironmentId}/deployments",
        .success_code = 201,
    };

    action_name: []const u8 = "StartDeployment",
    Request: type = struct {
        application_id: []const u8,
        environment_id: []const u8,
        deployment_strategy_id: []const u8,
        configuration_profile_id: []const u8,
        configuration_version: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        kms_key_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .deployment_strategy_id = "DeploymentStrategyId",
                .configuration_profile_id = "ConfigurationProfileId",
                .configuration_version = "ConfigurationVersion",
                .description = "Description",
                .tags = "Tags",
                .kms_key_identifier = "KmsKeyIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_deployment) } {
            return .{ .service_metadata = service_metadata, .action = start_deployment };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        deployment_strategy_id: ?[]const u8 = null,
        configuration_profile_id: ?[]const u8 = null,
        deployment_number: ?i64 = null,
        configuration_name: ?[]const u8 = null,
        configuration_location_uri: ?[]const u8 = null,
        configuration_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        deployment_duration_in_minutes: ?i64 = null,
        growth_type: ?[]const u8 = null,
        growth_factor: ?f32 = null,
        final_bake_time_in_minutes: ?i64 = null,
        state: ?[]const u8 = null,
        event_log: ?[]DeploymentEvent = null,
        percentage_complete: ?f32 = null,
        started_at: ?i64 = null,
        completed_at: ?i64 = null,
        applied_extensions: ?[]AppliedExtension = null,
        kms_key_arn: ?[]const u8 = null,
        kms_key_identifier: ?[]const u8 = null,
        version_label: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .deployment_strategy_id = "DeploymentStrategyId",
                .configuration_profile_id = "ConfigurationProfileId",
                .deployment_number = "DeploymentNumber",
                .configuration_name = "ConfigurationName",
                .configuration_location_uri = "ConfigurationLocationUri",
                .configuration_version = "ConfigurationVersion",
                .description = "Description",
                .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                .growth_type = "GrowthType",
                .growth_factor = "GrowthFactor",
                .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                .state = "State",
                .event_log = "EventLog",
                .percentage_complete = "PercentageComplete",
                .started_at = "StartedAt",
                .completed_at = "CompletedAt",
                .applied_extensions = "AppliedExtensions",
                .kms_key_arn = "KmsKeyArn",
                .kms_key_identifier = "KmsKeyIdentifier",
                .version_label = "VersionLabel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const stop_deployment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{ApplicationId}/environments/{EnvironmentId}/deployments/{DeploymentNumber}",
        .success_code = 202,
    };

    action_name: []const u8 = "StopDeployment",
    Request: type = struct {
        application_id: []const u8,
        environment_id: []const u8,
        deployment_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .deployment_number = "DeploymentNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_deployment) } {
            return .{ .service_metadata = service_metadata, .action = stop_deployment };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        deployment_strategy_id: ?[]const u8 = null,
        configuration_profile_id: ?[]const u8 = null,
        deployment_number: ?i64 = null,
        configuration_name: ?[]const u8 = null,
        configuration_location_uri: ?[]const u8 = null,
        configuration_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        deployment_duration_in_minutes: ?i64 = null,
        growth_type: ?[]const u8 = null,
        growth_factor: ?f32 = null,
        final_bake_time_in_minutes: ?i64 = null,
        state: ?[]const u8 = null,
        event_log: ?[]DeploymentEvent = null,
        percentage_complete: ?f32 = null,
        started_at: ?i64 = null,
        completed_at: ?i64 = null,
        applied_extensions: ?[]AppliedExtension = null,
        kms_key_arn: ?[]const u8 = null,
        kms_key_identifier: ?[]const u8 = null,
        version_label: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .deployment_strategy_id = "DeploymentStrategyId",
                .configuration_profile_id = "ConfigurationProfileId",
                .deployment_number = "DeploymentNumber",
                .configuration_name = "ConfigurationName",
                .configuration_location_uri = "ConfigurationLocationUri",
                .configuration_version = "ConfigurationVersion",
                .description = "Description",
                .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                .growth_type = "GrowthType",
                .growth_factor = "GrowthFactor",
                .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                .state = "State",
                .event_log = "EventLog",
                .percentage_complete = "PercentageComplete",
                .started_at = "StartedAt",
                .completed_at = "CompletedAt",
                .applied_extensions = "AppliedExtensions",
                .kms_key_arn = "KmsKeyArn",
                .kms_key_identifier = "KmsKeyIdentifier",
                .version_label = "VersionLabel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_application: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/applications/{ApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        application_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_configuration_profile: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/applications/{ApplicationId}/configurationprofiles/{ConfigurationProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConfigurationProfile",
    Request: type = struct {
        application_id: []const u8,
        configuration_profile_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        retrieval_role_arn: ?[]const u8 = null,
        validators: ?[]Validator = null,
        kms_key_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
                .name = "Name",
                .description = "Description",
                .retrieval_role_arn = "RetrievalRoleArn",
                .validators = "Validators",
                .kms_key_identifier = "KmsKeyIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_profile };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        retrieval_role_arn: ?[]const u8 = null,
        validators: ?[]Validator = null,
        type: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        kms_key_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .location_uri = "LocationUri",
                .retrieval_role_arn = "RetrievalRoleArn",
                .validators = "Validators",
                .type = "Type",
                .kms_key_arn = "KmsKeyArn",
                .kms_key_identifier = "KmsKeyIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_deployment_strategy: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/deploymentstrategies/{DeploymentStrategyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDeploymentStrategy",
    Request: type = struct {
        deployment_strategy_id: []const u8,
        description: ?[]const u8 = null,
        deployment_duration_in_minutes: ?i64 = null,
        final_bake_time_in_minutes: ?i64 = null,
        growth_factor: ?f32 = null,
        growth_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_strategy_id = "DeploymentStrategyId",
                .description = "Description",
                .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                .growth_factor = "GrowthFactor",
                .growth_type = "GrowthType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_deployment_strategy) } {
            return .{ .service_metadata = service_metadata, .action = update_deployment_strategy };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        deployment_duration_in_minutes: ?i64 = null,
        growth_type: ?[]const u8 = null,
        growth_factor: ?f32 = null,
        final_bake_time_in_minutes: ?i64 = null,
        replicate_to: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
                .growth_type = "GrowthType",
                .growth_factor = "GrowthFactor",
                .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
                .replicate_to = "ReplicateTo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_environment: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/applications/{ApplicationId}/environments/{EnvironmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEnvironment",
    Request: type = struct {
        application_id: []const u8,
        environment_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        monitors: ?[]Monitor = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .name = "Name",
                .description = "Description",
                .monitors = "Monitors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_environment };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        state: ?[]const u8 = null,
        monitors: ?[]Monitor = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .state = "State",
                .monitors = "Monitors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_extension: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/extensions/{ExtensionIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateExtension",
    Request: type = struct {
        extension_identifier: []const u8,
        description: ?[]const u8 = null,
        actions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]Action = null,
        } = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Parameter = null,
        } = null,
        version_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .extension_identifier = "ExtensionIdentifier",
                .description = "Description",
                .actions = "Actions",
                .parameters = "Parameters",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "actions", field_name))
                return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_extension) } {
            return .{ .service_metadata = service_metadata, .action = update_extension };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_number: ?i64 = null,
        arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        actions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]Action = null,
        } = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Parameter = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .version_number = "VersionNumber",
                .arn = "Arn",
                .description = "Description",
                .actions = "Actions",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "actions", field_name))
                return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_extension_association: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/extensionassociations/{ExtensionAssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateExtensionAssociation",
    Request: type = struct {
        extension_association_id: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .extension_association_id = "ExtensionAssociationId",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_extension_association) } {
            return .{ .service_metadata = service_metadata, .action = update_extension_association };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        extension_arn: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        extension_version_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .extension_arn = "ExtensionArn",
                .resource_arn = "ResourceArn",
                .arn = "Arn",
                .parameters = "Parameters",
                .extension_version_number = "ExtensionVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const validate_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{ApplicationId}/configurationprofiles/{ConfigurationProfileId}/validators",
        .success_code = 204,
    };

    action_name: []const u8 = "ValidateConfiguration",
    Request: type = struct {
        application_id: []const u8,
        configuration_profile_id: []const u8,
        configuration_version: []const u8,

        pub const http_query = .{
            .configuration_version = "configuration_version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .configuration_profile_id = "ConfigurationProfileId",
                .configuration_version = "ConfigurationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_configuration) } {
            return .{ .service_metadata = service_metadata, .action = validate_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};

pub const Parameter = struct {
    description: ?[]const u8 = null,
    required: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .required = "Required",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    uri: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .uri = "Uri",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Monitor = struct {
    alarm_arn: []const u8,
    alarm_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alarm_arn = "AlarmArn",
            .alarm_role_arn = "AlarmRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Validator = struct {
    type: []const u8,
    content: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const AppliedExtension = struct {
    extension_id: ?[]const u8 = null,
    extension_association_id: ?[]const u8 = null,
    version_number: ?i64 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .extension_id = "ExtensionId",
            .extension_association_id = "ExtensionAssociationId",
            .version_number = "VersionNumber",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const DeploymentEvent = struct {
    event_type: ?[]const u8 = null,
    triggered_by: ?[]const u8 = null,
    description: ?[]const u8 = null,
    action_invocations: ?[]ActionInvocation = null,
    occurred_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_type = "EventType",
            .triggered_by = "TriggeredBy",
            .description = "Description",
            .action_invocations = "ActionInvocations",
            .occurred_at = "OccurredAt",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionInvocation = struct {
    extension_identifier: ?[]const u8 = null,
    action_name: ?[]const u8 = null,
    uri: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    invocation_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .extension_identifier = "ExtensionIdentifier",
            .action_name = "ActionName",
            .uri = "Uri",
            .role_arn = "RoleArn",
            .error_message = "ErrorMessage",
            .error_code = "ErrorCode",
            .invocation_id = "InvocationId",
        };
        return @field(mappings, field_name);
    }
};

pub const Environment = struct {
    application_id: ?[]const u8 = null,
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    state: ?[]const u8 = null,
    monitors: ?[]Monitor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .id = "Id",
            .name = "Name",
            .description = "Description",
            .state = "State",
            .monitors = "Monitors",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentStrategy = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    deployment_duration_in_minutes: ?i64 = null,
    growth_type: ?[]const u8 = null,
    growth_factor: ?f32 = null,
    final_bake_time_in_minutes: ?i64 = null,
    replicate_to: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .description = "Description",
            .deployment_duration_in_minutes = "DeploymentDurationInMinutes",
            .growth_type = "GrowthType",
            .growth_factor = "GrowthFactor",
            .final_bake_time_in_minutes = "FinalBakeTimeInMinutes",
            .replicate_to = "ReplicateTo",
        };
        return @field(mappings, field_name);
    }
};

pub const Application = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};
