const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-05-19";
pub const sdk_id: []const u8 = "AppFabric";
pub const arn_namespace: ?[]const u8 = "appfabric";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "appfabric";
pub const name: []const u8 = "FabricFrontEndService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-05-19",
    sdk_id: []const u8 = "AppFabric",
    arn_namespace: ?[]const u8 = "appfabric",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "appfabric",
    name: []const u8 = "FabricFrontEndService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_user_access_tasks: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/useraccess/batchget",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetUserAccessTasks",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        task_id_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .task_id_list = "taskIdList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_user_access_tasks) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_user_access_tasks };
        }
    },
    Response: type = struct {
        user_access_results_list: ?[]struct {
            app: ?[]const u8 = null,
            tenant_id: ?[]const u8 = null,
            tenant_display_name: ?[]const u8 = null,
            task_id: ?[]const u8 = null,
            result_status: ?[]const u8 = null,
            email: ?[]const u8 = null,
            user_id: ?[]const u8 = null,
            user_full_name: ?[]const u8 = null,
            user_first_name: ?[]const u8 = null,
            user_last_name: ?[]const u8 = null,
            user_status: ?[]const u8 = null,
            task_error: ?TaskError = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app = "app",
                    .tenant_id = "tenantId",
                    .tenant_display_name = "tenantDisplayName",
                    .task_id = "taskId",
                    .result_status = "resultStatus",
                    .email = "email",
                    .user_id = "userId",
                    .user_full_name = "userFullName",
                    .user_first_name = "userFirstName",
                    .user_last_name = "userLastName",
                    .user_status = "userStatus",
                    .task_error = "taskError",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_access_results_list = "userAccessResultsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const connect_app_authorization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/appbundles/{appBundleIdentifier}/appauthorizations/{appAuthorizationIdentifier}/connect",
        .success_code = 200,
    };

    action_name: []const u8 = "ConnectAppAuthorization",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        app_authorization_identifier: []const u8,
        auth_request: ?struct {
            redirect_uri: []const u8,
            code: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .redirect_uri = "redirectUri",
                    .code = "code",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .app_authorization_identifier = "appAuthorizationIdentifier",
                .auth_request = "authRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(connect_app_authorization) } {
            return .{ .service_metadata = service_metadata, .action = connect_app_authorization };
        }
    },
    Response: type = struct {
        app_authorization_summary: AppAuthorizationSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_authorization_summary = "appAuthorizationSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_app_authorization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/appbundles/{appBundleIdentifier}/appauthorizations",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppAuthorization",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        app: []const u8,
        credential: Credential,
        tenant: Tenant,
        auth_type: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .app = "app",
                .credential = "credential",
                .tenant = "tenant",
                .auth_type = "authType",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_authorization) } {
            return .{ .service_metadata = service_metadata, .action = create_app_authorization };
        }
    },
    Response: type = struct {
        app_authorization: AppAuthorization,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_authorization = "appAuthorization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_app_bundle: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/appbundles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppBundle",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        customer_managed_key_identifier: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .customer_managed_key_identifier = "customerManagedKeyIdentifier",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_bundle) } {
            return .{ .service_metadata = service_metadata, .action = create_app_bundle };
        }
    },
    Response: type = struct {
        app_bundle: AppBundle,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle = "appBundle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_ingestion: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateIngestion",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        app: []const u8,
        tenant_id: []const u8,
        ingestion_type: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .app = "app",
                .tenant_id = "tenantId",
                .ingestion_type = "ingestionType",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = create_ingestion };
        }
    },
    Response: type = struct {
        ingestion: Ingestion,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion = "ingestion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_ingestion_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}/ingestiondestinations",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateIngestionDestination",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        ingestion_identifier: []const u8,
        processing_configuration: ProcessingConfiguration,
        destination_configuration: DestinationConfiguration,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .ingestion_identifier = "ingestionIdentifier",
                .processing_configuration = "processingConfiguration",
                .destination_configuration = "destinationConfiguration",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ingestion_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_ingestion_destination };
        }
    },
    Response: type = struct {
        ingestion_destination: IngestionDestination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion_destination = "ingestionDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_app_authorization: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/appbundles/{appBundleIdentifier}/appauthorizations/{appAuthorizationIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppAuthorization",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        app_authorization_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .app_authorization_identifier = "appAuthorizationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_authorization) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_authorization };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_app_bundle: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/appbundles/{appBundleIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppBundle",
    Request: type = struct {
        app_bundle_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_bundle) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_bundle };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_ingestion: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIngestion",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        ingestion_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .ingestion_identifier = "ingestionIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = delete_ingestion };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_ingestion_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}/ingestiondestinations/{ingestionDestinationIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIngestionDestination",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        ingestion_identifier: []const u8,
        ingestion_destination_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .ingestion_identifier = "ingestionIdentifier",
                .ingestion_destination_identifier = "ingestionDestinationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ingestion_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_ingestion_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_app_authorization: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/appbundles/{appBundleIdentifier}/appauthorizations/{appAuthorizationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAppAuthorization",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        app_authorization_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .app_authorization_identifier = "appAuthorizationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_authorization) } {
            return .{ .service_metadata = service_metadata, .action = get_app_authorization };
        }
    },
    Response: type = struct {
        app_authorization: AppAuthorization,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_authorization = "appAuthorization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_app_bundle: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/appbundles/{appBundleIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAppBundle",
    Request: type = struct {
        app_bundle_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_bundle) } {
            return .{ .service_metadata = service_metadata, .action = get_app_bundle };
        }
    },
    Response: type = struct {
        app_bundle: AppBundle,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle = "appBundle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_ingestion: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIngestion",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        ingestion_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .ingestion_identifier = "ingestionIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = get_ingestion };
        }
    },
    Response: type = struct {
        ingestion: Ingestion,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion = "ingestion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_ingestion_destination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}/ingestiondestinations/{ingestionDestinationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIngestionDestination",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        ingestion_identifier: []const u8,
        ingestion_destination_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .ingestion_identifier = "ingestionIdentifier",
                .ingestion_destination_identifier = "ingestionDestinationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ingestion_destination) } {
            return .{ .service_metadata = service_metadata, .action = get_ingestion_destination };
        }
    },
    Response: type = struct {
        ingestion_destination: IngestionDestination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion_destination = "ingestionDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_authorizations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/appbundles/{appBundleIdentifier}/appauthorizations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppAuthorizations",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_authorizations) } {
            return .{ .service_metadata = service_metadata, .action = list_app_authorizations };
        }
    },
    Response: type = struct {
        app_authorization_summary_list: []AppAuthorizationSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_authorization_summary_list = "appAuthorizationSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_bundles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/appbundles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppBundles",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_bundles) } {
            return .{ .service_metadata = service_metadata, .action = list_app_bundles };
        }
    },
    Response: type = struct {
        app_bundle_summary_list: []struct {
            arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_summary_list = "appBundleSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_ingestion_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}/ingestiondestinations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIngestionDestinations",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        ingestion_identifier: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .ingestion_identifier = "ingestionIdentifier",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ingestion_destinations) } {
            return .{ .service_metadata = service_metadata, .action = list_ingestion_destinations };
        }
    },
    Response: type = struct {
        ingestion_destinations: []struct {
            arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion_destinations = "ingestionDestinations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_ingestions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIngestions",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ingestions) } {
            return .{ .service_metadata = service_metadata, .action = list_ingestions };
        }
    },
    Response: type = struct {
        ingestions: []struct {
            arn: []const u8,
            app: []const u8,
            tenant_id: []const u8,
            state: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .app = "app",
                    .tenant_id = "tenantId",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestions = "ingestions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_ingestion: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartIngestion",
    Request: type = struct {
        ingestion_identifier: []const u8,
        app_bundle_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion_identifier = "ingestionIdentifier",
                .app_bundle_identifier = "appBundleIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = start_ingestion };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_user_access_tasks: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/useraccess/start",
        .success_code = 201,
    };

    action_name: []const u8 = "StartUserAccessTasks",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        email: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .email = "email",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_user_access_tasks) } {
            return .{ .service_metadata = service_metadata, .action = start_user_access_tasks };
        }
    },
    Response: type = struct {
        user_access_tasks_list: ?[]struct {
            app: []const u8,
            tenant_id: []const u8,
            task_id: ?[]const u8 = null,
            @"error": ?TaskError = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app = "app",
                    .tenant_id = "tenantId",
                    .task_id = "taskId",
                    .@"error" = "error",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_access_tasks_list = "userAccessTasksList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_ingestion: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopIngestion",
    Request: type = struct {
        ingestion_identifier: []const u8,
        app_bundle_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion_identifier = "ingestionIdentifier",
                .app_bundle_identifier = "appBundleIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = stop_ingestion };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_app_authorization: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/appbundles/{appBundleIdentifier}/appauthorizations/{appAuthorizationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppAuthorization",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        app_authorization_identifier: []const u8,
        credential: ?Credential = null,
        tenant: ?Tenant = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .app_authorization_identifier = "appAuthorizationIdentifier",
                .credential = "credential",
                .tenant = "tenant",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_authorization) } {
            return .{ .service_metadata = service_metadata, .action = update_app_authorization };
        }
    },
    Response: type = struct {
        app_authorization: AppAuthorization,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_authorization = "appAuthorization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_ingestion_destination: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/appbundles/{appBundleIdentifier}/ingestions/{ingestionIdentifier}/ingestiondestinations/{ingestionDestinationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIngestionDestination",
    Request: type = struct {
        app_bundle_identifier: []const u8,
        ingestion_identifier: []const u8,
        ingestion_destination_identifier: []const u8,
        destination_configuration: DestinationConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_bundle_identifier = "appBundleIdentifier",
                .ingestion_identifier = "ingestionIdentifier",
                .ingestion_destination_identifier = "ingestionDestinationIdentifier",
                .destination_configuration = "destinationConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ingestion_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_ingestion_destination };
        }
    },
    Response: type = struct {
        ingestion_destination: IngestionDestination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion_destination = "ingestionDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const IngestionDestination = struct {
    arn: []const u8,
    ingestion_arn: []const u8,
    processing_configuration: ProcessingConfiguration,
    destination_configuration: DestinationConfiguration,
    status: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .ingestion_arn = "ingestionArn",
            .processing_configuration = "processingConfiguration",
            .destination_configuration = "destinationConfiguration",
            .status = "status",
            .status_reason = "statusReason",
            .created_at = "createdAt",
            .updated_at = "updatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfiguration = union {
    audit_log: ?AuditLogDestinationConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit_log = "auditLog",
        };
        return @field(mappings, field_name);
    }
};

pub const AuditLogDestinationConfiguration = struct {
    destination: Destination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = union {
    s3_bucket: ?S3Bucket,
    firehose_stream: ?FirehoseStream,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .firehose_stream = "firehoseStream",
        };
        return @field(mappings, field_name);
    }
};

pub const FirehoseStream = struct {
    stream_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_name = "streamName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Bucket = struct {
    bucket_name: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingConfiguration = union {
    audit_log: ?AuditLogProcessingConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit_log = "auditLog",
        };
        return @field(mappings, field_name);
    }
};

pub const AuditLogProcessingConfiguration = struct {
    schema: []const u8,
    format: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema = "schema",
            .format = "format",
        };
        return @field(mappings, field_name);
    }
};

pub const AppAuthorization = struct {
    app_authorization_arn: []const u8,
    app_bundle_arn: []const u8,
    app: []const u8,
    tenant: Tenant,
    auth_type: []const u8,
    status: []const u8,
    created_at: i64,
    updated_at: i64,
    persona: ?[]const u8 = null,
    auth_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_authorization_arn = "appAuthorizationArn",
            .app_bundle_arn = "appBundleArn",
            .app = "app",
            .tenant = "tenant",
            .auth_type = "authType",
            .status = "status",
            .created_at = "createdAt",
            .updated_at = "updatedAt",
            .persona = "persona",
            .auth_url = "authUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const Tenant = struct {
    tenant_identifier: []const u8,
    tenant_display_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tenant_identifier = "tenantIdentifier",
            .tenant_display_name = "tenantDisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const Credential = union {
    oauth2_credential: ?Oauth2Credential,
    api_key_credential: ?ApiKeyCredential,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .oauth2_credential = "oauth2Credential",
            .api_key_credential = "apiKeyCredential",
        };
        return @field(mappings, field_name);
    }
};

pub const ApiKeyCredential = struct {
    api_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_key = "apiKey",
        };
        return @field(mappings, field_name);
    }
};

pub const Oauth2Credential = struct {
    client_id: []const u8,
    client_secret: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "clientId",
            .client_secret = "clientSecret",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskError = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const AppAuthorizationSummary = struct {
    app_authorization_arn: []const u8,
    app_bundle_arn: []const u8,
    app: []const u8,
    tenant: Tenant,
    status: []const u8,
    updated_at: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_authorization_arn = "appAuthorizationArn",
            .app_bundle_arn = "appBundleArn",
            .app = "app",
            .tenant = "tenant",
            .status = "status",
            .updated_at = "updatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Ingestion = struct {
    arn: []const u8,
    app_bundle_arn: []const u8,
    app: []const u8,
    tenant_id: []const u8,
    created_at: i64,
    updated_at: i64,
    state: []const u8,
    ingestion_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .app_bundle_arn = "appBundleArn",
            .app = "app",
            .tenant_id = "tenantId",
            .created_at = "createdAt",
            .updated_at = "updatedAt",
            .state = "state",
            .ingestion_type = "ingestionType",
        };
        return @field(mappings, field_name);
    }
};

pub const AppBundle = struct {
    arn: []const u8,
    customer_managed_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .customer_managed_key_arn = "customerManagedKeyArn",
        };
        return @field(mappings, field_name);
    }
};
