const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-29";
pub const sdk_id: []const u8 = "AppIntegrations";
pub const arn_namespace: ?[]const u8 = "app-integrations";
pub const endpoint_prefix: []const u8 = "app-integrations";
pub const sigv4_name: []const u8 = "app-integrations";
pub const name: []const u8 = "AmazonAppIntegrationService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-29",
    sdk_id: []const u8 = "AppIntegrations",
    arn_namespace: ?[]const u8 = "app-integrations",
    endpoint_prefix: []const u8 = "app-integrations",
    sigv4_name: []const u8 = "app-integrations",
    name: []const u8 = "AmazonAppIntegrationService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        name: []const u8,
        namespace: []const u8,
        description: ?[]const u8 = null,
        application_source_config: ApplicationSourceConfig,
        subscriptions: ?[]Subscription = null,
        publications: ?[]Publication = null,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        permissions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .namespace = "Namespace",
                .description = "Description",
                .application_source_config = "ApplicationSourceConfig",
                .subscriptions = "Subscriptions",
                .publications = "Publications",
                .client_token = "ClientToken",
                .tags = "Tags",
                .permissions = "Permissions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateResource,
        InternalServiceError,
        InvalidRequest,
        ResourceQuotaExceeded,
        Throttling,
        UnsupportedOperation,
    },
} = .{};
pub const create_data_integration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/dataIntegrations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataIntegration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        kms_key: []const u8,
        source_uri: []const u8,
        schedule_config: ?ScheduleConfiguration = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,
        file_configuration: ?FileConfiguration = null,
        object_configuration: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .kms_key = "KmsKey",
                .source_uri = "SourceURI",
                .schedule_config = "ScheduleConfig",
                .tags = "Tags",
                .client_token = "ClientToken",
                .file_configuration = "FileConfiguration",
                .object_configuration = "ObjectConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "object_configuration", field_name))
                return try serializeMap(self.object_configuration, self.fieldNameFor("object_configuration"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_integration) } {
            return .{ .service_metadata = service_metadata, .action = create_data_integration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        kms_key: ?[]const u8 = null,
        source_uri: ?[]const u8 = null,
        schedule_configuration: ?ScheduleConfiguration = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,
        file_configuration: ?FileConfiguration = null,
        object_configuration: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .kms_key = "KmsKey",
                .source_uri = "SourceURI",
                .schedule_configuration = "ScheduleConfiguration",
                .tags = "Tags",
                .client_token = "ClientToken",
                .file_configuration = "FileConfiguration",
                .object_configuration = "ObjectConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "object_configuration", field_name))
                return try serializeMap(self.object_configuration, self.fieldNameFor("object_configuration"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateResource,
        InternalServiceError,
        InvalidRequest,
        ResourceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_event_integration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/eventIntegrations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEventIntegration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        event_filter: EventFilter,
        event_bridge_bus: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .event_filter = "EventFilter",
                .event_bridge_bus = "EventBridgeBus",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_integration) } {
            return .{ .service_metadata = service_metadata, .action = create_event_integration };
        }
    },
    Response: type = struct {
        event_integration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_integration_arn = "EventIntegrationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateResource,
        InternalServiceError,
        InvalidRequest,
        ResourceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const delete_application: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_data_integration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/dataIntegrations/{DataIntegrationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataIntegration",
    Request: type = struct {
        data_integration_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_integration_identifier = "DataIntegrationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_integration) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_integration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_event_integration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/eventIntegrations/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEventIntegration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_integration) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_integration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplication",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application) } {
            return .{ .service_metadata = service_metadata, .action = get_application };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        description: ?[]const u8 = null,
        application_source_config: ?ApplicationSourceConfig = null,
        subscriptions: ?[]Subscription = null,
        publications: ?[]Publication = null,
        created_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        permissions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .namespace = "Namespace",
                .description = "Description",
                .application_source_config = "ApplicationSourceConfig",
                .subscriptions = "Subscriptions",
                .publications = "Publications",
                .created_time = "CreatedTime",
                .last_modified_time = "LastModifiedTime",
                .tags = "Tags",
                .permissions = "Permissions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_data_integration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/dataIntegrations/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataIntegration",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_integration) } {
            return .{ .service_metadata = service_metadata, .action = get_data_integration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        kms_key: ?[]const u8 = null,
        source_uri: ?[]const u8 = null,
        schedule_configuration: ?ScheduleConfiguration = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        file_configuration: ?FileConfiguration = null,
        object_configuration: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .kms_key = "KmsKey",
                .source_uri = "SourceURI",
                .schedule_configuration = "ScheduleConfiguration",
                .tags = "Tags",
                .file_configuration = "FileConfiguration",
                .object_configuration = "ObjectConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "object_configuration", field_name))
                return try serializeMap(self.object_configuration, self.fieldNameFor("object_configuration"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_event_integration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/eventIntegrations/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEventIntegration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_integration) } {
            return .{ .service_metadata = service_metadata, .action = get_event_integration };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        event_integration_arn: ?[]const u8 = null,
        event_bridge_bus: ?[]const u8 = null,
        event_filter: ?EventFilter = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .event_integration_arn = "EventIntegrationArn",
                .event_bridge_bus = "EventBridgeBus",
                .event_filter = "EventFilter",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_application_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplicationAssociations",
    Request: type = struct {
        application_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_application_associations };
        }
    },
    Response: type = struct {
        application_associations: ?[]struct {
            application_association_arn: ?[]const u8 = null,
            application_arn: ?[]const u8 = null,
            client_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_association_arn = "ApplicationAssociationArn",
                    .application_arn = "ApplicationArn",
                    .client_id = "ClientId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_associations = "ApplicationAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        applications: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            namespace: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .namespace = "Namespace",
                    .created_time = "CreatedTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "Applications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_data_integration_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/dataIntegrations/{DataIntegrationIdentifier}/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataIntegrationAssociations",
    Request: type = struct {
        data_integration_identifier: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_integration_identifier = "DataIntegrationIdentifier",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_integration_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_data_integration_associations };
        }
    },
    Response: type = struct {
        data_integration_associations: ?[]struct {
            data_integration_association_arn: ?[]const u8 = null,
            data_integration_arn: ?[]const u8 = null,
            client_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_integration_association_arn = "DataIntegrationAssociationArn",
                    .data_integration_arn = "DataIntegrationArn",
                    .client_id = "ClientId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_integration_associations = "DataIntegrationAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_data_integrations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/dataIntegrations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataIntegrations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_integrations) } {
            return .{ .service_metadata = service_metadata, .action = list_data_integrations };
        }
    },
    Response: type = struct {
        data_integrations: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            source_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .source_uri = "SourceURI",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_integrations = "DataIntegrations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_event_integration_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/eventIntegrations/{EventIntegrationName}/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEventIntegrationAssociations",
    Request: type = struct {
        event_integration_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_integration_name = "EventIntegrationName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_integration_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_event_integration_associations };
        }
    },
    Response: type = struct {
        event_integration_associations: ?[]struct {
            event_integration_association_arn: ?[]const u8 = null,
            event_integration_association_id: ?[]const u8 = null,
            event_integration_name: ?[]const u8 = null,
            client_id: ?[]const u8 = null,
            event_bridge_rule_name: ?[]const u8 = null,
            client_association_metadata: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_integration_association_arn = "EventIntegrationAssociationArn",
                    .event_integration_association_id = "EventIntegrationAssociationId",
                    .event_integration_name = "EventIntegrationName",
                    .client_id = "ClientId",
                    .event_bridge_rule_name = "EventBridgeRuleName",
                    .client_association_metadata = "ClientAssociationMetadata",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "client_association_metadata", field_name))
                    return try serializeMap(self.client_association_metadata, self.fieldNameFor("client_association_metadata"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_integration_associations = "EventIntegrationAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_event_integrations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/eventIntegrations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEventIntegrations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_integrations) } {
            return .{ .service_metadata = service_metadata, .action = list_event_integrations };
        }
    },
    Response: type = struct {
        event_integrations: ?[]struct {
            event_integration_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            event_filter: ?EventFilter = null,
            event_bridge_bus: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_integration_arn = "EventIntegrationArn",
                    .name = "Name",
                    .description = "Description",
                    .event_filter = "EventFilter",
                    .event_bridge_bus = "EventBridgeBus",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_integrations = "EventIntegrations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_application: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/applications/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        application_source_config: ?ApplicationSourceConfig = null,
        subscriptions: ?[]Subscription = null,
        publications: ?[]Publication = null,
        permissions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .description = "Description",
                .application_source_config = "ApplicationSourceConfig",
                .subscriptions = "Subscriptions",
                .publications = "Publications",
                .permissions = "Permissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        UnsupportedOperation,
    },
} = .{};
pub const update_data_integration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/dataIntegrations/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataIntegration",
    Request: type = struct {
        identifier: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_integration) } {
            return .{ .service_metadata = service_metadata, .action = update_data_integration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_event_integration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/eventIntegrations/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEventIntegration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_event_integration) } {
            return .{ .service_metadata = service_metadata, .action = update_event_integration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const Publication = struct {
    event: []const u8,
    schema: []const u8,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event = "Event",
            .schema = "Schema",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const Subscription = struct {
    event: []const u8,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event = "Event",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationSourceConfig = struct {
    external_url_config: ?ExternalUrlConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_url_config = "ExternalUrlConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ExternalUrlConfig = struct {
    access_url: []const u8,
    approved_origins: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_url = "AccessUrl",
            .approved_origins = "ApprovedOrigins",
        };
        return @field(mappings, field_name);
    }
};

pub const EventFilter = struct {
    source: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
        };
        return @field(mappings, field_name);
    }
};

pub const FileConfiguration = struct {
    folders: [][]const u8,
    filters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .folders = "Folders",
            .filters = "Filters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "filters", field_name))
            return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
        return false;
    }
};

pub const ScheduleConfiguration = struct {
    first_execution_from: ?[]const u8 = null,
    object: ?[]const u8 = null,
    schedule_expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .first_execution_from = "FirstExecutionFrom",
            .object = "Object",
            .schedule_expression = "ScheduleExpression",
        };
        return @field(mappings, field_name);
    }
};
