const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-05-15";
pub const sdk_id: []const u8 = "AppRunner";
pub const arn_namespace: ?[]const u8 = "apprunner";
pub const endpoint_prefix: []const u8 = "apprunner";
pub const sigv4_name: []const u8 = "apprunner";
pub const name: []const u8 = "AppRunner";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2020-05-15",
    sdk_id: []const u8 = "AppRunner",
    arn_namespace: ?[]const u8 = "apprunner",
    endpoint_prefix: []const u8 = "apprunner",
    sigv4_name: []const u8 = "apprunner",
    name: []const u8 = "AppRunner",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const associate_custom_domain: struct {
    action_name: []const u8 = "AssociateCustomDomain",
    Request: type = struct {
        service_arn: []const u8,
        domain_name: []const u8,
        enable_www_subdomain: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
                .domain_name = "DomainName",
                .enable_www_subdomain = "EnableWWWSubdomain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_custom_domain) } {
            return .{ .service_metadata = service_metadata, .action = associate_custom_domain };
        }
    },
    Response: type = struct {
        dns_target: []const u8,
        service_arn: []const u8,
        custom_domain: CustomDomain,
        vpc_dns_targets: []VpcDNSTarget,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dns_target = "DNSTarget",
                .service_arn = "ServiceArn",
                .custom_domain = "CustomDomain",
                .vpc_dns_targets = "VpcDNSTargets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
    },
} = .{};
pub const create_auto_scaling_configuration: struct {
    action_name: []const u8 = "CreateAutoScalingConfiguration",
    Request: type = struct {
        auto_scaling_configuration_name: []const u8,
        max_concurrency: ?i64 = null,
        min_size: ?i64 = null,
        max_size: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration_name = "AutoScalingConfigurationName",
                .max_concurrency = "MaxConcurrency",
                .min_size = "MinSize",
                .max_size = "MaxSize",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_auto_scaling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_auto_scaling_configuration };
        }
    },
    Response: type = struct {
        auto_scaling_configuration: AutoScalingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration = "AutoScalingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_connection: struct {
    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        connection_name: []const u8,
        provider_type: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_name = "ConnectionName",
                .provider_type = "ProviderType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {
        connection: Connection,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_observability_configuration: struct {
    action_name: []const u8 = "CreateObservabilityConfiguration",
    Request: type = struct {
        observability_configuration_name: []const u8,
        trace_configuration: ?TraceConfiguration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observability_configuration_name = "ObservabilityConfigurationName",
                .trace_configuration = "TraceConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_observability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_observability_configuration };
        }
    },
    Response: type = struct {
        observability_configuration: ObservabilityConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observability_configuration = "ObservabilityConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_service: struct {
    action_name: []const u8 = "CreateService",
    Request: type = struct {
        service_name: []const u8,
        source_configuration: SourceConfiguration,
        instance_configuration: ?InstanceConfiguration = null,
        tags: ?[]Tag = null,
        encryption_configuration: ?EncryptionConfiguration = null,
        health_check_configuration: ?HealthCheckConfiguration = null,
        auto_scaling_configuration_arn: ?[]const u8 = null,
        network_configuration: ?NetworkConfiguration = null,
        observability_configuration: ?ServiceObservabilityConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_name = "ServiceName",
                .source_configuration = "SourceConfiguration",
                .instance_configuration = "InstanceConfiguration",
                .tags = "Tags",
                .encryption_configuration = "EncryptionConfiguration",
                .health_check_configuration = "HealthCheckConfiguration",
                .auto_scaling_configuration_arn = "AutoScalingConfigurationArn",
                .network_configuration = "NetworkConfiguration",
                .observability_configuration = "ObservabilityConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_service) } {
            return .{ .service_metadata = service_metadata, .action = create_service };
        }
    },
    Response: type = struct {
        service: Service,
        operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "Service",
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_vpc_connector: struct {
    action_name: []const u8 = "CreateVpcConnector",
    Request: type = struct {
        vpc_connector_name: []const u8,
        subnets: [][]const u8,
        security_groups: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connector_name = "VpcConnectorName",
                .subnets = "Subnets",
                .security_groups = "SecurityGroups",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_connector) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_connector };
        }
    },
    Response: type = struct {
        vpc_connector: VpcConnector,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connector = "VpcConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_vpc_ingress_connection: struct {
    action_name: []const u8 = "CreateVpcIngressConnection",
    Request: type = struct {
        service_arn: []const u8,
        vpc_ingress_connection_name: []const u8,
        ingress_vpc_configuration: IngressVpcConfiguration,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
                .vpc_ingress_connection_name = "VpcIngressConnectionName",
                .ingress_vpc_configuration = "IngressVpcConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_ingress_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_ingress_connection };
        }
    },
    Response: type = struct {
        vpc_ingress_connection: VpcIngressConnection,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_ingress_connection = "VpcIngressConnection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ServiceQuotaExceeded,
    },
} = .{};
pub const delete_auto_scaling_configuration: struct {
    action_name: []const u8 = "DeleteAutoScalingConfiguration",
    Request: type = struct {
        auto_scaling_configuration_arn: []const u8,
        delete_all_revisions: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration_arn = "AutoScalingConfigurationArn",
                .delete_all_revisions = "DeleteAllRevisions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_auto_scaling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_auto_scaling_configuration };
        }
    },
    Response: type = struct {
        auto_scaling_configuration: AutoScalingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration = "AutoScalingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        connection_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_observability_configuration: struct {
    action_name: []const u8 = "DeleteObservabilityConfiguration",
    Request: type = struct {
        observability_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observability_configuration_arn = "ObservabilityConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_observability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_observability_configuration };
        }
    },
    Response: type = struct {
        observability_configuration: ObservabilityConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observability_configuration = "ObservabilityConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_service: struct {
    action_name: []const u8 = "DeleteService",
    Request: type = struct {
        service_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_service) } {
            return .{ .service_metadata = service_metadata, .action = delete_service };
        }
    },
    Response: type = struct {
        service: Service,
        operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "Service",
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const delete_vpc_connector: struct {
    action_name: []const u8 = "DeleteVpcConnector",
    Request: type = struct {
        vpc_connector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connector_arn = "VpcConnectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_connector) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_connector };
        }
    },
    Response: type = struct {
        vpc_connector: VpcConnector,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connector = "VpcConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_vpc_ingress_connection: struct {
    action_name: []const u8 = "DeleteVpcIngressConnection",
    Request: type = struct {
        vpc_ingress_connection_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_ingress_connection_arn = "VpcIngressConnectionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_ingress_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_ingress_connection };
        }
    },
    Response: type = struct {
        vpc_ingress_connection: VpcIngressConnection,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_ingress_connection = "VpcIngressConnection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const describe_auto_scaling_configuration: struct {
    action_name: []const u8 = "DescribeAutoScalingConfiguration",
    Request: type = struct {
        auto_scaling_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration_arn = "AutoScalingConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_auto_scaling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_auto_scaling_configuration };
        }
    },
    Response: type = struct {
        auto_scaling_configuration: AutoScalingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration = "AutoScalingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_custom_domains: struct {
    action_name: []const u8 = "DescribeCustomDomains",
    Request: type = struct {
        service_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_domains) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_domains };
        }
    },
    Response: type = struct {
        dns_target: []const u8,
        service_arn: []const u8,
        custom_domains: []CustomDomain,
        vpc_dns_targets: []VpcDNSTarget,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dns_target = "DNSTarget",
                .service_arn = "ServiceArn",
                .custom_domains = "CustomDomains",
                .vpc_dns_targets = "VpcDNSTargets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_observability_configuration: struct {
    action_name: []const u8 = "DescribeObservabilityConfiguration",
    Request: type = struct {
        observability_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observability_configuration_arn = "ObservabilityConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_observability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_observability_configuration };
        }
    },
    Response: type = struct {
        observability_configuration: ObservabilityConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observability_configuration = "ObservabilityConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_service: struct {
    action_name: []const u8 = "DescribeService",
    Request: type = struct {
        service_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_service) } {
            return .{ .service_metadata = service_metadata, .action = describe_service };
        }
    },
    Response: type = struct {
        service: Service,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "Service",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_vpc_connector: struct {
    action_name: []const u8 = "DescribeVpcConnector",
    Request: type = struct {
        vpc_connector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connector_arn = "VpcConnectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_connector) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_connector };
        }
    },
    Response: type = struct {
        vpc_connector: VpcConnector,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connector = "VpcConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_vpc_ingress_connection: struct {
    action_name: []const u8 = "DescribeVpcIngressConnection",
    Request: type = struct {
        vpc_ingress_connection_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_ingress_connection_arn = "VpcIngressConnectionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_ingress_connection) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_ingress_connection };
        }
    },
    Response: type = struct {
        vpc_ingress_connection: VpcIngressConnection,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_ingress_connection = "VpcIngressConnection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_custom_domain: struct {
    action_name: []const u8 = "DisassociateCustomDomain",
    Request: type = struct {
        service_arn: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_custom_domain) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_custom_domain };
        }
    },
    Response: type = struct {
        dns_target: []const u8,
        service_arn: []const u8,
        custom_domain: CustomDomain,
        vpc_dns_targets: []VpcDNSTarget,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dns_target = "DNSTarget",
                .service_arn = "ServiceArn",
                .custom_domain = "CustomDomain",
                .vpc_dns_targets = "VpcDNSTargets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const list_auto_scaling_configurations: struct {
    action_name: []const u8 = "ListAutoScalingConfigurations",
    Request: type = struct {
        auto_scaling_configuration_name: ?[]const u8 = null,
        latest_only: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration_name = "AutoScalingConfigurationName",
                .latest_only = "LatestOnly",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_auto_scaling_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_auto_scaling_configurations };
        }
    },
    Response: type = struct {
        auto_scaling_configuration_summary_list: []AutoScalingConfigurationSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration_summary_list = "AutoScalingConfigurationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const list_connections: struct {
    action_name: []const u8 = "ListConnections",
    Request: type = struct {
        connection_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_name = "ConnectionName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connections) } {
            return .{ .service_metadata = service_metadata, .action = list_connections };
        }
    },
    Response: type = struct {
        connection_summary_list: []struct {
            connection_name: ?[]const u8 = null,
            connection_arn: ?[]const u8 = null,
            provider_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connection_name = "ConnectionName",
                    .connection_arn = "ConnectionArn",
                    .provider_type = "ProviderType",
                    .status = "Status",
                    .created_at = "CreatedAt",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_summary_list = "ConnectionSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const list_observability_configurations: struct {
    action_name: []const u8 = "ListObservabilityConfigurations",
    Request: type = struct {
        observability_configuration_name: ?[]const u8 = null,
        latest_only: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observability_configuration_name = "ObservabilityConfigurationName",
                .latest_only = "LatestOnly",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_observability_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_observability_configurations };
        }
    },
    Response: type = struct {
        observability_configuration_summary_list: []struct {
            observability_configuration_arn: ?[]const u8 = null,
            observability_configuration_name: ?[]const u8 = null,
            observability_configuration_revision: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .observability_configuration_arn = "ObservabilityConfigurationArn",
                    .observability_configuration_name = "ObservabilityConfigurationName",
                    .observability_configuration_revision = "ObservabilityConfigurationRevision",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observability_configuration_summary_list = "ObservabilityConfigurationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const list_operations: struct {
    action_name: []const u8 = "ListOperations",
    Request: type = struct {
        service_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_operations) } {
            return .{ .service_metadata = service_metadata, .action = list_operations };
        }
    },
    Response: type = struct {
        operation_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            target_arn: ?[]const u8 = null,
            started_at: ?i64 = null,
            ended_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .status = "Status",
                    .target_arn = "TargetArn",
                    .started_at = "StartedAt",
                    .ended_at = "EndedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_summary_list = "OperationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_services: struct {
    action_name: []const u8 = "ListServices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_services) } {
            return .{ .service_metadata = service_metadata, .action = list_services };
        }
    },
    Response: type = struct {
        service_summary_list: []struct {
            service_name: ?[]const u8 = null,
            service_id: ?[]const u8 = null,
            service_arn: ?[]const u8 = null,
            service_url: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_name = "ServiceName",
                    .service_id = "ServiceId",
                    .service_arn = "ServiceArn",
                    .service_url = "ServiceUrl",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_summary_list = "ServiceSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const list_services_for_auto_scaling_configuration: struct {
    action_name: []const u8 = "ListServicesForAutoScalingConfiguration",
    Request: type = struct {
        auto_scaling_configuration_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration_arn = "AutoScalingConfigurationArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_services_for_auto_scaling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = list_services_for_auto_scaling_configuration };
        }
    },
    Response: type = struct {
        service_arn_list: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn_list = "ServiceArnList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const list_vpc_connectors: struct {
    action_name: []const u8 = "ListVpcConnectors",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_connectors) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_connectors };
        }
    },
    Response: type = struct {
        vpc_connectors: []VpcConnector,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connectors = "VpcConnectors",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const list_vpc_ingress_connections: struct {
    action_name: []const u8 = "ListVpcIngressConnections",
    Request: type = struct {
        filter: ?struct {
            service_arn: ?[]const u8 = null,
            vpc_endpoint_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_arn = "ServiceArn",
                    .vpc_endpoint_id = "VpcEndpointId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_ingress_connections) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_ingress_connections };
        }
    },
    Response: type = struct {
        vpc_ingress_connection_summary_list: []struct {
            vpc_ingress_connection_arn: ?[]const u8 = null,
            service_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpc_ingress_connection_arn = "VpcIngressConnectionArn",
                    .service_arn = "ServiceArn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_ingress_connection_summary_list = "VpcIngressConnectionSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const pause_service: struct {
    action_name: []const u8 = "PauseService",
    Request: type = struct {
        service_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(pause_service) } {
            return .{ .service_metadata = service_metadata, .action = pause_service };
        }
    },
    Response: type = struct {
        service: Service,
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "Service",
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const resume_service: struct {
    action_name: []const u8 = "ResumeService",
    Request: type = struct {
        service_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_service) } {
            return .{ .service_metadata = service_metadata, .action = resume_service };
        }
    },
    Response: type = struct {
        service: Service,
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "Service",
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const start_deployment: struct {
    action_name: []const u8 = "StartDeployment",
    Request: type = struct {
        service_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_deployment) } {
            return .{ .service_metadata = service_metadata, .action = start_deployment };
        }
    },
    Response: type = struct {
        operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const update_default_auto_scaling_configuration: struct {
    action_name: []const u8 = "UpdateDefaultAutoScalingConfiguration",
    Request: type = struct {
        auto_scaling_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration_arn = "AutoScalingConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_default_auto_scaling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_default_auto_scaling_configuration };
        }
    },
    Response: type = struct {
        auto_scaling_configuration: AutoScalingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_scaling_configuration = "AutoScalingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_service: struct {
    action_name: []const u8 = "UpdateService",
    Request: type = struct {
        service_arn: []const u8,
        source_configuration: ?SourceConfiguration = null,
        instance_configuration: ?InstanceConfiguration = null,
        auto_scaling_configuration_arn: ?[]const u8 = null,
        health_check_configuration: ?HealthCheckConfiguration = null,
        network_configuration: ?NetworkConfiguration = null,
        observability_configuration: ?ServiceObservabilityConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "ServiceArn",
                .source_configuration = "SourceConfiguration",
                .instance_configuration = "InstanceConfiguration",
                .auto_scaling_configuration_arn = "AutoScalingConfigurationArn",
                .health_check_configuration = "HealthCheckConfiguration",
                .network_configuration = "NetworkConfiguration",
                .observability_configuration = "ObservabilityConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service) } {
            return .{ .service_metadata = service_metadata, .action = update_service };
        }
    },
    Response: type = struct {
        service: Service,
        operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "Service",
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const update_vpc_ingress_connection: struct {
    action_name: []const u8 = "UpdateVpcIngressConnection",
    Request: type = struct {
        vpc_ingress_connection_arn: []const u8,
        ingress_vpc_configuration: IngressVpcConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_ingress_connection_arn = "VpcIngressConnectionArn",
                .ingress_vpc_configuration = "IngressVpcConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpc_ingress_connection) } {
            return .{ .service_metadata = service_metadata, .action = update_vpc_ingress_connection };
        }
    },
    Response: type = struct {
        vpc_ingress_connection: VpcIngressConnection,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_ingress_connection = "VpcIngressConnection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        InvalidState,
        ResourceNotFound,
    },
} = .{};

pub const VpcIngressConnection = struct {
    vpc_ingress_connection_arn: ?[]const u8 = null,
    vpc_ingress_connection_name: ?[]const u8 = null,
    service_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    ingress_vpc_configuration: ?IngressVpcConfiguration = null,
    created_at: ?i64 = null,
    deleted_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_ingress_connection_arn = "VpcIngressConnectionArn",
            .vpc_ingress_connection_name = "VpcIngressConnectionName",
            .service_arn = "ServiceArn",
            .status = "Status",
            .account_id = "AccountId",
            .domain_name = "DomainName",
            .ingress_vpc_configuration = "IngressVpcConfiguration",
            .created_at = "CreatedAt",
            .deleted_at = "DeletedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const IngressVpcConfiguration = struct {
    vpc_id: ?[]const u8 = null,
    vpc_endpoint_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
            .vpc_endpoint_id = "VpcEndpointId",
        };
        return @field(mappings, field_name);
    }
};

pub const Service = struct {
    service_name: []const u8,
    service_id: []const u8,
    service_arn: []const u8,
    service_url: ?[]const u8 = null,
    created_at: i64,
    updated_at: i64,
    deleted_at: ?i64 = null,
    status: []const u8,
    source_configuration: SourceConfiguration,
    instance_configuration: InstanceConfiguration,
    encryption_configuration: ?EncryptionConfiguration = null,
    health_check_configuration: ?HealthCheckConfiguration = null,
    auto_scaling_configuration_summary: AutoScalingConfigurationSummary,
    network_configuration: NetworkConfiguration,
    observability_configuration: ?ServiceObservabilityConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_name = "ServiceName",
            .service_id = "ServiceId",
            .service_arn = "ServiceArn",
            .service_url = "ServiceUrl",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
            .deleted_at = "DeletedAt",
            .status = "Status",
            .source_configuration = "SourceConfiguration",
            .instance_configuration = "InstanceConfiguration",
            .encryption_configuration = "EncryptionConfiguration",
            .health_check_configuration = "HealthCheckConfiguration",
            .auto_scaling_configuration_summary = "AutoScalingConfigurationSummary",
            .network_configuration = "NetworkConfiguration",
            .observability_configuration = "ObservabilityConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceObservabilityConfiguration = struct {
    observability_enabled: bool,
    observability_configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .observability_enabled = "ObservabilityEnabled",
            .observability_configuration_arn = "ObservabilityConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkConfiguration = struct {
    egress_configuration: ?EgressConfiguration = null,
    ingress_configuration: ?IngressConfiguration = null,
    ip_address_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .egress_configuration = "EgressConfiguration",
            .ingress_configuration = "IngressConfiguration",
            .ip_address_type = "IpAddressType",
        };
        return @field(mappings, field_name);
    }
};

pub const IngressConfiguration = struct {
    is_publicly_accessible: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_publicly_accessible = "IsPubliclyAccessible",
        };
        return @field(mappings, field_name);
    }
};

pub const EgressConfiguration = struct {
    egress_type: ?[]const u8 = null,
    vpc_connector_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .egress_type = "EgressType",
            .vpc_connector_arn = "VpcConnectorArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingConfigurationSummary = struct {
    auto_scaling_configuration_arn: ?[]const u8 = null,
    auto_scaling_configuration_name: ?[]const u8 = null,
    auto_scaling_configuration_revision: ?i64 = null,
    status: ?[]const u8 = null,
    created_at: ?i64 = null,
    has_associated_service: ?bool = null,
    is_default: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_scaling_configuration_arn = "AutoScalingConfigurationArn",
            .auto_scaling_configuration_name = "AutoScalingConfigurationName",
            .auto_scaling_configuration_revision = "AutoScalingConfigurationRevision",
            .status = "Status",
            .created_at = "CreatedAt",
            .has_associated_service = "HasAssociatedService",
            .is_default = "IsDefault",
        };
        return @field(mappings, field_name);
    }
};

pub const HealthCheckConfiguration = struct {
    protocol: ?[]const u8 = null,
    path: ?[]const u8 = null,
    interval: ?i64 = null,
    timeout: ?i64 = null,
    healthy_threshold: ?i64 = null,
    unhealthy_threshold: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "Protocol",
            .path = "Path",
            .interval = "Interval",
            .timeout = "Timeout",
            .healthy_threshold = "HealthyThreshold",
            .unhealthy_threshold = "UnhealthyThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    kms_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key = "KmsKey",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceConfiguration = struct {
    cpu: ?[]const u8 = null,
    memory: ?[]const u8 = null,
    instance_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu = "Cpu",
            .memory = "Memory",
            .instance_role_arn = "InstanceRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConfiguration = struct {
    code_repository: ?CodeRepository = null,
    image_repository: ?ImageRepository = null,
    auto_deployments_enabled: ?bool = null,
    authentication_configuration: ?AuthenticationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code_repository = "CodeRepository",
            .image_repository = "ImageRepository",
            .auto_deployments_enabled = "AutoDeploymentsEnabled",
            .authentication_configuration = "AuthenticationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthenticationConfiguration = struct {
    connection_arn: ?[]const u8 = null,
    access_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_arn = "ConnectionArn",
            .access_role_arn = "AccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageRepository = struct {
    image_identifier: []const u8,
    image_configuration: ?ImageConfiguration = null,
    image_repository_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_identifier = "ImageIdentifier",
            .image_configuration = "ImageConfiguration",
            .image_repository_type = "ImageRepositoryType",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageConfiguration = struct {
    runtime_environment_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    start_command: ?[]const u8 = null,
    port: ?[]const u8 = null,
    runtime_environment_secrets: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .runtime_environment_variables = "RuntimeEnvironmentVariables",
            .start_command = "StartCommand",
            .port = "Port",
            .runtime_environment_secrets = "RuntimeEnvironmentSecrets",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "runtime_environment_variables", field_name))
            return try serializeMap(self.runtime_environment_variables, self.fieldNameFor("runtime_environment_variables"), options, out_stream);
        if (std.mem.eql(u8, "runtime_environment_secrets", field_name))
            return try serializeMap(self.runtime_environment_secrets, self.fieldNameFor("runtime_environment_secrets"), options, out_stream);
        return false;
    }
};

pub const CodeRepository = struct {
    repository_url: []const u8,
    source_code_version: SourceCodeVersion,
    code_configuration: ?CodeConfiguration = null,
    source_directory: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_url = "RepositoryUrl",
            .source_code_version = "SourceCodeVersion",
            .code_configuration = "CodeConfiguration",
            .source_directory = "SourceDirectory",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeConfiguration = struct {
    configuration_source: []const u8,
    code_configuration_values: ?CodeConfigurationValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration_source = "ConfigurationSource",
            .code_configuration_values = "CodeConfigurationValues",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeConfigurationValues = struct {
    runtime: []const u8,
    build_command: ?[]const u8 = null,
    start_command: ?[]const u8 = null,
    port: ?[]const u8 = null,
    runtime_environment_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    runtime_environment_secrets: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .runtime = "Runtime",
            .build_command = "BuildCommand",
            .start_command = "StartCommand",
            .port = "Port",
            .runtime_environment_variables = "RuntimeEnvironmentVariables",
            .runtime_environment_secrets = "RuntimeEnvironmentSecrets",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "runtime_environment_variables", field_name))
            return try serializeMap(self.runtime_environment_variables, self.fieldNameFor("runtime_environment_variables"), options, out_stream);
        if (std.mem.eql(u8, "runtime_environment_secrets", field_name))
            return try serializeMap(self.runtime_environment_secrets, self.fieldNameFor("runtime_environment_secrets"), options, out_stream);
        return false;
    }
};

pub const SourceCodeVersion = struct {
    type: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingConfiguration = struct {
    auto_scaling_configuration_arn: ?[]const u8 = null,
    auto_scaling_configuration_name: ?[]const u8 = null,
    auto_scaling_configuration_revision: ?i64 = null,
    latest: ?bool = null,
    status: ?[]const u8 = null,
    max_concurrency: ?i64 = null,
    min_size: ?i64 = null,
    max_size: ?i64 = null,
    created_at: ?i64 = null,
    deleted_at: ?i64 = null,
    has_associated_service: ?bool = null,
    is_default: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_scaling_configuration_arn = "AutoScalingConfigurationArn",
            .auto_scaling_configuration_name = "AutoScalingConfigurationName",
            .auto_scaling_configuration_revision = "AutoScalingConfigurationRevision",
            .latest = "Latest",
            .status = "Status",
            .max_concurrency = "MaxConcurrency",
            .min_size = "MinSize",
            .max_size = "MaxSize",
            .created_at = "CreatedAt",
            .deleted_at = "DeletedAt",
            .has_associated_service = "HasAssociatedService",
            .is_default = "IsDefault",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConnector = struct {
    vpc_connector_name: ?[]const u8 = null,
    vpc_connector_arn: ?[]const u8 = null,
    vpc_connector_revision: ?i64 = null,
    subnets: ?[][]const u8 = null,
    security_groups: ?[][]const u8 = null,
    status: ?[]const u8 = null,
    created_at: ?i64 = null,
    deleted_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_connector_name = "VpcConnectorName",
            .vpc_connector_arn = "VpcConnectorArn",
            .vpc_connector_revision = "VpcConnectorRevision",
            .subnets = "Subnets",
            .security_groups = "SecurityGroups",
            .status = "Status",
            .created_at = "CreatedAt",
            .deleted_at = "DeletedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcDNSTarget = struct {
    vpc_ingress_connection_arn: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_ingress_connection_arn = "VpcIngressConnectionArn",
            .vpc_id = "VpcId",
            .domain_name = "DomainName",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomDomain = struct {
    domain_name: []const u8,
    enable_www_subdomain: bool,
    certificate_validation_records: ?[]CertificateValidationRecord = null,
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .enable_www_subdomain = "EnableWWWSubdomain",
            .certificate_validation_records = "CertificateValidationRecords",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateValidationRecord = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .value = "Value",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ObservabilityConfiguration = struct {
    observability_configuration_arn: ?[]const u8 = null,
    observability_configuration_name: ?[]const u8 = null,
    trace_configuration: ?TraceConfiguration = null,
    observability_configuration_revision: ?i64 = null,
    latest: ?bool = null,
    status: ?[]const u8 = null,
    created_at: ?i64 = null,
    deleted_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .observability_configuration_arn = "ObservabilityConfigurationArn",
            .observability_configuration_name = "ObservabilityConfigurationName",
            .trace_configuration = "TraceConfiguration",
            .observability_configuration_revision = "ObservabilityConfigurationRevision",
            .latest = "Latest",
            .status = "Status",
            .created_at = "CreatedAt",
            .deleted_at = "DeletedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const TraceConfiguration = struct {
    vendor: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vendor = "Vendor",
        };
        return @field(mappings, field_name);
    }
};

pub const Connection = struct {
    connection_name: ?[]const u8 = null,
    connection_arn: ?[]const u8 = null,
    provider_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_name = "ConnectionName",
            .connection_arn = "ConnectionArn",
            .provider_type = "ProviderType",
            .status = "Status",
            .created_at = "CreatedAt",
        };
        return @field(mappings, field_name);
    }
};
