const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-12-01";
pub const sdk_id: []const u8 = "AppStream";
pub const arn_namespace: ?[]const u8 = "appstream";
pub const endpoint_prefix: []const u8 = "appstream2";
pub const sigv4_name: []const u8 = "appstream";
pub const name: []const u8 = "PhotonAdminProxyService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-12-01",
    sdk_id: []const u8 = "AppStream",
    arn_namespace: ?[]const u8 = "appstream",
    endpoint_prefix: []const u8 = "appstream2",
    sigv4_name: []const u8 = "appstream",
    name: []const u8 = "PhotonAdminProxyService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_app_block_builder_app_block: struct {
    action_name: []const u8 = "AssociateAppBlockBuilderAppBlock",
    Request: type = struct {
        app_block_arn: []const u8,
        app_block_builder_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_arn = "AppBlockArn",
                .app_block_builder_name = "AppBlockBuilderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_app_block_builder_app_block) } {
            return .{ .service_metadata = service_metadata, .action = associate_app_block_builder_app_block };
        }
    },
    Response: type = struct {
        app_block_builder_app_block_association: ?AppBlockBuilderAppBlockAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_builder_app_block_association = "AppBlockBuilderAppBlockAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidParameterCombination,
        LimitExceeded,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const associate_application_fleet: struct {
    action_name: []const u8 = "AssociateApplicationFleet",
    Request: type = struct {
        fleet_name: []const u8,
        application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_name = "FleetName",
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_application_fleet) } {
            return .{ .service_metadata = service_metadata, .action = associate_application_fleet };
        }
    },
    Response: type = struct {
        application_fleet_association: ?ApplicationFleetAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_fleet_association = "ApplicationFleetAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidParameterCombination,
        LimitExceeded,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const associate_application_to_entitlement: struct {
    action_name: []const u8 = "AssociateApplicationToEntitlement",
    Request: type = struct {
        stack_name: []const u8,
        entitlement_name: []const u8,
        application_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_name = "StackName",
                .entitlement_name = "EntitlementName",
                .application_identifier = "ApplicationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_application_to_entitlement) } {
            return .{ .service_metadata = service_metadata, .action = associate_application_to_entitlement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntitlementNotFound,
        LimitExceeded,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const associate_fleet: struct {
    action_name: []const u8 = "AssociateFleet",
    Request: type = struct {
        fleet_name: []const u8,
        stack_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_name = "FleetName",
                .stack_name = "StackName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_fleet) } {
            return .{ .service_metadata = service_metadata, .action = associate_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        IncompatibleImage,
        InvalidAccountStatus,
        LimitExceeded,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const batch_associate_user_stack: struct {
    action_name: []const u8 = "BatchAssociateUserStack",
    Request: type = struct {
        user_stack_associations: []UserStackAssociation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_stack_associations = "UserStackAssociations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_associate_user_stack) } {
            return .{ .service_metadata = service_metadata, .action = batch_associate_user_stack };
        }
    },
    Response: type = struct {
        errors: ?[]UserStackAssociationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        OperationNotPermitted,
    },
} = .{};
pub const batch_disassociate_user_stack: struct {
    action_name: []const u8 = "BatchDisassociateUserStack",
    Request: type = struct {
        user_stack_associations: []UserStackAssociation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_stack_associations = "UserStackAssociations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disassociate_user_stack) } {
            return .{ .service_metadata = service_metadata, .action = batch_disassociate_user_stack };
        }
    },
    Response: type = struct {
        errors: ?[]UserStackAssociationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        OperationNotPermitted,
    },
} = .{};
pub const copy_image: struct {
    action_name: []const u8 = "CopyImage",
    Request: type = struct {
        source_image_name: []const u8,
        destination_image_name: []const u8,
        destination_region: []const u8,
        destination_image_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_image_name = "SourceImageName",
                .destination_image_name = "DestinationImageName",
                .destination_region = "DestinationRegion",
                .destination_image_description = "DestinationImageDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_image) } {
            return .{ .service_metadata = service_metadata, .action = copy_image };
        }
    },
    Response: type = struct {
        destination_image_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_image_name = "DestinationImageName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IncompatibleImage,
        InvalidAccountStatus,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const create_app_block: struct {
    action_name: []const u8 = "CreateAppBlock",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        source_s3_location: S3Location,
        setup_script_details: ?ScriptDetails = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        post_setup_script_details: ?ScriptDetails = null,
        packaging_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .display_name = "DisplayName",
                .source_s3_location = "SourceS3Location",
                .setup_script_details = "SetupScriptDetails",
                .tags = "Tags",
                .post_setup_script_details = "PostSetupScriptDetails",
                .packaging_type = "PackagingType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_block) } {
            return .{ .service_metadata = service_metadata, .action = create_app_block };
        }
    },
    Response: type = struct {
        app_block: ?AppBlock = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block = "AppBlock",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        LimitExceeded,
        OperationNotPermitted,
        ResourceAlreadyExists,
    },
} = .{};
pub const create_app_block_builder: struct {
    action_name: []const u8 = "CreateAppBlockBuilder",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        platform: []const u8,
        instance_type: []const u8,
        vpc_config: VpcConfig,
        enable_default_internet_access: ?bool = null,
        iam_role_arn: ?[]const u8 = null,
        access_endpoints: ?[]AccessEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .display_name = "DisplayName",
                .tags = "Tags",
                .platform = "Platform",
                .instance_type = "InstanceType",
                .vpc_config = "VpcConfig",
                .enable_default_internet_access = "EnableDefaultInternetAccess",
                .iam_role_arn = "IamRoleArn",
                .access_endpoints = "AccessEndpoints",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_block_builder) } {
            return .{ .service_metadata = service_metadata, .action = create_app_block_builder };
        }
    },
    Response: type = struct {
        app_block_builder: ?AppBlockBuilder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_builder = "AppBlockBuilder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidAccountStatus,
        InvalidParameterCombination,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        RequestLimitExceeded,
        ResourceAlreadyExists,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const create_app_block_builder_streaming_url: struct {
    action_name: []const u8 = "CreateAppBlockBuilderStreamingURL",
    Request: type = struct {
        app_block_builder_name: []const u8,
        validity: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_builder_name = "AppBlockBuilderName",
                .validity = "Validity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_block_builder_streaming_url) } {
            return .{ .service_metadata = service_metadata, .action = create_app_block_builder_streaming_url };
        }
    },
    Response: type = struct {
        streaming_url: ?[]const u8 = null,
        expires: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_url = "StreamingURL",
                .expires = "Expires",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const create_application: struct {
    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        name: []const u8,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        icon_s3_location: S3Location,
        launch_path: []const u8,
        working_directory: ?[]const u8 = null,
        launch_parameters: ?[]const u8 = null,
        platforms: [][]const u8,
        instance_families: [][]const u8,
        app_block_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .display_name = "DisplayName",
                .description = "Description",
                .icon_s3_location = "IconS3Location",
                .launch_path = "LaunchPath",
                .working_directory = "WorkingDirectory",
                .launch_parameters = "LaunchParameters",
                .platforms = "Platforms",
                .instance_families = "InstanceFamilies",
                .app_block_arn = "AppBlockArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        application: ?Application = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "Application",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        LimitExceeded,
        OperationNotPermitted,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const create_directory_config: struct {
    action_name: []const u8 = "CreateDirectoryConfig",
    Request: type = struct {
        directory_name: []const u8,
        organizational_unit_distinguished_names: [][]const u8,
        service_account_credentials: ?ServiceAccountCredentials = null,
        certificate_based_auth_properties: ?CertificateBasedAuthProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_name = "DirectoryName",
                .organizational_unit_distinguished_names = "OrganizationalUnitDistinguishedNames",
                .service_account_credentials = "ServiceAccountCredentials",
                .certificate_based_auth_properties = "CertificateBasedAuthProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_directory_config) } {
            return .{ .service_metadata = service_metadata, .action = create_directory_config };
        }
    },
    Response: type = struct {
        directory_config: ?DirectoryConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_config = "DirectoryConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAccountStatus,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const create_entitlement: struct {
    action_name: []const u8 = "CreateEntitlement",
    Request: type = struct {
        name: []const u8,
        stack_name: []const u8,
        description: ?[]const u8 = null,
        app_visibility: []const u8,
        attributes: []EntitlementAttribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .stack_name = "StackName",
                .description = "Description",
                .app_visibility = "AppVisibility",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_entitlement) } {
            return .{ .service_metadata = service_metadata, .action = create_entitlement };
        }
    },
    Response: type = struct {
        entitlement: ?Entitlement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlement = "Entitlement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntitlementAlreadyExists,
        LimitExceeded,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const create_fleet: struct {
    action_name: []const u8 = "CreateFleet",
    Request: type = struct {
        name: []const u8,
        image_name: ?[]const u8 = null,
        image_arn: ?[]const u8 = null,
        instance_type: []const u8,
        fleet_type: ?[]const u8 = null,
        compute_capacity: ?ComputeCapacity = null,
        vpc_config: ?VpcConfig = null,
        max_user_duration_in_seconds: ?i64 = null,
        disconnect_timeout_in_seconds: ?i64 = null,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        enable_default_internet_access: ?bool = null,
        domain_join_info: ?DomainJoinInfo = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        idle_disconnect_timeout_in_seconds: ?i64 = null,
        iam_role_arn: ?[]const u8 = null,
        stream_view: ?[]const u8 = null,
        platform: ?[]const u8 = null,
        max_concurrent_sessions: ?i64 = null,
        usb_device_filter_strings: ?[][]const u8 = null,
        session_script_s3_location: ?S3Location = null,
        max_sessions_per_instance: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .image_name = "ImageName",
                .image_arn = "ImageArn",
                .instance_type = "InstanceType",
                .fleet_type = "FleetType",
                .compute_capacity = "ComputeCapacity",
                .vpc_config = "VpcConfig",
                .max_user_duration_in_seconds = "MaxUserDurationInSeconds",
                .disconnect_timeout_in_seconds = "DisconnectTimeoutInSeconds",
                .description = "Description",
                .display_name = "DisplayName",
                .enable_default_internet_access = "EnableDefaultInternetAccess",
                .domain_join_info = "DomainJoinInfo",
                .tags = "Tags",
                .idle_disconnect_timeout_in_seconds = "IdleDisconnectTimeoutInSeconds",
                .iam_role_arn = "IamRoleArn",
                .stream_view = "StreamView",
                .platform = "Platform",
                .max_concurrent_sessions = "MaxConcurrentSessions",
                .usb_device_filter_strings = "UsbDeviceFilterStrings",
                .session_script_s3_location = "SessionScriptS3Location",
                .max_sessions_per_instance = "MaxSessionsPerInstance",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fleet) } {
            return .{ .service_metadata = service_metadata, .action = create_fleet };
        }
    },
    Response: type = struct {
        fleet: ?Fleet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet = "Fleet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        IncompatibleImage,
        InvalidAccountStatus,
        InvalidParameterCombination,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        RequestLimitExceeded,
        ResourceAlreadyExists,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const create_image_builder: struct {
    action_name: []const u8 = "CreateImageBuilder",
    Request: type = struct {
        name: []const u8,
        image_name: ?[]const u8 = null,
        image_arn: ?[]const u8 = null,
        instance_type: []const u8,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        vpc_config: ?VpcConfig = null,
        iam_role_arn: ?[]const u8 = null,
        enable_default_internet_access: ?bool = null,
        domain_join_info: ?DomainJoinInfo = null,
        appstream_agent_version: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        access_endpoints: ?[]AccessEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .image_name = "ImageName",
                .image_arn = "ImageArn",
                .instance_type = "InstanceType",
                .description = "Description",
                .display_name = "DisplayName",
                .vpc_config = "VpcConfig",
                .iam_role_arn = "IamRoleArn",
                .enable_default_internet_access = "EnableDefaultInternetAccess",
                .domain_join_info = "DomainJoinInfo",
                .appstream_agent_version = "AppstreamAgentVersion",
                .tags = "Tags",
                .access_endpoints = "AccessEndpoints",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image_builder) } {
            return .{ .service_metadata = service_metadata, .action = create_image_builder };
        }
    },
    Response: type = struct {
        image_builder: ?ImageBuilder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_builder = "ImageBuilder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        IncompatibleImage,
        InvalidAccountStatus,
        InvalidParameterCombination,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        RequestLimitExceeded,
        ResourceAlreadyExists,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const create_image_builder_streaming_url: struct {
    action_name: []const u8 = "CreateImageBuilderStreamingURL",
    Request: type = struct {
        name: []const u8,
        validity: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .validity = "Validity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image_builder_streaming_url) } {
            return .{ .service_metadata = service_metadata, .action = create_image_builder_streaming_url };
        }
    },
    Response: type = struct {
        streaming_url: ?[]const u8 = null,
        expires: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_url = "StreamingURL",
                .expires = "Expires",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const create_stack: struct {
    action_name: []const u8 = "CreateStack",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        storage_connectors: ?[]StorageConnector = null,
        redirect_url: ?[]const u8 = null,
        feedback_url: ?[]const u8 = null,
        user_settings: ?[]UserSetting = null,
        application_settings: ?ApplicationSettings = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        access_endpoints: ?[]AccessEndpoint = null,
        embed_host_domains: ?[][]const u8 = null,
        streaming_experience_settings: ?StreamingExperienceSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .display_name = "DisplayName",
                .storage_connectors = "StorageConnectors",
                .redirect_url = "RedirectURL",
                .feedback_url = "FeedbackURL",
                .user_settings = "UserSettings",
                .application_settings = "ApplicationSettings",
                .tags = "Tags",
                .access_endpoints = "AccessEndpoints",
                .embed_host_domains = "EmbedHostDomains",
                .streaming_experience_settings = "StreamingExperienceSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stack) } {
            return .{ .service_metadata = service_metadata, .action = create_stack };
        }
    },
    Response: type = struct {
        stack: ?Stack = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack = "Stack",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidAccountStatus,
        InvalidParameterCombination,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const create_streaming_url: struct {
    action_name: []const u8 = "CreateStreamingURL",
    Request: type = struct {
        stack_name: []const u8,
        fleet_name: []const u8,
        user_id: []const u8,
        application_id: ?[]const u8 = null,
        validity: ?i64 = null,
        session_context: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_name = "StackName",
                .fleet_name = "FleetName",
                .user_id = "UserId",
                .application_id = "ApplicationId",
                .validity = "Validity",
                .session_context = "SessionContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_streaming_url) } {
            return .{ .service_metadata = service_metadata, .action = create_streaming_url };
        }
    },
    Response: type = struct {
        streaming_url: ?[]const u8 = null,
        expires: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_url = "StreamingURL",
                .expires = "Expires",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        OperationNotPermitted,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const create_updated_image: struct {
    action_name: []const u8 = "CreateUpdatedImage",
    Request: type = struct {
        existing_image_name: []const u8,
        new_image_name: []const u8,
        new_image_description: ?[]const u8 = null,
        new_image_display_name: ?[]const u8 = null,
        new_image_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .existing_image_name = "existingImageName",
                .new_image_name = "newImageName",
                .new_image_description = "newImageDescription",
                .new_image_display_name = "newImageDisplayName",
                .new_image_tags = "newImageTags",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "new_image_tags", field_name))
                return try serializeMap(self.new_image_tags, self.fieldNameFor("new_image_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_updated_image) } {
            return .{ .service_metadata = service_metadata, .action = create_updated_image };
        }
    },
    Response: type = struct {
        image: ?Image = null,
        can_update_image: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "image",
                .can_update_image = "canUpdateImage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        IncompatibleImage,
        InvalidAccountStatus,
        LimitExceeded,
        OperationNotPermitted,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const create_usage_report_subscription: struct {
    action_name: []const u8 = "CreateUsageReportSubscription",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_usage_report_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_usage_report_subscription };
        }
    },
    Response: type = struct {
        s3_bucket_name: ?[]const u8 = null,
        schedule: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_bucket_name = "S3BucketName",
                .schedule = "Schedule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAccountStatus,
        InvalidRole,
        LimitExceeded,
    },
} = .{};
pub const create_user: struct {
    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        user_name: []const u8,
        message_action: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        authentication_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .message_action = "MessageAction",
                .first_name = "FirstName",
                .last_name = "LastName",
                .authentication_type = "AuthenticationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAccountStatus,
        InvalidParameterCombination,
        LimitExceeded,
        OperationNotPermitted,
        ResourceAlreadyExists,
    },
} = .{};
pub const delete_app_block: struct {
    action_name: []const u8 = "DeleteAppBlock",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_block) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_block };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_app_block_builder: struct {
    action_name: []const u8 = "DeleteAppBlockBuilder",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_block_builder) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_block_builder };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_application: struct {
    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_directory_config: struct {
    action_name: []const u8 = "DeleteDirectoryConfig",
    Request: type = struct {
        directory_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_name = "DirectoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_directory_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_directory_config };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_entitlement: struct {
    action_name: []const u8 = "DeleteEntitlement",
    Request: type = struct {
        name: []const u8,
        stack_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .stack_name = "StackName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_entitlement) } {
            return .{ .service_metadata = service_metadata, .action = delete_entitlement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntitlementNotFound,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const delete_fleet: struct {
    action_name: []const u8 = "DeleteFleet",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleet) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_image: struct {
    action_name: []const u8 = "DeleteImage",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image) } {
            return .{ .service_metadata = service_metadata, .action = delete_image };
        }
    },
    Response: type = struct {
        image: ?Image = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_image_builder: struct {
    action_name: []const u8 = "DeleteImageBuilder",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image_builder) } {
            return .{ .service_metadata = service_metadata, .action = delete_image_builder };
        }
    },
    Response: type = struct {
        image_builder: ?ImageBuilder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_builder = "ImageBuilder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const delete_image_permissions: struct {
    action_name: []const u8 = "DeleteImagePermissions",
    Request: type = struct {
        name: []const u8,
        shared_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .shared_account_id = "SharedAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image_permissions) } {
            return .{ .service_metadata = service_metadata, .action = delete_image_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const delete_stack: struct {
    action_name: []const u8 = "DeleteStack",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stack) } {
            return .{ .service_metadata = service_metadata, .action = delete_stack };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_usage_report_subscription: struct {
    action_name: []const u8 = "DeleteUsageReportSubscription",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_usage_report_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_usage_report_subscription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAccountStatus,
        ResourceNotFound,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        user_name: []const u8,
        authentication_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .authentication_type = "AuthenticationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_app_block_builder_app_block_associations: struct {
    action_name: []const u8 = "DescribeAppBlockBuilderAppBlockAssociations",
    Request: type = struct {
        app_block_arn: ?[]const u8 = null,
        app_block_builder_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_arn = "AppBlockArn",
                .app_block_builder_name = "AppBlockBuilderName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_block_builder_app_block_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_block_builder_app_block_associations };
        }
    },
    Response: type = struct {
        app_block_builder_app_block_associations: ?[]AppBlockBuilderAppBlockAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_builder_app_block_associations = "AppBlockBuilderAppBlockAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        OperationNotPermitted,
    },
} = .{};
pub const describe_app_block_builders: struct {
    action_name: []const u8 = "DescribeAppBlockBuilders",
    Request: type = struct {
        names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_block_builders) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_block_builders };
        }
    },
    Response: type = struct {
        app_block_builders: ?[]AppBlockBuilder = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_builders = "AppBlockBuilders",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const describe_app_blocks: struct {
    action_name: []const u8 = "DescribeAppBlocks",
    Request: type = struct {
        arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arns = "Arns",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_blocks) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_blocks };
        }
    },
    Response: type = struct {
        app_blocks: ?[]AppBlock = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_blocks = "AppBlocks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const describe_application_fleet_associations: struct {
    action_name: []const u8 = "DescribeApplicationFleetAssociations",
    Request: type = struct {
        fleet_name: ?[]const u8 = null,
        application_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_name = "FleetName",
                .application_arn = "ApplicationArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application_fleet_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_application_fleet_associations };
        }
    },
    Response: type = struct {
        application_fleet_associations: ?[]ApplicationFleetAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_fleet_associations = "ApplicationFleetAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        OperationNotPermitted,
    },
} = .{};
pub const describe_applications: struct {
    action_name: []const u8 = "DescribeApplications",
    Request: type = struct {
        arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arns = "Arns",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_applications) } {
            return .{ .service_metadata = service_metadata, .action = describe_applications };
        }
    },
    Response: type = struct {
        applications: ?[]Application = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "Applications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const describe_directory_configs: struct {
    action_name: []const u8 = "DescribeDirectoryConfigs",
    Request: type = struct {
        directory_names: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_names = "DirectoryNames",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_directory_configs) } {
            return .{ .service_metadata = service_metadata, .action = describe_directory_configs };
        }
    },
    Response: type = struct {
        directory_configs: ?[]DirectoryConfig = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_configs = "DirectoryConfigs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_entitlements: struct {
    action_name: []const u8 = "DescribeEntitlements",
    Request: type = struct {
        name: ?[]const u8 = null,
        stack_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .stack_name = "StackName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_entitlements) } {
            return .{ .service_metadata = service_metadata, .action = describe_entitlements };
        }
    },
    Response: type = struct {
        entitlements: ?[]Entitlement = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlements = "Entitlements",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntitlementNotFound,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const describe_fleets: struct {
    action_name: []const u8 = "DescribeFleets",
    Request: type = struct {
        names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleets) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleets };
        }
    },
    Response: type = struct {
        fleets: ?[]Fleet = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleets = "Fleets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_image_builders: struct {
    action_name: []const u8 = "DescribeImageBuilders",
    Request: type = struct {
        names: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_image_builders) } {
            return .{ .service_metadata = service_metadata, .action = describe_image_builders };
        }
    },
    Response: type = struct {
        image_builders: ?[]ImageBuilder = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_builders = "ImageBuilders",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_image_permissions: struct {
    action_name: []const u8 = "DescribeImagePermissions",
    Request: type = struct {
        name: []const u8,
        max_results: ?i64 = null,
        shared_aws_account_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .max_results = "MaxResults",
                .shared_aws_account_ids = "SharedAwsAccountIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_image_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_image_permissions };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        shared_image_permissions_list: ?[]struct {
            shared_account_id: []const u8,
            image_permissions: ImagePermissions,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .shared_account_id = "sharedAccountId",
                    .image_permissions = "imagePermissions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .shared_image_permissions_list = "SharedImagePermissionsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_images: struct {
    action_name: []const u8 = "DescribeImages",
    Request: type = struct {
        names: ?[][]const u8 = null,
        arns: ?[][]const u8 = null,
        type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .arns = "Arns",
                .type = "Type",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_images) } {
            return .{ .service_metadata = service_metadata, .action = describe_images };
        }
    },
    Response: type = struct {
        images: ?[]Image = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .images = "Images",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        ResourceNotFound,
    },
} = .{};
pub const describe_sessions: struct {
    action_name: []const u8 = "DescribeSessions",
    Request: type = struct {
        stack_name: []const u8,
        fleet_name: []const u8,
        user_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,
        authentication_type: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_name = "StackName",
                .fleet_name = "FleetName",
                .user_id = "UserId",
                .next_token = "NextToken",
                .limit = "Limit",
                .authentication_type = "AuthenticationType",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_sessions) } {
            return .{ .service_metadata = service_metadata, .action = describe_sessions };
        }
    },
    Response: type = struct {
        sessions: ?[]struct {
            id: []const u8,
            user_id: []const u8,
            stack_name: []const u8,
            fleet_name: []const u8,
            state: []const u8,
            connection_state: ?[]const u8 = null,
            start_time: ?i64 = null,
            max_expiration_time: ?i64 = null,
            authentication_type: ?[]const u8 = null,
            network_access_configuration: ?NetworkAccessConfiguration = null,
            instance_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .user_id = "UserId",
                    .stack_name = "StackName",
                    .fleet_name = "FleetName",
                    .state = "State",
                    .connection_state = "ConnectionState",
                    .start_time = "StartTime",
                    .max_expiration_time = "MaxExpirationTime",
                    .authentication_type = "AuthenticationType",
                    .network_access_configuration = "NetworkAccessConfiguration",
                    .instance_id = "InstanceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sessions = "Sessions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
    },
} = .{};
pub const describe_stacks: struct {
    action_name: []const u8 = "DescribeStacks",
    Request: type = struct {
        names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stacks) } {
            return .{ .service_metadata = service_metadata, .action = describe_stacks };
        }
    },
    Response: type = struct {
        stacks: ?[]Stack = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stacks = "Stacks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_usage_report_subscriptions: struct {
    action_name: []const u8 = "DescribeUsageReportSubscriptions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_usage_report_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_usage_report_subscriptions };
        }
    },
    Response: type = struct {
        usage_report_subscriptions: ?[]struct {
            s3_bucket_name: ?[]const u8 = null,
            schedule: ?[]const u8 = null,
            last_generated_report_date: ?i64 = null,
            subscription_errors: ?[]struct {
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_message = "ErrorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_bucket_name = "S3BucketName",
                    .schedule = "Schedule",
                    .last_generated_report_date = "LastGeneratedReportDate",
                    .subscription_errors = "SubscriptionErrors",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_report_subscriptions = "UsageReportSubscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAccountStatus,
        ResourceNotFound,
    },
} = .{};
pub const describe_users: struct {
    action_name: []const u8 = "DescribeUsers",
    Request: type = struct {
        authentication_type: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_type = "AuthenticationType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_users) } {
            return .{ .service_metadata = service_metadata, .action = describe_users };
        }
    },
    Response: type = struct {
        users: ?[]struct {
            arn: ?[]const u8 = null,
            user_name: ?[]const u8 = null,
            enabled: ?bool = null,
            status: ?[]const u8 = null,
            first_name: ?[]const u8 = null,
            last_name: ?[]const u8 = null,
            created_time: ?i64 = null,
            authentication_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .user_name = "UserName",
                    .enabled = "Enabled",
                    .status = "Status",
                    .first_name = "FirstName",
                    .last_name = "LastName",
                    .created_time = "CreatedTime",
                    .authentication_type = "AuthenticationType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const describe_user_stack_associations: struct {
    action_name: []const u8 = "DescribeUserStackAssociations",
    Request: type = struct {
        stack_name: ?[]const u8 = null,
        user_name: ?[]const u8 = null,
        authentication_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_name = "StackName",
                .user_name = "UserName",
                .authentication_type = "AuthenticationType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_stack_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_stack_associations };
        }
    },
    Response: type = struct {
        user_stack_associations: ?[]UserStackAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_stack_associations = "UserStackAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        OperationNotPermitted,
    },
} = .{};
pub const disable_user: struct {
    action_name: []const u8 = "DisableUser",
    Request: type = struct {
        user_name: []const u8,
        authentication_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .authentication_type = "AuthenticationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_user) } {
            return .{ .service_metadata = service_metadata, .action = disable_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const disassociate_app_block_builder_app_block: struct {
    action_name: []const u8 = "DisassociateAppBlockBuilderAppBlock",
    Request: type = struct {
        app_block_arn: []const u8,
        app_block_builder_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_arn = "AppBlockArn",
                .app_block_builder_name = "AppBlockBuilderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_app_block_builder_app_block) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_app_block_builder_app_block };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidParameterCombination,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_application_fleet: struct {
    action_name: []const u8 = "DisassociateApplicationFleet",
    Request: type = struct {
        fleet_name: []const u8,
        application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_name = "FleetName",
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_application_fleet) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_application_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidParameterCombination,
        OperationNotPermitted,
    },
} = .{};
pub const disassociate_application_from_entitlement: struct {
    action_name: []const u8 = "DisassociateApplicationFromEntitlement",
    Request: type = struct {
        stack_name: []const u8,
        entitlement_name: []const u8,
        application_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_name = "StackName",
                .entitlement_name = "EntitlementName",
                .application_identifier = "ApplicationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_application_from_entitlement) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_application_from_entitlement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntitlementNotFound,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_fleet: struct {
    action_name: []const u8 = "DisassociateFleet",
    Request: type = struct {
        fleet_name: []const u8,
        stack_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_name = "FleetName",
                .stack_name = "StackName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_fleet) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const enable_user: struct {
    action_name: []const u8 = "EnableUser",
    Request: type = struct {
        user_name: []const u8,
        authentication_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .authentication_type = "AuthenticationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_user) } {
            return .{ .service_metadata = service_metadata, .action = enable_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAccountStatus,
        ResourceNotFound,
    },
} = .{};
pub const expire_session: struct {
    action_name: []const u8 = "ExpireSession",
    Request: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(expire_session) } {
            return .{ .service_metadata = service_metadata, .action = expire_session };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_associated_fleets: struct {
    action_name: []const u8 = "ListAssociatedFleets",
    Request: type = struct {
        stack_name: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_name = "StackName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associated_fleets) } {
            return .{ .service_metadata = service_metadata, .action = list_associated_fleets };
        }
    },
    Response: type = struct {
        names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_associated_stacks: struct {
    action_name: []const u8 = "ListAssociatedStacks",
    Request: type = struct {
        fleet_name: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_name = "FleetName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associated_stacks) } {
            return .{ .service_metadata = service_metadata, .action = list_associated_stacks };
        }
    },
    Response: type = struct {
        names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_entitled_applications: struct {
    action_name: []const u8 = "ListEntitledApplications",
    Request: type = struct {
        stack_name: []const u8,
        entitlement_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_name = "StackName",
                .entitlement_name = "EntitlementName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_entitled_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_entitled_applications };
        }
    },
    Response: type = struct {
        entitled_applications: ?[]struct {
            application_identifier: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_identifier = "ApplicationIdentifier",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitled_applications = "EntitledApplications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntitlementNotFound,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const start_app_block_builder: struct {
    action_name: []const u8 = "StartAppBlockBuilder",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_app_block_builder) } {
            return .{ .service_metadata = service_metadata, .action = start_app_block_builder };
        }
    },
    Response: type = struct {
        app_block_builder: ?AppBlockBuilder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_builder = "AppBlockBuilder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidAccountStatus,
        LimitExceeded,
        OperationNotPermitted,
        RequestLimitExceeded,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const start_fleet: struct {
    action_name: []const u8 = "StartFleet",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_fleet) } {
            return .{ .service_metadata = service_metadata, .action = start_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidAccountStatus,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        RequestLimitExceeded,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const start_image_builder: struct {
    action_name: []const u8 = "StartImageBuilder",
    Request: type = struct {
        name: []const u8,
        appstream_agent_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .appstream_agent_version = "AppstreamAgentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_image_builder) } {
            return .{ .service_metadata = service_metadata, .action = start_image_builder };
        }
    },
    Response: type = struct {
        image_builder: ?ImageBuilder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_builder = "ImageBuilder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        IncompatibleImage,
        InvalidAccountStatus,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const stop_app_block_builder: struct {
    action_name: []const u8 = "StopAppBlockBuilder",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_app_block_builder) } {
            return .{ .service_metadata = service_metadata, .action = stop_app_block_builder };
        }
    },
    Response: type = struct {
        app_block_builder: ?AppBlockBuilder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_builder = "AppBlockBuilder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const stop_fleet: struct {
    action_name: []const u8 = "StopFleet",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_fleet) } {
            return .{ .service_metadata = service_metadata, .action = stop_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        ResourceNotFound,
    },
} = .{};
pub const stop_image_builder: struct {
    action_name: []const u8 = "StopImageBuilder",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_image_builder) } {
            return .{ .service_metadata = service_metadata, .action = stop_image_builder };
        }
    },
    Response: type = struct {
        image_builder: ?ImageBuilder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_builder = "ImageBuilder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAccountStatus,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_app_block_builder: struct {
    action_name: []const u8 = "UpdateAppBlockBuilder",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        platform: ?[]const u8 = null,
        instance_type: ?[]const u8 = null,
        vpc_config: ?VpcConfig = null,
        enable_default_internet_access: ?bool = null,
        iam_role_arn: ?[]const u8 = null,
        access_endpoints: ?[]AccessEndpoint = null,
        attributes_to_delete: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .display_name = "DisplayName",
                .platform = "Platform",
                .instance_type = "InstanceType",
                .vpc_config = "VpcConfig",
                .enable_default_internet_access = "EnableDefaultInternetAccess",
                .iam_role_arn = "IamRoleArn",
                .access_endpoints = "AccessEndpoints",
                .attributes_to_delete = "AttributesToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_block_builder) } {
            return .{ .service_metadata = service_metadata, .action = update_app_block_builder };
        }
    },
    Response: type = struct {
        app_block_builder: ?AppBlockBuilder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_block_builder = "AppBlockBuilder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidAccountStatus,
        InvalidParameterCombination,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        RequestLimitExceeded,
        ResourceInUse,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const update_application: struct {
    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        name: []const u8,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        icon_s3_location: ?S3Location = null,
        launch_path: ?[]const u8 = null,
        working_directory: ?[]const u8 = null,
        launch_parameters: ?[]const u8 = null,
        app_block_arn: ?[]const u8 = null,
        attributes_to_delete: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .display_name = "DisplayName",
                .description = "Description",
                .icon_s3_location = "IconS3Location",
                .launch_path = "LaunchPath",
                .working_directory = "WorkingDirectory",
                .launch_parameters = "LaunchParameters",
                .app_block_arn = "AppBlockArn",
                .attributes_to_delete = "AttributesToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {
        application: ?Application = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "Application",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const update_directory_config: struct {
    action_name: []const u8 = "UpdateDirectoryConfig",
    Request: type = struct {
        directory_name: []const u8,
        organizational_unit_distinguished_names: ?[][]const u8 = null,
        service_account_credentials: ?ServiceAccountCredentials = null,
        certificate_based_auth_properties: ?CertificateBasedAuthProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_name = "DirectoryName",
                .organizational_unit_distinguished_names = "OrganizationalUnitDistinguishedNames",
                .service_account_credentials = "ServiceAccountCredentials",
                .certificate_based_auth_properties = "CertificateBasedAuthProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_directory_config) } {
            return .{ .service_metadata = service_metadata, .action = update_directory_config };
        }
    },
    Response: type = struct {
        directory_config: ?DirectoryConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_config = "DirectoryConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidRole,
        OperationNotPermitted,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_entitlement: struct {
    action_name: []const u8 = "UpdateEntitlement",
    Request: type = struct {
        name: []const u8,
        stack_name: []const u8,
        description: ?[]const u8 = null,
        app_visibility: ?[]const u8 = null,
        attributes: ?[]EntitlementAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .stack_name = "StackName",
                .description = "Description",
                .app_visibility = "AppVisibility",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_entitlement) } {
            return .{ .service_metadata = service_metadata, .action = update_entitlement };
        }
    },
    Response: type = struct {
        entitlement: ?Entitlement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlement = "Entitlement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntitlementNotFound,
        OperationNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const update_fleet: struct {
    action_name: []const u8 = "UpdateFleet",
    Request: type = struct {
        image_name: ?[]const u8 = null,
        image_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        instance_type: ?[]const u8 = null,
        compute_capacity: ?ComputeCapacity = null,
        vpc_config: ?VpcConfig = null,
        max_user_duration_in_seconds: ?i64 = null,
        disconnect_timeout_in_seconds: ?i64 = null,
        delete_vpc_config: ?bool = null,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        enable_default_internet_access: ?bool = null,
        domain_join_info: ?DomainJoinInfo = null,
        idle_disconnect_timeout_in_seconds: ?i64 = null,
        attributes_to_delete: ?[][]const u8 = null,
        iam_role_arn: ?[]const u8 = null,
        stream_view: ?[]const u8 = null,
        platform: ?[]const u8 = null,
        max_concurrent_sessions: ?i64 = null,
        usb_device_filter_strings: ?[][]const u8 = null,
        session_script_s3_location: ?S3Location = null,
        max_sessions_per_instance: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_name = "ImageName",
                .image_arn = "ImageArn",
                .name = "Name",
                .instance_type = "InstanceType",
                .compute_capacity = "ComputeCapacity",
                .vpc_config = "VpcConfig",
                .max_user_duration_in_seconds = "MaxUserDurationInSeconds",
                .disconnect_timeout_in_seconds = "DisconnectTimeoutInSeconds",
                .delete_vpc_config = "DeleteVpcConfig",
                .description = "Description",
                .display_name = "DisplayName",
                .enable_default_internet_access = "EnableDefaultInternetAccess",
                .domain_join_info = "DomainJoinInfo",
                .idle_disconnect_timeout_in_seconds = "IdleDisconnectTimeoutInSeconds",
                .attributes_to_delete = "AttributesToDelete",
                .iam_role_arn = "IamRoleArn",
                .stream_view = "StreamView",
                .platform = "Platform",
                .max_concurrent_sessions = "MaxConcurrentSessions",
                .usb_device_filter_strings = "UsbDeviceFilterStrings",
                .session_script_s3_location = "SessionScriptS3Location",
                .max_sessions_per_instance = "MaxSessionsPerInstance",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_fleet) } {
            return .{ .service_metadata = service_metadata, .action = update_fleet };
        }
    },
    Response: type = struct {
        fleet: ?Fleet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet = "Fleet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        IncompatibleImage,
        InvalidAccountStatus,
        InvalidParameterCombination,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        RequestLimitExceeded,
        ResourceInUse,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const update_image_permissions: struct {
    action_name: []const u8 = "UpdateImagePermissions",
    Request: type = struct {
        name: []const u8,
        shared_account_id: []const u8,
        image_permissions: ImagePermissions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .shared_account_id = "SharedAccountId",
                .image_permissions = "ImagePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_image_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_image_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotAvailable,
        ResourceNotFound,
    },
} = .{};
pub const update_stack: struct {
    action_name: []const u8 = "UpdateStack",
    Request: type = struct {
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        name: []const u8,
        storage_connectors: ?[]StorageConnector = null,
        delete_storage_connectors: ?bool = null,
        redirect_url: ?[]const u8 = null,
        feedback_url: ?[]const u8 = null,
        attributes_to_delete: ?[][]const u8 = null,
        user_settings: ?[]UserSetting = null,
        application_settings: ?ApplicationSettings = null,
        access_endpoints: ?[]AccessEndpoint = null,
        embed_host_domains: ?[][]const u8 = null,
        streaming_experience_settings: ?StreamingExperienceSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .display_name = "DisplayName",
                .description = "Description",
                .name = "Name",
                .storage_connectors = "StorageConnectors",
                .delete_storage_connectors = "DeleteStorageConnectors",
                .redirect_url = "RedirectURL",
                .feedback_url = "FeedbackURL",
                .attributes_to_delete = "AttributesToDelete",
                .user_settings = "UserSettings",
                .application_settings = "ApplicationSettings",
                .access_endpoints = "AccessEndpoints",
                .embed_host_domains = "EmbedHostDomains",
                .streaming_experience_settings = "StreamingExperienceSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_stack) } {
            return .{ .service_metadata = service_metadata, .action = update_stack };
        }
    },
    Response: type = struct {
        stack: ?Stack = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack = "Stack",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        IncompatibleImage,
        InvalidAccountStatus,
        InvalidParameterCombination,
        InvalidRole,
        LimitExceeded,
        OperationNotPermitted,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};

pub const Stack = struct {
    arn: ?[]const u8 = null,
    name: []const u8,
    description: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    created_time: ?i64 = null,
    storage_connectors: ?[]StorageConnector = null,
    redirect_url: ?[]const u8 = null,
    feedback_url: ?[]const u8 = null,
    stack_errors: ?[]StackError = null,
    user_settings: ?[]UserSetting = null,
    application_settings: ?ApplicationSettingsResponse = null,
    access_endpoints: ?[]AccessEndpoint = null,
    embed_host_domains: ?[][]const u8 = null,
    streaming_experience_settings: ?StreamingExperienceSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
            .description = "Description",
            .display_name = "DisplayName",
            .created_time = "CreatedTime",
            .storage_connectors = "StorageConnectors",
            .redirect_url = "RedirectURL",
            .feedback_url = "FeedbackURL",
            .stack_errors = "StackErrors",
            .user_settings = "UserSettings",
            .application_settings = "ApplicationSettings",
            .access_endpoints = "AccessEndpoints",
            .embed_host_domains = "EmbedHostDomains",
            .streaming_experience_settings = "StreamingExperienceSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingExperienceSettings = struct {
    preferred_protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .preferred_protocol = "PreferredProtocol",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessEndpoint = struct {
    endpoint_type: []const u8,
    vpce_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_type = "EndpointType",
            .vpce_id = "VpceId",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationSettingsResponse = struct {
    enabled: ?bool = null,
    settings_group: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .settings_group = "SettingsGroup",
            .s3_bucket_name = "S3BucketName",
        };
        return @field(mappings, field_name);
    }
};

pub const UserSetting = struct {
    action: []const u8,
    permission: []const u8,
    maximum_length: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .permission = "Permission",
            .maximum_length = "MaximumLength",
        };
        return @field(mappings, field_name);
    }
};

pub const StackError = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageConnector = struct {
    connector_type: []const u8,
    resource_identifier: ?[]const u8 = null,
    domains: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_type = "ConnectorType",
            .resource_identifier = "ResourceIdentifier",
            .domains = "Domains",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationSettings = struct {
    enabled: bool,
    settings_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .settings_group = "SettingsGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const ImagePermissions = struct {
    allow_fleet: ?bool = null,
    allow_image_builder: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_fleet = "allowFleet",
            .allow_image_builder = "allowImageBuilder",
        };
        return @field(mappings, field_name);
    }
};

pub const Fleet = struct {
    arn: []const u8,
    name: []const u8,
    display_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    image_name: ?[]const u8 = null,
    image_arn: ?[]const u8 = null,
    instance_type: []const u8,
    fleet_type: ?[]const u8 = null,
    compute_capacity_status: ComputeCapacityStatus,
    max_user_duration_in_seconds: ?i64 = null,
    disconnect_timeout_in_seconds: ?i64 = null,
    state: []const u8,
    vpc_config: ?VpcConfig = null,
    created_time: ?i64 = null,
    fleet_errors: ?[]FleetError = null,
    enable_default_internet_access: ?bool = null,
    domain_join_info: ?DomainJoinInfo = null,
    idle_disconnect_timeout_in_seconds: ?i64 = null,
    iam_role_arn: ?[]const u8 = null,
    stream_view: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    max_concurrent_sessions: ?i64 = null,
    usb_device_filter_strings: ?[][]const u8 = null,
    session_script_s3_location: ?S3Location = null,
    max_sessions_per_instance: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
            .display_name = "DisplayName",
            .description = "Description",
            .image_name = "ImageName",
            .image_arn = "ImageArn",
            .instance_type = "InstanceType",
            .fleet_type = "FleetType",
            .compute_capacity_status = "ComputeCapacityStatus",
            .max_user_duration_in_seconds = "MaxUserDurationInSeconds",
            .disconnect_timeout_in_seconds = "DisconnectTimeoutInSeconds",
            .state = "State",
            .vpc_config = "VpcConfig",
            .created_time = "CreatedTime",
            .fleet_errors = "FleetErrors",
            .enable_default_internet_access = "EnableDefaultInternetAccess",
            .domain_join_info = "DomainJoinInfo",
            .idle_disconnect_timeout_in_seconds = "IdleDisconnectTimeoutInSeconds",
            .iam_role_arn = "IamRoleArn",
            .stream_view = "StreamView",
            .platform = "Platform",
            .max_concurrent_sessions = "MaxConcurrentSessions",
            .usb_device_filter_strings = "UsbDeviceFilterStrings",
            .session_script_s3_location = "SessionScriptS3Location",
            .max_sessions_per_instance = "MaxSessionsPerInstance",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    s3_bucket: []const u8,
    s3_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key = "S3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainJoinInfo = struct {
    directory_name: ?[]const u8 = null,
    organizational_unit_distinguished_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .directory_name = "DirectoryName",
            .organizational_unit_distinguished_name = "OrganizationalUnitDistinguishedName",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetError = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfig = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeCapacityStatus = struct {
    desired: i64,
    running: ?i64 = null,
    in_use: ?i64 = null,
    available: ?i64 = null,
    desired_user_sessions: ?i64 = null,
    available_user_sessions: ?i64 = null,
    active_user_sessions: ?i64 = null,
    actual_user_sessions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .desired = "Desired",
            .running = "Running",
            .in_use = "InUse",
            .available = "Available",
            .desired_user_sessions = "DesiredUserSessions",
            .available_user_sessions = "AvailableUserSessions",
            .active_user_sessions = "ActiveUserSessions",
            .actual_user_sessions = "ActualUserSessions",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeCapacity = struct {
    desired_instances: ?i64 = null,
    desired_sessions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .desired_instances = "DesiredInstances",
            .desired_sessions = "DesiredSessions",
        };
        return @field(mappings, field_name);
    }
};

pub const Entitlement = struct {
    name: []const u8,
    stack_name: []const u8,
    description: ?[]const u8 = null,
    app_visibility: []const u8,
    attributes: []EntitlementAttribute,
    created_time: ?i64 = null,
    last_modified_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .stack_name = "StackName",
            .description = "Description",
            .app_visibility = "AppVisibility",
            .attributes = "Attributes",
            .created_time = "CreatedTime",
            .last_modified_time = "LastModifiedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const EntitlementAttribute = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DirectoryConfig = struct {
    directory_name: []const u8,
    organizational_unit_distinguished_names: ?[][]const u8 = null,
    service_account_credentials: ?ServiceAccountCredentials = null,
    created_time: ?i64 = null,
    certificate_based_auth_properties: ?CertificateBasedAuthProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .directory_name = "DirectoryName",
            .organizational_unit_distinguished_names = "OrganizationalUnitDistinguishedNames",
            .service_account_credentials = "ServiceAccountCredentials",
            .created_time = "CreatedTime",
            .certificate_based_auth_properties = "CertificateBasedAuthProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateBasedAuthProperties = struct {
    status: ?[]const u8 = null,
    certificate_authority_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .certificate_authority_arn = "CertificateAuthorityArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceAccountCredentials = struct {
    account_name: []const u8,
    account_password: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_name = "AccountName",
            .account_password = "AccountPassword",
        };
        return @field(mappings, field_name);
    }
};

pub const Application = struct {
    name: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    icon_url: ?[]const u8 = null,
    launch_path: ?[]const u8 = null,
    launch_parameters: ?[]const u8 = null,
    enabled: ?bool = null,
    metadata: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    working_directory: ?[]const u8 = null,
    description: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    app_block_arn: ?[]const u8 = null,
    icon_s3_location: ?S3Location = null,
    platforms: ?[][]const u8 = null,
    instance_families: ?[][]const u8 = null,
    created_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .display_name = "DisplayName",
            .icon_url = "IconURL",
            .launch_path = "LaunchPath",
            .launch_parameters = "LaunchParameters",
            .enabled = "Enabled",
            .metadata = "Metadata",
            .working_directory = "WorkingDirectory",
            .description = "Description",
            .arn = "Arn",
            .app_block_arn = "AppBlockArn",
            .icon_s3_location = "IconS3Location",
            .platforms = "Platforms",
            .instance_families = "InstanceFamilies",
            .created_time = "CreatedTime",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "metadata", field_name))
            return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
        return false;
    }
};

pub const AppBlockBuilder = struct {
    arn: []const u8,
    name: []const u8,
    display_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    platform: []const u8,
    instance_type: []const u8,
    enable_default_internet_access: ?bool = null,
    iam_role_arn: ?[]const u8 = null,
    vpc_config: VpcConfig,
    state: []const u8,
    created_time: ?i64 = null,
    app_block_builder_errors: ?[]ResourceError = null,
    state_change_reason: ?AppBlockBuilderStateChangeReason = null,
    access_endpoints: ?[]AccessEndpoint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
            .display_name = "DisplayName",
            .description = "Description",
            .platform = "Platform",
            .instance_type = "InstanceType",
            .enable_default_internet_access = "EnableDefaultInternetAccess",
            .iam_role_arn = "IamRoleArn",
            .vpc_config = "VpcConfig",
            .state = "State",
            .created_time = "CreatedTime",
            .app_block_builder_errors = "AppBlockBuilderErrors",
            .state_change_reason = "StateChangeReason",
            .access_endpoints = "AccessEndpoints",
        };
        return @field(mappings, field_name);
    }
};

pub const AppBlockBuilderStateChangeReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceError = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    error_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
            .error_timestamp = "ErrorTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageBuilder = struct {
    name: []const u8,
    arn: ?[]const u8 = null,
    image_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    vpc_config: ?VpcConfig = null,
    instance_type: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    iam_role_arn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    state_change_reason: ?ImageBuilderStateChangeReason = null,
    created_time: ?i64 = null,
    enable_default_internet_access: ?bool = null,
    domain_join_info: ?DomainJoinInfo = null,
    network_access_configuration: ?NetworkAccessConfiguration = null,
    image_builder_errors: ?[]ResourceError = null,
    appstream_agent_version: ?[]const u8 = null,
    access_endpoints: ?[]AccessEndpoint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .arn = "Arn",
            .image_arn = "ImageArn",
            .description = "Description",
            .display_name = "DisplayName",
            .vpc_config = "VpcConfig",
            .instance_type = "InstanceType",
            .platform = "Platform",
            .iam_role_arn = "IamRoleArn",
            .state = "State",
            .state_change_reason = "StateChangeReason",
            .created_time = "CreatedTime",
            .enable_default_internet_access = "EnableDefaultInternetAccess",
            .domain_join_info = "DomainJoinInfo",
            .network_access_configuration = "NetworkAccessConfiguration",
            .image_builder_errors = "ImageBuilderErrors",
            .appstream_agent_version = "AppstreamAgentVersion",
            .access_endpoints = "AccessEndpoints",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkAccessConfiguration = struct {
    eni_private_ip_address: ?[]const u8 = null,
    eni_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eni_private_ip_address = "EniPrivateIpAddress",
            .eni_id = "EniId",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageBuilderStateChangeReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const UserStackAssociation = struct {
    stack_name: []const u8,
    user_name: []const u8,
    authentication_type: []const u8,
    send_email_notification: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stack_name = "StackName",
            .user_name = "UserName",
            .authentication_type = "AuthenticationType",
            .send_email_notification = "SendEmailNotification",
        };
        return @field(mappings, field_name);
    }
};

pub const Image = struct {
    name: []const u8,
    arn: ?[]const u8 = null,
    base_image_arn: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    state: ?[]const u8 = null,
    visibility: ?[]const u8 = null,
    image_builder_supported: ?bool = null,
    image_builder_name: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    description: ?[]const u8 = null,
    state_change_reason: ?ImageStateChangeReason = null,
    applications: ?[]Application = null,
    created_time: ?i64 = null,
    public_base_image_released_date: ?i64 = null,
    appstream_agent_version: ?[]const u8 = null,
    image_permissions: ?ImagePermissions = null,
    image_errors: ?[]ResourceError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .arn = "Arn",
            .base_image_arn = "BaseImageArn",
            .display_name = "DisplayName",
            .state = "State",
            .visibility = "Visibility",
            .image_builder_supported = "ImageBuilderSupported",
            .image_builder_name = "ImageBuilderName",
            .platform = "Platform",
            .description = "Description",
            .state_change_reason = "StateChangeReason",
            .applications = "Applications",
            .created_time = "CreatedTime",
            .public_base_image_released_date = "PublicBaseImageReleasedDate",
            .appstream_agent_version = "AppstreamAgentVersion",
            .image_permissions = "ImagePermissions",
            .image_errors = "ImageErrors",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageStateChangeReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationFleetAssociation = struct {
    fleet_name: []const u8,
    application_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fleet_name = "FleetName",
            .application_arn = "ApplicationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AppBlock = struct {
    name: []const u8,
    arn: []const u8,
    description: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    source_s3_location: ?S3Location = null,
    setup_script_details: ?ScriptDetails = null,
    created_time: ?i64 = null,
    post_setup_script_details: ?ScriptDetails = null,
    packaging_type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    app_block_errors: ?[]ErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .arn = "Arn",
            .description = "Description",
            .display_name = "DisplayName",
            .source_s3_location = "SourceS3Location",
            .setup_script_details = "SetupScriptDetails",
            .created_time = "CreatedTime",
            .post_setup_script_details = "PostSetupScriptDetails",
            .packaging_type = "PackagingType",
            .state = "State",
            .app_block_errors = "AppBlockErrors",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetails = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ScriptDetails = struct {
    script_s3_location: S3Location,
    executable_path: []const u8,
    executable_parameters: ?[]const u8 = null,
    timeout_in_seconds: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .script_s3_location = "ScriptS3Location",
            .executable_path = "ExecutablePath",
            .executable_parameters = "ExecutableParameters",
            .timeout_in_seconds = "TimeoutInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const AppBlockBuilderAppBlockAssociation = struct {
    app_block_arn: []const u8,
    app_block_builder_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_block_arn = "AppBlockArn",
            .app_block_builder_name = "AppBlockBuilderName",
        };
        return @field(mappings, field_name);
    }
};

pub const UserStackAssociationError = struct {
    user_stack_association: ?UserStackAssociation = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_stack_association = "UserStackAssociation",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};
