const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-23";
pub const sdk_id: []const u8 = "Appflow";
pub const arn_namespace: ?[]const u8 = "appflow";
pub const endpoint_prefix: []const u8 = "appflow";
pub const sigv4_name: []const u8 = "appflow";
pub const name: []const u8 = "SandstoneConfigurationServiceLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-23",
    sdk_id: []const u8 = "Appflow",
    arn_namespace: ?[]const u8 = "appflow",
    endpoint_prefix: []const u8 = "appflow",
    sigv4_name: []const u8 = "appflow",
    name: []const u8 = "SandstoneConfigurationServiceLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_flow_executions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cancel-flow-executions",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelFlowExecutions",
    Request: type = struct {
        flow_name: []const u8,
        execution_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_name = "flowName",
                .execution_ids = "executionIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_flow_executions) } {
            return .{ .service_metadata = service_metadata, .action = cancel_flow_executions };
        }
    },
    Response: type = struct {
        invalid_executions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invalid_executions = "invalidExecutions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_connector_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/create-connector-profile",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConnectorProfile",
    Request: type = struct {
        connector_profile_name: []const u8,
        kms_arn: ?[]const u8 = null,
        connector_type: []const u8,
        connector_label: ?[]const u8 = null,
        connection_mode: []const u8,
        connector_profile_config: ConnectorProfileConfig,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_name = "connectorProfileName",
                .kms_arn = "kmsArn",
                .connector_type = "connectorType",
                .connector_label = "connectorLabel",
                .connection_mode = "connectionMode",
                .connector_profile_config = "connectorProfileConfig",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connector_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_connector_profile };
        }
    },
    Response: type = struct {
        connector_profile_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_arn = "connectorProfileArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ConnectorAuthentication,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/create-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFlow",
    Request: type = struct {
        flow_name: []const u8,
        description: ?[]const u8 = null,
        kms_arn: ?[]const u8 = null,
        trigger_config: TriggerConfig,
        source_flow_config: SourceFlowConfig,
        destination_flow_config_list: []DestinationFlowConfig,
        tasks: []Task,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        metadata_catalog_config: ?MetadataCatalogConfig = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_name = "flowName",
                .description = "description",
                .kms_arn = "kmsArn",
                .trigger_config = "triggerConfig",
                .source_flow_config = "sourceFlowConfig",
                .destination_flow_config_list = "destinationFlowConfigList",
                .tasks = "tasks",
                .tags = "tags",
                .metadata_catalog_config = "metadataCatalogConfig",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_flow) } {
            return .{ .service_metadata = service_metadata, .action = create_flow };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        flow_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .flow_status = "flowStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ConnectorAuthentication,
        ConnectorServer,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_connector_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-connector-profile",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConnectorProfile",
    Request: type = struct {
        connector_profile_name: []const u8,
        force_delete: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_name = "connectorProfileName",
                .force_delete = "forceDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connector_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_connector_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const delete_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFlow",
    Request: type = struct {
        flow_name: []const u8,
        force_delete: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_name = "flowName",
                .force_delete = "forceDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_flow) } {
            return .{ .service_metadata = service_metadata, .action = delete_flow };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const describe_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-connector",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConnector",
    Request: type = struct {
        connector_type: []const u8,
        connector_label: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_type = "connectorType",
                .connector_label = "connectorLabel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connector) } {
            return .{ .service_metadata = service_metadata, .action = describe_connector };
        }
    },
    Response: type = struct {
        connector_configuration: ?ConnectorConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_configuration = "connectorConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_connector_entity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-connector-entity",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConnectorEntity",
    Request: type = struct {
        connector_entity_name: []const u8,
        connector_type: ?[]const u8 = null,
        connector_profile_name: ?[]const u8 = null,
        api_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_entity_name = "connectorEntityName",
                .connector_type = "connectorType",
                .connector_profile_name = "connectorProfileName",
                .api_version = "apiVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connector_entity) } {
            return .{ .service_metadata = service_metadata, .action = describe_connector_entity };
        }
    },
    Response: type = struct {
        connector_entity_fields: []struct {
            identifier: []const u8,
            parent_identifier: ?[]const u8 = null,
            label: ?[]const u8 = null,
            is_primary_key: ?bool = null,
            default_value: ?[]const u8 = null,
            is_deprecated: ?bool = null,
            supported_field_type_details: ?struct {
                v1: struct {
                    field_type: []const u8,
                    filter_operators: [][]const u8,
                    supported_values: ?[][]const u8 = null,
                    value_regex_pattern: ?[]const u8 = null,
                    supported_date_format: ?[]const u8 = null,
                    field_value_range: ?Range = null,
                    field_length_range: ?Range = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .field_type = "fieldType",
                            .filter_operators = "filterOperators",
                            .supported_values = "supportedValues",
                            .value_regex_pattern = "valueRegexPattern",
                            .supported_date_format = "supportedDateFormat",
                            .field_value_range = "fieldValueRange",
                            .field_length_range = "fieldLengthRange",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .v1 = "v1",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            description: ?[]const u8 = null,
            source_properties: ?struct {
                is_retrievable: ?bool = null,
                is_queryable: ?bool = null,
                is_timestamp_field_for_incremental_queries: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .is_retrievable = "isRetrievable",
                        .is_queryable = "isQueryable",
                        .is_timestamp_field_for_incremental_queries = "isTimestampFieldForIncrementalQueries",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            destination_properties: ?struct {
                is_creatable: ?bool = null,
                is_nullable: ?bool = null,
                is_upsertable: ?bool = null,
                is_updatable: ?bool = null,
                is_defaulted_on_create: ?bool = null,
                supported_write_operations: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .is_creatable = "isCreatable",
                        .is_nullable = "isNullable",
                        .is_upsertable = "isUpsertable",
                        .is_updatable = "isUpdatable",
                        .is_defaulted_on_create = "isDefaultedOnCreate",
                        .supported_write_operations = "supportedWriteOperations",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            custom_properties: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identifier = "identifier",
                    .parent_identifier = "parentIdentifier",
                    .label = "label",
                    .is_primary_key = "isPrimaryKey",
                    .default_value = "defaultValue",
                    .is_deprecated = "isDeprecated",
                    .supported_field_type_details = "supportedFieldTypeDetails",
                    .description = "description",
                    .source_properties = "sourceProperties",
                    .destination_properties = "destinationProperties",
                    .custom_properties = "customProperties",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "custom_properties", field_name))
                    return try serializeMap(self.custom_properties, self.fieldNameFor("custom_properties"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_entity_fields = "connectorEntityFields",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConnectorAuthentication,
        ConnectorServer,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_connector_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-connector-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConnectorProfiles",
    Request: type = struct {
        connector_profile_names: ?[][]const u8 = null,
        connector_type: ?[]const u8 = null,
        connector_label: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_names = "connectorProfileNames",
                .connector_type = "connectorType",
                .connector_label = "connectorLabel",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connector_profiles) } {
            return .{ .service_metadata = service_metadata, .action = describe_connector_profiles };
        }
    },
    Response: type = struct {
        connector_profile_details: ?[]struct {
            connector_profile_arn: ?[]const u8 = null,
            connector_profile_name: ?[]const u8 = null,
            connector_type: ?[]const u8 = null,
            connector_label: ?[]const u8 = null,
            connection_mode: ?[]const u8 = null,
            credentials_arn: ?[]const u8 = null,
            connector_profile_properties: ?ConnectorProfileProperties = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            private_connection_provisioning_state: ?struct {
                status: ?[]const u8 = null,
                failure_message: ?[]const u8 = null,
                failure_cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "status",
                        .failure_message = "failureMessage",
                        .failure_cause = "failureCause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connector_profile_arn = "connectorProfileArn",
                    .connector_profile_name = "connectorProfileName",
                    .connector_type = "connectorType",
                    .connector_label = "connectorLabel",
                    .connection_mode = "connectionMode",
                    .credentials_arn = "credentialsArn",
                    .connector_profile_properties = "connectorProfileProperties",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .private_connection_provisioning_state = "privateConnectionProvisioningState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_details = "connectorProfileDetails",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_connectors: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-connectors",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConnectors",
    Request: type = struct {
        connector_types: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_types = "connectorTypes",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connectors) } {
            return .{ .service_metadata = service_metadata, .action = describe_connectors };
        }
    },
    Response: type = struct {
        connector_configurations: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ConnectorConfiguration = null,
        } = null,
        connectors: ?[]ConnectorDetail = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_configurations = "connectorConfigurations",
                .connectors = "connectors",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "connector_configurations", field_name))
                return try serializeMap(self.connector_configurations, self.fieldNameFor("connector_configurations"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFlow",
    Request: type = struct {
        flow_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_name = "flowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_flow) } {
            return .{ .service_metadata = service_metadata, .action = describe_flow };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        flow_name: ?[]const u8 = null,
        kms_arn: ?[]const u8 = null,
        flow_status: ?[]const u8 = null,
        flow_status_message: ?[]const u8 = null,
        source_flow_config: ?SourceFlowConfig = null,
        destination_flow_config_list: ?[]DestinationFlowConfig = null,
        last_run_execution_details: ?ExecutionDetails = null,
        trigger_config: ?TriggerConfig = null,
        tasks: ?[]Task = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        created_by: ?[]const u8 = null,
        last_updated_by: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        metadata_catalog_config: ?MetadataCatalogConfig = null,
        last_run_metadata_catalog_details: ?[]MetadataCatalogDetail = null,
        schema_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .description = "description",
                .flow_name = "flowName",
                .kms_arn = "kmsArn",
                .flow_status = "flowStatus",
                .flow_status_message = "flowStatusMessage",
                .source_flow_config = "sourceFlowConfig",
                .destination_flow_config_list = "destinationFlowConfigList",
                .last_run_execution_details = "lastRunExecutionDetails",
                .trigger_config = "triggerConfig",
                .tasks = "tasks",
                .created_at = "createdAt",
                .last_updated_at = "lastUpdatedAt",
                .created_by = "createdBy",
                .last_updated_by = "lastUpdatedBy",
                .tags = "tags",
                .metadata_catalog_config = "metadataCatalogConfig",
                .last_run_metadata_catalog_details = "lastRunMetadataCatalogDetails",
                .schema_version = "schemaVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const describe_flow_execution_records: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-flow-execution-records",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFlowExecutionRecords",
    Request: type = struct {
        flow_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_name = "flowName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_flow_execution_records) } {
            return .{ .service_metadata = service_metadata, .action = describe_flow_execution_records };
        }
    },
    Response: type = struct {
        flow_executions: ?[]struct {
            execution_id: ?[]const u8 = null,
            execution_status: ?[]const u8 = null,
            execution_result: ?struct {
                error_info: ?struct {
                    put_failures_count: ?i64 = null,
                    execution_message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .put_failures_count = "putFailuresCount",
                            .execution_message = "executionMessage",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                bytes_processed: ?i64 = null,
                bytes_written: ?i64 = null,
                records_processed: ?i64 = null,
                num_parallel_processes: ?i64 = null,
                max_page_size: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_info = "errorInfo",
                        .bytes_processed = "bytesProcessed",
                        .bytes_written = "bytesWritten",
                        .records_processed = "recordsProcessed",
                        .num_parallel_processes = "numParallelProcesses",
                        .max_page_size = "maxPageSize",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            started_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            data_pull_start_time: ?i64 = null,
            data_pull_end_time: ?i64 = null,
            metadata_catalog_details: ?[]MetadataCatalogDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_id = "executionId",
                    .execution_status = "executionStatus",
                    .execution_result = "executionResult",
                    .started_at = "startedAt",
                    .last_updated_at = "lastUpdatedAt",
                    .data_pull_start_time = "dataPullStartTime",
                    .data_pull_end_time = "dataPullEndTime",
                    .metadata_catalog_details = "metadataCatalogDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_executions = "flowExecutions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_connector_entities: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-connector-entities",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConnectorEntities",
    Request: type = struct {
        connector_profile_name: ?[]const u8 = null,
        connector_type: ?[]const u8 = null,
        entities_path: ?[]const u8 = null,
        api_version: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_name = "connectorProfileName",
                .connector_type = "connectorType",
                .entities_path = "entitiesPath",
                .api_version = "apiVersion",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connector_entities) } {
            return .{ .service_metadata = service_metadata, .action = list_connector_entities };
        }
    },
    Response: type = struct {
        connector_entity_map: []struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                name: []const u8,
                label: ?[]const u8 = null,
                has_nested_entities: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .label = "label",
                        .has_nested_entities = "hasNestedEntities",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_entity_map = "connectorEntityMap",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "connector_entity_map", field_name))
                return try serializeMap(self.connector_entity_map, self.fieldNameFor("connector_entity_map"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConnectorAuthentication,
        ConnectorServer,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_connectors: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-connectors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConnectors",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connectors) } {
            return .{ .service_metadata = service_metadata, .action = list_connectors };
        }
    },
    Response: type = struct {
        connectors: ?[]ConnectorDetail = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connectors = "connectors",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_flows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-flows",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFlows",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_flows) } {
            return .{ .service_metadata = service_metadata, .action = list_flows };
        }
    },
    Response: type = struct {
        flows: ?[]struct {
            flow_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            flow_name: ?[]const u8 = null,
            flow_status: ?[]const u8 = null,
            source_connector_type: ?[]const u8 = null,
            source_connector_label: ?[]const u8 = null,
            destination_connector_type: ?[]const u8 = null,
            destination_connector_label: ?[]const u8 = null,
            trigger_type: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            created_by: ?[]const u8 = null,
            last_updated_by: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            last_run_execution_details: ?ExecutionDetails = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .flow_arn = "flowArn",
                    .description = "description",
                    .flow_name = "flowName",
                    .flow_status = "flowStatus",
                    .source_connector_type = "sourceConnectorType",
                    .source_connector_label = "sourceConnectorLabel",
                    .destination_connector_type = "destinationConnectorType",
                    .destination_connector_label = "destinationConnectorLabel",
                    .trigger_type = "triggerType",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .created_by = "createdBy",
                    .last_updated_by = "lastUpdatedBy",
                    .tags = "tags",
                    .last_run_execution_details = "lastRunExecutionDetails",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flows = "flows",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const register_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/register-connector",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterConnector",
    Request: type = struct {
        connector_label: ?[]const u8 = null,
        description: ?[]const u8 = null,
        connector_provisioning_type: ?[]const u8 = null,
        connector_provisioning_config: ?ConnectorProvisioningConfig = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_label = "connectorLabel",
                .description = "description",
                .connector_provisioning_type = "connectorProvisioningType",
                .connector_provisioning_config = "connectorProvisioningConfig",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_connector) } {
            return .{ .service_metadata = service_metadata, .action = register_connector };
        }
    },
    Response: type = struct {
        connector_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_arn = "connectorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ConnectorAuthentication,
        ConnectorServer,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const reset_connector_metadata_cache: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/reset-connector-metadata-cache",
        .success_code = 200,
    };

    action_name: []const u8 = "ResetConnectorMetadataCache",
    Request: type = struct {
        connector_profile_name: ?[]const u8 = null,
        connector_type: ?[]const u8 = null,
        connector_entity_name: ?[]const u8 = null,
        entities_path: ?[]const u8 = null,
        api_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_name = "connectorProfileName",
                .connector_type = "connectorType",
                .connector_entity_name = "connectorEntityName",
                .entities_path = "entitiesPath",
                .api_version = "apiVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_connector_metadata_cache) } {
            return .{ .service_metadata = service_metadata, .action = reset_connector_metadata_cache };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/start-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "StartFlow",
    Request: type = struct {
        flow_name: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_name = "flowName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_flow) } {
            return .{ .service_metadata = service_metadata, .action = start_flow };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        flow_status: ?[]const u8 = null,
        execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .flow_status = "flowStatus",
                .execution_id = "executionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
    },
} = .{};
pub const stop_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/stop-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "StopFlow",
    Request: type = struct {
        flow_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_name = "flowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_flow) } {
            return .{ .service_metadata = service_metadata, .action = stop_flow };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        flow_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .flow_status = "flowStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const unregister_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/unregister-connector",
        .success_code = 200,
    };

    action_name: []const u8 = "UnregisterConnector",
    Request: type = struct {
        connector_label: []const u8,
        force_delete: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_label = "connectorLabel",
                .force_delete = "forceDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unregister_connector) } {
            return .{ .service_metadata = service_metadata, .action = unregister_connector };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_connector_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-connector-profile",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConnectorProfile",
    Request: type = struct {
        connector_profile_name: []const u8,
        connection_mode: []const u8,
        connector_profile_config: ConnectorProfileConfig,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_name = "connectorProfileName",
                .connection_mode = "connectionMode",
                .connector_profile_config = "connectorProfileConfig",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connector_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_connector_profile };
        }
    },
    Response: type = struct {
        connector_profile_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_profile_arn = "connectorProfileArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ConnectorAuthentication,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_connector_registration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-connector-registration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConnectorRegistration",
    Request: type = struct {
        connector_label: []const u8,
        description: ?[]const u8 = null,
        connector_provisioning_config: ?ConnectorProvisioningConfig = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_label = "connectorLabel",
                .description = "description",
                .connector_provisioning_config = "connectorProvisioningConfig",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connector_registration) } {
            return .{ .service_metadata = service_metadata, .action = update_connector_registration };
        }
    },
    Response: type = struct {
        connector_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_arn = "connectorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ConnectorAuthentication,
        ConnectorServer,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFlow",
    Request: type = struct {
        flow_name: []const u8,
        description: ?[]const u8 = null,
        trigger_config: TriggerConfig,
        source_flow_config: SourceFlowConfig,
        destination_flow_config_list: []DestinationFlowConfig,
        tasks: []Task,
        metadata_catalog_config: ?MetadataCatalogConfig = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_name = "flowName",
                .description = "description",
                .trigger_config = "triggerConfig",
                .source_flow_config = "sourceFlowConfig",
                .destination_flow_config_list = "destinationFlowConfigList",
                .tasks = "tasks",
                .metadata_catalog_config = "metadataCatalogConfig",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_flow) } {
            return .{ .service_metadata = service_metadata, .action = update_flow };
        }
    },
    Response: type = struct {
        flow_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_status = "flowStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ConnectorAuthentication,
        ConnectorServer,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};

pub const MetadataCatalogConfig = struct {
    glue_data_catalog: ?GlueDataCatalogConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .glue_data_catalog = "glueDataCatalog",
        };
        return @field(mappings, field_name);
    }
};

pub const GlueDataCatalogConfig = struct {
    role_arn: []const u8,
    database_name: []const u8,
    table_prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .database_name = "databaseName",
            .table_prefix = "tablePrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Task = struct {
    source_fields: [][]const u8,
    connector_operator: ?ConnectorOperator = null,
    destination_field: ?[]const u8 = null,
    task_type: []const u8,
    task_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_fields = "sourceFields",
            .connector_operator = "connectorOperator",
            .destination_field = "destinationField",
            .task_type = "taskType",
            .task_properties = "taskProperties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "task_properties", field_name))
            return try serializeMap(self.task_properties, self.fieldNameFor("task_properties"), options, out_stream);
        return false;
    }
};

pub const ConnectorOperator = struct {
    amplitude: ?[]const u8 = null,
    datadog: ?[]const u8 = null,
    dynatrace: ?[]const u8 = null,
    google_analytics: ?[]const u8 = null,
    infor_nexus: ?[]const u8 = null,
    marketo: ?[]const u8 = null,
    s3: ?[]const u8 = null,
    salesforce: ?[]const u8 = null,
    service_now: ?[]const u8 = null,
    singular: ?[]const u8 = null,
    slack: ?[]const u8 = null,
    trendmicro: ?[]const u8 = null,
    veeva: ?[]const u8 = null,
    zendesk: ?[]const u8 = null,
    sapo_data: ?[]const u8 = null,
    custom_connector: ?[]const u8 = null,
    pardot: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amplitude = "Amplitude",
            .datadog = "Datadog",
            .dynatrace = "Dynatrace",
            .google_analytics = "GoogleAnalytics",
            .infor_nexus = "InforNexus",
            .marketo = "Marketo",
            .s3 = "S3",
            .salesforce = "Salesforce",
            .service_now = "ServiceNow",
            .singular = "Singular",
            .slack = "Slack",
            .trendmicro = "Trendmicro",
            .veeva = "Veeva",
            .zendesk = "Zendesk",
            .sapo_data = "SAPOData",
            .custom_connector = "CustomConnector",
            .pardot = "Pardot",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationFlowConfig = struct {
    connector_type: []const u8,
    api_version: ?[]const u8 = null,
    connector_profile_name: ?[]const u8 = null,
    destination_connector_properties: DestinationConnectorProperties,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_type = "connectorType",
            .api_version = "apiVersion",
            .connector_profile_name = "connectorProfileName",
            .destination_connector_properties = "destinationConnectorProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConnectorProperties = struct {
    redshift: ?RedshiftDestinationProperties = null,
    s3: ?S3DestinationProperties = null,
    salesforce: ?SalesforceDestinationProperties = null,
    snowflake: ?SnowflakeDestinationProperties = null,
    event_bridge: ?EventBridgeDestinationProperties = null,
    lookout_metrics: ?LookoutMetricsDestinationProperties = null,
    upsolver: ?UpsolverDestinationProperties = null,
    honeycode: ?HoneycodeDestinationProperties = null,
    customer_profiles: ?CustomerProfilesDestinationProperties = null,
    zendesk: ?ZendeskDestinationProperties = null,
    marketo: ?MarketoDestinationProperties = null,
    custom_connector: ?CustomConnectorDestinationProperties = null,
    sapo_data: ?SAPODataDestinationProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .redshift = "Redshift",
            .s3 = "S3",
            .salesforce = "Salesforce",
            .snowflake = "Snowflake",
            .event_bridge = "EventBridge",
            .lookout_metrics = "LookoutMetrics",
            .upsolver = "Upsolver",
            .honeycode = "Honeycode",
            .customer_profiles = "CustomerProfiles",
            .zendesk = "Zendesk",
            .marketo = "Marketo",
            .custom_connector = "CustomConnector",
            .sapo_data = "SAPOData",
        };
        return @field(mappings, field_name);
    }
};

pub const SAPODataDestinationProperties = struct {
    object_path: []const u8,
    success_response_handling_config: ?SuccessResponseHandlingConfig = null,
    id_field_names: ?[][]const u8 = null,
    error_handling_config: ?ErrorHandlingConfig = null,
    write_operation_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_path = "objectPath",
            .success_response_handling_config = "successResponseHandlingConfig",
            .id_field_names = "idFieldNames",
            .error_handling_config = "errorHandlingConfig",
            .write_operation_type = "writeOperationType",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorHandlingConfig = struct {
    fail_on_first_destination_error: ?bool = null,
    bucket_prefix: ?[]const u8 = null,
    bucket_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fail_on_first_destination_error = "failOnFirstDestinationError",
            .bucket_prefix = "bucketPrefix",
            .bucket_name = "bucketName",
        };
        return @field(mappings, field_name);
    }
};

pub const SuccessResponseHandlingConfig = struct {
    bucket_prefix: ?[]const u8 = null,
    bucket_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_prefix = "bucketPrefix",
            .bucket_name = "bucketName",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomConnectorDestinationProperties = struct {
    entity_name: []const u8,
    error_handling_config: ?ErrorHandlingConfig = null,
    write_operation_type: ?[]const u8 = null,
    id_field_names: ?[][]const u8 = null,
    custom_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_name = "entityName",
            .error_handling_config = "errorHandlingConfig",
            .write_operation_type = "writeOperationType",
            .id_field_names = "idFieldNames",
            .custom_properties = "customProperties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "custom_properties", field_name))
            return try serializeMap(self.custom_properties, self.fieldNameFor("custom_properties"), options, out_stream);
        return false;
    }
};

pub const MarketoDestinationProperties = struct {
    object: []const u8,
    error_handling_config: ?ErrorHandlingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .error_handling_config = "errorHandlingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ZendeskDestinationProperties = struct {
    object: []const u8,
    id_field_names: ?[][]const u8 = null,
    error_handling_config: ?ErrorHandlingConfig = null,
    write_operation_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .id_field_names = "idFieldNames",
            .error_handling_config = "errorHandlingConfig",
            .write_operation_type = "writeOperationType",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerProfilesDestinationProperties = struct {
    domain_name: []const u8,
    object_type_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "domainName",
            .object_type_name = "objectTypeName",
        };
        return @field(mappings, field_name);
    }
};

pub const HoneycodeDestinationProperties = struct {
    object: []const u8,
    error_handling_config: ?ErrorHandlingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .error_handling_config = "errorHandlingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const UpsolverDestinationProperties = struct {
    bucket_name: []const u8,
    bucket_prefix: ?[]const u8 = null,
    s3_output_format_config: UpsolverS3OutputFormatConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .bucket_prefix = "bucketPrefix",
            .s3_output_format_config = "s3OutputFormatConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const UpsolverS3OutputFormatConfig = struct {
    file_type: ?[]const u8 = null,
    prefix_config: PrefixConfig,
    aggregation_config: ?AggregationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_type = "fileType",
            .prefix_config = "prefixConfig",
            .aggregation_config = "aggregationConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregationConfig = struct {
    aggregation_type: ?[]const u8 = null,
    target_file_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aggregation_type = "aggregationType",
            .target_file_size = "targetFileSize",
        };
        return @field(mappings, field_name);
    }
};

pub const PrefixConfig = struct {
    prefix_type: ?[]const u8 = null,
    prefix_format: ?[]const u8 = null,
    path_prefix_hierarchy: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix_type = "prefixType",
            .prefix_format = "prefixFormat",
            .path_prefix_hierarchy = "pathPrefixHierarchy",
        };
        return @field(mappings, field_name);
    }
};

pub const LookoutMetricsDestinationProperties = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const EventBridgeDestinationProperties = struct {
    object: []const u8,
    error_handling_config: ?ErrorHandlingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .error_handling_config = "errorHandlingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const SnowflakeDestinationProperties = struct {
    object: []const u8,
    intermediate_bucket_name: []const u8,
    bucket_prefix: ?[]const u8 = null,
    error_handling_config: ?ErrorHandlingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .intermediate_bucket_name = "intermediateBucketName",
            .bucket_prefix = "bucketPrefix",
            .error_handling_config = "errorHandlingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceDestinationProperties = struct {
    object: []const u8,
    id_field_names: ?[][]const u8 = null,
    error_handling_config: ?ErrorHandlingConfig = null,
    write_operation_type: ?[]const u8 = null,
    data_transfer_api: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .id_field_names = "idFieldNames",
            .error_handling_config = "errorHandlingConfig",
            .write_operation_type = "writeOperationType",
            .data_transfer_api = "dataTransferApi",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationProperties = struct {
    bucket_name: []const u8,
    bucket_prefix: ?[]const u8 = null,
    s3_output_format_config: ?S3OutputFormatConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .bucket_prefix = "bucketPrefix",
            .s3_output_format_config = "s3OutputFormatConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const S3OutputFormatConfig = struct {
    file_type: ?[]const u8 = null,
    prefix_config: ?PrefixConfig = null,
    aggregation_config: ?AggregationConfig = null,
    preserve_source_data_typing: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_type = "fileType",
            .prefix_config = "prefixConfig",
            .aggregation_config = "aggregationConfig",
            .preserve_source_data_typing = "preserveSourceDataTyping",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftDestinationProperties = struct {
    object: []const u8,
    intermediate_bucket_name: []const u8,
    bucket_prefix: ?[]const u8 = null,
    error_handling_config: ?ErrorHandlingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .intermediate_bucket_name = "intermediateBucketName",
            .bucket_prefix = "bucketPrefix",
            .error_handling_config = "errorHandlingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceFlowConfig = struct {
    connector_type: []const u8,
    api_version: ?[]const u8 = null,
    connector_profile_name: ?[]const u8 = null,
    source_connector_properties: SourceConnectorProperties,
    incremental_pull_config: ?IncrementalPullConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_type = "connectorType",
            .api_version = "apiVersion",
            .connector_profile_name = "connectorProfileName",
            .source_connector_properties = "sourceConnectorProperties",
            .incremental_pull_config = "incrementalPullConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const IncrementalPullConfig = struct {
    datetime_type_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .datetime_type_field_name = "datetimeTypeFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConnectorProperties = struct {
    amplitude: ?AmplitudeSourceProperties = null,
    datadog: ?DatadogSourceProperties = null,
    dynatrace: ?DynatraceSourceProperties = null,
    google_analytics: ?GoogleAnalyticsSourceProperties = null,
    infor_nexus: ?InforNexusSourceProperties = null,
    marketo: ?MarketoSourceProperties = null,
    s3: ?S3SourceProperties = null,
    salesforce: ?SalesforceSourceProperties = null,
    service_now: ?ServiceNowSourceProperties = null,
    singular: ?SingularSourceProperties = null,
    slack: ?SlackSourceProperties = null,
    trendmicro: ?TrendmicroSourceProperties = null,
    veeva: ?VeevaSourceProperties = null,
    zendesk: ?ZendeskSourceProperties = null,
    sapo_data: ?SAPODataSourceProperties = null,
    custom_connector: ?CustomConnectorSourceProperties = null,
    pardot: ?PardotSourceProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amplitude = "Amplitude",
            .datadog = "Datadog",
            .dynatrace = "Dynatrace",
            .google_analytics = "GoogleAnalytics",
            .infor_nexus = "InforNexus",
            .marketo = "Marketo",
            .s3 = "S3",
            .salesforce = "Salesforce",
            .service_now = "ServiceNow",
            .singular = "Singular",
            .slack = "Slack",
            .trendmicro = "Trendmicro",
            .veeva = "Veeva",
            .zendesk = "Zendesk",
            .sapo_data = "SAPOData",
            .custom_connector = "CustomConnector",
            .pardot = "Pardot",
        };
        return @field(mappings, field_name);
    }
};

pub const PardotSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomConnectorSourceProperties = struct {
    entity_name: []const u8,
    custom_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    data_transfer_api: ?DataTransferApi = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_name = "entityName",
            .custom_properties = "customProperties",
            .data_transfer_api = "dataTransferApi",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "custom_properties", field_name))
            return try serializeMap(self.custom_properties, self.fieldNameFor("custom_properties"), options, out_stream);
        return false;
    }
};

pub const DataTransferApi = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const SAPODataSourceProperties = struct {
    object_path: ?[]const u8 = null,
    parallelism_config: ?SAPODataParallelismConfig = null,
    pagination_config: ?SAPODataPaginationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_path = "objectPath",
            .parallelism_config = "parallelismConfig",
            .pagination_config = "paginationConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const SAPODataPaginationConfig = struct {
    max_page_size: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_page_size = "maxPageSize",
        };
        return @field(mappings, field_name);
    }
};

pub const SAPODataParallelismConfig = struct {
    max_parallelism: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_parallelism = "maxParallelism",
        };
        return @field(mappings, field_name);
    }
};

pub const ZendeskSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const VeevaSourceProperties = struct {
    object: []const u8,
    document_type: ?[]const u8 = null,
    include_source_files: ?bool = null,
    include_renditions: ?bool = null,
    include_all_versions: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .document_type = "documentType",
            .include_source_files = "includeSourceFiles",
            .include_renditions = "includeRenditions",
            .include_all_versions = "includeAllVersions",
        };
        return @field(mappings, field_name);
    }
};

pub const TrendmicroSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const SlackSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const SingularSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceSourceProperties = struct {
    object: []const u8,
    enable_dynamic_field_update: ?bool = null,
    include_deleted_records: ?bool = null,
    data_transfer_api: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
            .enable_dynamic_field_update = "enableDynamicFieldUpdate",
            .include_deleted_records = "includeDeletedRecords",
            .data_transfer_api = "dataTransferApi",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SourceProperties = struct {
    bucket_name: []const u8,
    bucket_prefix: ?[]const u8 = null,
    s3_input_format_config: ?S3InputFormatConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .bucket_prefix = "bucketPrefix",
            .s3_input_format_config = "s3InputFormatConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const S3InputFormatConfig = struct {
    s3_input_file_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_input_file_type = "s3InputFileType",
        };
        return @field(mappings, field_name);
    }
};

pub const MarketoSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const InforNexusSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const GoogleAnalyticsSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const DynatraceSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const DatadogSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const AmplitudeSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "object",
        };
        return @field(mappings, field_name);
    }
};

pub const TriggerConfig = struct {
    trigger_type: []const u8,
    trigger_properties: ?TriggerProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trigger_type = "triggerType",
            .trigger_properties = "triggerProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const TriggerProperties = struct {
    scheduled: ?ScheduledTriggerProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scheduled = "Scheduled",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduledTriggerProperties = struct {
    schedule_expression: []const u8,
    data_pull_mode: ?[]const u8 = null,
    schedule_start_time: ?i64 = null,
    schedule_end_time: ?i64 = null,
    timezone: ?[]const u8 = null,
    schedule_offset: ?i64 = null,
    first_execution_from: ?i64 = null,
    flow_error_deactivation_threshold: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "scheduleExpression",
            .data_pull_mode = "dataPullMode",
            .schedule_start_time = "scheduleStartTime",
            .schedule_end_time = "scheduleEndTime",
            .timezone = "timezone",
            .schedule_offset = "scheduleOffset",
            .first_execution_from = "firstExecutionFrom",
            .flow_error_deactivation_threshold = "flowErrorDeactivationThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorProvisioningConfig = struct {
    lambda: ?LambdaConnectorProvisioningConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda = "lambda",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaConnectorProvisioningConfig = struct {
    lambda_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_arn = "lambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorProfileConfig = struct {
    connector_profile_properties: ConnectorProfileProperties,
    connector_profile_credentials: ?ConnectorProfileCredentials = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_profile_properties = "connectorProfileProperties",
            .connector_profile_credentials = "connectorProfileCredentials",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorProfileCredentials = struct {
    amplitude: ?AmplitudeConnectorProfileCredentials = null,
    datadog: ?DatadogConnectorProfileCredentials = null,
    dynatrace: ?DynatraceConnectorProfileCredentials = null,
    google_analytics: ?GoogleAnalyticsConnectorProfileCredentials = null,
    honeycode: ?HoneycodeConnectorProfileCredentials = null,
    infor_nexus: ?InforNexusConnectorProfileCredentials = null,
    marketo: ?MarketoConnectorProfileCredentials = null,
    redshift: ?RedshiftConnectorProfileCredentials = null,
    salesforce: ?SalesforceConnectorProfileCredentials = null,
    service_now: ?ServiceNowConnectorProfileCredentials = null,
    singular: ?SingularConnectorProfileCredentials = null,
    slack: ?SlackConnectorProfileCredentials = null,
    snowflake: ?SnowflakeConnectorProfileCredentials = null,
    trendmicro: ?TrendmicroConnectorProfileCredentials = null,
    veeva: ?VeevaConnectorProfileCredentials = null,
    zendesk: ?ZendeskConnectorProfileCredentials = null,
    sapo_data: ?SAPODataConnectorProfileCredentials = null,
    custom_connector: ?CustomConnectorProfileCredentials = null,
    pardot: ?PardotConnectorProfileCredentials = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amplitude = "Amplitude",
            .datadog = "Datadog",
            .dynatrace = "Dynatrace",
            .google_analytics = "GoogleAnalytics",
            .honeycode = "Honeycode",
            .infor_nexus = "InforNexus",
            .marketo = "Marketo",
            .redshift = "Redshift",
            .salesforce = "Salesforce",
            .service_now = "ServiceNow",
            .singular = "Singular",
            .slack = "Slack",
            .snowflake = "Snowflake",
            .trendmicro = "Trendmicro",
            .veeva = "Veeva",
            .zendesk = "Zendesk",
            .sapo_data = "SAPOData",
            .custom_connector = "CustomConnector",
            .pardot = "Pardot",
        };
        return @field(mappings, field_name);
    }
};

pub const PardotConnectorProfileCredentials = struct {
    access_token: ?[]const u8 = null,
    refresh_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,
    client_credentials_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_token = "accessToken",
            .refresh_token = "refreshToken",
            .o_auth_request = "oAuthRequest",
            .client_credentials_arn = "clientCredentialsArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorOAuthRequest = struct {
    auth_code: ?[]const u8 = null,
    redirect_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auth_code = "authCode",
            .redirect_uri = "redirectUri",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomConnectorProfileCredentials = struct {
    authentication_type: []const u8,
    basic: ?BasicAuthCredentials = null,
    oauth2: ?OAuth2Credentials = null,
    api_key: ?ApiKeyCredentials = null,
    custom: ?CustomAuthCredentials = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authentication_type = "authenticationType",
            .basic = "basic",
            .oauth2 = "oauth2",
            .api_key = "apiKey",
            .custom = "custom",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomAuthCredentials = struct {
    custom_authentication_type: []const u8,
    credentials_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_authentication_type = "customAuthenticationType",
            .credentials_map = "credentialsMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "credentials_map", field_name))
            return try serializeMap(self.credentials_map, self.fieldNameFor("credentials_map"), options, out_stream);
        return false;
    }
};

pub const ApiKeyCredentials = struct {
    api_key: []const u8,
    api_secret_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_key = "apiKey",
            .api_secret_key = "apiSecretKey",
        };
        return @field(mappings, field_name);
    }
};

pub const OAuth2Credentials = struct {
    client_id: ?[]const u8 = null,
    client_secret: ?[]const u8 = null,
    access_token: ?[]const u8 = null,
    refresh_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "clientId",
            .client_secret = "clientSecret",
            .access_token = "accessToken",
            .refresh_token = "refreshToken",
            .o_auth_request = "oAuthRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const BasicAuthCredentials = struct {
    username: []const u8,
    password: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "username",
            .password = "password",
        };
        return @field(mappings, field_name);
    }
};

pub const SAPODataConnectorProfileCredentials = struct {
    basic_auth_credentials: ?BasicAuthCredentials = null,
    o_auth_credentials: ?OAuthCredentials = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .basic_auth_credentials = "basicAuthCredentials",
            .o_auth_credentials = "oAuthCredentials",
        };
        return @field(mappings, field_name);
    }
};

pub const OAuthCredentials = struct {
    client_id: []const u8,
    client_secret: []const u8,
    access_token: ?[]const u8 = null,
    refresh_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "clientId",
            .client_secret = "clientSecret",
            .access_token = "accessToken",
            .refresh_token = "refreshToken",
            .o_auth_request = "oAuthRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const ZendeskConnectorProfileCredentials = struct {
    client_id: []const u8,
    client_secret: []const u8,
    access_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "clientId",
            .client_secret = "clientSecret",
            .access_token = "accessToken",
            .o_auth_request = "oAuthRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const VeevaConnectorProfileCredentials = struct {
    username: []const u8,
    password: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "username",
            .password = "password",
        };
        return @field(mappings, field_name);
    }
};

pub const TrendmicroConnectorProfileCredentials = struct {
    api_secret_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_secret_key = "apiSecretKey",
        };
        return @field(mappings, field_name);
    }
};

pub const SnowflakeConnectorProfileCredentials = struct {
    username: []const u8,
    password: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "username",
            .password = "password",
        };
        return @field(mappings, field_name);
    }
};

pub const SlackConnectorProfileCredentials = struct {
    client_id: []const u8,
    client_secret: []const u8,
    access_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "clientId",
            .client_secret = "clientSecret",
            .access_token = "accessToken",
            .o_auth_request = "oAuthRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const SingularConnectorProfileCredentials = struct {
    api_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_key = "apiKey",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowConnectorProfileCredentials = struct {
    username: ?[]const u8 = null,
    password: ?[]const u8 = null,
    o_auth2_credentials: ?OAuth2Credentials = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "username",
            .password = "password",
            .o_auth2_credentials = "oAuth2Credentials",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceConnectorProfileCredentials = struct {
    access_token: ?[]const u8 = null,
    refresh_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,
    client_credentials_arn: ?[]const u8 = null,
    o_auth2_grant_type: ?[]const u8 = null,
    jwt_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_token = "accessToken",
            .refresh_token = "refreshToken",
            .o_auth_request = "oAuthRequest",
            .client_credentials_arn = "clientCredentialsArn",
            .o_auth2_grant_type = "oAuth2GrantType",
            .jwt_token = "jwtToken",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftConnectorProfileCredentials = struct {
    username: ?[]const u8 = null,
    password: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "username",
            .password = "password",
        };
        return @field(mappings, field_name);
    }
};

pub const MarketoConnectorProfileCredentials = struct {
    client_id: []const u8,
    client_secret: []const u8,
    access_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "clientId",
            .client_secret = "clientSecret",
            .access_token = "accessToken",
            .o_auth_request = "oAuthRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const InforNexusConnectorProfileCredentials = struct {
    access_key_id: []const u8,
    user_id: []const u8,
    secret_access_key: []const u8,
    datakey: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_key_id = "accessKeyId",
            .user_id = "userId",
            .secret_access_key = "secretAccessKey",
            .datakey = "datakey",
        };
        return @field(mappings, field_name);
    }
};

pub const HoneycodeConnectorProfileCredentials = struct {
    access_token: ?[]const u8 = null,
    refresh_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_token = "accessToken",
            .refresh_token = "refreshToken",
            .o_auth_request = "oAuthRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const GoogleAnalyticsConnectorProfileCredentials = struct {
    client_id: []const u8,
    client_secret: []const u8,
    access_token: ?[]const u8 = null,
    refresh_token: ?[]const u8 = null,
    o_auth_request: ?ConnectorOAuthRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "clientId",
            .client_secret = "clientSecret",
            .access_token = "accessToken",
            .refresh_token = "refreshToken",
            .o_auth_request = "oAuthRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const DynatraceConnectorProfileCredentials = struct {
    api_token: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_token = "apiToken",
        };
        return @field(mappings, field_name);
    }
};

pub const DatadogConnectorProfileCredentials = struct {
    api_key: []const u8,
    application_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_key = "apiKey",
            .application_key = "applicationKey",
        };
        return @field(mappings, field_name);
    }
};

pub const AmplitudeConnectorProfileCredentials = struct {
    api_key: []const u8,
    secret_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_key = "apiKey",
            .secret_key = "secretKey",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorProfileProperties = struct {
    amplitude: ?AmplitudeConnectorProfileProperties = null,
    datadog: ?DatadogConnectorProfileProperties = null,
    dynatrace: ?DynatraceConnectorProfileProperties = null,
    google_analytics: ?GoogleAnalyticsConnectorProfileProperties = null,
    honeycode: ?HoneycodeConnectorProfileProperties = null,
    infor_nexus: ?InforNexusConnectorProfileProperties = null,
    marketo: ?MarketoConnectorProfileProperties = null,
    redshift: ?RedshiftConnectorProfileProperties = null,
    salesforce: ?SalesforceConnectorProfileProperties = null,
    service_now: ?ServiceNowConnectorProfileProperties = null,
    singular: ?SingularConnectorProfileProperties = null,
    slack: ?SlackConnectorProfileProperties = null,
    snowflake: ?SnowflakeConnectorProfileProperties = null,
    trendmicro: ?TrendmicroConnectorProfileProperties = null,
    veeva: ?VeevaConnectorProfileProperties = null,
    zendesk: ?ZendeskConnectorProfileProperties = null,
    sapo_data: ?SAPODataConnectorProfileProperties = null,
    custom_connector: ?CustomConnectorProfileProperties = null,
    pardot: ?PardotConnectorProfileProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amplitude = "Amplitude",
            .datadog = "Datadog",
            .dynatrace = "Dynatrace",
            .google_analytics = "GoogleAnalytics",
            .honeycode = "Honeycode",
            .infor_nexus = "InforNexus",
            .marketo = "Marketo",
            .redshift = "Redshift",
            .salesforce = "Salesforce",
            .service_now = "ServiceNow",
            .singular = "Singular",
            .slack = "Slack",
            .snowflake = "Snowflake",
            .trendmicro = "Trendmicro",
            .veeva = "Veeva",
            .zendesk = "Zendesk",
            .sapo_data = "SAPOData",
            .custom_connector = "CustomConnector",
            .pardot = "Pardot",
        };
        return @field(mappings, field_name);
    }
};

pub const PardotConnectorProfileProperties = struct {
    instance_url: ?[]const u8 = null,
    is_sandbox_environment: ?bool = null,
    business_unit_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
            .is_sandbox_environment = "isSandboxEnvironment",
            .business_unit_id = "businessUnitId",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomConnectorProfileProperties = struct {
    profile_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    o_auth2_properties: ?OAuth2Properties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .profile_properties = "profileProperties",
            .o_auth2_properties = "oAuth2Properties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "profile_properties", field_name))
            return try serializeMap(self.profile_properties, self.fieldNameFor("profile_properties"), options, out_stream);
        return false;
    }
};

pub const OAuth2Properties = struct {
    token_url: []const u8,
    o_auth2_grant_type: []const u8,
    token_url_custom_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .token_url = "tokenUrl",
            .o_auth2_grant_type = "oAuth2GrantType",
            .token_url_custom_properties = "tokenUrlCustomProperties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "token_url_custom_properties", field_name))
            return try serializeMap(self.token_url_custom_properties, self.fieldNameFor("token_url_custom_properties"), options, out_stream);
        return false;
    }
};

pub const SAPODataConnectorProfileProperties = struct {
    application_host_url: []const u8,
    application_service_path: []const u8,
    port_number: i64,
    client_number: []const u8,
    logon_language: ?[]const u8 = null,
    private_link_service_name: ?[]const u8 = null,
    o_auth_properties: ?OAuthProperties = null,
    disable_sso: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_host_url = "applicationHostUrl",
            .application_service_path = "applicationServicePath",
            .port_number = "portNumber",
            .client_number = "clientNumber",
            .logon_language = "logonLanguage",
            .private_link_service_name = "privateLinkServiceName",
            .o_auth_properties = "oAuthProperties",
            .disable_sso = "disableSSO",
        };
        return @field(mappings, field_name);
    }
};

pub const OAuthProperties = struct {
    token_url: []const u8,
    auth_code_url: []const u8,
    o_auth_scopes: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .token_url = "tokenUrl",
            .auth_code_url = "authCodeUrl",
            .o_auth_scopes = "oAuthScopes",
        };
        return @field(mappings, field_name);
    }
};

pub const ZendeskConnectorProfileProperties = struct {
    instance_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const VeevaConnectorProfileProperties = struct {
    instance_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const TrendmicroConnectorProfileProperties = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const SnowflakeConnectorProfileProperties = struct {
    warehouse: []const u8,
    stage: []const u8,
    bucket_name: []const u8,
    bucket_prefix: ?[]const u8 = null,
    private_link_service_name: ?[]const u8 = null,
    account_name: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .warehouse = "warehouse",
            .stage = "stage",
            .bucket_name = "bucketName",
            .bucket_prefix = "bucketPrefix",
            .private_link_service_name = "privateLinkServiceName",
            .account_name = "accountName",
            .region = "region",
        };
        return @field(mappings, field_name);
    }
};

pub const SlackConnectorProfileProperties = struct {
    instance_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const SingularConnectorProfileProperties = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const ServiceNowConnectorProfileProperties = struct {
    instance_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceConnectorProfileProperties = struct {
    instance_url: ?[]const u8 = null,
    is_sandbox_environment: ?bool = null,
    use_private_link_for_metadata_and_authorization: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
            .is_sandbox_environment = "isSandboxEnvironment",
            .use_private_link_for_metadata_and_authorization = "usePrivateLinkForMetadataAndAuthorization",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftConnectorProfileProperties = struct {
    database_url: ?[]const u8 = null,
    bucket_name: []const u8,
    bucket_prefix: ?[]const u8 = null,
    role_arn: []const u8,
    data_api_role_arn: ?[]const u8 = null,
    is_redshift_serverless: ?bool = null,
    cluster_identifier: ?[]const u8 = null,
    workgroup_name: ?[]const u8 = null,
    database_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_url = "databaseUrl",
            .bucket_name = "bucketName",
            .bucket_prefix = "bucketPrefix",
            .role_arn = "roleArn",
            .data_api_role_arn = "dataApiRoleArn",
            .is_redshift_serverless = "isRedshiftServerless",
            .cluster_identifier = "clusterIdentifier",
            .workgroup_name = "workgroupName",
            .database_name = "databaseName",
        };
        return @field(mappings, field_name);
    }
};

pub const MarketoConnectorProfileProperties = struct {
    instance_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const InforNexusConnectorProfileProperties = struct {
    instance_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const HoneycodeConnectorProfileProperties = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const GoogleAnalyticsConnectorProfileProperties = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const DynatraceConnectorProfileProperties = struct {
    instance_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const DatadogConnectorProfileProperties = struct {
    instance_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_url = "instanceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const AmplitudeConnectorProfileProperties = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const ExecutionDetails = struct {
    most_recent_execution_message: ?[]const u8 = null,
    most_recent_execution_time: ?i64 = null,
    most_recent_execution_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .most_recent_execution_message = "mostRecentExecutionMessage",
            .most_recent_execution_time = "mostRecentExecutionTime",
            .most_recent_execution_status = "mostRecentExecutionStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorDetail = struct {
    connector_description: ?[]const u8 = null,
    connector_name: ?[]const u8 = null,
    connector_owner: ?[]const u8 = null,
    connector_version: ?[]const u8 = null,
    application_type: ?[]const u8 = null,
    connector_type: ?[]const u8 = null,
    connector_label: ?[]const u8 = null,
    registered_at: ?i64 = null,
    registered_by: ?[]const u8 = null,
    connector_provisioning_type: ?[]const u8 = null,
    connector_modes: ?[][]const u8 = null,
    supported_data_transfer_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_description = "connectorDescription",
            .connector_name = "connectorName",
            .connector_owner = "connectorOwner",
            .connector_version = "connectorVersion",
            .application_type = "applicationType",
            .connector_type = "connectorType",
            .connector_label = "connectorLabel",
            .registered_at = "registeredAt",
            .registered_by = "registeredBy",
            .connector_provisioning_type = "connectorProvisioningType",
            .connector_modes = "connectorModes",
            .supported_data_transfer_types = "supportedDataTransferTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const MetadataCatalogDetail = struct {
    catalog_type: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    table_registration_output: ?RegistrationOutput = null,
    partition_registration_output: ?RegistrationOutput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_type = "catalogType",
            .table_name = "tableName",
            .table_registration_output = "tableRegistrationOutput",
            .partition_registration_output = "partitionRegistrationOutput",
        };
        return @field(mappings, field_name);
    }
};

pub const RegistrationOutput = struct {
    message: ?[]const u8 = null,
    result: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
            .result = "result",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorConfiguration = struct {
    can_use_as_source: ?bool = null,
    can_use_as_destination: ?bool = null,
    supported_destination_connectors: ?[][]const u8 = null,
    supported_scheduling_frequencies: ?[][]const u8 = null,
    is_private_link_enabled: ?bool = null,
    is_private_link_endpoint_url_required: ?bool = null,
    supported_trigger_types: ?[][]const u8 = null,
    connector_metadata: ?ConnectorMetadata = null,
    connector_type: ?[]const u8 = null,
    connector_label: ?[]const u8 = null,
    connector_description: ?[]const u8 = null,
    connector_owner: ?[]const u8 = null,
    connector_name: ?[]const u8 = null,
    connector_version: ?[]const u8 = null,
    connector_arn: ?[]const u8 = null,
    connector_modes: ?[][]const u8 = null,
    authentication_config: ?AuthenticationConfig = null,
    connector_runtime_settings: ?[]ConnectorRuntimeSetting = null,
    supported_api_versions: ?[][]const u8 = null,
    supported_operators: ?[][]const u8 = null,
    supported_write_operations: ?[][]const u8 = null,
    connector_provisioning_type: ?[]const u8 = null,
    connector_provisioning_config: ?ConnectorProvisioningConfig = null,
    logo_url: ?[]const u8 = null,
    registered_at: ?i64 = null,
    registered_by: ?[]const u8 = null,
    supported_data_transfer_types: ?[][]const u8 = null,
    supported_data_transfer_apis: ?[]DataTransferApi = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .can_use_as_source = "canUseAsSource",
            .can_use_as_destination = "canUseAsDestination",
            .supported_destination_connectors = "supportedDestinationConnectors",
            .supported_scheduling_frequencies = "supportedSchedulingFrequencies",
            .is_private_link_enabled = "isPrivateLinkEnabled",
            .is_private_link_endpoint_url_required = "isPrivateLinkEndpointUrlRequired",
            .supported_trigger_types = "supportedTriggerTypes",
            .connector_metadata = "connectorMetadata",
            .connector_type = "connectorType",
            .connector_label = "connectorLabel",
            .connector_description = "connectorDescription",
            .connector_owner = "connectorOwner",
            .connector_name = "connectorName",
            .connector_version = "connectorVersion",
            .connector_arn = "connectorArn",
            .connector_modes = "connectorModes",
            .authentication_config = "authenticationConfig",
            .connector_runtime_settings = "connectorRuntimeSettings",
            .supported_api_versions = "supportedApiVersions",
            .supported_operators = "supportedOperators",
            .supported_write_operations = "supportedWriteOperations",
            .connector_provisioning_type = "connectorProvisioningType",
            .connector_provisioning_config = "connectorProvisioningConfig",
            .logo_url = "logoURL",
            .registered_at = "registeredAt",
            .registered_by = "registeredBy",
            .supported_data_transfer_types = "supportedDataTransferTypes",
            .supported_data_transfer_apis = "supportedDataTransferApis",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorRuntimeSetting = struct {
    key: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    is_required: ?bool = null,
    label: ?[]const u8 = null,
    description: ?[]const u8 = null,
    scope: ?[]const u8 = null,
    connector_supplied_value_options: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .data_type = "dataType",
            .is_required = "isRequired",
            .label = "label",
            .description = "description",
            .scope = "scope",
            .connector_supplied_value_options = "connectorSuppliedValueOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthenticationConfig = struct {
    is_basic_auth_supported: ?bool = null,
    is_api_key_auth_supported: ?bool = null,
    is_o_auth2_supported: ?bool = null,
    is_custom_auth_supported: ?bool = null,
    o_auth2_defaults: ?OAuth2Defaults = null,
    custom_auth_configs: ?[]CustomAuthConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_basic_auth_supported = "isBasicAuthSupported",
            .is_api_key_auth_supported = "isApiKeyAuthSupported",
            .is_o_auth2_supported = "isOAuth2Supported",
            .is_custom_auth_supported = "isCustomAuthSupported",
            .o_auth2_defaults = "oAuth2Defaults",
            .custom_auth_configs = "customAuthConfigs",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomAuthConfig = struct {
    custom_authentication_type: ?[]const u8 = null,
    auth_parameters: ?[]AuthParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_authentication_type = "customAuthenticationType",
            .auth_parameters = "authParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthParameter = struct {
    key: ?[]const u8 = null,
    is_required: ?bool = null,
    label: ?[]const u8 = null,
    description: ?[]const u8 = null,
    is_sensitive_field: ?bool = null,
    connector_supplied_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .is_required = "isRequired",
            .label = "label",
            .description = "description",
            .is_sensitive_field = "isSensitiveField",
            .connector_supplied_values = "connectorSuppliedValues",
        };
        return @field(mappings, field_name);
    }
};

pub const OAuth2Defaults = struct {
    oauth_scopes: ?[][]const u8 = null,
    token_urls: ?[][]const u8 = null,
    auth_code_urls: ?[][]const u8 = null,
    oauth2_grant_types_supported: ?[][]const u8 = null,
    oauth2_custom_properties: ?[]OAuth2CustomParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .oauth_scopes = "oauthScopes",
            .token_urls = "tokenUrls",
            .auth_code_urls = "authCodeUrls",
            .oauth2_grant_types_supported = "oauth2GrantTypesSupported",
            .oauth2_custom_properties = "oauth2CustomProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const OAuth2CustomParameter = struct {
    key: ?[]const u8 = null,
    is_required: ?bool = null,
    label: ?[]const u8 = null,
    description: ?[]const u8 = null,
    is_sensitive_field: ?bool = null,
    connector_supplied_values: ?[][]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .is_required = "isRequired",
            .label = "label",
            .description = "description",
            .is_sensitive_field = "isSensitiveField",
            .connector_supplied_values = "connectorSuppliedValues",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorMetadata = struct {
    amplitude: ?AmplitudeMetadata = null,
    datadog: ?DatadogMetadata = null,
    dynatrace: ?DynatraceMetadata = null,
    google_analytics: ?GoogleAnalyticsMetadata = null,
    infor_nexus: ?InforNexusMetadata = null,
    marketo: ?MarketoMetadata = null,
    redshift: ?RedshiftMetadata = null,
    s3: ?S3Metadata = null,
    salesforce: ?SalesforceMetadata = null,
    service_now: ?ServiceNowMetadata = null,
    singular: ?SingularMetadata = null,
    slack: ?SlackMetadata = null,
    snowflake: ?SnowflakeMetadata = null,
    trendmicro: ?TrendmicroMetadata = null,
    veeva: ?VeevaMetadata = null,
    zendesk: ?ZendeskMetadata = null,
    event_bridge: ?EventBridgeMetadata = null,
    upsolver: ?UpsolverMetadata = null,
    customer_profiles: ?CustomerProfilesMetadata = null,
    honeycode: ?HoneycodeMetadata = null,
    sapo_data: ?SAPODataMetadata = null,
    pardot: ?PardotMetadata = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amplitude = "Amplitude",
            .datadog = "Datadog",
            .dynatrace = "Dynatrace",
            .google_analytics = "GoogleAnalytics",
            .infor_nexus = "InforNexus",
            .marketo = "Marketo",
            .redshift = "Redshift",
            .s3 = "S3",
            .salesforce = "Salesforce",
            .service_now = "ServiceNow",
            .singular = "Singular",
            .slack = "Slack",
            .snowflake = "Snowflake",
            .trendmicro = "Trendmicro",
            .veeva = "Veeva",
            .zendesk = "Zendesk",
            .event_bridge = "EventBridge",
            .upsolver = "Upsolver",
            .customer_profiles = "CustomerProfiles",
            .honeycode = "Honeycode",
            .sapo_data = "SAPOData",
            .pardot = "Pardot",
        };
        return @field(mappings, field_name);
    }
};

pub const PardotMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const SAPODataMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const HoneycodeMetadata = struct {
    o_auth_scopes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .o_auth_scopes = "oAuthScopes",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerProfilesMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const UpsolverMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const EventBridgeMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const ZendeskMetadata = struct {
    o_auth_scopes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .o_auth_scopes = "oAuthScopes",
        };
        return @field(mappings, field_name);
    }
};

pub const VeevaMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const TrendmicroMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const SnowflakeMetadata = struct {
    supported_regions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .supported_regions = "supportedRegions",
        };
        return @field(mappings, field_name);
    }
};

pub const SlackMetadata = struct {
    o_auth_scopes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .o_auth_scopes = "oAuthScopes",
        };
        return @field(mappings, field_name);
    }
};

pub const SingularMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const ServiceNowMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const SalesforceMetadata = struct {
    o_auth_scopes: ?[][]const u8 = null,
    data_transfer_apis: ?[][]const u8 = null,
    oauth2_grant_types_supported: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .o_auth_scopes = "oAuthScopes",
            .data_transfer_apis = "dataTransferApis",
            .oauth2_grant_types_supported = "oauth2GrantTypesSupported",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Metadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const RedshiftMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const MarketoMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const InforNexusMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const GoogleAnalyticsMetadata = struct {
    o_auth_scopes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .o_auth_scopes = "oAuthScopes",
        };
        return @field(mappings, field_name);
    }
};

pub const DynatraceMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const DatadogMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const AmplitudeMetadata = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Range = struct {
    maximum: ?f64 = null,
    minimum: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum = "maximum",
            .minimum = "minimum",
        };
        return @field(mappings, field_name);
    }
};
