const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-02-06";
pub const sdk_id: []const u8 = "Application Auto Scaling";
pub const arn_namespace: ?[]const u8 = "application-autoscaling";
pub const endpoint_prefix: []const u8 = "application-autoscaling";
pub const sigv4_name: []const u8 = "application-autoscaling";
pub const name: []const u8 = "AnyScaleFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-02-06",
    sdk_id: []const u8 = "Application Auto Scaling",
    arn_namespace: ?[]const u8 = "application-autoscaling",
    endpoint_prefix: []const u8 = "application-autoscaling",
    sigv4_name: []const u8 = "application-autoscaling",
    name: []const u8 = "AnyScaleFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const delete_scaling_policy: struct {
    action_name: []const u8 = "DeleteScalingPolicy",
    Request: type = struct {
        policy_name: []const u8,
        service_namespace: []const u8,
        resource_id: []const u8,
        scalable_dimension: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "PolicyName",
                .service_namespace = "ServiceNamespace",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_scaling_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        ObjectNotFound,
        Validation,
    },
} = .{};
pub const delete_scheduled_action: struct {
    action_name: []const u8 = "DeleteScheduledAction",
    Request: type = struct {
        service_namespace: []const u8,
        scheduled_action_name: []const u8,
        resource_id: []const u8,
        scalable_dimension: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_namespace = "ServiceNamespace",
                .scheduled_action_name = "ScheduledActionName",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scheduled_action) } {
            return .{ .service_metadata = service_metadata, .action = delete_scheduled_action };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        ObjectNotFound,
        Validation,
    },
} = .{};
pub const deregister_scalable_target: struct {
    action_name: []const u8 = "DeregisterScalableTarget",
    Request: type = struct {
        service_namespace: []const u8,
        resource_id: []const u8,
        scalable_dimension: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_namespace = "ServiceNamespace",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_scalable_target) } {
            return .{ .service_metadata = service_metadata, .action = deregister_scalable_target };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        ObjectNotFound,
        Validation,
    },
} = .{};
pub const describe_scalable_targets: struct {
    action_name: []const u8 = "DescribeScalableTargets",
    Request: type = struct {
        service_namespace: []const u8,
        resource_ids: ?[][]const u8 = null,
        scalable_dimension: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_namespace = "ServiceNamespace",
                .resource_ids = "ResourceIds",
                .scalable_dimension = "ScalableDimension",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scalable_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_scalable_targets };
        }
    },
    Response: type = struct {
        scalable_targets: ?[]struct {
            service_namespace: []const u8,
            resource_id: []const u8,
            scalable_dimension: []const u8,
            min_capacity: i64,
            max_capacity: i64,
            role_arn: []const u8,
            creation_time: i64,
            suspended_state: ?SuspendedState = null,
            scalable_target_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_namespace = "ServiceNamespace",
                    .resource_id = "ResourceId",
                    .scalable_dimension = "ScalableDimension",
                    .min_capacity = "MinCapacity",
                    .max_capacity = "MaxCapacity",
                    .role_arn = "RoleARN",
                    .creation_time = "CreationTime",
                    .suspended_state = "SuspendedState",
                    .scalable_target_arn = "ScalableTargetARN",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scalable_targets = "ScalableTargets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const describe_scaling_activities: struct {
    action_name: []const u8 = "DescribeScalingActivities",
    Request: type = struct {
        service_namespace: []const u8,
        resource_id: ?[]const u8 = null,
        scalable_dimension: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        include_not_scaled_activities: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_namespace = "ServiceNamespace",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .include_not_scaled_activities = "IncludeNotScaledActivities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scaling_activities) } {
            return .{ .service_metadata = service_metadata, .action = describe_scaling_activities };
        }
    },
    Response: type = struct {
        scaling_activities: ?[]struct {
            activity_id: []const u8,
            service_namespace: []const u8,
            resource_id: []const u8,
            scalable_dimension: []const u8,
            description: []const u8,
            cause: []const u8,
            start_time: i64,
            end_time: ?i64 = null,
            status_code: []const u8,
            status_message: ?[]const u8 = null,
            details: ?[]const u8 = null,
            not_scaled_reasons: ?[]struct {
                code: []const u8,
                max_capacity: ?i64 = null,
                min_capacity: ?i64 = null,
                current_capacity: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "Code",
                        .max_capacity = "MaxCapacity",
                        .min_capacity = "MinCapacity",
                        .current_capacity = "CurrentCapacity",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .activity_id = "ActivityId",
                    .service_namespace = "ServiceNamespace",
                    .resource_id = "ResourceId",
                    .scalable_dimension = "ScalableDimension",
                    .description = "Description",
                    .cause = "Cause",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .status_code = "StatusCode",
                    .status_message = "StatusMessage",
                    .details = "Details",
                    .not_scaled_reasons = "NotScaledReasons",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_activities = "ScalingActivities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const describe_scaling_policies: struct {
    action_name: []const u8 = "DescribeScalingPolicies",
    Request: type = struct {
        policy_names: ?[][]const u8 = null,
        service_namespace: []const u8,
        resource_id: ?[]const u8 = null,
        scalable_dimension: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_names = "PolicyNames",
                .service_namespace = "ServiceNamespace",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scaling_policies) } {
            return .{ .service_metadata = service_metadata, .action = describe_scaling_policies };
        }
    },
    Response: type = struct {
        scaling_policies: ?[]struct {
            policy_arn: []const u8,
            policy_name: []const u8,
            service_namespace: []const u8,
            resource_id: []const u8,
            scalable_dimension: []const u8,
            policy_type: []const u8,
            step_scaling_policy_configuration: ?StepScalingPolicyConfiguration = null,
            target_tracking_scaling_policy_configuration: ?TargetTrackingScalingPolicyConfiguration = null,
            alarms: ?[]Alarm = null,
            creation_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_arn = "PolicyARN",
                    .policy_name = "PolicyName",
                    .service_namespace = "ServiceNamespace",
                    .resource_id = "ResourceId",
                    .scalable_dimension = "ScalableDimension",
                    .policy_type = "PolicyType",
                    .step_scaling_policy_configuration = "StepScalingPolicyConfiguration",
                    .target_tracking_scaling_policy_configuration = "TargetTrackingScalingPolicyConfiguration",
                    .alarms = "Alarms",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_policies = "ScalingPolicies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        FailedResourceAccess,
        InternalService,
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const describe_scheduled_actions: struct {
    action_name: []const u8 = "DescribeScheduledActions",
    Request: type = struct {
        scheduled_action_names: ?[][]const u8 = null,
        service_namespace: []const u8,
        resource_id: ?[]const u8 = null,
        scalable_dimension: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_action_names = "ScheduledActionNames",
                .service_namespace = "ServiceNamespace",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scheduled_actions) } {
            return .{ .service_metadata = service_metadata, .action = describe_scheduled_actions };
        }
    },
    Response: type = struct {
        scheduled_actions: ?[]struct {
            scheduled_action_name: []const u8,
            scheduled_action_arn: []const u8,
            service_namespace: []const u8,
            schedule: []const u8,
            timezone: ?[]const u8 = null,
            resource_id: []const u8,
            scalable_dimension: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            scalable_target_action: ?ScalableTargetAction = null,
            creation_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scheduled_action_name = "ScheduledActionName",
                    .scheduled_action_arn = "ScheduledActionARN",
                    .service_namespace = "ServiceNamespace",
                    .schedule = "Schedule",
                    .timezone = "Timezone",
                    .resource_id = "ResourceId",
                    .scalable_dimension = "ScalableDimension",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .scalable_target_action = "ScalableTargetAction",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_actions = "ScheduledActions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const put_scaling_policy: struct {
    action_name: []const u8 = "PutScalingPolicy",
    Request: type = struct {
        policy_name: []const u8,
        service_namespace: []const u8,
        resource_id: []const u8,
        scalable_dimension: []const u8,
        policy_type: ?[]const u8 = null,
        step_scaling_policy_configuration: ?StepScalingPolicyConfiguration = null,
        target_tracking_scaling_policy_configuration: ?TargetTrackingScalingPolicyConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "PolicyName",
                .service_namespace = "ServiceNamespace",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
                .policy_type = "PolicyType",
                .step_scaling_policy_configuration = "StepScalingPolicyConfiguration",
                .target_tracking_scaling_policy_configuration = "TargetTrackingScalingPolicyConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_scaling_policy };
        }
    },
    Response: type = struct {
        policy_arn: []const u8,
        alarms: ?[]Alarm = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_arn = "PolicyARN",
                .alarms = "Alarms",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        FailedResourceAccess,
        InternalService,
        LimitExceeded,
        ObjectNotFound,
        Validation,
    },
} = .{};
pub const put_scheduled_action: struct {
    action_name: []const u8 = "PutScheduledAction",
    Request: type = struct {
        service_namespace: []const u8,
        schedule: ?[]const u8 = null,
        timezone: ?[]const u8 = null,
        scheduled_action_name: []const u8,
        resource_id: []const u8,
        scalable_dimension: []const u8,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        scalable_target_action: ?ScalableTargetAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_namespace = "ServiceNamespace",
                .schedule = "Schedule",
                .timezone = "Timezone",
                .scheduled_action_name = "ScheduledActionName",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .scalable_target_action = "ScalableTargetAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_scheduled_action) } {
            return .{ .service_metadata = service_metadata, .action = put_scheduled_action };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        LimitExceeded,
        ObjectNotFound,
        Validation,
    },
} = .{};
pub const register_scalable_target: struct {
    action_name: []const u8 = "RegisterScalableTarget",
    Request: type = struct {
        service_namespace: []const u8,
        resource_id: []const u8,
        scalable_dimension: []const u8,
        min_capacity: ?i64 = null,
        max_capacity: ?i64 = null,
        role_arn: ?[]const u8 = null,
        suspended_state: ?SuspendedState = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_namespace = "ServiceNamespace",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
                .min_capacity = "MinCapacity",
                .max_capacity = "MaxCapacity",
                .role_arn = "RoleARN",
                .suspended_state = "SuspendedState",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_scalable_target) } {
            return .{ .service_metadata = service_metadata, .action = register_scalable_target };
        }
    },
    Response: type = struct {
        scalable_target_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scalable_target_arn = "ScalableTargetARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        TooManyTags,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const SuspendedState = struct {
    dynamic_scaling_in_suspended: ?bool = null,
    dynamic_scaling_out_suspended: ?bool = null,
    scheduled_scaling_suspended: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dynamic_scaling_in_suspended = "DynamicScalingInSuspended",
            .dynamic_scaling_out_suspended = "DynamicScalingOutSuspended",
            .scheduled_scaling_suspended = "ScheduledScalingSuspended",
        };
        return @field(mappings, field_name);
    }
};

pub const ScalableTargetAction = struct {
    min_capacity: ?i64 = null,
    max_capacity: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_capacity = "MinCapacity",
            .max_capacity = "MaxCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const Alarm = struct {
    alarm_name: []const u8,
    alarm_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alarm_name = "AlarmName",
            .alarm_arn = "AlarmARN",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetTrackingScalingPolicyConfiguration = struct {
    target_value: f64,
    predefined_metric_specification: ?PredefinedMetricSpecification = null,
    customized_metric_specification: ?CustomizedMetricSpecification = null,
    scale_out_cooldown: ?i64 = null,
    scale_in_cooldown: ?i64 = null,
    disable_scale_in: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_value = "TargetValue",
            .predefined_metric_specification = "PredefinedMetricSpecification",
            .customized_metric_specification = "CustomizedMetricSpecification",
            .scale_out_cooldown = "ScaleOutCooldown",
            .scale_in_cooldown = "ScaleInCooldown",
            .disable_scale_in = "DisableScaleIn",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomizedMetricSpecification = struct {
    metric_name: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    dimensions: ?[]MetricDimension = null,
    statistic: ?[]const u8 = null,
    unit: ?[]const u8 = null,
    metrics: ?[]TargetTrackingMetricDataQuery = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .namespace = "Namespace",
            .dimensions = "Dimensions",
            .statistic = "Statistic",
            .unit = "Unit",
            .metrics = "Metrics",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetTrackingMetricDataQuery = struct {
    expression: ?[]const u8 = null,
    id: []const u8,
    label: ?[]const u8 = null,
    metric_stat: ?TargetTrackingMetricStat = null,
    return_data: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .id = "Id",
            .label = "Label",
            .metric_stat = "MetricStat",
            .return_data = "ReturnData",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetTrackingMetricStat = struct {
    metric: TargetTrackingMetric,
    stat: []const u8,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric = "Metric",
            .stat = "Stat",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetTrackingMetric = struct {
    dimensions: ?[]TargetTrackingMetricDimension = null,
    metric_name: ?[]const u8 = null,
    namespace: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
            .metric_name = "MetricName",
            .namespace = "Namespace",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetTrackingMetricDimension = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricDimension = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PredefinedMetricSpecification = struct {
    predefined_metric_type: []const u8,
    resource_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .predefined_metric_type = "PredefinedMetricType",
            .resource_label = "ResourceLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const StepScalingPolicyConfiguration = struct {
    adjustment_type: ?[]const u8 = null,
    step_adjustments: ?[]StepAdjustment = null,
    min_adjustment_magnitude: ?i64 = null,
    cooldown: ?i64 = null,
    metric_aggregation_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adjustment_type = "AdjustmentType",
            .step_adjustments = "StepAdjustments",
            .min_adjustment_magnitude = "MinAdjustmentMagnitude",
            .cooldown = "Cooldown",
            .metric_aggregation_type = "MetricAggregationType",
        };
        return @field(mappings, field_name);
    }
};

pub const StepAdjustment = struct {
    metric_interval_lower_bound: ?f64 = null,
    metric_interval_upper_bound: ?f64 = null,
    scaling_adjustment: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_interval_lower_bound = "MetricIntervalLowerBound",
            .metric_interval_upper_bound = "MetricIntervalUpperBound",
            .scaling_adjustment = "ScalingAdjustment",
        };
        return @field(mappings, field_name);
    }
};
