const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-09-10";
pub const sdk_id: []const u8 = "ApplicationCostProfiler";
pub const arn_namespace: ?[]const u8 = "application-cost-profiler";
pub const endpoint_prefix: []const u8 = "application-cost-profiler";
pub const sigv4_name: []const u8 = "application-cost-profiler";
pub const name: []const u8 = "AWSApplicationCostProfiler";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-09-10",
    sdk_id: []const u8 = "ApplicationCostProfiler",
    arn_namespace: ?[]const u8 = "application-cost-profiler",
    endpoint_prefix: []const u8 = "application-cost-profiler",
    sigv4_name: []const u8 = "application-cost-profiler",
    name: []const u8 = "AWSApplicationCostProfiler",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_report_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/reportDefinition/{reportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteReportDefinition",
    Request: type = struct {
        report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_report_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_report_definition };
        }
    },
    Response: type = struct {
        report_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_report_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/reportDefinition/{reportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReportDefinition",
    Request: type = struct {
        report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_report_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_report_definition };
        }
    },
    Response: type = struct {
        report_id: []const u8,
        report_description: []const u8,
        report_frequency: []const u8,
        format: []const u8,
        destination_s3_location: S3Location,
        created_at: i64,
        last_updated: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
                .report_description = "reportDescription",
                .report_frequency = "reportFrequency",
                .format = "format",
                .destination_s3_location = "destinationS3Location",
                .created_at = "createdAt",
                .last_updated = "lastUpdated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const import_application_usage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/importApplicationUsage",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportApplicationUsage",
    Request: type = struct {
        source_s3_location: struct {
            bucket: []const u8,
            key: []const u8,
            region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket = "bucket",
                    .key = "key",
                    .region = "region",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_s3_location = "sourceS3Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_application_usage) } {
            return .{ .service_metadata = service_metadata, .action = import_application_usage };
        }
    },
    Response: type = struct {
        import_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_report_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/reportDefinition",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReportDefinitions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_report_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_report_definitions };
        }
    },
    Response: type = struct {
        report_definitions: ?[]struct {
            report_id: ?[]const u8 = null,
            report_description: ?[]const u8 = null,
            report_frequency: ?[]const u8 = null,
            format: ?[]const u8 = null,
            destination_s3_location: ?S3Location = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .report_id = "reportId",
                    .report_description = "reportDescription",
                    .report_frequency = "reportFrequency",
                    .format = "format",
                    .destination_s3_location = "destinationS3Location",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_definitions = "reportDefinitions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const put_report_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/reportDefinition",
        .success_code = 200,
    };

    action_name: []const u8 = "PutReportDefinition",
    Request: type = struct {
        report_id: []const u8,
        report_description: []const u8,
        report_frequency: []const u8,
        format: []const u8,
        destination_s3_location: S3Location,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
                .report_description = "reportDescription",
                .report_frequency = "reportFrequency",
                .format = "format",
                .destination_s3_location = "destinationS3Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_report_definition) } {
            return .{ .service_metadata = service_metadata, .action = put_report_definition };
        }
    },
    Response: type = struct {
        report_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_report_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/reportDefinition/{reportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateReportDefinition",
    Request: type = struct {
        report_id: []const u8,
        report_description: []const u8,
        report_frequency: []const u8,
        format: []const u8,
        destination_s3_location: S3Location,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
                .report_description = "reportDescription",
                .report_frequency = "reportFrequency",
                .format = "format",
                .destination_s3_location = "destinationS3Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_report_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_report_definition };
        }
    },
    Response: type = struct {
        report_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const S3Location = struct {
    bucket: []const u8,
    prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};
