const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-25";
pub const sdk_id: []const u8 = "Application Insights";
pub const arn_namespace: ?[]const u8 = "applicationinsights";
pub const endpoint_prefix: []const u8 = "applicationinsights";
pub const sigv4_name: []const u8 = "applicationinsights";
pub const name: []const u8 = "EC2WindowsBarleyService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-25",
    sdk_id: []const u8 = "Application Insights",
    arn_namespace: ?[]const u8 = "applicationinsights",
    endpoint_prefix: []const u8 = "applicationinsights",
    sigv4_name: []const u8 = "applicationinsights",
    name: []const u8 = "EC2WindowsBarleyService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_workload: struct {
    action_name: []const u8 = "AddWorkload",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        workload_configuration: WorkloadConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .workload_configuration = "WorkloadConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_workload) } {
            return .{ .service_metadata = service_metadata, .action = add_workload };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_configuration: ?WorkloadConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_configuration = "WorkloadConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_application: struct {
    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        resource_group_name: ?[]const u8 = null,
        ops_center_enabled: ?bool = null,
        cwe_monitor_enabled: ?bool = null,
        ops_item_sns_topic_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        auto_config_enabled: ?bool = null,
        auto_create: ?bool = null,
        grouping_type: ?[]const u8 = null,
        attach_missing_permission: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .ops_center_enabled = "OpsCenterEnabled",
                .cwe_monitor_enabled = "CWEMonitorEnabled",
                .ops_item_sns_topic_arn = "OpsItemSNSTopicArn",
                .tags = "Tags",
                .auto_config_enabled = "AutoConfigEnabled",
                .auto_create = "AutoCreate",
                .grouping_type = "GroupingType",
                .attach_missing_permission = "AttachMissingPermission",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        application_info: ?ApplicationInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_info = "ApplicationInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        TagsAlreadyExist,
        Validation,
    },
} = .{};
pub const create_component: struct {
    action_name: []const u8 = "CreateComponent",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        resource_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .resource_list = "ResourceList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_component) } {
            return .{ .service_metadata = service_metadata, .action = create_component };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_log_pattern: struct {
    action_name: []const u8 = "CreateLogPattern",
    Request: type = struct {
        resource_group_name: []const u8,
        pattern_set_name: []const u8,
        pattern_name: []const u8,
        pattern: []const u8,
        rank: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .pattern_set_name = "PatternSetName",
                .pattern_name = "PatternName",
                .pattern = "Pattern",
                .rank = "Rank",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_log_pattern) } {
            return .{ .service_metadata = service_metadata, .action = create_log_pattern };
        }
    },
    Response: type = struct {
        log_pattern: ?LogPattern = null,
        resource_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_pattern = "LogPattern",
                .resource_group_name = "ResourceGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_application: struct {
    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        resource_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_component: struct {
    action_name: []const u8 = "DeleteComponent",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_component) } {
            return .{ .service_metadata = service_metadata, .action = delete_component };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_log_pattern: struct {
    action_name: []const u8 = "DeleteLogPattern",
    Request: type = struct {
        resource_group_name: []const u8,
        pattern_set_name: []const u8,
        pattern_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .pattern_set_name = "PatternSetName",
                .pattern_name = "PatternName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_log_pattern) } {
            return .{ .service_metadata = service_metadata, .action = delete_log_pattern };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_application: struct {
    action_name: []const u8 = "DescribeApplication",
    Request: type = struct {
        resource_group_name: []const u8,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application) } {
            return .{ .service_metadata = service_metadata, .action = describe_application };
        }
    },
    Response: type = struct {
        application_info: ?ApplicationInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_info = "ApplicationInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_component: struct {
    action_name: []const u8 = "DescribeComponent",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_component) } {
            return .{ .service_metadata = service_metadata, .action = describe_component };
        }
    },
    Response: type = struct {
        application_component: ?ApplicationComponent = null,
        resource_list: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component = "ApplicationComponent",
                .resource_list = "ResourceList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_component_configuration: struct {
    action_name: []const u8 = "DescribeComponentConfiguration",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_component_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_component_configuration };
        }
    },
    Response: type = struct {
        monitor: ?bool = null,
        tier: ?[]const u8 = null,
        component_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitor = "Monitor",
                .tier = "Tier",
                .component_configuration = "ComponentConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_component_configuration_recommendation: struct {
    action_name: []const u8 = "DescribeComponentConfigurationRecommendation",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        tier: []const u8,
        workload_name: ?[]const u8 = null,
        recommendation_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .tier = "Tier",
                .workload_name = "WorkloadName",
                .recommendation_type = "RecommendationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_component_configuration_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = describe_component_configuration_recommendation };
        }
    },
    Response: type = struct {
        component_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_configuration = "ComponentConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_log_pattern: struct {
    action_name: []const u8 = "DescribeLogPattern",
    Request: type = struct {
        resource_group_name: []const u8,
        pattern_set_name: []const u8,
        pattern_name: []const u8,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .pattern_set_name = "PatternSetName",
                .pattern_name = "PatternName",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_log_pattern) } {
            return .{ .service_metadata = service_metadata, .action = describe_log_pattern };
        }
    },
    Response: type = struct {
        resource_group_name: ?[]const u8 = null,
        account_id: ?[]const u8 = null,
        log_pattern: ?LogPattern = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .account_id = "AccountId",
                .log_pattern = "LogPattern",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_observation: struct {
    action_name: []const u8 = "DescribeObservation",
    Request: type = struct {
        observation_id: []const u8,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observation_id = "ObservationId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_observation) } {
            return .{ .service_metadata = service_metadata, .action = describe_observation };
        }
    },
    Response: type = struct {
        observation: ?Observation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .observation = "Observation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_problem: struct {
    action_name: []const u8 = "DescribeProblem",
    Request: type = struct {
        problem_id: []const u8,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .problem_id = "ProblemId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_problem) } {
            return .{ .service_metadata = service_metadata, .action = describe_problem };
        }
    },
    Response: type = struct {
        problem: ?Problem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .problem = "Problem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_problem_observations: struct {
    action_name: []const u8 = "DescribeProblemObservations",
    Request: type = struct {
        problem_id: []const u8,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .problem_id = "ProblemId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_problem_observations) } {
            return .{ .service_metadata = service_metadata, .action = describe_problem_observations };
        }
    },
    Response: type = struct {
        related_observations: ?struct {
            observation_list: ?[]Observation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .observation_list = "ObservationList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .related_observations = "RelatedObservations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_workload: struct {
    action_name: []const u8 = "DescribeWorkload",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        workload_id: []const u8,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .workload_id = "WorkloadId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workload) } {
            return .{ .service_metadata = service_metadata, .action = describe_workload };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_remarks: ?[]const u8 = null,
        workload_configuration: ?WorkloadConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_remarks = "WorkloadRemarks",
                .workload_configuration = "WorkloadConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_applications: struct {
    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        application_info_list: ?[]ApplicationInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_info_list = "ApplicationInfoList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_components: struct {
    action_name: []const u8 = "ListComponents",
    Request: type = struct {
        resource_group_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_components) } {
            return .{ .service_metadata = service_metadata, .action = list_components };
        }
    },
    Response: type = struct {
        application_component_list: ?[]ApplicationComponent = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component_list = "ApplicationComponentList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_configuration_history: struct {
    action_name: []const u8 = "ListConfigurationHistory",
    Request: type = struct {
        resource_group_name: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        event_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .event_status = "EventStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_history) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_history };
        }
    },
    Response: type = struct {
        event_list: ?[]struct {
            resource_group_name: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            monitored_resource_arn: ?[]const u8 = null,
            event_status: ?[]const u8 = null,
            event_resource_type: ?[]const u8 = null,
            event_time: ?i64 = null,
            event_detail: ?[]const u8 = null,
            event_resource_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_group_name = "ResourceGroupName",
                    .account_id = "AccountId",
                    .monitored_resource_arn = "MonitoredResourceARN",
                    .event_status = "EventStatus",
                    .event_resource_type = "EventResourceType",
                    .event_time = "EventTime",
                    .event_detail = "EventDetail",
                    .event_resource_name = "EventResourceName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_list = "EventList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_log_patterns: struct {
    action_name: []const u8 = "ListLogPatterns",
    Request: type = struct {
        resource_group_name: []const u8,
        pattern_set_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .pattern_set_name = "PatternSetName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_log_patterns) } {
            return .{ .service_metadata = service_metadata, .action = list_log_patterns };
        }
    },
    Response: type = struct {
        resource_group_name: ?[]const u8 = null,
        account_id: ?[]const u8 = null,
        log_patterns: ?[]LogPattern = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .account_id = "AccountId",
                .log_patterns = "LogPatterns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_log_pattern_sets: struct {
    action_name: []const u8 = "ListLogPatternSets",
    Request: type = struct {
        resource_group_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_log_pattern_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_log_pattern_sets };
        }
    },
    Response: type = struct {
        resource_group_name: ?[]const u8 = null,
        account_id: ?[]const u8 = null,
        log_pattern_sets: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .account_id = "AccountId",
                .log_pattern_sets = "LogPatternSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_problems: struct {
    action_name: []const u8 = "ListProblems",
    Request: type = struct {
        account_id: ?[]const u8 = null,
        resource_group_name: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        component_name: ?[]const u8 = null,
        visibility: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .resource_group_name = "ResourceGroupName",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .component_name = "ComponentName",
                .visibility = "Visibility",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_problems) } {
            return .{ .service_metadata = service_metadata, .action = list_problems };
        }
    },
    Response: type = struct {
        problem_list: ?[]Problem = null,
        next_token: ?[]const u8 = null,
        resource_group_name: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .problem_list = "ProblemList",
                .next_token = "NextToken",
                .resource_group_name = "ResourceGroupName",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_workloads: struct {
    action_name: []const u8 = "ListWorkloads",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workloads) } {
            return .{ .service_metadata = service_metadata, .action = list_workloads };
        }
    },
    Response: type = struct {
        workload_list: ?[]struct {
            workload_id: ?[]const u8 = null,
            component_name: ?[]const u8 = null,
            workload_name: ?[]const u8 = null,
            tier: ?[]const u8 = null,
            workload_remarks: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workload_id = "WorkloadId",
                    .component_name = "ComponentName",
                    .workload_name = "WorkloadName",
                    .tier = "Tier",
                    .workload_remarks = "WorkloadRemarks",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_list = "WorkloadList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const remove_workload: struct {
    action_name: []const u8 = "RemoveWorkload",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        workload_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .workload_id = "WorkloadId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_workload) } {
            return .{ .service_metadata = service_metadata, .action = remove_workload };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        TooManyTags,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_application: struct {
    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        resource_group_name: []const u8,
        ops_center_enabled: ?bool = null,
        cwe_monitor_enabled: ?bool = null,
        ops_item_sns_topic_arn: ?[]const u8 = null,
        remove_sns_topic: ?bool = null,
        auto_config_enabled: ?bool = null,
        attach_missing_permission: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .ops_center_enabled = "OpsCenterEnabled",
                .cwe_monitor_enabled = "CWEMonitorEnabled",
                .ops_item_sns_topic_arn = "OpsItemSNSTopicArn",
                .remove_sns_topic = "RemoveSNSTopic",
                .auto_config_enabled = "AutoConfigEnabled",
                .attach_missing_permission = "AttachMissingPermission",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {
        application_info: ?ApplicationInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_info = "ApplicationInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_component: struct {
    action_name: []const u8 = "UpdateComponent",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        new_component_name: ?[]const u8 = null,
        resource_list: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .new_component_name = "NewComponentName",
                .resource_list = "ResourceList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_component) } {
            return .{ .service_metadata = service_metadata, .action = update_component };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_component_configuration: struct {
    action_name: []const u8 = "UpdateComponentConfiguration",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        monitor: ?bool = null,
        tier: ?[]const u8 = null,
        component_configuration: ?[]const u8 = null,
        auto_config_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .monitor = "Monitor",
                .tier = "Tier",
                .component_configuration = "ComponentConfiguration",
                .auto_config_enabled = "AutoConfigEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_component_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_component_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_log_pattern: struct {
    action_name: []const u8 = "UpdateLogPattern",
    Request: type = struct {
        resource_group_name: []const u8,
        pattern_set_name: []const u8,
        pattern_name: []const u8,
        pattern: ?[]const u8 = null,
        rank: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .pattern_set_name = "PatternSetName",
                .pattern_name = "PatternName",
                .pattern = "Pattern",
                .rank = "Rank",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_log_pattern) } {
            return .{ .service_metadata = service_metadata, .action = update_log_pattern };
        }
    },
    Response: type = struct {
        resource_group_name: ?[]const u8 = null,
        log_pattern: ?LogPattern = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .log_pattern = "LogPattern",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_problem: struct {
    action_name: []const u8 = "UpdateProblem",
    Request: type = struct {
        problem_id: []const u8,
        update_status: ?[]const u8 = null,
        visibility: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .problem_id = "ProblemId",
                .update_status = "UpdateStatus",
                .visibility = "Visibility",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_problem) } {
            return .{ .service_metadata = service_metadata, .action = update_problem };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_workload: struct {
    action_name: []const u8 = "UpdateWorkload",
    Request: type = struct {
        resource_group_name: []const u8,
        component_name: []const u8,
        workload_id: ?[]const u8 = null,
        workload_configuration: WorkloadConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_name = "ResourceGroupName",
                .component_name = "ComponentName",
                .workload_id = "WorkloadId",
                .workload_configuration = "WorkloadConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workload) } {
            return .{ .service_metadata = service_metadata, .action = update_workload };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_configuration: ?WorkloadConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_configuration = "WorkloadConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const WorkloadConfiguration = struct {
    workload_name: ?[]const u8 = null,
    tier: ?[]const u8 = null,
    configuration: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workload_name = "WorkloadName",
            .tier = "Tier",
            .configuration = "Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const LogPattern = struct {
    pattern_set_name: ?[]const u8 = null,
    pattern_name: ?[]const u8 = null,
    pattern: ?[]const u8 = null,
    rank: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pattern_set_name = "PatternSetName",
            .pattern_name = "PatternName",
            .pattern = "Pattern",
            .rank = "Rank",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationInfo = struct {
    account_id: ?[]const u8 = null,
    resource_group_name: ?[]const u8 = null,
    life_cycle: ?[]const u8 = null,
    ops_item_sns_topic_arn: ?[]const u8 = null,
    ops_center_enabled: ?bool = null,
    cwe_monitor_enabled: ?bool = null,
    remarks: ?[]const u8 = null,
    auto_config_enabled: ?bool = null,
    discovery_type: ?[]const u8 = null,
    attach_missing_permission: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .resource_group_name = "ResourceGroupName",
            .life_cycle = "LifeCycle",
            .ops_item_sns_topic_arn = "OpsItemSNSTopicArn",
            .ops_center_enabled = "OpsCenterEnabled",
            .cwe_monitor_enabled = "CWEMonitorEnabled",
            .remarks = "Remarks",
            .auto_config_enabled = "AutoConfigEnabled",
            .discovery_type = "DiscoveryType",
            .attach_missing_permission = "AttachMissingPermission",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Problem = struct {
    id: ?[]const u8 = null,
    title: ?[]const u8 = null,
    insights: ?[]const u8 = null,
    status: ?[]const u8 = null,
    affected_resource: ?[]const u8 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    severity_level: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    resource_group_name: ?[]const u8 = null,
    feedback: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    recurring_count: ?i64 = null,
    last_recurrence_time: ?i64 = null,
    visibility: ?[]const u8 = null,
    resolution_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .title = "Title",
            .insights = "Insights",
            .status = "Status",
            .affected_resource = "AffectedResource",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .severity_level = "SeverityLevel",
            .account_id = "AccountId",
            .resource_group_name = "ResourceGroupName",
            .feedback = "Feedback",
            .recurring_count = "RecurringCount",
            .last_recurrence_time = "LastRecurrenceTime",
            .visibility = "Visibility",
            .resolution_method = "ResolutionMethod",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "feedback", field_name))
            return try serializeMap(self.feedback, self.fieldNameFor("feedback"), options, out_stream);
        return false;
    }
};

pub const ApplicationComponent = struct {
    component_name: ?[]const u8 = null,
    component_remarks: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    os_type: ?[]const u8 = null,
    tier: ?[]const u8 = null,
    monitor: ?bool = null,
    detected_workload: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,


    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "value", field_name))
            return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
        return false;
    }
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_name = "ComponentName",
            .component_remarks = "ComponentRemarks",
            .resource_type = "ResourceType",
            .os_type = "OsType",
            .tier = "Tier",
            .monitor = "Monitor",
            .detected_workload = "DetectedWorkload",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "detected_workload", field_name))
            return try serializeMap(self.detected_workload, self.fieldNameFor("detected_workload"), options, out_stream);
        return false;
    }
};

pub const Observation = struct {
    id: ?[]const u8 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    source_type: ?[]const u8 = null,
    source_arn: ?[]const u8 = null,
    log_group: ?[]const u8 = null,
    line_time: ?i64 = null,
    log_text: ?[]const u8 = null,
    log_filter: ?[]const u8 = null,
    metric_namespace: ?[]const u8 = null,
    metric_name: ?[]const u8 = null,
    unit: ?[]const u8 = null,
    value: ?f64 = null,
    cloud_watch_event_id: ?[]const u8 = null,
    cloud_watch_event_source: ?[]const u8 = null,
    cloud_watch_event_detail_type: ?[]const u8 = null,
    health_event_arn: ?[]const u8 = null,
    health_service: ?[]const u8 = null,
    health_event_type_code: ?[]const u8 = null,
    health_event_type_category: ?[]const u8 = null,
    health_event_description: ?[]const u8 = null,
    code_deploy_deployment_id: ?[]const u8 = null,
    code_deploy_deployment_group: ?[]const u8 = null,
    code_deploy_state: ?[]const u8 = null,
    code_deploy_application: ?[]const u8 = null,
    code_deploy_instance_group_id: ?[]const u8 = null,
    ec2_state: ?[]const u8 = null,
    rds_event_categories: ?[]const u8 = null,
    rds_event_message: ?[]const u8 = null,
    s3_event_name: ?[]const u8 = null,
    states_execution_arn: ?[]const u8 = null,
    states_arn: ?[]const u8 = null,
    states_status: ?[]const u8 = null,
    states_input: ?[]const u8 = null,
    ebs_event: ?[]const u8 = null,
    ebs_result: ?[]const u8 = null,
    ebs_cause: ?[]const u8 = null,
    ebs_request_id: ?[]const u8 = null,
    x_ray_fault_percent: ?i64 = null,
    x_ray_throttle_percent: ?i64 = null,
    x_ray_error_percent: ?i64 = null,
    x_ray_request_count: ?i64 = null,
    x_ray_request_average_latency: ?i64 = null,
    x_ray_node_name: ?[]const u8 = null,
    x_ray_node_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .source_type = "SourceType",
            .source_arn = "SourceARN",
            .log_group = "LogGroup",
            .line_time = "LineTime",
            .log_text = "LogText",
            .log_filter = "LogFilter",
            .metric_namespace = "MetricNamespace",
            .metric_name = "MetricName",
            .unit = "Unit",
            .value = "Value",
            .cloud_watch_event_id = "CloudWatchEventId",
            .cloud_watch_event_source = "CloudWatchEventSource",
            .cloud_watch_event_detail_type = "CloudWatchEventDetailType",
            .health_event_arn = "HealthEventArn",
            .health_service = "HealthService",
            .health_event_type_code = "HealthEventTypeCode",
            .health_event_type_category = "HealthEventTypeCategory",
            .health_event_description = "HealthEventDescription",
            .code_deploy_deployment_id = "CodeDeployDeploymentId",
            .code_deploy_deployment_group = "CodeDeployDeploymentGroup",
            .code_deploy_state = "CodeDeployState",
            .code_deploy_application = "CodeDeployApplication",
            .code_deploy_instance_group_id = "CodeDeployInstanceGroupId",
            .ec2_state = "Ec2State",
            .rds_event_categories = "RdsEventCategories",
            .rds_event_message = "RdsEventMessage",
            .s3_event_name = "S3EventName",
            .states_execution_arn = "StatesExecutionArn",
            .states_arn = "StatesArn",
            .states_status = "StatesStatus",
            .states_input = "StatesInput",
            .ebs_event = "EbsEvent",
            .ebs_result = "EbsResult",
            .ebs_cause = "EbsCause",
            .ebs_request_id = "EbsRequestId",
            .x_ray_fault_percent = "XRayFaultPercent",
            .x_ray_throttle_percent = "XRayThrottlePercent",
            .x_ray_error_percent = "XRayErrorPercent",
            .x_ray_request_count = "XRayRequestCount",
            .x_ray_request_average_latency = "XRayRequestAverageLatency",
            .x_ray_node_name = "XRayNodeName",
            .x_ray_node_type = "XRayNodeType",
        };
        return @field(mappings, field_name);
    }
};
