const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-05-18";
pub const sdk_id: []const u8 = "Athena";
pub const arn_namespace: ?[]const u8 = "athena";
pub const endpoint_prefix: []const u8 = "athena";
pub const sigv4_name: []const u8 = "athena";
pub const name: []const u8 = "AmazonAthena";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-05-18",
    sdk_id: []const u8 = "Athena",
    arn_namespace: ?[]const u8 = "athena",
    endpoint_prefix: []const u8 = "athena",
    sigv4_name: []const u8 = "athena",
    name: []const u8 = "AmazonAthena",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_get_named_query: struct {
    action_name: []const u8 = "BatchGetNamedQuery",
    Request: type = struct {
        named_query_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_ids = "NamedQueryIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_named_query) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_named_query };
        }
    },
    Response: type = struct {
        named_queries: ?[]NamedQuery = null,
        unprocessed_named_query_ids: ?[]struct {
            named_query_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .named_query_id = "NamedQueryId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_queries = "NamedQueries",
                .unprocessed_named_query_ids = "UnprocessedNamedQueryIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const batch_get_prepared_statement: struct {
    action_name: []const u8 = "BatchGetPreparedStatement",
    Request: type = struct {
        prepared_statement_names: [][]const u8,
        work_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prepared_statement_names = "PreparedStatementNames",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_prepared_statement };
        }
    },
    Response: type = struct {
        prepared_statements: ?[]PreparedStatement = null,
        unprocessed_prepared_statement_names: ?[]struct {
            statement_name: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .statement_name = "StatementName",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prepared_statements = "PreparedStatements",
                .unprocessed_prepared_statement_names = "UnprocessedPreparedStatementNames",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const batch_get_query_execution: struct {
    action_name: []const u8 = "BatchGetQueryExecution",
    Request: type = struct {
        query_execution_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_ids = "QueryExecutionIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_query_execution) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_query_execution };
        }
    },
    Response: type = struct {
        query_executions: ?[]QueryExecution = null,
        unprocessed_query_execution_ids: ?[]struct {
            query_execution_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .query_execution_id = "QueryExecutionId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_executions = "QueryExecutions",
                .unprocessed_query_execution_ids = "UnprocessedQueryExecutionIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const cancel_capacity_reservation: struct {
    action_name: []const u8 = "CancelCapacityReservation",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = cancel_capacity_reservation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_capacity_reservation: struct {
    action_name: []const u8 = "CreateCapacityReservation",
    Request: type = struct {
        target_dpus: i64,
        name: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_dpus = "TargetDpus",
                .name = "Name",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = create_capacity_reservation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_data_catalog: struct {
    action_name: []const u8 = "CreateDataCatalog",
    Request: type = struct {
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .parameters = "Parameters",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_catalog) } {
            return .{ .service_metadata = service_metadata, .action = create_data_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_named_query: struct {
    action_name: []const u8 = "CreateNamedQuery",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        database: []const u8,
        query_string: []const u8,
        client_request_token: ?[]const u8 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .database = "Database",
                .query_string = "QueryString",
                .client_request_token = "ClientRequestToken",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_named_query) } {
            return .{ .service_metadata = service_metadata, .action = create_named_query };
        }
    },
    Response: type = struct {
        named_query_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_id = "NamedQueryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_notebook: struct {
    action_name: []const u8 = "CreateNotebook",
    Request: type = struct {
        work_group: []const u8,
        name: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .name = "Name",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_notebook) } {
            return .{ .service_metadata = service_metadata, .action = create_notebook };
        }
    },
    Response: type = struct {
        notebook_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_id = "NotebookId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const create_prepared_statement: struct {
    action_name: []const u8 = "CreatePreparedStatement",
    Request: type = struct {
        statement_name: []const u8,
        work_group: []const u8,
        query_statement: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_name = "StatementName",
                .work_group = "WorkGroup",
                .query_statement = "QueryStatement",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = create_prepared_statement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_presigned_notebook_url: struct {
    action_name: []const u8 = "CreatePresignedNotebookUrl",
    Request: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_presigned_notebook_url) } {
            return .{ .service_metadata = service_metadata, .action = create_presigned_notebook_url };
        }
    },
    Response: type = struct {
        notebook_url: []const u8,
        auth_token: []const u8,
        auth_token_expiration_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_url = "NotebookUrl",
                .auth_token = "AuthToken",
                .auth_token_expiration_time = "AuthTokenExpirationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const create_work_group: struct {
    action_name: []const u8 = "CreateWorkGroup",
    Request: type = struct {
        name: []const u8,
        configuration: ?WorkGroupConfiguration = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .configuration = "Configuration",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_work_group) } {
            return .{ .service_metadata = service_metadata, .action = create_work_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_capacity_reservation: struct {
    action_name: []const u8 = "DeleteCapacityReservation",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = delete_capacity_reservation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_data_catalog: struct {
    action_name: []const u8 = "DeleteDataCatalog",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_catalog) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_named_query: struct {
    action_name: []const u8 = "DeleteNamedQuery",
    Request: type = struct {
        named_query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_id = "NamedQueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_named_query) } {
            return .{ .service_metadata = service_metadata, .action = delete_named_query };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_notebook: struct {
    action_name: []const u8 = "DeleteNotebook",
    Request: type = struct {
        notebook_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_id = "NotebookId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_notebook) } {
            return .{ .service_metadata = service_metadata, .action = delete_notebook };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const delete_prepared_statement: struct {
    action_name: []const u8 = "DeletePreparedStatement",
    Request: type = struct {
        statement_name: []const u8,
        work_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_name = "StatementName",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = delete_prepared_statement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_work_group: struct {
    action_name: []const u8 = "DeleteWorkGroup",
    Request: type = struct {
        work_group: []const u8,
        recursive_delete_option: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .recursive_delete_option = "RecursiveDeleteOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_work_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_work_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const export_notebook: struct {
    action_name: []const u8 = "ExportNotebook",
    Request: type = struct {
        notebook_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_id = "NotebookId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_notebook) } {
            return .{ .service_metadata = service_metadata, .action = export_notebook };
        }
    },
    Response: type = struct {
        notebook_metadata: ?NotebookMetadata = null,
        payload: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_metadata = "NotebookMetadata",
                .payload = "Payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const get_calculation_execution: struct {
    action_name: []const u8 = "GetCalculationExecution",
    Request: type = struct {
        calculation_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculation_execution_id = "CalculationExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_calculation_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_calculation_execution };
        }
    },
    Response: type = struct {
        calculation_execution_id: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        working_directory: ?[]const u8 = null,
        status: ?CalculationStatus = null,
        statistics: ?CalculationStatistics = null,
        result: ?struct {
            std_out_s3_uri: ?[]const u8 = null,
            std_error_s3_uri: ?[]const u8 = null,
            result_s3_uri: ?[]const u8 = null,
            result_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .std_out_s3_uri = "StdOutS3Uri",
                    .std_error_s3_uri = "StdErrorS3Uri",
                    .result_s3_uri = "ResultS3Uri",
                    .result_type = "ResultType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculation_execution_id = "CalculationExecutionId",
                .session_id = "SessionId",
                .description = "Description",
                .working_directory = "WorkingDirectory",
                .status = "Status",
                .statistics = "Statistics",
                .result = "Result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_calculation_execution_code: struct {
    action_name: []const u8 = "GetCalculationExecutionCode",
    Request: type = struct {
        calculation_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculation_execution_id = "CalculationExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_calculation_execution_code) } {
            return .{ .service_metadata = service_metadata, .action = get_calculation_execution_code };
        }
    },
    Response: type = struct {
        code_block: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_block = "CodeBlock",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_calculation_execution_status: struct {
    action_name: []const u8 = "GetCalculationExecutionStatus",
    Request: type = struct {
        calculation_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculation_execution_id = "CalculationExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_calculation_execution_status) } {
            return .{ .service_metadata = service_metadata, .action = get_calculation_execution_status };
        }
    },
    Response: type = struct {
        status: ?CalculationStatus = null,
        statistics: ?CalculationStatistics = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .statistics = "Statistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_capacity_assignment_configuration: struct {
    action_name: []const u8 = "GetCapacityAssignmentConfiguration",
    Request: type = struct {
        capacity_reservation_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_name = "CapacityReservationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_capacity_assignment_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_capacity_assignment_configuration };
        }
    },
    Response: type = struct {
        capacity_assignment_configuration: struct {
            capacity_reservation_name: ?[]const u8 = null,
            capacity_assignments: ?[]CapacityAssignment = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .capacity_reservation_name = "CapacityReservationName",
                    .capacity_assignments = "CapacityAssignments",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_assignment_configuration = "CapacityAssignmentConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_capacity_reservation: struct {
    action_name: []const u8 = "GetCapacityReservation",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = get_capacity_reservation };
        }
    },
    Response: type = struct {
        capacity_reservation: CapacityReservation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation = "CapacityReservation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_database: struct {
    action_name: []const u8 = "GetDatabase",
    Request: type = struct {
        catalog_name: []const u8,
        database_name: []const u8,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_name = "CatalogName",
                .database_name = "DatabaseName",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_database) } {
            return .{ .service_metadata = service_metadata, .action = get_database };
        }
    },
    Response: type = struct {
        database: ?Database = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database = "Database",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        Metadata,
    },
} = .{};
pub const get_data_catalog: struct {
    action_name: []const u8 = "GetDataCatalog",
    Request: type = struct {
        name: []const u8,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_catalog) } {
            return .{ .service_metadata = service_metadata, .action = get_data_catalog };
        }
    },
    Response: type = struct {
        data_catalog: ?struct {
            name: []const u8,
            description: ?[]const u8 = null,
            type: []const u8,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .description = "Description",
                    .type = "Type",
                    .parameters = "Parameters",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_catalog = "DataCatalog",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_named_query: struct {
    action_name: []const u8 = "GetNamedQuery",
    Request: type = struct {
        named_query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_id = "NamedQueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_named_query) } {
            return .{ .service_metadata = service_metadata, .action = get_named_query };
        }
    },
    Response: type = struct {
        named_query: ?NamedQuery = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query = "NamedQuery",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_notebook_metadata: struct {
    action_name: []const u8 = "GetNotebookMetadata",
    Request: type = struct {
        notebook_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_id = "NotebookId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_notebook_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_notebook_metadata };
        }
    },
    Response: type = struct {
        notebook_metadata: ?NotebookMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_metadata = "NotebookMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const get_prepared_statement: struct {
    action_name: []const u8 = "GetPreparedStatement",
    Request: type = struct {
        statement_name: []const u8,
        work_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_name = "StatementName",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = get_prepared_statement };
        }
    },
    Response: type = struct {
        prepared_statement: ?PreparedStatement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prepared_statement = "PreparedStatement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_query_execution: struct {
    action_name: []const u8 = "GetQueryExecution",
    Request: type = struct {
        query_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_query_execution };
        }
    },
    Response: type = struct {
        query_execution: ?QueryExecution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution = "QueryExecution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_query_results: struct {
    action_name: []const u8 = "GetQueryResults",
    Request: type = struct {
        query_execution_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_results) } {
            return .{ .service_metadata = service_metadata, .action = get_query_results };
        }
    },
    Response: type = struct {
        update_count: ?i64 = null,
        result_set: ?struct {
            rows: ?[]struct {
                data: ?[]struct {
                    var_char_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .var_char_value = "VarCharValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .data = "Data",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            result_set_metadata: ?struct {
                column_info: ?[]struct {
                    catalog_name: ?[]const u8 = null,
                    schema_name: ?[]const u8 = null,
                    table_name: ?[]const u8 = null,
                    name: []const u8,
                    label: ?[]const u8 = null,
                    type: []const u8,
                    precision: ?i64 = null,
                    scale: ?i64 = null,
                    nullable: ?[]const u8 = null,
                    case_sensitive: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .catalog_name = "CatalogName",
                            .schema_name = "SchemaName",
                            .table_name = "TableName",
                            .name = "Name",
                            .label = "Label",
                            .type = "Type",
                            .precision = "Precision",
                            .scale = "Scale",
                            .nullable = "Nullable",
                            .case_sensitive = "CaseSensitive",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .column_info = "ColumnInfo",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rows = "Rows",
                    .result_set_metadata = "ResultSetMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_count = "UpdateCount",
                .result_set = "ResultSet",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const get_query_runtime_statistics: struct {
    action_name: []const u8 = "GetQueryRuntimeStatistics",
    Request: type = struct {
        query_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_runtime_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_query_runtime_statistics };
        }
    },
    Response: type = struct {
        query_runtime_statistics: ?struct {
            timeline: ?struct {
                query_queue_time_in_millis: ?i64 = null,
                service_pre_processing_time_in_millis: ?i64 = null,
                query_planning_time_in_millis: ?i64 = null,
                engine_execution_time_in_millis: ?i64 = null,
                service_processing_time_in_millis: ?i64 = null,
                total_execution_time_in_millis: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .query_queue_time_in_millis = "QueryQueueTimeInMillis",
                        .service_pre_processing_time_in_millis = "ServicePreProcessingTimeInMillis",
                        .query_planning_time_in_millis = "QueryPlanningTimeInMillis",
                        .engine_execution_time_in_millis = "EngineExecutionTimeInMillis",
                        .service_processing_time_in_millis = "ServiceProcessingTimeInMillis",
                        .total_execution_time_in_millis = "TotalExecutionTimeInMillis",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            rows: ?struct {
                input_rows: ?i64 = null,
                input_bytes: ?i64 = null,
                output_bytes: ?i64 = null,
                output_rows: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input_rows = "InputRows",
                        .input_bytes = "InputBytes",
                        .output_bytes = "OutputBytes",
                        .output_rows = "OutputRows",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            output_stage: ?QueryStage = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timeline = "Timeline",
                    .rows = "Rows",
                    .output_stage = "OutputStage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_runtime_statistics = "QueryRuntimeStatistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_session: struct {
    action_name: []const u8 = "GetSession",
    Request: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_session) } {
            return .{ .service_metadata = service_metadata, .action = get_session };
        }
    },
    Response: type = struct {
        session_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        work_group: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        engine_configuration: ?EngineConfiguration = null,
        notebook_version: ?[]const u8 = null,
        session_configuration: ?struct {
            execution_role: ?[]const u8 = null,
            working_directory: ?[]const u8 = null,
            idle_timeout_seconds: ?i64 = null,
            encryption_configuration: ?EncryptionConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_role = "ExecutionRole",
                    .working_directory = "WorkingDirectory",
                    .idle_timeout_seconds = "IdleTimeoutSeconds",
                    .encryption_configuration = "EncryptionConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?SessionStatus = null,
        statistics: ?struct {
            dpu_execution_in_millis: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dpu_execution_in_millis = "DpuExecutionInMillis",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .description = "Description",
                .work_group = "WorkGroup",
                .engine_version = "EngineVersion",
                .engine_configuration = "EngineConfiguration",
                .notebook_version = "NotebookVersion",
                .session_configuration = "SessionConfiguration",
                .status = "Status",
                .statistics = "Statistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_session_status: struct {
    action_name: []const u8 = "GetSessionStatus",
    Request: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_session_status) } {
            return .{ .service_metadata = service_metadata, .action = get_session_status };
        }
    },
    Response: type = struct {
        session_id: ?[]const u8 = null,
        status: ?SessionStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_table_metadata: struct {
    action_name: []const u8 = "GetTableMetadata",
    Request: type = struct {
        catalog_name: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_name = "CatalogName",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_table_metadata };
        }
    },
    Response: type = struct {
        table_metadata: ?TableMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_metadata = "TableMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        Metadata,
    },
} = .{};
pub const get_work_group: struct {
    action_name: []const u8 = "GetWorkGroup",
    Request: type = struct {
        work_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_work_group) } {
            return .{ .service_metadata = service_metadata, .action = get_work_group };
        }
    },
    Response: type = struct {
        work_group: ?struct {
            name: []const u8,
            state: ?[]const u8 = null,
            configuration: ?WorkGroupConfiguration = null,
            description: ?[]const u8 = null,
            creation_time: ?i64 = null,
            identity_center_application_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .state = "State",
                    .configuration = "Configuration",
                    .description = "Description",
                    .creation_time = "CreationTime",
                    .identity_center_application_arn = "IdentityCenterApplicationArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const import_notebook: struct {
    action_name: []const u8 = "ImportNotebook",
    Request: type = struct {
        work_group: []const u8,
        name: []const u8,
        payload: ?[]const u8 = null,
        type: []const u8,
        notebook_s3_location_uri: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .name = "Name",
                .payload = "Payload",
                .type = "Type",
                .notebook_s3_location_uri = "NotebookS3LocationUri",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_notebook) } {
            return .{ .service_metadata = service_metadata, .action = import_notebook };
        }
    },
    Response: type = struct {
        notebook_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_id = "NotebookId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const list_application_dpu_sizes: struct {
    action_name: []const u8 = "ListApplicationDPUSizes",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_dpu_sizes) } {
            return .{ .service_metadata = service_metadata, .action = list_application_dpu_sizes };
        }
    },
    Response: type = struct {
        application_dpu_sizes: ?[]struct {
            application_runtime_id: ?[]const u8 = null,
            supported_dpu_sizes: ?[]i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_runtime_id = "ApplicationRuntimeId",
                    .supported_dpu_sizes = "SupportedDPUSizes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_dpu_sizes = "ApplicationDPUSizes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const list_calculation_executions: struct {
    action_name: []const u8 = "ListCalculationExecutions",
    Request: type = struct {
        session_id: []const u8,
        state_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .state_filter = "StateFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_calculation_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_calculation_executions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        calculations: ?[]struct {
            calculation_execution_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?CalculationStatus = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .calculation_execution_id = "CalculationExecutionId",
                    .description = "Description",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .calculations = "Calculations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_capacity_reservations: struct {
    action_name: []const u8 = "ListCapacityReservations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_capacity_reservations) } {
            return .{ .service_metadata = service_metadata, .action = list_capacity_reservations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        capacity_reservations: []CapacityReservation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .capacity_reservations = "CapacityReservations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_databases: struct {
    action_name: []const u8 = "ListDatabases",
    Request: type = struct {
        catalog_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_name = "CatalogName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_databases) } {
            return .{ .service_metadata = service_metadata, .action = list_databases };
        }
    },
    Response: type = struct {
        database_list: ?[]Database = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_list = "DatabaseList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        Metadata,
    },
} = .{};
pub const list_data_catalogs: struct {
    action_name: []const u8 = "ListDataCatalogs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_catalogs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_catalogs };
        }
    },
    Response: type = struct {
        data_catalogs_summary: ?[]struct {
            catalog_name: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .catalog_name = "CatalogName",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_catalogs_summary = "DataCatalogsSummary",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_engine_versions: struct {
    action_name: []const u8 = "ListEngineVersions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_engine_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_engine_versions };
        }
    },
    Response: type = struct {
        engine_versions: ?[]EngineVersion = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_versions = "EngineVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_executors: struct {
    action_name: []const u8 = "ListExecutors",
    Request: type = struct {
        session_id: []const u8,
        executor_state_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .executor_state_filter = "ExecutorStateFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_executors) } {
            return .{ .service_metadata = service_metadata, .action = list_executors };
        }
    },
    Response: type = struct {
        session_id: []const u8,
        next_token: ?[]const u8 = null,
        executors_summary: ?[]struct {
            executor_id: []const u8,
            executor_type: ?[]const u8 = null,
            start_date_time: ?i64 = null,
            termination_date_time: ?i64 = null,
            executor_state: ?[]const u8 = null,
            executor_size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .executor_id = "ExecutorId",
                    .executor_type = "ExecutorType",
                    .start_date_time = "StartDateTime",
                    .termination_date_time = "TerminationDateTime",
                    .executor_state = "ExecutorState",
                    .executor_size = "ExecutorSize",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .next_token = "NextToken",
                .executors_summary = "ExecutorsSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_named_queries: struct {
    action_name: []const u8 = "ListNamedQueries",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_named_queries) } {
            return .{ .service_metadata = service_metadata, .action = list_named_queries };
        }
    },
    Response: type = struct {
        named_query_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_ids = "NamedQueryIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_notebook_metadata: struct {
    action_name: []const u8 = "ListNotebookMetadata",
    Request: type = struct {
        filters: ?struct {
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        work_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notebook_metadata) } {
            return .{ .service_metadata = service_metadata, .action = list_notebook_metadata };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        notebook_metadata_list: ?[]NotebookMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .notebook_metadata_list = "NotebookMetadataList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const list_notebook_sessions: struct {
    action_name: []const u8 = "ListNotebookSessions",
    Request: type = struct {
        notebook_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_id = "NotebookId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notebook_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_notebook_sessions };
        }
    },
    Response: type = struct {
        notebook_sessions_list: []struct {
            session_id: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_id = "SessionId",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_sessions_list = "NotebookSessionsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_prepared_statements: struct {
    action_name: []const u8 = "ListPreparedStatements",
    Request: type = struct {
        work_group: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_prepared_statements) } {
            return .{ .service_metadata = service_metadata, .action = list_prepared_statements };
        }
    },
    Response: type = struct {
        prepared_statements: ?[]struct {
            statement_name: ?[]const u8 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .statement_name = "StatementName",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prepared_statements = "PreparedStatements",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_query_executions: struct {
    action_name: []const u8 = "ListQueryExecutions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_query_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_query_executions };
        }
    },
    Response: type = struct {
        query_execution_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_ids = "QueryExecutionIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_sessions: struct {
    action_name: []const u8 = "ListSessions",
    Request: type = struct {
        work_group: []const u8,
        state_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .state_filter = "StateFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_sessions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        sessions: ?[]struct {
            session_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            engine_version: ?EngineVersion = null,
            notebook_version: ?[]const u8 = null,
            status: ?SessionStatus = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_id = "SessionId",
                    .description = "Description",
                    .engine_version = "EngineVersion",
                    .notebook_version = "NotebookVersion",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .sessions = "Sessions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_table_metadata: struct {
    action_name: []const u8 = "ListTableMetadata",
    Request: type = struct {
        catalog_name: []const u8,
        database_name: []const u8,
        expression: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_name = "CatalogName",
                .database_name = "DatabaseName",
                .expression = "Expression",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_table_metadata) } {
            return .{ .service_metadata = service_metadata, .action = list_table_metadata };
        }
    },
    Response: type = struct {
        table_metadata_list: ?[]TableMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_metadata_list = "TableMetadataList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        Metadata,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_work_groups: struct {
    action_name: []const u8 = "ListWorkGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_work_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_work_groups };
        }
    },
    Response: type = struct {
        work_groups: ?[]struct {
            name: ?[]const u8 = null,
            state: ?[]const u8 = null,
            description: ?[]const u8 = null,
            creation_time: ?i64 = null,
            engine_version: ?EngineVersion = null,
            identity_center_application_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .state = "State",
                    .description = "Description",
                    .creation_time = "CreationTime",
                    .engine_version = "EngineVersion",
                    .identity_center_application_arn = "IdentityCenterApplicationArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_groups = "WorkGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const put_capacity_assignment_configuration: struct {
    action_name: []const u8 = "PutCapacityAssignmentConfiguration",
    Request: type = struct {
        capacity_reservation_name: []const u8,
        capacity_assignments: []CapacityAssignment,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_name = "CapacityReservationName",
                .capacity_assignments = "CapacityAssignments",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_capacity_assignment_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_capacity_assignment_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const start_calculation_execution: struct {
    action_name: []const u8 = "StartCalculationExecution",
    Request: type = struct {
        session_id: []const u8,
        description: ?[]const u8 = null,
        calculation_configuration: ?struct {
            code_block: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code_block = "CodeBlock",
                };
                return @field(mappings, field_name);
            }
        } = null,
        code_block: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .description = "Description",
                .calculation_configuration = "CalculationConfiguration",
                .code_block = "CodeBlock",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_calculation_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_calculation_execution };
        }
    },
    Response: type = struct {
        calculation_execution_id: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculation_execution_id = "CalculationExecutionId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const start_query_execution: struct {
    action_name: []const u8 = "StartQueryExecution",
    Request: type = struct {
        query_string: []const u8,
        client_request_token: ?[]const u8 = null,
        query_execution_context: ?QueryExecutionContext = null,
        result_configuration: ?ResultConfiguration = null,
        work_group: ?[]const u8 = null,
        execution_parameters: ?[][]const u8 = null,
        result_reuse_configuration: ?ResultReuseConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_string = "QueryString",
                .client_request_token = "ClientRequestToken",
                .query_execution_context = "QueryExecutionContext",
                .result_configuration = "ResultConfiguration",
                .work_group = "WorkGroup",
                .execution_parameters = "ExecutionParameters",
                .result_reuse_configuration = "ResultReuseConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_query_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_query_execution };
        }
    },
    Response: type = struct {
        query_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const start_session: struct {
    action_name: []const u8 = "StartSession",
    Request: type = struct {
        description: ?[]const u8 = null,
        work_group: []const u8,
        engine_configuration: EngineConfiguration,
        notebook_version: ?[]const u8 = null,
        session_idle_timeout_in_minutes: ?i64 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .work_group = "WorkGroup",
                .engine_configuration = "EngineConfiguration",
                .notebook_version = "NotebookVersion",
                .session_idle_timeout_in_minutes = "SessionIdleTimeoutInMinutes",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_session) } {
            return .{ .service_metadata = service_metadata, .action = start_session };
        }
    },
    Response: type = struct {
        session_id: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
        SessionAlreadyExists,
        TooManyRequests,
    },
} = .{};
pub const stop_calculation_execution: struct {
    action_name: []const u8 = "StopCalculationExecution",
    Request: type = struct {
        calculation_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculation_execution_id = "CalculationExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_calculation_execution) } {
            return .{ .service_metadata = service_metadata, .action = stop_calculation_execution };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const stop_query_execution: struct {
    action_name: []const u8 = "StopQueryExecution",
    Request: type = struct {
        query_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_query_execution) } {
            return .{ .service_metadata = service_metadata, .action = stop_query_execution };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const terminate_session: struct {
    action_name: []const u8 = "TerminateSession",
    Request: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_session) } {
            return .{ .service_metadata = service_metadata, .action = terminate_session };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_capacity_reservation: struct {
    action_name: []const u8 = "UpdateCapacityReservation",
    Request: type = struct {
        target_dpus: i64,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_dpus = "TargetDpus",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = update_capacity_reservation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const update_data_catalog: struct {
    action_name: []const u8 = "UpdateDataCatalog",
    Request: type = struct {
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_catalog) } {
            return .{ .service_metadata = service_metadata, .action = update_data_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const update_named_query: struct {
    action_name: []const u8 = "UpdateNamedQuery",
    Request: type = struct {
        named_query_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        query_string: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_id = "NamedQueryId",
                .name = "Name",
                .description = "Description",
                .query_string = "QueryString",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_named_query) } {
            return .{ .service_metadata = service_metadata, .action = update_named_query };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const update_notebook: struct {
    action_name: []const u8 = "UpdateNotebook",
    Request: type = struct {
        notebook_id: []const u8,
        payload: []const u8,
        type: []const u8,
        session_id: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_id = "NotebookId",
                .payload = "Payload",
                .type = "Type",
                .session_id = "SessionId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_notebook) } {
            return .{ .service_metadata = service_metadata, .action = update_notebook };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const update_notebook_metadata: struct {
    action_name: []const u8 = "UpdateNotebookMetadata",
    Request: type = struct {
        notebook_id: []const u8,
        client_request_token: ?[]const u8 = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_id = "NotebookId",
                .client_request_token = "ClientRequestToken",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_notebook_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_notebook_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const update_prepared_statement: struct {
    action_name: []const u8 = "UpdatePreparedStatement",
    Request: type = struct {
        statement_name: []const u8,
        work_group: []const u8,
        query_statement: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_name = "StatementName",
                .work_group = "WorkGroup",
                .query_statement = "QueryStatement",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = update_prepared_statement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_work_group: struct {
    action_name: []const u8 = "UpdateWorkGroup",
    Request: type = struct {
        work_group: []const u8,
        description: ?[]const u8 = null,
        configuration_updates: ?struct {
            enforce_work_group_configuration: ?bool = null,
            result_configuration_updates: ?struct {
                output_location: ?[]const u8 = null,
                remove_output_location: ?bool = null,
                encryption_configuration: ?EncryptionConfiguration = null,
                remove_encryption_configuration: ?bool = null,
                expected_bucket_owner: ?[]const u8 = null,
                remove_expected_bucket_owner: ?bool = null,
                acl_configuration: ?AclConfiguration = null,
                remove_acl_configuration: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .output_location = "OutputLocation",
                        .remove_output_location = "RemoveOutputLocation",
                        .encryption_configuration = "EncryptionConfiguration",
                        .remove_encryption_configuration = "RemoveEncryptionConfiguration",
                        .expected_bucket_owner = "ExpectedBucketOwner",
                        .remove_expected_bucket_owner = "RemoveExpectedBucketOwner",
                        .acl_configuration = "AclConfiguration",
                        .remove_acl_configuration = "RemoveAclConfiguration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            publish_cloud_watch_metrics_enabled: ?bool = null,
            bytes_scanned_cutoff_per_query: ?i64 = null,
            remove_bytes_scanned_cutoff_per_query: ?bool = null,
            requester_pays_enabled: ?bool = null,
            engine_version: ?EngineVersion = null,
            remove_customer_content_encryption_configuration: ?bool = null,
            additional_configuration: ?[]const u8 = null,
            execution_role: ?[]const u8 = null,
            customer_content_encryption_configuration: ?CustomerContentEncryptionConfiguration = null,
            enable_minimum_encryption_configuration: ?bool = null,
            query_results_s3_access_grants_configuration: ?QueryResultsS3AccessGrantsConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enforce_work_group_configuration = "EnforceWorkGroupConfiguration",
                    .result_configuration_updates = "ResultConfigurationUpdates",
                    .publish_cloud_watch_metrics_enabled = "PublishCloudWatchMetricsEnabled",
                    .bytes_scanned_cutoff_per_query = "BytesScannedCutoffPerQuery",
                    .remove_bytes_scanned_cutoff_per_query = "RemoveBytesScannedCutoffPerQuery",
                    .requester_pays_enabled = "RequesterPaysEnabled",
                    .engine_version = "EngineVersion",
                    .remove_customer_content_encryption_configuration = "RemoveCustomerContentEncryptionConfiguration",
                    .additional_configuration = "AdditionalConfiguration",
                    .execution_role = "ExecutionRole",
                    .customer_content_encryption_configuration = "CustomerContentEncryptionConfiguration",
                    .enable_minimum_encryption_configuration = "EnableMinimumEncryptionConfiguration",
                    .query_results_s3_access_grants_configuration = "QueryResultsS3AccessGrantsConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .description = "Description",
                .configuration_updates = "ConfigurationUpdates",
                .state = "State",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_work_group) } {
            return .{ .service_metadata = service_metadata, .action = update_work_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};

pub const QueryResultsS3AccessGrantsConfiguration = struct {
    enable_s3_access_grants: bool,
    create_user_level_prefix: ?bool = null,
    authentication_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_s3_access_grants = "EnableS3AccessGrants",
            .create_user_level_prefix = "CreateUserLevelPrefix",
            .authentication_type = "AuthenticationType",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerContentEncryptionConfiguration = struct {
    kms_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key = "KmsKey",
        };
        return @field(mappings, field_name);
    }
};

pub const EngineVersion = struct {
    selected_engine_version: ?[]const u8 = null,
    effective_engine_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_engine_version = "SelectedEngineVersion",
            .effective_engine_version = "EffectiveEngineVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const AclConfiguration = struct {
    s3_acl_option: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_acl_option = "S3AclOption",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    encryption_option: []const u8,
    kms_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_option = "EncryptionOption",
            .kms_key = "KmsKey",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const EngineConfiguration = struct {
    coordinator_dpu_size: ?i64 = null,
    max_concurrent_dpus: i64,
    default_executor_dpu_size: ?i64 = null,
    additional_configs: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    spark_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .coordinator_dpu_size = "CoordinatorDpuSize",
            .max_concurrent_dpus = "MaxConcurrentDpus",
            .default_executor_dpu_size = "DefaultExecutorDpuSize",
            .additional_configs = "AdditionalConfigs",
            .spark_properties = "SparkProperties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_configs", field_name))
            return try serializeMap(self.additional_configs, self.fieldNameFor("additional_configs"), options, out_stream);
        if (std.mem.eql(u8, "spark_properties", field_name))
            return try serializeMap(self.spark_properties, self.fieldNameFor("spark_properties"), options, out_stream);
        return false;
    }
};

pub const ResultReuseConfiguration = struct {
    result_reuse_by_age_configuration: ?ResultReuseByAgeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .result_reuse_by_age_configuration = "ResultReuseByAgeConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ResultReuseByAgeConfiguration = struct {
    enabled: bool,
    max_age_in_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .max_age_in_minutes = "MaxAgeInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const ResultConfiguration = struct {
    output_location: ?[]const u8 = null,
    encryption_configuration: ?EncryptionConfiguration = null,
    expected_bucket_owner: ?[]const u8 = null,
    acl_configuration: ?AclConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_location = "OutputLocation",
            .encryption_configuration = "EncryptionConfiguration",
            .expected_bucket_owner = "ExpectedBucketOwner",
            .acl_configuration = "AclConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryExecutionContext = struct {
    database: ?[]const u8 = null,
    catalog: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database = "Database",
            .catalog = "Catalog",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityAssignment = struct {
    work_group_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .work_group_names = "WorkGroupNames",
        };
        return @field(mappings, field_name);
    }
};

pub const TableMetadata = struct {
    name: []const u8,
    create_time: ?i64 = null,
    last_access_time: ?i64 = null,
    table_type: ?[]const u8 = null,
    columns: ?[]Column = null,
    partition_keys: ?[]Column = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .create_time = "CreateTime",
            .last_access_time = "LastAccessTime",
            .table_type = "TableType",
            .columns = "Columns",
            .partition_keys = "PartitionKeys",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const Column = struct {
    name: []const u8,
    type: ?[]const u8 = null,
    comment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .comment = "Comment",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionStatus = struct {
    start_date_time: ?i64 = null,
    last_modified_date_time: ?i64 = null,
    end_date_time: ?i64 = null,
    idle_since_date_time: ?i64 = null,
    state: ?[]const u8 = null,
    state_change_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_date_time = "StartDateTime",
            .last_modified_date_time = "LastModifiedDateTime",
            .end_date_time = "EndDateTime",
            .idle_since_date_time = "IdleSinceDateTime",
            .state = "State",
            .state_change_reason = "StateChangeReason",
        };
        return @field(mappings, field_name);
    }
};

pub const NotebookMetadata = struct {
    notebook_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    work_group: ?[]const u8 = null,
    creation_time: ?i64 = null,
    type: ?[]const u8 = null,
    last_modified_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notebook_id = "NotebookId",
            .name = "Name",
            .work_group = "WorkGroup",
            .creation_time = "CreationTime",
            .type = "Type",
            .last_modified_time = "LastModifiedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Database = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const CapacityReservation = struct {
    name: []const u8,
    status: []const u8,
    target_dpus: i64,
    allocated_dpus: i64,
    last_allocation: ?CapacityAllocation = null,
    last_successful_allocation_time: ?i64 = null,
    creation_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .target_dpus = "TargetDpus",
            .allocated_dpus = "AllocatedDpus",
            .last_allocation = "LastAllocation",
            .last_successful_allocation_time = "LastSuccessfulAllocationTime",
            .creation_time = "CreationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityAllocation = struct {
    status: []const u8,
    status_message: ?[]const u8 = null,
    request_time: i64,
    request_completion_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .status_message = "StatusMessage",
            .request_time = "RequestTime",
            .request_completion_time = "RequestCompletionTime",
        };
        return @field(mappings, field_name);
    }
};

pub const CalculationStatus = struct {
    submission_date_time: ?i64 = null,
    completion_date_time: ?i64 = null,
    state: ?[]const u8 = null,
    state_change_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .submission_date_time = "SubmissionDateTime",
            .completion_date_time = "CompletionDateTime",
            .state = "State",
            .state_change_reason = "StateChangeReason",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkGroupConfiguration = struct {
    result_configuration: ?ResultConfiguration = null,
    enforce_work_group_configuration: ?bool = null,
    publish_cloud_watch_metrics_enabled: ?bool = null,
    bytes_scanned_cutoff_per_query: ?i64 = null,
    requester_pays_enabled: ?bool = null,
    engine_version: ?EngineVersion = null,
    additional_configuration: ?[]const u8 = null,
    execution_role: ?[]const u8 = null,
    customer_content_encryption_configuration: ?CustomerContentEncryptionConfiguration = null,
    enable_minimum_encryption_configuration: ?bool = null,
    identity_center_configuration: ?IdentityCenterConfiguration = null,
    query_results_s3_access_grants_configuration: ?QueryResultsS3AccessGrantsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .result_configuration = "ResultConfiguration",
            .enforce_work_group_configuration = "EnforceWorkGroupConfiguration",
            .publish_cloud_watch_metrics_enabled = "PublishCloudWatchMetricsEnabled",
            .bytes_scanned_cutoff_per_query = "BytesScannedCutoffPerQuery",
            .requester_pays_enabled = "RequesterPaysEnabled",
            .engine_version = "EngineVersion",
            .additional_configuration = "AdditionalConfiguration",
            .execution_role = "ExecutionRole",
            .customer_content_encryption_configuration = "CustomerContentEncryptionConfiguration",
            .enable_minimum_encryption_configuration = "EnableMinimumEncryptionConfiguration",
            .identity_center_configuration = "IdentityCenterConfiguration",
            .query_results_s3_access_grants_configuration = "QueryResultsS3AccessGrantsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityCenterConfiguration = struct {
    enable_identity_center: ?bool = null,
    identity_center_instance_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_identity_center = "EnableIdentityCenter",
            .identity_center_instance_arn = "IdentityCenterInstanceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryStage = struct {
    stage_id: ?i64 = null,
    state: ?[]const u8 = null,
    output_bytes: ?i64 = null,
    output_rows: ?i64 = null,
    input_bytes: ?i64 = null,
    input_rows: ?i64 = null,
    execution_time: ?i64 = null,
    query_stage_plan: ?QueryStagePlanNode = null,
    sub_stages: ?[]QueryStage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stage_id = "StageId",
            .state = "State",
            .output_bytes = "OutputBytes",
            .output_rows = "OutputRows",
            .input_bytes = "InputBytes",
            .input_rows = "InputRows",
            .execution_time = "ExecutionTime",
            .query_stage_plan = "QueryStagePlan",
            .sub_stages = "SubStages",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryStagePlanNode = struct {
    name: ?[]const u8 = null,
    identifier: ?[]const u8 = null,
    children: ?[]QueryStagePlanNode = null,
    remote_sources: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .identifier = "Identifier",
            .children = "Children",
            .remote_sources = "RemoteSources",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryExecution = struct {
    query_execution_id: ?[]const u8 = null,
    query: ?[]const u8 = null,
    statement_type: ?[]const u8 = null,
    result_configuration: ?ResultConfiguration = null,
    result_reuse_configuration: ?ResultReuseConfiguration = null,
    query_execution_context: ?QueryExecutionContext = null,
    status: ?QueryExecutionStatus = null,
    statistics: ?QueryExecutionStatistics = null,
    work_group: ?[]const u8 = null,
    engine_version: ?EngineVersion = null,
    execution_parameters: ?[][]const u8 = null,
    substatement_type: ?[]const u8 = null,
    query_results_s3_access_grants_configuration: ?QueryResultsS3AccessGrantsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_execution_id = "QueryExecutionId",
            .query = "Query",
            .statement_type = "StatementType",
            .result_configuration = "ResultConfiguration",
            .result_reuse_configuration = "ResultReuseConfiguration",
            .query_execution_context = "QueryExecutionContext",
            .status = "Status",
            .statistics = "Statistics",
            .work_group = "WorkGroup",
            .engine_version = "EngineVersion",
            .execution_parameters = "ExecutionParameters",
            .substatement_type = "SubstatementType",
            .query_results_s3_access_grants_configuration = "QueryResultsS3AccessGrantsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryExecutionStatistics = struct {
    engine_execution_time_in_millis: ?i64 = null,
    data_scanned_in_bytes: ?i64 = null,
    data_manifest_location: ?[]const u8 = null,
    total_execution_time_in_millis: ?i64 = null,
    query_queue_time_in_millis: ?i64 = null,
    service_pre_processing_time_in_millis: ?i64 = null,
    query_planning_time_in_millis: ?i64 = null,
    service_processing_time_in_millis: ?i64 = null,
    result_reuse_information: ?ResultReuseInformation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .engine_execution_time_in_millis = "EngineExecutionTimeInMillis",
            .data_scanned_in_bytes = "DataScannedInBytes",
            .data_manifest_location = "DataManifestLocation",
            .total_execution_time_in_millis = "TotalExecutionTimeInMillis",
            .query_queue_time_in_millis = "QueryQueueTimeInMillis",
            .service_pre_processing_time_in_millis = "ServicePreProcessingTimeInMillis",
            .query_planning_time_in_millis = "QueryPlanningTimeInMillis",
            .service_processing_time_in_millis = "ServiceProcessingTimeInMillis",
            .result_reuse_information = "ResultReuseInformation",
        };
        return @field(mappings, field_name);
    }
};

pub const ResultReuseInformation = struct {
    reused_previous_result: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reused_previous_result = "ReusedPreviousResult",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryExecutionStatus = struct {
    state: ?[]const u8 = null,
    state_change_reason: ?[]const u8 = null,
    submission_date_time: ?i64 = null,
    completion_date_time: ?i64 = null,
    athena_error: ?AthenaError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .state_change_reason = "StateChangeReason",
            .submission_date_time = "SubmissionDateTime",
            .completion_date_time = "CompletionDateTime",
            .athena_error = "AthenaError",
        };
        return @field(mappings, field_name);
    }
};

pub const AthenaError = struct {
    error_category: ?i64 = null,
    error_type: ?i64 = null,
    retryable: ?bool = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_category = "ErrorCategory",
            .error_type = "ErrorType",
            .retryable = "Retryable",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const PreparedStatement = struct {
    statement_name: ?[]const u8 = null,
    query_statement: ?[]const u8 = null,
    work_group_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    last_modified_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statement_name = "StatementName",
            .query_statement = "QueryStatement",
            .work_group_name = "WorkGroupName",
            .description = "Description",
            .last_modified_time = "LastModifiedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const NamedQuery = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    database: []const u8,
    query_string: []const u8,
    named_query_id: ?[]const u8 = null,
    work_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .database = "Database",
            .query_string = "QueryString",
            .named_query_id = "NamedQueryId",
            .work_group = "WorkGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const CalculationStatistics = struct {
    dpu_execution_in_millis: ?i64 = null,
    progress: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dpu_execution_in_millis = "DpuExecutionInMillis",
            .progress = "Progress",
        };
        return @field(mappings, field_name);
    }
};
