const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "AuditManager";
pub const arn_namespace: ?[]const u8 = "auditmanager";
pub const endpoint_prefix: []const u8 = "auditmanager";
pub const sigv4_name: []const u8 = "auditmanager";
pub const name: []const u8 = "BedrockAssessmentManagerLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "AuditManager",
    arn_namespace: ?[]const u8 = "auditmanager",
    endpoint_prefix: []const u8 = "auditmanager",
    sigv4_name: []const u8 = "auditmanager",
    name: []const u8 = "BedrockAssessmentManagerLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_assessment_report_evidence_folder: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}/associateToAssessmentReport",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateAssessmentReportEvidenceFolder",
    Request: type = struct {
        assessment_id: []const u8,
        evidence_folder_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .evidence_folder_id = "evidenceFolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_assessment_report_evidence_folder) } {
            return .{ .service_metadata = service_metadata, .action = associate_assessment_report_evidence_folder };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const batch_associate_assessment_report_evidence: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}/batchAssociateToAssessmentReport",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchAssociateAssessmentReportEvidence",
    Request: type = struct {
        assessment_id: []const u8,
        evidence_folder_id: []const u8,
        evidence_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .evidence_folder_id = "evidenceFolderId",
                .evidence_ids = "evidenceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_associate_assessment_report_evidence) } {
            return .{ .service_metadata = service_metadata, .action = batch_associate_assessment_report_evidence };
        }
    },
    Response: type = struct {
        evidence_ids: ?[][]const u8 = null,
        errors: ?[]AssessmentReportEvidenceError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evidence_ids = "evidenceIds",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const batch_create_delegation_by_assessment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assessments/{assessmentId}/delegations",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchCreateDelegationByAssessment",
    Request: type = struct {
        create_delegation_requests: []CreateDelegationRequest,
        assessment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_delegation_requests = "createDelegationRequests",
                .assessment_id = "assessmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_delegation_by_assessment) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_delegation_by_assessment };
        }
    },
    Response: type = struct {
        delegations: ?[]Delegation = null,
        errors: ?[]struct {
            create_delegation_request: ?CreateDelegationRequest = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .create_delegation_request = "createDelegationRequest",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegations = "delegations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const batch_delete_delegation_by_assessment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}/delegations",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeleteDelegationByAssessment",
    Request: type = struct {
        delegation_ids: [][]const u8,
        assessment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegation_ids = "delegationIds",
                .assessment_id = "assessmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_delegation_by_assessment) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_delegation_by_assessment };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            delegation_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .delegation_id = "delegationId",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const batch_disassociate_assessment_report_evidence: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}/batchDisassociateFromAssessmentReport",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDisassociateAssessmentReportEvidence",
    Request: type = struct {
        assessment_id: []const u8,
        evidence_folder_id: []const u8,
        evidence_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .evidence_folder_id = "evidenceFolderId",
                .evidence_ids = "evidenceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disassociate_assessment_report_evidence) } {
            return .{ .service_metadata = service_metadata, .action = batch_disassociate_assessment_report_evidence };
        }
    },
    Response: type = struct {
        evidence_ids: ?[][]const u8 = null,
        errors: ?[]AssessmentReportEvidenceError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evidence_ids = "evidenceIds",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const batch_import_evidence_to_assessment_control: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assessments/{assessmentId}/controlSets/{controlSetId}/controls/{controlId}/evidence",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchImportEvidenceToAssessmentControl",
    Request: type = struct {
        assessment_id: []const u8,
        control_set_id: []const u8,
        control_id: []const u8,
        manual_evidence: []ManualEvidence,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .control_set_id = "controlSetId",
                .control_id = "controlId",
                .manual_evidence = "manualEvidence",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_import_evidence_to_assessment_control) } {
            return .{ .service_metadata = service_metadata, .action = batch_import_evidence_to_assessment_control };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            manual_evidence: ?ManualEvidence = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .manual_evidence = "manualEvidence",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_assessment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assessments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAssessment",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        assessment_reports_destination: AssessmentReportsDestination,
        scope: Scope,
        roles: []Role,
        framework_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .assessment_reports_destination = "assessmentReportsDestination",
                .scope = "scope",
                .roles = "roles",
                .framework_id = "frameworkId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_assessment) } {
            return .{ .service_metadata = service_metadata, .action = create_assessment };
        }
    },
    Response: type = struct {
        assessment: ?Assessment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment = "assessment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_assessment_framework: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assessmentFrameworks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAssessmentFramework",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        compliance_type: ?[]const u8 = null,
        control_sets: []struct {
            name: []const u8,
            controls: ?[]CreateAssessmentFrameworkControl = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .controls = "controls",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .compliance_type = "complianceType",
                .control_sets = "controlSets",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_assessment_framework) } {
            return .{ .service_metadata = service_metadata, .action = create_assessment_framework };
        }
    },
    Response: type = struct {
        framework: ?Framework = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework = "framework",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_assessment_report: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assessments/{assessmentId}/reports",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAssessmentReport",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        assessment_id: []const u8,
        query_statement: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .assessment_id = "assessmentId",
                .query_statement = "queryStatement",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_assessment_report) } {
            return .{ .service_metadata = service_metadata, .action = create_assessment_report };
        }
    },
    Response: type = struct {
        assessment_report: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            aws_account_id: ?[]const u8 = null,
            assessment_id: ?[]const u8 = null,
            assessment_name: ?[]const u8 = null,
            author: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .aws_account_id = "awsAccountId",
                    .assessment_id = "assessmentId",
                    .assessment_name = "assessmentName",
                    .author = "author",
                    .status = "status",
                    .creation_time = "creationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_report = "assessmentReport",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_control: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/controls",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateControl",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        testing_information: ?[]const u8 = null,
        action_plan_title: ?[]const u8 = null,
        action_plan_instructions: ?[]const u8 = null,
        control_mapping_sources: []struct {
            source_name: ?[]const u8 = null,
            source_description: ?[]const u8 = null,
            source_set_up_option: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            source_keyword: ?SourceKeyword = null,
            source_frequency: ?[]const u8 = null,
            troubleshooting_text: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_name = "sourceName",
                    .source_description = "sourceDescription",
                    .source_set_up_option = "sourceSetUpOption",
                    .source_type = "sourceType",
                    .source_keyword = "sourceKeyword",
                    .source_frequency = "sourceFrequency",
                    .troubleshooting_text = "troubleshootingText",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .testing_information = "testingInformation",
                .action_plan_title = "actionPlanTitle",
                .action_plan_instructions = "actionPlanInstructions",
                .control_mapping_sources = "controlMappingSources",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_control) } {
            return .{ .service_metadata = service_metadata, .action = create_control };
        }
    },
    Response: type = struct {
        control: ?Control = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control = "control",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_assessment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/assessments/{assessmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAssessment",
    Request: type = struct {
        assessment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_assessment) } {
            return .{ .service_metadata = service_metadata, .action = delete_assessment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_assessment_framework: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/assessmentFrameworks/{frameworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAssessmentFramework",
    Request: type = struct {
        framework_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_id = "frameworkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_assessment_framework) } {
            return .{ .service_metadata = service_metadata, .action = delete_assessment_framework };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_assessment_framework_share: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/assessmentFrameworkShareRequests/{requestId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAssessmentFrameworkShare",
    Request: type = struct {
        request_id: []const u8,
        request_type: []const u8,

        pub const http_query = .{
            .request_type = "requestType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .request_type = "requestType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_assessment_framework_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_assessment_framework_share };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_assessment_report: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/assessments/{assessmentId}/reports/{assessmentReportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAssessmentReport",
    Request: type = struct {
        assessment_id: []const u8,
        assessment_report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .assessment_report_id = "assessmentReportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_assessment_report) } {
            return .{ .service_metadata = service_metadata, .action = delete_assessment_report };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_control: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/controls/{controlId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteControl",
    Request: type = struct {
        control_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_id = "controlId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_control) } {
            return .{ .service_metadata = service_metadata, .action = delete_control };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const deregister_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/account/deregisterAccount",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_account) } {
            return .{ .service_metadata = service_metadata, .action = deregister_account };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const deregister_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/account/deregisterOrganizationAdminAccount",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "adminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = deregister_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const disassociate_assessment_report_evidence_folder: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}/disassociateFromAssessmentReport",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateAssessmentReportEvidenceFolder",
    Request: type = struct {
        assessment_id: []const u8,
        evidence_folder_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .evidence_folder_id = "evidenceFolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_assessment_report_evidence_folder) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_assessment_report_evidence_folder };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_account_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/account/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccountStatus",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_status) } {
            return .{ .service_metadata = service_metadata, .action = get_account_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
    },
} = .{};
pub const get_assessment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments/{assessmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssessment",
    Request: type = struct {
        assessment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_assessment) } {
            return .{ .service_metadata = service_metadata, .action = get_assessment };
        }
    },
    Response: type = struct {
        assessment: ?Assessment = null,
        user_role: ?Role = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment = "assessment",
                .user_role = "userRole",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_assessment_framework: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessmentFrameworks/{frameworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssessmentFramework",
    Request: type = struct {
        framework_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_id = "frameworkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_assessment_framework) } {
            return .{ .service_metadata = service_metadata, .action = get_assessment_framework };
        }
    },
    Response: type = struct {
        framework: ?Framework = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework = "framework",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_assessment_report_url: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments/{assessmentId}/reports/{assessmentReportId}/url",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssessmentReportUrl",
    Request: type = struct {
        assessment_report_id: []const u8,
        assessment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_report_id = "assessmentReportId",
                .assessment_id = "assessmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_assessment_report_url) } {
            return .{ .service_metadata = service_metadata, .action = get_assessment_report_url };
        }
    },
    Response: type = struct {
        pre_signed_url: ?struct {
            hyperlink_name: ?[]const u8 = null,
            link: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hyperlink_name = "hyperlinkName",
                    .link = "link",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pre_signed_url = "preSignedUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_change_logs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments/{assessmentId}/changelogs",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChangeLogs",
    Request: type = struct {
        assessment_id: []const u8,
        control_set_id: ?[]const u8 = null,
        control_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .control_set_id = "controlSetId",
            .control_id = "controlId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .control_set_id = "controlSetId",
                .control_id = "controlId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_change_logs) } {
            return .{ .service_metadata = service_metadata, .action = get_change_logs };
        }
    },
    Response: type = struct {
        change_logs: ?[]struct {
            object_type: ?[]const u8 = null,
            object_name: ?[]const u8 = null,
            action: ?[]const u8 = null,
            created_at: ?i64 = null,
            created_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .object_type = "objectType",
                    .object_name = "objectName",
                    .action = "action",
                    .created_at = "createdAt",
                    .created_by = "createdBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_logs = "changeLogs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_control: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/controls/{controlId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetControl",
    Request: type = struct {
        control_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_id = "controlId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_control) } {
            return .{ .service_metadata = service_metadata, .action = get_control };
        }
    },
    Response: type = struct {
        control: ?Control = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control = "control",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_delegations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/delegations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDelegations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_delegations) } {
            return .{ .service_metadata = service_metadata, .action = get_delegations };
        }
    },
    Response: type = struct {
        delegations: ?[]struct {
            id: ?[]const u8 = null,
            assessment_name: ?[]const u8 = null,
            assessment_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            creation_time: ?i64 = null,
            control_set_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .assessment_name = "assessmentName",
                    .assessment_id = "assessmentId",
                    .status = "status",
                    .role_arn = "roleArn",
                    .creation_time = "creationTime",
                    .control_set_name = "controlSetName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegations = "delegations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const get_evidence: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments/{assessmentId}/controlSets/{controlSetId}/evidenceFolders/{evidenceFolderId}/evidence/{evidenceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEvidence",
    Request: type = struct {
        assessment_id: []const u8,
        control_set_id: []const u8,
        evidence_folder_id: []const u8,
        evidence_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .control_set_id = "controlSetId",
                .evidence_folder_id = "evidenceFolderId",
                .evidence_id = "evidenceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_evidence) } {
            return .{ .service_metadata = service_metadata, .action = get_evidence };
        }
    },
    Response: type = struct {
        evidence: ?Evidence = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evidence = "evidence",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_evidence_by_evidence_folder: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments/{assessmentId}/controlSets/{controlSetId}/evidenceFolders/{evidenceFolderId}/evidence",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEvidenceByEvidenceFolder",
    Request: type = struct {
        assessment_id: []const u8,
        control_set_id: []const u8,
        evidence_folder_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .control_set_id = "controlSetId",
                .evidence_folder_id = "evidenceFolderId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_evidence_by_evidence_folder) } {
            return .{ .service_metadata = service_metadata, .action = get_evidence_by_evidence_folder };
        }
    },
    Response: type = struct {
        evidence: ?[]Evidence = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evidence = "evidence",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_evidence_file_upload_url: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/evidenceFileUploadUrl",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEvidenceFileUploadUrl",
    Request: type = struct {
        file_name: []const u8,

        pub const http_query = .{
            .file_name = "fileName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_name = "fileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_evidence_file_upload_url) } {
            return .{ .service_metadata = service_metadata, .action = get_evidence_file_upload_url };
        }
    },
    Response: type = struct {
        evidence_file_name: ?[]const u8 = null,
        upload_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evidence_file_name = "evidenceFileName",
                .upload_url = "uploadUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_evidence_folder: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments/{assessmentId}/controlSets/{controlSetId}/evidenceFolders/{evidenceFolderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEvidenceFolder",
    Request: type = struct {
        assessment_id: []const u8,
        control_set_id: []const u8,
        evidence_folder_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .control_set_id = "controlSetId",
                .evidence_folder_id = "evidenceFolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_evidence_folder) } {
            return .{ .service_metadata = service_metadata, .action = get_evidence_folder };
        }
    },
    Response: type = struct {
        evidence_folder: ?AssessmentEvidenceFolder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evidence_folder = "evidenceFolder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_evidence_folders_by_assessment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments/{assessmentId}/evidenceFolders",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEvidenceFoldersByAssessment",
    Request: type = struct {
        assessment_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_evidence_folders_by_assessment) } {
            return .{ .service_metadata = service_metadata, .action = get_evidence_folders_by_assessment };
        }
    },
    Response: type = struct {
        evidence_folders: ?[]AssessmentEvidenceFolder = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evidence_folders = "evidenceFolders",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_evidence_folders_by_assessment_control: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments/{assessmentId}/evidenceFolders-by-assessment-control/{controlSetId}/{controlId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEvidenceFoldersByAssessmentControl",
    Request: type = struct {
        assessment_id: []const u8,
        control_set_id: []const u8,
        control_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .control_set_id = "controlSetId",
                .control_id = "controlId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_evidence_folders_by_assessment_control) } {
            return .{ .service_metadata = service_metadata, .action = get_evidence_folders_by_assessment_control };
        }
    },
    Response: type = struct {
        evidence_folders: ?[]AssessmentEvidenceFolder = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evidence_folders = "evidenceFolders",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_insights: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsights",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insights) } {
            return .{ .service_metadata = service_metadata, .action = get_insights };
        }
    },
    Response: type = struct {
        insights: ?struct {
            active_assessments_count: ?i64 = null,
            noncompliant_evidence_count: ?i64 = null,
            compliant_evidence_count: ?i64 = null,
            inconclusive_evidence_count: ?i64 = null,
            assessment_controls_count_by_noncompliant_evidence: ?i64 = null,
            total_assessment_controls_count: ?i64 = null,
            last_updated: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .active_assessments_count = "activeAssessmentsCount",
                    .noncompliant_evidence_count = "noncompliantEvidenceCount",
                    .compliant_evidence_count = "compliantEvidenceCount",
                    .inconclusive_evidence_count = "inconclusiveEvidenceCount",
                    .assessment_controls_count_by_noncompliant_evidence = "assessmentControlsCountByNoncompliantEvidence",
                    .total_assessment_controls_count = "totalAssessmentControlsCount",
                    .last_updated = "lastUpdated",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insights = "insights",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
    },
} = .{};
pub const get_insights_by_assessment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/assessments/{assessmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsightsByAssessment",
    Request: type = struct {
        assessment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insights_by_assessment) } {
            return .{ .service_metadata = service_metadata, .action = get_insights_by_assessment };
        }
    },
    Response: type = struct {
        insights: ?struct {
            noncompliant_evidence_count: ?i64 = null,
            compliant_evidence_count: ?i64 = null,
            inconclusive_evidence_count: ?i64 = null,
            assessment_controls_count_by_noncompliant_evidence: ?i64 = null,
            total_assessment_controls_count: ?i64 = null,
            last_updated: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .noncompliant_evidence_count = "noncompliantEvidenceCount",
                    .compliant_evidence_count = "compliantEvidenceCount",
                    .inconclusive_evidence_count = "inconclusiveEvidenceCount",
                    .assessment_controls_count_by_noncompliant_evidence = "assessmentControlsCountByNoncompliantEvidence",
                    .total_assessment_controls_count = "totalAssessmentControlsCount",
                    .last_updated = "lastUpdated",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insights = "insights",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_organization_admin_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/account/organizationAdminAccount",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOrganizationAdminAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = get_organization_admin_account };
        }
    },
    Response: type = struct {
        admin_account_id: ?[]const u8 = null,
        organization_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "adminAccountId",
                .organization_id = "organizationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_services_in_scope: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/services",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServicesInScope",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_services_in_scope) } {
            return .{ .service_metadata = service_metadata, .action = get_services_in_scope };
        }
    },
    Response: type = struct {
        service_metadata: ?[]struct {
            name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            category: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .display_name = "displayName",
                    .description = "description",
                    .category = "category",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_metadata = "serviceMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const get_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/settings/{attribute}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSettings",
    Request: type = struct {
        attribute: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "attribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_settings };
        }
    },
    Response: type = struct {
        settings: ?Settings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .settings = "settings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
    },
} = .{};
pub const list_assessment_control_insights_by_control_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/controls-by-assessment",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssessmentControlInsightsByControlDomain",
    Request: type = struct {
        control_domain_id: []const u8,
        assessment_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .control_domain_id = "controlDomainId",
            .assessment_id = "assessmentId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_domain_id = "controlDomainId",
                .assessment_id = "assessmentId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessment_control_insights_by_control_domain) } {
            return .{ .service_metadata = service_metadata, .action = list_assessment_control_insights_by_control_domain };
        }
    },
    Response: type = struct {
        control_insights_by_assessment: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            evidence_insights: ?EvidenceInsights = null,
            control_set_name: ?[]const u8 = null,
            last_updated: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .id = "id",
                    .evidence_insights = "evidenceInsights",
                    .control_set_name = "controlSetName",
                    .last_updated = "lastUpdated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_insights_by_assessment = "controlInsightsByAssessment",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_assessment_frameworks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessmentFrameworks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssessmentFrameworks",
    Request: type = struct {
        framework_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .framework_type = "frameworkType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_type = "frameworkType",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessment_frameworks) } {
            return .{ .service_metadata = service_metadata, .action = list_assessment_frameworks };
        }
    },
    Response: type = struct {
        framework_metadata_list: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            logo: ?[]const u8 = null,
            compliance_type: ?[]const u8 = null,
            controls_count: ?i64 = null,
            control_sets_count: ?i64 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .id = "id",
                    .type = "type",
                    .name = "name",
                    .description = "description",
                    .logo = "logo",
                    .compliance_type = "complianceType",
                    .controls_count = "controlsCount",
                    .control_sets_count = "controlSetsCount",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_metadata_list = "frameworkMetadataList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_assessment_framework_share_requests: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessmentFrameworkShareRequests",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssessmentFrameworkShareRequests",
    Request: type = struct {
        request_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .request_type = "requestType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_type = "requestType",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessment_framework_share_requests) } {
            return .{ .service_metadata = service_metadata, .action = list_assessment_framework_share_requests };
        }
    },
    Response: type = struct {
        assessment_framework_share_requests: ?[]AssessmentFrameworkShareRequest = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_framework_share_requests = "assessmentFrameworkShareRequests",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_assessment_reports: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessmentReports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssessmentReports",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessment_reports) } {
            return .{ .service_metadata = service_metadata, .action = list_assessment_reports };
        }
    },
    Response: type = struct {
        assessment_reports: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            assessment_id: ?[]const u8 = null,
            assessment_name: ?[]const u8 = null,
            author: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .assessment_id = "assessmentId",
                    .assessment_name = "assessmentName",
                    .author = "author",
                    .status = "status",
                    .creation_time = "creationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_reports = "assessmentReports",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_assessments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assessments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssessments",
    Request: type = struct {
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status = "status",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessments) } {
            return .{ .service_metadata = service_metadata, .action = list_assessments };
        }
    },
    Response: type = struct {
        assessment_metadata: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            compliance_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            roles: ?[]Role = null,
            delegations: ?[]Delegation = null,
            creation_time: ?i64 = null,
            last_updated: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .id = "id",
                    .compliance_type = "complianceType",
                    .status = "status",
                    .roles = "roles",
                    .delegations = "delegations",
                    .creation_time = "creationTime",
                    .last_updated = "lastUpdated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_metadata = "assessmentMetadata",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_control_domain_insights: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/control-domains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListControlDomainInsights",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_control_domain_insights) } {
            return .{ .service_metadata = service_metadata, .action = list_control_domain_insights };
        }
    },
    Response: type = struct {
        control_domain_insights: ?[]ControlDomainInsights = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_domain_insights = "controlDomainInsights",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_control_domain_insights_by_assessment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/control-domains-by-assessment",
        .success_code = 200,
    };

    action_name: []const u8 = "ListControlDomainInsightsByAssessment",
    Request: type = struct {
        assessment_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .assessment_id = "assessmentId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_control_domain_insights_by_assessment) } {
            return .{ .service_metadata = service_metadata, .action = list_control_domain_insights_by_assessment };
        }
    },
    Response: type = struct {
        control_domain_insights: ?[]ControlDomainInsights = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_domain_insights = "controlDomainInsights",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_control_insights_by_control_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/controls",
        .success_code = 200,
    };

    action_name: []const u8 = "ListControlInsightsByControlDomain",
    Request: type = struct {
        control_domain_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .control_domain_id = "controlDomainId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_domain_id = "controlDomainId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_control_insights_by_control_domain) } {
            return .{ .service_metadata = service_metadata, .action = list_control_insights_by_control_domain };
        }
    },
    Response: type = struct {
        control_insights_metadata: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            evidence_insights: ?EvidenceInsights = null,
            last_updated: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .id = "id",
                    .evidence_insights = "evidenceInsights",
                    .last_updated = "lastUpdated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_insights_metadata = "controlInsightsMetadata",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_controls: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/controls",
        .success_code = 200,
    };

    action_name: []const u8 = "ListControls",
    Request: type = struct {
        control_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .control_type = "controlType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_type = "controlType",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_controls) } {
            return .{ .service_metadata = service_metadata, .action = list_controls };
        }
    },
    Response: type = struct {
        control_metadata_list: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            control_sources: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .id = "id",
                    .name = "name",
                    .control_sources = "controlSources",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_metadata_list = "controlMetadataList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_keywords_for_data_source: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/dataSourceKeywords",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKeywordsForDataSource",
    Request: type = struct {
        source: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .source = "source",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "source",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_keywords_for_data_source) } {
            return .{ .service_metadata = service_metadata, .action = list_keywords_for_data_source };
        }
    },
    Response: type = struct {
        keywords: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keywords = "keywords",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_notifications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/notifications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNotifications",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notifications) } {
            return .{ .service_metadata = service_metadata, .action = list_notifications };
        }
    },
    Response: type = struct {
        notifications: ?[]struct {
            id: ?[]const u8 = null,
            assessment_id: ?[]const u8 = null,
            assessment_name: ?[]const u8 = null,
            control_set_id: ?[]const u8 = null,
            control_set_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            event_time: ?i64 = null,
            source: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .assessment_id = "assessmentId",
                    .assessment_name = "assessmentName",
                    .control_set_id = "controlSetId",
                    .control_set_name = "controlSetName",
                    .description = "description",
                    .event_time = "eventTime",
                    .source = "source",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notifications = "notifications",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const register_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/account/registerAccount",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterAccount",
    Request: type = struct {
        kms_key: ?[]const u8 = null,
        delegated_admin_account: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key = "kmsKey",
                .delegated_admin_account = "delegatedAdminAccount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_account) } {
            return .{ .service_metadata = service_metadata, .action = register_account };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const register_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/account/registerOrganizationAdminAccount",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "adminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = register_organization_admin_account };
        }
    },
    Response: type = struct {
        admin_account_id: ?[]const u8 = null,
        organization_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "adminAccountId",
                .organization_id = "organizationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_assessment_framework_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assessmentFrameworks/{frameworkId}/shareRequests",
        .success_code = 200,
    };

    action_name: []const u8 = "StartAssessmentFrameworkShare",
    Request: type = struct {
        framework_id: []const u8,
        destination_account: []const u8,
        destination_region: []const u8,
        comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_id = "frameworkId",
                .destination_account = "destinationAccount",
                .destination_region = "destinationRegion",
                .comment = "comment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_assessment_framework_share) } {
            return .{ .service_metadata = service_metadata, .action = start_assessment_framework_share };
        }
    },
    Response: type = struct {
        assessment_framework_share_request: ?AssessmentFrameworkShareRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_framework_share_request = "assessmentFrameworkShareRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_assessment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAssessment",
    Request: type = struct {
        assessment_id: []const u8,
        assessment_name: ?[]const u8 = null,
        assessment_description: ?[]const u8 = null,
        scope: Scope,
        assessment_reports_destination: ?AssessmentReportsDestination = null,
        roles: ?[]Role = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .assessment_name = "assessmentName",
                .assessment_description = "assessmentDescription",
                .scope = "scope",
                .assessment_reports_destination = "assessmentReportsDestination",
                .roles = "roles",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_assessment) } {
            return .{ .service_metadata = service_metadata, .action = update_assessment };
        }
    },
    Response: type = struct {
        assessment: ?Assessment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment = "assessment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_assessment_control: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}/controlSets/{controlSetId}/controls/{controlId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAssessmentControl",
    Request: type = struct {
        assessment_id: []const u8,
        control_set_id: []const u8,
        control_id: []const u8,
        control_status: ?[]const u8 = null,
        comment_body: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .control_set_id = "controlSetId",
                .control_id = "controlId",
                .control_status = "controlStatus",
                .comment_body = "commentBody",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_assessment_control) } {
            return .{ .service_metadata = service_metadata, .action = update_assessment_control };
        }
    },
    Response: type = struct {
        control: ?AssessmentControl = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control = "control",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_assessment_control_set_status: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}/controlSets/{controlSetId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAssessmentControlSetStatus",
    Request: type = struct {
        assessment_id: []const u8,
        control_set_id: []const u8,
        status: []const u8,
        comment: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .control_set_id = "controlSetId",
                .status = "status",
                .comment = "comment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_assessment_control_set_status) } {
            return .{ .service_metadata = service_metadata, .action = update_assessment_control_set_status };
        }
    },
    Response: type = struct {
        control_set: ?AssessmentControlSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_set = "controlSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_assessment_framework: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessmentFrameworks/{frameworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAssessmentFramework",
    Request: type = struct {
        framework_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        compliance_type: ?[]const u8 = null,
        control_sets: []struct {
            id: ?[]const u8 = null,
            name: []const u8,
            controls: []CreateAssessmentFrameworkControl,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .controls = "controls",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_id = "frameworkId",
                .name = "name",
                .description = "description",
                .compliance_type = "complianceType",
                .control_sets = "controlSets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_assessment_framework) } {
            return .{ .service_metadata = service_metadata, .action = update_assessment_framework };
        }
    },
    Response: type = struct {
        framework: ?Framework = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework = "framework",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_assessment_framework_share: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessmentFrameworkShareRequests/{requestId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAssessmentFrameworkShare",
    Request: type = struct {
        request_id: []const u8,
        request_type: []const u8,
        action: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .request_type = "requestType",
                .action = "action",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_assessment_framework_share) } {
            return .{ .service_metadata = service_metadata, .action = update_assessment_framework_share };
        }
    },
    Response: type = struct {
        assessment_framework_share_request: ?AssessmentFrameworkShareRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_framework_share_request = "assessmentFrameworkShareRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const update_assessment_status: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assessments/{assessmentId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAssessmentStatus",
    Request: type = struct {
        assessment_id: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_assessment_status) } {
            return .{ .service_metadata = service_metadata, .action = update_assessment_status };
        }
    },
    Response: type = struct {
        assessment: ?Assessment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment = "assessment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const update_control: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/controls/{controlId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateControl",
    Request: type = struct {
        control_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        testing_information: ?[]const u8 = null,
        action_plan_title: ?[]const u8 = null,
        action_plan_instructions: ?[]const u8 = null,
        control_mapping_sources: []ControlMappingSource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_id = "controlId",
                .name = "name",
                .description = "description",
                .testing_information = "testingInformation",
                .action_plan_title = "actionPlanTitle",
                .action_plan_instructions = "actionPlanInstructions",
                .control_mapping_sources = "controlMappingSources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_control) } {
            return .{ .service_metadata = service_metadata, .action = update_control };
        }
    },
    Response: type = struct {
        control: ?Control = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control = "control",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSettings",
    Request: type = struct {
        sns_topic: ?[]const u8 = null,
        default_assessment_reports_destination: ?AssessmentReportsDestination = null,
        default_process_owners: ?[]Role = null,
        kms_key: ?[]const u8 = null,
        evidence_finder_enabled: ?bool = null,
        deregistration_policy: ?DeregistrationPolicy = null,
        default_export_destination: ?DefaultExportDestination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sns_topic = "snsTopic",
                .default_assessment_reports_destination = "defaultAssessmentReportsDestination",
                .default_process_owners = "defaultProcessOwners",
                .kms_key = "kmsKey",
                .evidence_finder_enabled = "evidenceFinderEnabled",
                .deregistration_policy = "deregistrationPolicy",
                .default_export_destination = "defaultExportDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_settings };
        }
    },
    Response: type = struct {
        settings: ?Settings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .settings = "settings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const validate_assessment_report_integrity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assessmentReports/integrity",
        .success_code = 200,
    };

    action_name: []const u8 = "ValidateAssessmentReportIntegrity",
    Request: type = struct {
        s3_relative_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_relative_path = "s3RelativePath",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_assessment_report_integrity) } {
            return .{ .service_metadata = service_metadata, .action = validate_assessment_report_integrity };
        }
    },
    Response: type = struct {
        signature_valid: ?bool = null,
        signature_algorithm: ?[]const u8 = null,
        signature_date_time: ?[]const u8 = null,
        signature_key_id: ?[]const u8 = null,
        validation_errors: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .signature_valid = "signatureValid",
                .signature_algorithm = "signatureAlgorithm",
                .signature_date_time = "signatureDateTime",
                .signature_key_id = "signatureKeyId",
                .validation_errors = "validationErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const Settings = struct {
    is_aws_org_enabled: ?bool = null,
    sns_topic: ?[]const u8 = null,
    default_assessment_reports_destination: ?AssessmentReportsDestination = null,
    default_process_owners: ?[]Role = null,
    kms_key: ?[]const u8 = null,
    evidence_finder_enablement: ?EvidenceFinderEnablement = null,
    deregistration_policy: ?DeregistrationPolicy = null,
    default_export_destination: ?DefaultExportDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_aws_org_enabled = "isAwsOrgEnabled",
            .sns_topic = "snsTopic",
            .default_assessment_reports_destination = "defaultAssessmentReportsDestination",
            .default_process_owners = "defaultProcessOwners",
            .kms_key = "kmsKey",
            .evidence_finder_enablement = "evidenceFinderEnablement",
            .deregistration_policy = "deregistrationPolicy",
            .default_export_destination = "defaultExportDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultExportDestination = struct {
    destination_type: ?[]const u8 = null,
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_type = "destinationType",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const DeregistrationPolicy = struct {
    delete_resources: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_resources = "deleteResources",
        };
        return @field(mappings, field_name);
    }
};

pub const EvidenceFinderEnablement = struct {
    event_data_store_arn: ?[]const u8 = null,
    enablement_status: ?[]const u8 = null,
    backfill_status: ?[]const u8 = null,
    @"error": ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_data_store_arn = "eventDataStoreArn",
            .enablement_status = "enablementStatus",
            .backfill_status = "backfillStatus",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const Role = struct {
    role_type: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_type = "roleType",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AssessmentReportsDestination = struct {
    destination_type: ?[]const u8 = null,
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_type = "destinationType",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const Control = struct {
    arn: ?[]const u8 = null,
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    testing_information: ?[]const u8 = null,
    action_plan_title: ?[]const u8 = null,
    action_plan_instructions: ?[]const u8 = null,
    control_sources: ?[]const u8 = null,
    control_mapping_sources: ?[]ControlMappingSource = null,
    created_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    created_by: ?[]const u8 = null,
    last_updated_by: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .id = "id",
            .type = "type",
            .name = "name",
            .description = "description",
            .testing_information = "testingInformation",
            .action_plan_title = "actionPlanTitle",
            .action_plan_instructions = "actionPlanInstructions",
            .control_sources = "controlSources",
            .control_mapping_sources = "controlMappingSources",
            .created_at = "createdAt",
            .last_updated_at = "lastUpdatedAt",
            .created_by = "createdBy",
            .last_updated_by = "lastUpdatedBy",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ControlMappingSource = struct {
    source_id: ?[]const u8 = null,
    source_name: ?[]const u8 = null,
    source_description: ?[]const u8 = null,
    source_set_up_option: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    source_keyword: ?SourceKeyword = null,
    source_frequency: ?[]const u8 = null,
    troubleshooting_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_id = "sourceId",
            .source_name = "sourceName",
            .source_description = "sourceDescription",
            .source_set_up_option = "sourceSetUpOption",
            .source_type = "sourceType",
            .source_keyword = "sourceKeyword",
            .source_frequency = "sourceFrequency",
            .troubleshooting_text = "troubleshootingText",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceKeyword = struct {
    keyword_input_type: ?[]const u8 = null,
    keyword_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .keyword_input_type = "keywordInputType",
            .keyword_value = "keywordValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Assessment = struct {
    arn: ?[]const u8 = null,
    aws_account: ?AWSAccount = null,
    metadata: ?AssessmentMetadata = null,
    framework: ?AssessmentFramework = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .aws_account = "awsAccount",
            .metadata = "metadata",
            .framework = "framework",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const AssessmentFramework = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    metadata: ?FrameworkMetadata = null,
    control_sets: ?[]AssessmentControlSet = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .metadata = "metadata",
            .control_sets = "controlSets",
        };
        return @field(mappings, field_name);
    }
};

pub const AssessmentControlSet = struct {
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    roles: ?[]Role = null,
    controls: ?[]AssessmentControl = null,
    delegations: ?[]Delegation = null,
    system_evidence_count: ?i64 = null,
    manual_evidence_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .description = "description",
            .status = "status",
            .roles = "roles",
            .controls = "controls",
            .delegations = "delegations",
            .system_evidence_count = "systemEvidenceCount",
            .manual_evidence_count = "manualEvidenceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const Delegation = struct {
    id: ?[]const u8 = null,
    assessment_name: ?[]const u8 = null,
    assessment_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    role_type: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    control_set_id: ?[]const u8 = null,
    comment: ?[]const u8 = null,
    created_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .assessment_name = "assessmentName",
            .assessment_id = "assessmentId",
            .status = "status",
            .role_arn = "roleArn",
            .role_type = "roleType",
            .creation_time = "creationTime",
            .last_updated = "lastUpdated",
            .control_set_id = "controlSetId",
            .comment = "comment",
            .created_by = "createdBy",
        };
        return @field(mappings, field_name);
    }
};

pub const AssessmentControl = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    response: ?[]const u8 = null,
    comments: ?[]ControlComment = null,
    evidence_sources: ?[][]const u8 = null,
    evidence_count: ?i64 = null,
    assessment_report_evidence_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .description = "description",
            .status = "status",
            .response = "response",
            .comments = "comments",
            .evidence_sources = "evidenceSources",
            .evidence_count = "evidenceCount",
            .assessment_report_evidence_count = "assessmentReportEvidenceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ControlComment = struct {
    author_name: ?[]const u8 = null,
    comment_body: ?[]const u8 = null,
    posted_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .author_name = "authorName",
            .comment_body = "commentBody",
            .posted_date = "postedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameworkMetadata = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    logo: ?[]const u8 = null,
    compliance_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .logo = "logo",
            .compliance_type = "complianceType",
        };
        return @field(mappings, field_name);
    }
};

pub const AssessmentMetadata = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    compliance_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    assessment_reports_destination: ?AssessmentReportsDestination = null,
    scope: ?Scope = null,
    roles: ?[]Role = null,
    delegations: ?[]Delegation = null,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .id = "id",
            .description = "description",
            .compliance_type = "complianceType",
            .status = "status",
            .assessment_reports_destination = "assessmentReportsDestination",
            .scope = "scope",
            .roles = "roles",
            .delegations = "delegations",
            .creation_time = "creationTime",
            .last_updated = "lastUpdated",
        };
        return @field(mappings, field_name);
    }
};

pub const Scope = struct {
    aws_accounts: ?[]AWSAccount = null,
    aws_services: ?[]AWSService = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_accounts = "awsAccounts",
            .aws_services = "awsServices",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSService = struct {
    service_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_name = "serviceName",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSAccount = struct {
    id: ?[]const u8 = null,
    email_address: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .email_address = "emailAddress",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssessmentFrameworkShareRequest = struct {
    id: ?[]const u8 = null,
    framework_id: ?[]const u8 = null,
    framework_name: ?[]const u8 = null,
    framework_description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    source_account: ?[]const u8 = null,
    destination_account: ?[]const u8 = null,
    destination_region: ?[]const u8 = null,
    expiration_time: ?i64 = null,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    comment: ?[]const u8 = null,
    standard_controls_count: ?i64 = null,
    custom_controls_count: ?i64 = null,
    compliance_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .framework_id = "frameworkId",
            .framework_name = "frameworkName",
            .framework_description = "frameworkDescription",
            .status = "status",
            .source_account = "sourceAccount",
            .destination_account = "destinationAccount",
            .destination_region = "destinationRegion",
            .expiration_time = "expirationTime",
            .creation_time = "creationTime",
            .last_updated = "lastUpdated",
            .comment = "comment",
            .standard_controls_count = "standardControlsCount",
            .custom_controls_count = "customControlsCount",
            .compliance_type = "complianceType",
        };
        return @field(mappings, field_name);
    }
};

pub const Framework = struct {
    arn: ?[]const u8 = null,
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    compliance_type: ?[]const u8 = null,
    description: ?[]const u8 = null,
    logo: ?[]const u8 = null,
    control_sources: ?[]const u8 = null,
    control_sets: ?[]ControlSet = null,
    created_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    created_by: ?[]const u8 = null,
    last_updated_by: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .id = "id",
            .name = "name",
            .type = "type",
            .compliance_type = "complianceType",
            .description = "description",
            .logo = "logo",
            .control_sources = "controlSources",
            .control_sets = "controlSets",
            .created_at = "createdAt",
            .last_updated_at = "lastUpdatedAt",
            .created_by = "createdBy",
            .last_updated_by = "lastUpdatedBy",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ControlSet = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    controls: ?[]Control = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .controls = "controls",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateAssessmentFrameworkControl = struct {
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const EvidenceInsights = struct {
    noncompliant_evidence_count: ?i64 = null,
    compliant_evidence_count: ?i64 = null,
    inconclusive_evidence_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .noncompliant_evidence_count = "noncompliantEvidenceCount",
            .compliant_evidence_count = "compliantEvidenceCount",
            .inconclusive_evidence_count = "inconclusiveEvidenceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ControlDomainInsights = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    controls_count_by_noncompliant_evidence: ?i64 = null,
    total_controls_count: ?i64 = null,
    evidence_insights: ?EvidenceInsights = null,
    last_updated: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .id = "id",
            .controls_count_by_noncompliant_evidence = "controlsCountByNoncompliantEvidence",
            .total_controls_count = "totalControlsCount",
            .evidence_insights = "evidenceInsights",
            .last_updated = "lastUpdated",
        };
        return @field(mappings, field_name);
    }
};

pub const AssessmentEvidenceFolder = struct {
    name: ?[]const u8 = null,
    date: ?i64 = null,
    assessment_id: ?[]const u8 = null,
    control_set_id: ?[]const u8 = null,
    control_id: ?[]const u8 = null,
    id: ?[]const u8 = null,
    data_source: ?[]const u8 = null,
    author: ?[]const u8 = null,
    total_evidence: ?i64 = null,
    assessment_report_selection_count: ?i64 = null,
    control_name: ?[]const u8 = null,
    evidence_resources_included_count: ?i64 = null,
    evidence_by_type_configuration_data_count: ?i64 = null,
    evidence_by_type_manual_count: ?i64 = null,
    evidence_by_type_compliance_check_count: ?i64 = null,
    evidence_by_type_compliance_check_issues_count: ?i64 = null,
    evidence_by_type_user_activity_count: ?i64 = null,
    evidence_aws_service_source_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .date = "date",
            .assessment_id = "assessmentId",
            .control_set_id = "controlSetId",
            .control_id = "controlId",
            .id = "id",
            .data_source = "dataSource",
            .author = "author",
            .total_evidence = "totalEvidence",
            .assessment_report_selection_count = "assessmentReportSelectionCount",
            .control_name = "controlName",
            .evidence_resources_included_count = "evidenceResourcesIncludedCount",
            .evidence_by_type_configuration_data_count = "evidenceByTypeConfigurationDataCount",
            .evidence_by_type_manual_count = "evidenceByTypeManualCount",
            .evidence_by_type_compliance_check_count = "evidenceByTypeComplianceCheckCount",
            .evidence_by_type_compliance_check_issues_count = "evidenceByTypeComplianceCheckIssuesCount",
            .evidence_by_type_user_activity_count = "evidenceByTypeUserActivityCount",
            .evidence_aws_service_source_count = "evidenceAwsServiceSourceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const Evidence = struct {
    data_source: ?[]const u8 = null,
    evidence_aws_account_id: ?[]const u8 = null,
    time: ?i64 = null,
    event_source: ?[]const u8 = null,
    event_name: ?[]const u8 = null,
    evidence_by_type: ?[]const u8 = null,
    resources_included: ?[]Resource = null,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    iam_id: ?[]const u8 = null,
    compliance_check: ?[]const u8 = null,
    aws_organization: ?[]const u8 = null,
    aws_account_id: ?[]const u8 = null,
    evidence_folder_id: ?[]const u8 = null,
    id: ?[]const u8 = null,
    assessment_report_selection: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source = "dataSource",
            .evidence_aws_account_id = "evidenceAwsAccountId",
            .time = "time",
            .event_source = "eventSource",
            .event_name = "eventName",
            .evidence_by_type = "evidenceByType",
            .resources_included = "resourcesIncluded",
            .attributes = "attributes",
            .iam_id = "iamId",
            .compliance_check = "complianceCheck",
            .aws_organization = "awsOrganization",
            .aws_account_id = "awsAccountId",
            .evidence_folder_id = "evidenceFolderId",
            .id = "id",
            .assessment_report_selection = "assessmentReportSelection",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const Resource = struct {
    arn: ?[]const u8 = null,
    value: ?[]const u8 = null,
    compliance_check: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .value = "value",
            .compliance_check = "complianceCheck",
        };
        return @field(mappings, field_name);
    }
};

pub const ManualEvidence = struct {
    s3_resource_path: ?[]const u8 = null,
    text_response: ?[]const u8 = null,
    evidence_file_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_resource_path = "s3ResourcePath",
            .text_response = "textResponse",
            .evidence_file_name = "evidenceFileName",
        };
        return @field(mappings, field_name);
    }
};

pub const AssessmentReportEvidenceError = struct {
    evidence_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .evidence_id = "evidenceId",
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateDelegationRequest = struct {
    comment: ?[]const u8 = null,
    control_set_id: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    role_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment = "comment",
            .control_set_id = "controlSetId",
            .role_arn = "roleArn",
            .role_type = "roleType",
        };
        return @field(mappings, field_name);
    }
};
