const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-01-06";
pub const sdk_id: []const u8 = "Auto Scaling Plans";
pub const arn_namespace: ?[]const u8 = "autoscaling-plans";
pub const endpoint_prefix: []const u8 = "autoscaling-plans";
pub const sigv4_name: []const u8 = "autoscaling-plans";
pub const name: []const u8 = "AnyScaleScalingPlannerFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-01-06",
    sdk_id: []const u8 = "Auto Scaling Plans",
    arn_namespace: ?[]const u8 = "autoscaling-plans",
    endpoint_prefix: []const u8 = "autoscaling-plans",
    sigv4_name: []const u8 = "autoscaling-plans",
    name: []const u8 = "AnyScaleScalingPlannerFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_scaling_plan: struct {
    action_name: []const u8 = "CreateScalingPlan",
    Request: type = struct {
        scaling_plan_name: []const u8,
        application_source: ApplicationSource,
        scaling_instructions: []ScalingInstruction,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plan_name = "ScalingPlanName",
                .application_source = "ApplicationSource",
                .scaling_instructions = "ScalingInstructions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_scaling_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_scaling_plan };
        }
    },
    Response: type = struct {
        scaling_plan_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plan_version = "ScalingPlanVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const delete_scaling_plan: struct {
    action_name: []const u8 = "DeleteScalingPlan",
    Request: type = struct {
        scaling_plan_name: []const u8,
        scaling_plan_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plan_name = "ScalingPlanName",
                .scaling_plan_version = "ScalingPlanVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scaling_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_scaling_plan };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        ObjectNotFound,
        Validation,
    },
} = .{};
pub const describe_scaling_plan_resources: struct {
    action_name: []const u8 = "DescribeScalingPlanResources",
    Request: type = struct {
        scaling_plan_name: []const u8,
        scaling_plan_version: i64,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plan_name = "ScalingPlanName",
                .scaling_plan_version = "ScalingPlanVersion",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scaling_plan_resources) } {
            return .{ .service_metadata = service_metadata, .action = describe_scaling_plan_resources };
        }
    },
    Response: type = struct {
        scaling_plan_resources: ?[]struct {
            scaling_plan_name: []const u8,
            scaling_plan_version: i64,
            service_namespace: []const u8,
            resource_id: []const u8,
            scalable_dimension: []const u8,
            scaling_policies: ?[]struct {
                policy_name: []const u8,
                policy_type: []const u8,
                target_tracking_configuration: ?TargetTrackingConfiguration = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .policy_name = "PolicyName",
                        .policy_type = "PolicyType",
                        .target_tracking_configuration = "TargetTrackingConfiguration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            scaling_status_code: []const u8,
            scaling_status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scaling_plan_name = "ScalingPlanName",
                    .scaling_plan_version = "ScalingPlanVersion",
                    .service_namespace = "ServiceNamespace",
                    .resource_id = "ResourceId",
                    .scalable_dimension = "ScalableDimension",
                    .scaling_policies = "ScalingPolicies",
                    .scaling_status_code = "ScalingStatusCode",
                    .scaling_status_message = "ScalingStatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plan_resources = "ScalingPlanResources",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const describe_scaling_plans: struct {
    action_name: []const u8 = "DescribeScalingPlans",
    Request: type = struct {
        scaling_plan_names: ?[][]const u8 = null,
        scaling_plan_version: ?i64 = null,
        application_sources: ?[]ApplicationSource = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plan_names = "ScalingPlanNames",
                .scaling_plan_version = "ScalingPlanVersion",
                .application_sources = "ApplicationSources",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scaling_plans) } {
            return .{ .service_metadata = service_metadata, .action = describe_scaling_plans };
        }
    },
    Response: type = struct {
        scaling_plans: ?[]struct {
            scaling_plan_name: []const u8,
            scaling_plan_version: i64,
            application_source: ApplicationSource,
            scaling_instructions: []ScalingInstruction,
            status_code: []const u8,
            status_message: ?[]const u8 = null,
            status_start_time: ?i64 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scaling_plan_name = "ScalingPlanName",
                    .scaling_plan_version = "ScalingPlanVersion",
                    .application_source = "ApplicationSource",
                    .scaling_instructions = "ScalingInstructions",
                    .status_code = "StatusCode",
                    .status_message = "StatusMessage",
                    .status_start_time = "StatusStartTime",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plans = "ScalingPlans",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const get_scaling_plan_resource_forecast_data: struct {
    action_name: []const u8 = "GetScalingPlanResourceForecastData",
    Request: type = struct {
        scaling_plan_name: []const u8,
        scaling_plan_version: i64,
        service_namespace: []const u8,
        resource_id: []const u8,
        scalable_dimension: []const u8,
        forecast_data_type: []const u8,
        start_time: i64,
        end_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plan_name = "ScalingPlanName",
                .scaling_plan_version = "ScalingPlanVersion",
                .service_namespace = "ServiceNamespace",
                .resource_id = "ResourceId",
                .scalable_dimension = "ScalableDimension",
                .forecast_data_type = "ForecastDataType",
                .start_time = "StartTime",
                .end_time = "EndTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_scaling_plan_resource_forecast_data) } {
            return .{ .service_metadata = service_metadata, .action = get_scaling_plan_resource_forecast_data };
        }
    },
    Response: type = struct {
        datapoints: []struct {
            timestamp: ?i64 = null,
            value: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datapoints = "Datapoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        Validation,
    },
} = .{};
pub const update_scaling_plan: struct {
    action_name: []const u8 = "UpdateScalingPlan",
    Request: type = struct {
        scaling_plan_name: []const u8,
        scaling_plan_version: i64,
        application_source: ?ApplicationSource = null,
        scaling_instructions: ?[]ScalingInstruction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_plan_name = "ScalingPlanName",
                .scaling_plan_version = "ScalingPlanVersion",
                .application_source = "ApplicationSource",
                .scaling_instructions = "ScalingInstructions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_scaling_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_scaling_plan };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentUpdate,
        InternalService,
        ObjectNotFound,
        Validation,
    },
} = .{};

pub const ScalingInstruction = struct {
    service_namespace: []const u8,
    resource_id: []const u8,
    scalable_dimension: []const u8,
    min_capacity: i64,
    max_capacity: i64,
    target_tracking_configurations: []TargetTrackingConfiguration,
    predefined_load_metric_specification: ?PredefinedLoadMetricSpecification = null,
    customized_load_metric_specification: ?CustomizedLoadMetricSpecification = null,
    scheduled_action_buffer_time: ?i64 = null,
    predictive_scaling_max_capacity_behavior: ?[]const u8 = null,
    predictive_scaling_max_capacity_buffer: ?i64 = null,
    predictive_scaling_mode: ?[]const u8 = null,
    scaling_policy_update_behavior: ?[]const u8 = null,
    disable_dynamic_scaling: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_namespace = "ServiceNamespace",
            .resource_id = "ResourceId",
            .scalable_dimension = "ScalableDimension",
            .min_capacity = "MinCapacity",
            .max_capacity = "MaxCapacity",
            .target_tracking_configurations = "TargetTrackingConfigurations",
            .predefined_load_metric_specification = "PredefinedLoadMetricSpecification",
            .customized_load_metric_specification = "CustomizedLoadMetricSpecification",
            .scheduled_action_buffer_time = "ScheduledActionBufferTime",
            .predictive_scaling_max_capacity_behavior = "PredictiveScalingMaxCapacityBehavior",
            .predictive_scaling_max_capacity_buffer = "PredictiveScalingMaxCapacityBuffer",
            .predictive_scaling_mode = "PredictiveScalingMode",
            .scaling_policy_update_behavior = "ScalingPolicyUpdateBehavior",
            .disable_dynamic_scaling = "DisableDynamicScaling",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomizedLoadMetricSpecification = struct {
    metric_name: []const u8,
    namespace: []const u8,
    dimensions: ?[]MetricDimension = null,
    statistic: []const u8,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .namespace = "Namespace",
            .dimensions = "Dimensions",
            .statistic = "Statistic",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricDimension = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PredefinedLoadMetricSpecification = struct {
    predefined_load_metric_type: []const u8,
    resource_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .predefined_load_metric_type = "PredefinedLoadMetricType",
            .resource_label = "ResourceLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetTrackingConfiguration = struct {
    predefined_scaling_metric_specification: ?PredefinedScalingMetricSpecification = null,
    customized_scaling_metric_specification: ?CustomizedScalingMetricSpecification = null,
    target_value: f64,
    disable_scale_in: ?bool = null,
    scale_out_cooldown: ?i64 = null,
    scale_in_cooldown: ?i64 = null,
    estimated_instance_warmup: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .predefined_scaling_metric_specification = "PredefinedScalingMetricSpecification",
            .customized_scaling_metric_specification = "CustomizedScalingMetricSpecification",
            .target_value = "TargetValue",
            .disable_scale_in = "DisableScaleIn",
            .scale_out_cooldown = "ScaleOutCooldown",
            .scale_in_cooldown = "ScaleInCooldown",
            .estimated_instance_warmup = "EstimatedInstanceWarmup",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomizedScalingMetricSpecification = struct {
    metric_name: []const u8,
    namespace: []const u8,
    dimensions: ?[]MetricDimension = null,
    statistic: []const u8,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .namespace = "Namespace",
            .dimensions = "Dimensions",
            .statistic = "Statistic",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const PredefinedScalingMetricSpecification = struct {
    predefined_scaling_metric_type: []const u8,
    resource_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .predefined_scaling_metric_type = "PredefinedScalingMetricType",
            .resource_label = "ResourceLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationSource = struct {
    cloud_formation_stack_arn: ?[]const u8 = null,
    tag_filters: ?[]TagFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_formation_stack_arn = "CloudFormationStackARN",
            .tag_filters = "TagFilters",
        };
        return @field(mappings, field_name);
    }
};

pub const TagFilter = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};
