const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-06-23";
pub const sdk_id: []const u8 = "b2bi";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "b2bi";
pub const sigv4_name: []const u8 = "b2bi";
pub const name: []const u8 = "B2BI";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2022-06-23",
    sdk_id: []const u8 = "b2bi",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "b2bi",
    sigv4_name: []const u8 = "b2bi",
    name: []const u8 = "B2BI",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const get_transformer_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/transformer-jobs/{transformerJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTransformerJob",
    Request: type = struct {
        transformer_job_id: []const u8,
        transformer_id: []const u8,

        pub const http_query = .{
            .transformer_id = "transformerId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transformer_job_id = "transformerJobId",
                .transformer_id = "transformerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transformer_job) } {
            return .{ .service_metadata = service_metadata, .action = get_transformer_job };
        }
    },
    Response: type = struct {
        status: []const u8,
        output_files: ?[]S3Location = null,
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .output_files = "outputFiles",
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_transformer_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/transformer-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartTransformerJob",
    Request: type = struct {
        input_file: S3Location,
        output_location: S3Location,
        transformer_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_file = "inputFile",
                .output_location = "outputLocation",
                .transformer_id = "transformerId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_transformer_job) } {
            return .{ .service_metadata = service_metadata, .action = start_transformer_job };
        }
    },
    Response: type = struct {
        transformer_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transformer_job_id = "transformerJobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const test_mapping: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/testmapping",
        .success_code = 201,
    };

    action_name: []const u8 = "TestMapping",
    Request: type = struct {
        input_file_content: []const u8,
        mapping_template: []const u8,
        file_format: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_file_content = "inputFileContent",
                .mapping_template = "mappingTemplate",
                .file_format = "fileFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_mapping) } {
            return .{ .service_metadata = service_metadata, .action = test_mapping };
        }
    },
    Response: type = struct {
        mapped_file_content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mapped_file_content = "mappedFileContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const test_parsing: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/testparsing",
        .success_code = 201,
    };

    action_name: []const u8 = "TestParsing",
    Request: type = struct {
        input_file: S3Location,
        file_format: []const u8,
        edi_type: union {
            x12_details: ?struct {
                transaction_set: ?[]const u8 = null,
                version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .transaction_set = "transactionSet",
                        .version = "version",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .x12_details = "x12Details",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_file = "inputFile",
                .file_format = "fileFormat",
                .edi_type = "ediType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_parsing) } {
            return .{ .service_metadata = service_metadata, .action = test_parsing };
        }
    },
    Response: type = struct {
        parsed_file_content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parsed_file_content = "parsedFileContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "TagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const S3Location = struct {
    bucket_name: ?[]const u8 = null,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .key = "key",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
