const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-04-10";
pub const sdk_id: []const u8 = "BackupStorage";
pub const arn_namespace: ?[]const u8 = "backup-storage";
pub const endpoint_prefix: []const u8 = "backupstorage";
pub const sigv4_name: []const u8 = "backup-storage";
pub const name: []const u8 = "CryoStorageFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-04-10",
    sdk_id: []const u8 = "BackupStorage",
    arn_namespace: ?[]const u8 = "backup-storage",
    endpoint_prefix: []const u8 = "backupstorage",
    sigv4_name: []const u8 = "backup-storage",
    name: []const u8 = "CryoStorageFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_object: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup-jobs/{BackupJobId}/object/{ObjectName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteObject",
    Request: type = struct {
        backup_job_id: []const u8,
        object_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_id = "BackupJobId",
                .object_name = "ObjectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_object) } {
            return .{ .service_metadata = service_metadata, .action = delete_object };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        IllegalArgument,
        ResourceNotFound,
        Retryable,
        ServiceInternal,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_chunk: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-jobs/{StorageJobId}/chunk/{ChunkToken}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChunk",
    Request: type = struct {
        storage_job_id: []const u8,
        chunk_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_job_id = "StorageJobId",
                .chunk_token = "ChunkToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_chunk) } {
            return .{ .service_metadata = service_metadata, .action = get_chunk };
        }
    },
    Response: type = struct {
        data: []const u8,
        length: i64,
        checksum: []const u8,
        checksum_algorithm: []const u8,
        pub const http_header = .{
            .length = "x-amz-data-length",
            .checksum = "x-amz-checksum",
            .checksum_algorithm = "x-amz-checksum-algorithm",
        };

        pub const http_payload: []const u8 = "data";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data = "Data",
                .length = "Length",
                .checksum = "Checksum",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalArgument,
        KMSInvalidKeyUsage,
        ResourceNotFound,
        Retryable,
        ServiceInternal,
        Throttling,
    },
} = .{};
pub const get_object_metadata: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-jobs/{StorageJobId}/object/{ObjectToken}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectMetadata",
    Request: type = struct {
        storage_job_id: []const u8,
        object_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_job_id = "StorageJobId",
                .object_token = "ObjectToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_object_metadata };
        }
    },
    Response: type = struct {
        metadata_string: ?[]const u8 = null,
        metadata_blob: ?[]const u8 = null,
        metadata_blob_length: ?i64 = null,
        metadata_blob_checksum: ?[]const u8 = null,
        metadata_blob_checksum_algorithm: ?[]const u8 = null,
        pub const http_header = .{
            .metadata_string = "x-amz-metadata-string",
            .metadata_blob_length = "x-amz-data-length",
            .metadata_blob_checksum = "x-amz-checksum",
            .metadata_blob_checksum_algorithm = "x-amz-checksum-algorithm",
        };

        pub const http_payload: []const u8 = "metadata_blob";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_string = "MetadataString",
                .metadata_blob = "MetadataBlob",
                .metadata_blob_length = "MetadataBlobLength",
                .metadata_blob_checksum = "MetadataBlobChecksum",
                .metadata_blob_checksum_algorithm = "MetadataBlobChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalArgument,
        KMSInvalidKeyUsage,
        ResourceNotFound,
        Retryable,
        ServiceInternal,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_chunks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-jobs/{StorageJobId}/chunks/{ObjectToken}/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChunks",
    Request: type = struct {
        storage_job_id: []const u8,
        object_token: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_job_id = "StorageJobId",
                .object_token = "ObjectToken",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_chunks) } {
            return .{ .service_metadata = service_metadata, .action = list_chunks };
        }
    },
    Response: type = struct {
        chunk_list: []struct {
            index: i64,
            length: i64,
            checksum: []const u8,
            checksum_algorithm: []const u8,
            chunk_token: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .index = "Index",
                    .length = "Length",
                    .checksum = "Checksum",
                    .checksum_algorithm = "ChecksumAlgorithm",
                    .chunk_token = "ChunkToken",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .chunk_list = "ChunkList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalArgument,
        ResourceNotFound,
        Retryable,
        ServiceInternal,
        ServiceUnavailable,
    },
} = .{};
pub const list_objects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-jobs/{StorageJobId}/objects/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjects",
    Request: type = struct {
        storage_job_id: []const u8,
        starting_object_name: ?[]const u8 = null,
        starting_object_prefix: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        created_before: ?i64 = null,
        created_after: ?i64 = null,

        pub const http_query = .{
            .starting_object_name = "starting-object-name",
            .starting_object_prefix = "starting-object-prefix",
            .max_results = "max-results",
            .next_token = "next-token",
            .created_before = "created-before",
            .created_after = "created-after",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_job_id = "StorageJobId",
                .starting_object_name = "StartingObjectName",
                .starting_object_prefix = "StartingObjectPrefix",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .created_before = "CreatedBefore",
                .created_after = "CreatedAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_objects) } {
            return .{ .service_metadata = service_metadata, .action = list_objects };
        }
    },
    Response: type = struct {
        object_list: []struct {
            name: []const u8,
            chunks_count: ?i64 = null,
            metadata_string: ?[]const u8 = null,
            object_checksum: []const u8,
            object_checksum_algorithm: []const u8,
            object_token: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .chunks_count = "ChunksCount",
                    .metadata_string = "MetadataString",
                    .object_checksum = "ObjectChecksum",
                    .object_checksum_algorithm = "ObjectChecksumAlgorithm",
                    .object_token = "ObjectToken",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_list = "ObjectList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalArgument,
        KMSInvalidKeyUsage,
        ResourceNotFound,
        Retryable,
        ServiceInternal,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const notify_object_complete: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-jobs/{BackupJobId}/object/{UploadId}/complete",
        .success_code = 200,
    };

    action_name: []const u8 = "NotifyObjectComplete",
    Request: type = struct {
        backup_job_id: []const u8,
        upload_id: []const u8,
        object_checksum: []const u8,
        object_checksum_algorithm: []const u8,
        metadata_string: ?[]const u8 = null,
        metadata_blob: ?[]const u8 = null,
        metadata_blob_length: ?i64 = null,
        metadata_blob_checksum: ?[]const u8 = null,
        metadata_blob_checksum_algorithm: ?[]const u8 = null,

        pub const http_query = .{
            .object_checksum = "checksum",
            .object_checksum_algorithm = "checksum-algorithm",
            .metadata_string = "metadata-string",
            .metadata_blob_length = "metadata-blob-length",
            .metadata_blob_checksum = "metadata-checksum",
            .metadata_blob_checksum_algorithm = "metadata-checksum-algorithm",
        };

        pub const http_payload: []const u8 = "metadata_blob";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_id = "BackupJobId",
                .upload_id = "UploadId",
                .object_checksum = "ObjectChecksum",
                .object_checksum_algorithm = "ObjectChecksumAlgorithm",
                .metadata_string = "MetadataString",
                .metadata_blob = "MetadataBlob",
                .metadata_blob_length = "MetadataBlobLength",
                .metadata_blob_checksum = "MetadataBlobChecksum",
                .metadata_blob_checksum_algorithm = "MetadataBlobChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_object_complete) } {
            return .{ .service_metadata = service_metadata, .action = notify_object_complete };
        }
    },
    Response: type = struct {
        object_checksum: []const u8,
        object_checksum_algorithm: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_checksum = "ObjectChecksum",
                .object_checksum_algorithm = "ObjectChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalArgument,
        KMSInvalidKeyUsage,
        NotReadableInputStream,
        Retryable,
        ServiceInternal,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const put_chunk: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-jobs/{BackupJobId}/chunk/{UploadId}/{ChunkIndex}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutChunk",
    Request: type = struct {
        backup_job_id: []const u8,
        upload_id: []const u8,
        chunk_index: i64,
        data: []const u8,
        length: i64,
        checksum: []const u8,
        checksum_algorithm: []const u8,

        pub const http_query = .{
            .length = "length",
            .checksum = "checksum",
            .checksum_algorithm = "checksum-algorithm",
        };

        pub const http_payload: []const u8 = "data";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_id = "BackupJobId",
                .upload_id = "UploadId",
                .chunk_index = "ChunkIndex",
                .data = "Data",
                .length = "Length",
                .checksum = "Checksum",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_chunk) } {
            return .{ .service_metadata = service_metadata, .action = put_chunk };
        }
    },
    Response: type = struct {
        chunk_checksum: []const u8,
        chunk_checksum_algorithm: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .chunk_checksum = "ChunkChecksum",
                .chunk_checksum_algorithm = "ChunkChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalArgument,
        KMSInvalidKeyUsage,
        NotReadableInputStream,
        Retryable,
        ServiceInternal,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const put_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-jobs/{BackupJobId}/object/{ObjectName}/put-object",
        .success_code = 200,
    };

    action_name: []const u8 = "PutObject",
    Request: type = struct {
        backup_job_id: []const u8,
        object_name: []const u8,
        metadata_string: ?[]const u8 = null,
        inline_chunk: ?[]const u8 = null,
        inline_chunk_length: ?i64 = null,
        inline_chunk_checksum: ?[]const u8 = null,
        inline_chunk_checksum_algorithm: ?[]const u8 = null,
        object_checksum: ?[]const u8 = null,
        object_checksum_algorithm: ?[]const u8 = null,
        throw_on_duplicate: ?bool = null,

        pub const http_query = .{
            .metadata_string = "metadata-string",
            .inline_chunk_length = "length",
            .inline_chunk_checksum = "checksum",
            .inline_chunk_checksum_algorithm = "checksum-algorithm",
            .object_checksum = "object-checksum",
            .object_checksum_algorithm = "object-checksum-algorithm",
            .throw_on_duplicate = "throwOnDuplicate",
        };

        pub const http_payload: []const u8 = "inline_chunk";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_id = "BackupJobId",
                .object_name = "ObjectName",
                .metadata_string = "MetadataString",
                .inline_chunk = "InlineChunk",
                .inline_chunk_length = "InlineChunkLength",
                .inline_chunk_checksum = "InlineChunkChecksum",
                .inline_chunk_checksum_algorithm = "InlineChunkChecksumAlgorithm",
                .object_checksum = "ObjectChecksum",
                .object_checksum_algorithm = "ObjectChecksumAlgorithm",
                .throw_on_duplicate = "ThrowOnDuplicate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_object) } {
            return .{ .service_metadata = service_metadata, .action = put_object };
        }
    },
    Response: type = struct {
        inline_chunk_checksum: []const u8,
        inline_chunk_checksum_algorithm: []const u8,
        object_checksum: []const u8,
        object_checksum_algorithm: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inline_chunk_checksum = "InlineChunkChecksum",
                .inline_chunk_checksum_algorithm = "InlineChunkChecksumAlgorithm",
                .object_checksum = "ObjectChecksum",
                .object_checksum_algorithm = "ObjectChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalArgument,
        KMSInvalidKeyUsage,
        NotReadableInputStream,
        Retryable,
        ServiceInternal,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const start_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-jobs/{BackupJobId}/object/{ObjectName}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartObject",
    Request: type = struct {
        backup_job_id: []const u8,
        object_name: []const u8,
        throw_on_duplicate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_id = "BackupJobId",
                .object_name = "ObjectName",
                .throw_on_duplicate = "ThrowOnDuplicate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_object) } {
            return .{ .service_metadata = service_metadata, .action = start_object };
        }
    },
    Response: type = struct {
        upload_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload_id = "UploadId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DataAlreadyExists,
        IllegalArgument,
        ResourceNotFound,
        Retryable,
        ServiceInternal,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
