const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-08-10";
pub const sdk_id: []const u8 = "Batch";
pub const arn_namespace: ?[]const u8 = "batch";
pub const endpoint_prefix: []const u8 = "batch";
pub const sigv4_name: []const u8 = "batch";
pub const name: []const u8 = "AWSBatchV20160810";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-08-10",
    sdk_id: []const u8 = "Batch",
    arn_namespace: ?[]const u8 = "batch",
    endpoint_prefix: []const u8 = "batch",
    sigv4_name: []const u8 = "batch",
    name: []const u8 = "AWSBatchV20160810",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/canceljob",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelJob",
    Request: type = struct {
        job_id: []const u8,
        reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const create_compute_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/createcomputeenvironment",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateComputeEnvironment",
    Request: type = struct {
        compute_environment_name: []const u8,
        type: []const u8,
        state: ?[]const u8 = null,
        unmanagedv_cpus: ?i64 = null,
        compute_resources: ?ComputeResource = null,
        service_role: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        eks_configuration: ?EksConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment_name = "computeEnvironmentName",
                .type = "type",
                .state = "state",
                .unmanagedv_cpus = "unmanagedvCpus",
                .compute_resources = "computeResources",
                .service_role = "serviceRole",
                .tags = "tags",
                .eks_configuration = "eksConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_compute_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_compute_environment };
        }
    },
    Response: type = struct {
        compute_environment_name: ?[]const u8 = null,
        compute_environment_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment_name = "computeEnvironmentName",
                .compute_environment_arn = "computeEnvironmentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const create_job_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/createjobqueue",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateJobQueue",
    Request: type = struct {
        job_queue_name: []const u8,
        state: ?[]const u8 = null,
        scheduling_policy_arn: ?[]const u8 = null,
        priority: i64,
        compute_environment_order: []ComputeEnvironmentOrder,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue_name = "jobQueueName",
                .state = "state",
                .scheduling_policy_arn = "schedulingPolicyArn",
                .priority = "priority",
                .compute_environment_order = "computeEnvironmentOrder",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job_queue) } {
            return .{ .service_metadata = service_metadata, .action = create_job_queue };
        }
    },
    Response: type = struct {
        job_queue_name: []const u8,
        job_queue_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue_name = "jobQueueName",
                .job_queue_arn = "jobQueueArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const create_scheduling_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/createschedulingpolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSchedulingPolicy",
    Request: type = struct {
        name: []const u8,
        fairshare_policy: ?FairsharePolicy = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .fairshare_policy = "fairsharePolicy",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_scheduling_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_scheduling_policy };
        }
    },
    Response: type = struct {
        name: []const u8,
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const delete_compute_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/deletecomputeenvironment",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteComputeEnvironment",
    Request: type = struct {
        compute_environment: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment = "computeEnvironment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_compute_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_compute_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const delete_job_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/deletejobqueue",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJobQueue",
    Request: type = struct {
        job_queue: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue = "jobQueue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job_queue) } {
            return .{ .service_metadata = service_metadata, .action = delete_job_queue };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const delete_scheduling_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/deleteschedulingpolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSchedulingPolicy",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scheduling_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_scheduling_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const deregister_job_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/deregisterjobdefinition",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterJobDefinition",
    Request: type = struct {
        job_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition = "jobDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = deregister_job_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_compute_environments: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describecomputeenvironments",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeComputeEnvironments",
    Request: type = struct {
        compute_environments: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environments = "computeEnvironments",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_compute_environments) } {
            return .{ .service_metadata = service_metadata, .action = describe_compute_environments };
        }
    },
    Response: type = struct {
        compute_environments: ?[]struct {
            compute_environment_name: []const u8,
            compute_environment_arn: []const u8,
            unmanagedv_cpus: ?i64 = null,
            ecs_cluster_arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            compute_resources: ?ComputeResource = null,
            service_role: ?[]const u8 = null,
            update_policy: ?UpdatePolicy = null,
            eks_configuration: ?EksConfiguration = null,
            container_orchestration_type: ?[]const u8 = null,
            uuid: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compute_environment_name = "computeEnvironmentName",
                    .compute_environment_arn = "computeEnvironmentArn",
                    .unmanagedv_cpus = "unmanagedvCpus",
                    .ecs_cluster_arn = "ecsClusterArn",
                    .tags = "tags",
                    .type = "type",
                    .state = "state",
                    .status = "status",
                    .status_reason = "statusReason",
                    .compute_resources = "computeResources",
                    .service_role = "serviceRole",
                    .update_policy = "updatePolicy",
                    .eks_configuration = "eksConfiguration",
                    .container_orchestration_type = "containerOrchestrationType",
                    .uuid = "uuid",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environments = "computeEnvironments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_job_definitions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describejobdefinitions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobDefinitions",
    Request: type = struct {
        job_definitions: ?[][]const u8 = null,
        max_results: ?i64 = null,
        job_definition_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definitions = "jobDefinitions",
                .max_results = "maxResults",
                .job_definition_name = "jobDefinitionName",
                .status = "status",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_definitions) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_definitions };
        }
    },
    Response: type = struct {
        job_definitions: ?[]struct {
            job_definition_name: []const u8,
            job_definition_arn: []const u8,
            revision: i64,
            status: ?[]const u8 = null,
            type: []const u8,
            scheduling_priority: ?i64 = null,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            retry_strategy: ?RetryStrategy = null,
            container_properties: ?ContainerProperties = null,
            timeout: ?JobTimeout = null,
            node_properties: ?NodeProperties = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            propagate_tags: ?bool = null,
            platform_capabilities: ?[][]const u8 = null,
            ecs_properties: ?EcsProperties = null,
            eks_properties: ?EksProperties = null,
            container_orchestration_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_definition_name = "jobDefinitionName",
                    .job_definition_arn = "jobDefinitionArn",
                    .revision = "revision",
                    .status = "status",
                    .type = "type",
                    .scheduling_priority = "schedulingPriority",
                    .parameters = "parameters",
                    .retry_strategy = "retryStrategy",
                    .container_properties = "containerProperties",
                    .timeout = "timeout",
                    .node_properties = "nodeProperties",
                    .tags = "tags",
                    .propagate_tags = "propagateTags",
                    .platform_capabilities = "platformCapabilities",
                    .ecs_properties = "ecsProperties",
                    .eks_properties = "eksProperties",
                    .container_orchestration_type = "containerOrchestrationType",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definitions = "jobDefinitions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_job_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describejobqueues",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobQueues",
    Request: type = struct {
        job_queues: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queues = "jobQueues",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_queues) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_queues };
        }
    },
    Response: type = struct {
        job_queues: ?[]struct {
            job_queue_name: []const u8,
            job_queue_arn: []const u8,
            state: []const u8,
            scheduling_policy_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            priority: i64,
            compute_environment_order: []ComputeEnvironmentOrder,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_queue_name = "jobQueueName",
                    .job_queue_arn = "jobQueueArn",
                    .state = "state",
                    .scheduling_policy_arn = "schedulingPolicyArn",
                    .status = "status",
                    .status_reason = "statusReason",
                    .priority = "priority",
                    .compute_environment_order = "computeEnvironmentOrder",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queues = "jobQueues",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describejobs",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobs",
    Request: type = struct {
        jobs: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_jobs) } {
            return .{ .service_metadata = service_metadata, .action = describe_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            job_arn: ?[]const u8 = null,
            job_name: []const u8,
            job_id: []const u8,
            job_queue: []const u8,
            status: []const u8,
            share_identifier: ?[]const u8 = null,
            scheduling_priority: ?i64 = null,
            attempts: ?[]struct {
                container: ?struct {
                    container_instance_arn: ?[]const u8 = null,
                    task_arn: ?[]const u8 = null,
                    exit_code: ?i64 = null,
                    reason: ?[]const u8 = null,
                    log_stream_name: ?[]const u8 = null,
                    network_interfaces: ?[]NetworkInterface = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .container_instance_arn = "containerInstanceArn",
                            .task_arn = "taskArn",
                            .exit_code = "exitCode",
                            .reason = "reason",
                            .log_stream_name = "logStreamName",
                            .network_interfaces = "networkInterfaces",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                started_at: ?i64 = null,
                stopped_at: ?i64 = null,
                status_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .container = "container",
                        .started_at = "startedAt",
                        .stopped_at = "stoppedAt",
                        .status_reason = "statusReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status_reason: ?[]const u8 = null,
            created_at: ?i64 = null,
            retry_strategy: ?RetryStrategy = null,
            started_at: i64,
            stopped_at: ?i64 = null,
            depends_on: ?[]JobDependency = null,
            job_definition: []const u8,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            container: ?struct {
                image: ?[]const u8 = null,
                vcpus: ?i64 = null,
                memory: ?i64 = null,
                command: ?[][]const u8 = null,
                job_role_arn: ?[]const u8 = null,
                execution_role_arn: ?[]const u8 = null,
                volumes: ?[]Volume = null,
                environment: ?[]KeyValuePair = null,
                mount_points: ?[]MountPoint = null,
                readonly_root_filesystem: ?bool = null,
                ulimits: ?[]Ulimit = null,
                privileged: ?bool = null,
                user: ?[]const u8 = null,
                exit_code: ?i64 = null,
                reason: ?[]const u8 = null,
                container_instance_arn: ?[]const u8 = null,
                task_arn: ?[]const u8 = null,
                log_stream_name: ?[]const u8 = null,
                instance_type: ?[]const u8 = null,
                network_interfaces: ?[]NetworkInterface = null,
                resource_requirements: ?[]ResourceRequirement = null,
                linux_parameters: ?LinuxParameters = null,
                log_configuration: ?LogConfiguration = null,
                secrets: ?[]Secret = null,
                network_configuration: ?NetworkConfiguration = null,
                fargate_platform_configuration: ?FargatePlatformConfiguration = null,
                ephemeral_storage: ?EphemeralStorage = null,
                runtime_platform: ?RuntimePlatform = null,
                repository_credentials: ?RepositoryCredentials = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .image = "image",
                        .vcpus = "vcpus",
                        .memory = "memory",
                        .command = "command",
                        .job_role_arn = "jobRoleArn",
                        .execution_role_arn = "executionRoleArn",
                        .volumes = "volumes",
                        .environment = "environment",
                        .mount_points = "mountPoints",
                        .readonly_root_filesystem = "readonlyRootFilesystem",
                        .ulimits = "ulimits",
                        .privileged = "privileged",
                        .user = "user",
                        .exit_code = "exitCode",
                        .reason = "reason",
                        .container_instance_arn = "containerInstanceArn",
                        .task_arn = "taskArn",
                        .log_stream_name = "logStreamName",
                        .instance_type = "instanceType",
                        .network_interfaces = "networkInterfaces",
                        .resource_requirements = "resourceRequirements",
                        .linux_parameters = "linuxParameters",
                        .log_configuration = "logConfiguration",
                        .secrets = "secrets",
                        .network_configuration = "networkConfiguration",
                        .fargate_platform_configuration = "fargatePlatformConfiguration",
                        .ephemeral_storage = "ephemeralStorage",
                        .runtime_platform = "runtimePlatform",
                        .repository_credentials = "repositoryCredentials",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            node_details: ?struct {
                node_index: ?i64 = null,
                is_main_node: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .node_index = "nodeIndex",
                        .is_main_node = "isMainNode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            node_properties: ?NodeProperties = null,
            array_properties: ?struct {
                status_summary: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,
                size: ?i64 = null,
                index: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status_summary = "statusSummary",
                        .size = "size",
                        .index = "index",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "status_summary", field_name))
                        return try serializeMap(self.status_summary, self.fieldNameFor("status_summary"), options, out_stream);
                    return false;
                }
            } = null,
            timeout: ?JobTimeout = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            propagate_tags: ?bool = null,
            platform_capabilities: ?[][]const u8 = null,
            eks_properties: ?struct {
                pod_properties: ?struct {
                    service_account_name: ?[]const u8 = null,
                    host_network: ?bool = null,
                    dns_policy: ?[]const u8 = null,
                    containers: ?[]EksContainerDetail = null,
                    init_containers: ?[]EksContainerDetail = null,
                    volumes: ?[]EksVolume = null,
                    pod_name: ?[]const u8 = null,
                    node_name: ?[]const u8 = null,
                    metadata: ?EksMetadata = null,
                    share_process_namespace: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .service_account_name = "serviceAccountName",
                            .host_network = "hostNetwork",
                            .dns_policy = "dnsPolicy",
                            .containers = "containers",
                            .init_containers = "initContainers",
                            .volumes = "volumes",
                            .pod_name = "podName",
                            .node_name = "nodeName",
                            .metadata = "metadata",
                            .share_process_namespace = "shareProcessNamespace",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pod_properties = "podProperties",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            eks_attempts: ?[]struct {
                containers: ?[]EksAttemptContainerDetail = null,
                init_containers: ?[]EksAttemptContainerDetail = null,
                pod_name: ?[]const u8 = null,
                node_name: ?[]const u8 = null,
                started_at: ?i64 = null,
                stopped_at: ?i64 = null,
                status_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .containers = "containers",
                        .init_containers = "initContainers",
                        .pod_name = "podName",
                        .node_name = "nodeName",
                        .started_at = "startedAt",
                        .stopped_at = "stoppedAt",
                        .status_reason = "statusReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ecs_properties: ?struct {
                task_properties: ?[]struct {
                    containers: ?[]struct {
                        command: ?[][]const u8 = null,
                        depends_on: ?[]TaskContainerDependency = null,
                        environment: ?[]KeyValuePair = null,
                        essential: ?bool = null,
                        image: ?[]const u8 = null,
                        linux_parameters: ?LinuxParameters = null,
                        log_configuration: ?LogConfiguration = null,
                        mount_points: ?[]MountPoint = null,
                        name: ?[]const u8 = null,
                        privileged: ?bool = null,
                        readonly_root_filesystem: ?bool = null,
                        repository_credentials: ?RepositoryCredentials = null,
                        resource_requirements: ?[]ResourceRequirement = null,
                        secrets: ?[]Secret = null,
                        ulimits: ?[]Ulimit = null,
                        user: ?[]const u8 = null,
                        exit_code: ?i64 = null,
                        reason: ?[]const u8 = null,
                        log_stream_name: ?[]const u8 = null,
                        network_interfaces: ?[]NetworkInterface = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .command = "command",
                                .depends_on = "dependsOn",
                                .environment = "environment",
                                .essential = "essential",
                                .image = "image",
                                .linux_parameters = "linuxParameters",
                                .log_configuration = "logConfiguration",
                                .mount_points = "mountPoints",
                                .name = "name",
                                .privileged = "privileged",
                                .readonly_root_filesystem = "readonlyRootFilesystem",
                                .repository_credentials = "repositoryCredentials",
                                .resource_requirements = "resourceRequirements",
                                .secrets = "secrets",
                                .ulimits = "ulimits",
                                .user = "user",
                                .exit_code = "exitCode",
                                .reason = "reason",
                                .log_stream_name = "logStreamName",
                                .network_interfaces = "networkInterfaces",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    container_instance_arn: ?[]const u8 = null,
                    task_arn: ?[]const u8 = null,
                    ephemeral_storage: ?EphemeralStorage = null,
                    execution_role_arn: ?[]const u8 = null,
                    platform_version: ?[]const u8 = null,
                    ipc_mode: ?[]const u8 = null,
                    task_role_arn: ?[]const u8 = null,
                    pid_mode: ?[]const u8 = null,
                    network_configuration: ?NetworkConfiguration = null,
                    runtime_platform: ?RuntimePlatform = null,
                    volumes: ?[]Volume = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .containers = "containers",
                            .container_instance_arn = "containerInstanceArn",
                            .task_arn = "taskArn",
                            .ephemeral_storage = "ephemeralStorage",
                            .execution_role_arn = "executionRoleArn",
                            .platform_version = "platformVersion",
                            .ipc_mode = "ipcMode",
                            .task_role_arn = "taskRoleArn",
                            .pid_mode = "pidMode",
                            .network_configuration = "networkConfiguration",
                            .runtime_platform = "runtimePlatform",
                            .volumes = "volumes",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .task_properties = "taskProperties",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            is_cancelled: ?bool = null,
            is_terminated: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_arn = "jobArn",
                    .job_name = "jobName",
                    .job_id = "jobId",
                    .job_queue = "jobQueue",
                    .status = "status",
                    .share_identifier = "shareIdentifier",
                    .scheduling_priority = "schedulingPriority",
                    .attempts = "attempts",
                    .status_reason = "statusReason",
                    .created_at = "createdAt",
                    .retry_strategy = "retryStrategy",
                    .started_at = "startedAt",
                    .stopped_at = "stoppedAt",
                    .depends_on = "dependsOn",
                    .job_definition = "jobDefinition",
                    .parameters = "parameters",
                    .container = "container",
                    .node_details = "nodeDetails",
                    .node_properties = "nodeProperties",
                    .array_properties = "arrayProperties",
                    .timeout = "timeout",
                    .tags = "tags",
                    .propagate_tags = "propagateTags",
                    .platform_capabilities = "platformCapabilities",
                    .eks_properties = "eksProperties",
                    .eks_attempts = "eksAttempts",
                    .ecs_properties = "ecsProperties",
                    .is_cancelled = "isCancelled",
                    .is_terminated = "isTerminated",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_scheduling_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describeschedulingpolicies",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSchedulingPolicies",
    Request: type = struct {
        arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arns = "arns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scheduling_policies) } {
            return .{ .service_metadata = service_metadata, .action = describe_scheduling_policies };
        }
    },
    Response: type = struct {
        scheduling_policies: ?[]struct {
            name: []const u8,
            arn: []const u8,
            fairshare_policy: ?FairsharePolicy = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .fairshare_policy = "fairsharePolicy",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduling_policies = "schedulingPolicies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/listjobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        job_queue: ?[]const u8 = null,
        array_job_id: ?[]const u8 = null,
        multi_node_job_id: ?[]const u8 = null,
        job_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue = "jobQueue",
                .array_job_id = "arrayJobId",
                .multi_node_job_id = "multiNodeJobId",
                .job_status = "jobStatus",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        job_summary_list: []struct {
            job_arn: ?[]const u8 = null,
            job_id: []const u8,
            job_name: []const u8,
            created_at: ?i64 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            started_at: ?i64 = null,
            stopped_at: ?i64 = null,
            container: ?struct {
                exit_code: ?i64 = null,
                reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .exit_code = "exitCode",
                        .reason = "reason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            array_properties: ?struct {
                size: ?i64 = null,
                index: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .size = "size",
                        .index = "index",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            node_properties: ?struct {
                is_main_node: ?bool = null,
                num_nodes: ?i64 = null,
                node_index: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .is_main_node = "isMainNode",
                        .num_nodes = "numNodes",
                        .node_index = "nodeIndex",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            job_definition: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_arn = "jobArn",
                    .job_id = "jobId",
                    .job_name = "jobName",
                    .created_at = "createdAt",
                    .status = "status",
                    .status_reason = "statusReason",
                    .started_at = "startedAt",
                    .stopped_at = "stoppedAt",
                    .container = "container",
                    .array_properties = "arrayProperties",
                    .node_properties = "nodeProperties",
                    .job_definition = "jobDefinition",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summary_list = "jobSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const list_scheduling_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/listschedulingpolicies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSchedulingPolicies",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_scheduling_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_scheduling_policies };
        }
    },
    Response: type = struct {
        scheduling_policies: ?[]struct {
            arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduling_policies = "schedulingPolicies",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const register_job_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/registerjobdefinition",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,
        type: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        scheduling_priority: ?i64 = null,
        container_properties: ?ContainerProperties = null,
        node_properties: ?NodeProperties = null,
        retry_strategy: ?RetryStrategy = null,
        propagate_tags: ?bool = null,
        timeout: ?JobTimeout = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        platform_capabilities: ?[][]const u8 = null,
        eks_properties: ?EksProperties = null,
        ecs_properties: ?EcsProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "jobDefinitionName",
                .type = "type",
                .parameters = "parameters",
                .scheduling_priority = "schedulingPriority",
                .container_properties = "containerProperties",
                .node_properties = "nodeProperties",
                .retry_strategy = "retryStrategy",
                .propagate_tags = "propagateTags",
                .timeout = "timeout",
                .tags = "tags",
                .platform_capabilities = "platformCapabilities",
                .eks_properties = "eksProperties",
                .ecs_properties = "ecsProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = register_job_definition };
        }
    },
    Response: type = struct {
        job_definition_name: []const u8,
        job_definition_arn: []const u8,
        revision: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "jobDefinitionName",
                .job_definition_arn = "jobDefinitionArn",
                .revision = "revision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const submit_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/submitjob",
        .success_code = 200,
    };

    action_name: []const u8 = "SubmitJob",
    Request: type = struct {
        job_name: []const u8,
        job_queue: []const u8,
        share_identifier: ?[]const u8 = null,
        scheduling_priority_override: ?i64 = null,
        array_properties: ?struct {
            size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .size = "size",
                };
                return @field(mappings, field_name);
            }
        } = null,
        depends_on: ?[]JobDependency = null,
        job_definition: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        container_overrides: ?ContainerOverrides = null,
        node_overrides: ?struct {
            num_nodes: ?i64 = null,
            node_property_overrides: ?[]struct {
                target_nodes: []const u8,
                container_overrides: ?ContainerOverrides = null,
                ecs_properties_override: ?EcsPropertiesOverride = null,
                instance_types: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .target_nodes = "targetNodes",
                        .container_overrides = "containerOverrides",
                        .ecs_properties_override = "ecsPropertiesOverride",
                        .instance_types = "instanceTypes",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .num_nodes = "numNodes",
                    .node_property_overrides = "nodePropertyOverrides",
                };
                return @field(mappings, field_name);
            }
        } = null,
        retry_strategy: ?RetryStrategy = null,
        propagate_tags: ?bool = null,
        timeout: ?JobTimeout = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        eks_properties_override: ?struct {
            pod_properties: ?struct {
                containers: ?[]EksContainerOverride = null,
                init_containers: ?[]EksContainerOverride = null,
                metadata: ?EksMetadata = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .containers = "containers",
                        .init_containers = "initContainers",
                        .metadata = "metadata",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pod_properties = "podProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        ecs_properties_override: ?EcsPropertiesOverride = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "jobName",
                .job_queue = "jobQueue",
                .share_identifier = "shareIdentifier",
                .scheduling_priority_override = "schedulingPriorityOverride",
                .array_properties = "arrayProperties",
                .depends_on = "dependsOn",
                .job_definition = "jobDefinition",
                .parameters = "parameters",
                .container_overrides = "containerOverrides",
                .node_overrides = "nodeOverrides",
                .retry_strategy = "retryStrategy",
                .propagate_tags = "propagateTags",
                .timeout = "timeout",
                .tags = "tags",
                .eks_properties_override = "eksPropertiesOverride",
                .ecs_properties_override = "ecsPropertiesOverride",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_job) } {
            return .{ .service_metadata = service_metadata, .action = submit_job };
        }
    },
    Response: type = struct {
        job_arn: ?[]const u8 = null,
        job_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_arn = "jobArn",
                .job_name = "jobName",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const terminate_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/terminatejob",
        .success_code = 200,
    };

    action_name: []const u8 = "TerminateJob",
    Request: type = struct {
        job_id: []const u8,
        reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_job) } {
            return .{ .service_metadata = service_metadata, .action = terminate_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const update_compute_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/updatecomputeenvironment",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateComputeEnvironment",
    Request: type = struct {
        compute_environment: []const u8,
        state: ?[]const u8 = null,
        unmanagedv_cpus: ?i64 = null,
        compute_resources: ?struct {
            minv_cpus: ?i64 = null,
            maxv_cpus: ?i64 = null,
            desiredv_cpus: ?i64 = null,
            subnets: ?[][]const u8 = null,
            security_group_ids: ?[][]const u8 = null,
            allocation_strategy: ?[]const u8 = null,
            instance_types: ?[][]const u8 = null,
            ec2_key_pair: ?[]const u8 = null,
            instance_role: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            placement_group: ?[]const u8 = null,
            bid_percentage: ?i64 = null,
            launch_template: ?LaunchTemplateSpecification = null,
            ec2_configuration: ?[]Ec2Configuration = null,
            update_to_latest_image_version: ?bool = null,
            type: ?[]const u8 = null,
            image_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .minv_cpus = "minvCpus",
                    .maxv_cpus = "maxvCpus",
                    .desiredv_cpus = "desiredvCpus",
                    .subnets = "subnets",
                    .security_group_ids = "securityGroupIds",
                    .allocation_strategy = "allocationStrategy",
                    .instance_types = "instanceTypes",
                    .ec2_key_pair = "ec2KeyPair",
                    .instance_role = "instanceRole",
                    .tags = "tags",
                    .placement_group = "placementGroup",
                    .bid_percentage = "bidPercentage",
                    .launch_template = "launchTemplate",
                    .ec2_configuration = "ec2Configuration",
                    .update_to_latest_image_version = "updateToLatestImageVersion",
                    .type = "type",
                    .image_id = "imageId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        service_role: ?[]const u8 = null,
        update_policy: ?UpdatePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment = "computeEnvironment",
                .state = "state",
                .unmanagedv_cpus = "unmanagedvCpus",
                .compute_resources = "computeResources",
                .service_role = "serviceRole",
                .update_policy = "updatePolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_compute_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_compute_environment };
        }
    },
    Response: type = struct {
        compute_environment_name: ?[]const u8 = null,
        compute_environment_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment_name = "computeEnvironmentName",
                .compute_environment_arn = "computeEnvironmentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const update_job_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/updatejobqueue",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJobQueue",
    Request: type = struct {
        job_queue: []const u8,
        state: ?[]const u8 = null,
        scheduling_policy_arn: ?[]const u8 = null,
        priority: ?i64 = null,
        compute_environment_order: ?[]ComputeEnvironmentOrder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue = "jobQueue",
                .state = "state",
                .scheduling_policy_arn = "schedulingPolicyArn",
                .priority = "priority",
                .compute_environment_order = "computeEnvironmentOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_queue) } {
            return .{ .service_metadata = service_metadata, .action = update_job_queue };
        }
    },
    Response: type = struct {
        job_queue_name: ?[]const u8 = null,
        job_queue_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue_name = "jobQueueName",
                .job_queue_arn = "jobQueueArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const update_scheduling_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/updateschedulingpolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSchedulingPolicy",
    Request: type = struct {
        arn: []const u8,
        fairshare_policy: ?FairsharePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .fairshare_policy = "fairsharePolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_scheduling_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_scheduling_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};

pub const FairsharePolicy = struct {
    share_decay_seconds: ?i64 = null,
    compute_reservation: ?i64 = null,
    share_distribution: ?[]ShareAttributes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .share_decay_seconds = "shareDecaySeconds",
            .compute_reservation = "computeReservation",
            .share_distribution = "shareDistribution",
        };
        return @field(mappings, field_name);
    }
};

pub const ShareAttributes = struct {
    share_identifier: []const u8,
    weight_factor: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .share_identifier = "shareIdentifier",
            .weight_factor = "weightFactor",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeEnvironmentOrder = struct {
    order: i64,
    compute_environment: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .order = "order",
            .compute_environment = "computeEnvironment",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdatePolicy = struct {
    terminate_jobs_on_update: ?bool = null,
    job_execution_timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .terminate_jobs_on_update = "terminateJobsOnUpdate",
            .job_execution_timeout_minutes = "jobExecutionTimeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2Configuration = struct {
    image_type: []const u8,
    image_id_override: ?[]const u8 = null,
    image_kubernetes_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_type = "imageType",
            .image_id_override = "imageIdOverride",
            .image_kubernetes_version = "imageKubernetesVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateSpecification = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .launch_template_name = "launchTemplateName",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const EcsPropertiesOverride = struct {
    task_properties: ?[]TaskPropertiesOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_properties = "taskProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskPropertiesOverride = struct {
    containers: ?[]TaskContainerOverrides = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .containers = "containers",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskContainerOverrides = struct {
    command: ?[][]const u8 = null,
    environment: ?[]KeyValuePair = null,
    name: ?[]const u8 = null,
    resource_requirements: ?[]ResourceRequirement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .command = "command",
            .environment = "environment",
            .name = "name",
            .resource_requirements = "resourceRequirements",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceRequirement = struct {
    value: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyValuePair = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const EksMetadata = struct {
    labels: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .labels = "labels",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "labels", field_name))
            return try serializeMap(self.labels, self.fieldNameFor("labels"), options, out_stream);
        return false;
    }
};

pub const EksContainerOverride = struct {
    name: ?[]const u8 = null,
    image: ?[]const u8 = null,
    command: ?[][]const u8 = null,
    args: ?[][]const u8 = null,
    env: ?[]EksContainerEnvironmentVariable = null,
    resources: ?EksContainerResourceRequirements = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .image = "image",
            .command = "command",
            .args = "args",
            .env = "env",
            .resources = "resources",
        };
        return @field(mappings, field_name);
    }
};

pub const EksContainerResourceRequirements = struct {
    limits: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    requests: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .limits = "limits",
            .requests = "requests",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "limits", field_name))
            return try serializeMap(self.limits, self.fieldNameFor("limits"), options, out_stream);
        if (std.mem.eql(u8, "requests", field_name))
            return try serializeMap(self.requests, self.fieldNameFor("requests"), options, out_stream);
        return false;
    }
};

pub const EksContainerEnvironmentVariable = struct {
    name: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const JobTimeout = struct {
    attempt_duration_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attempt_duration_seconds = "attemptDurationSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const RetryStrategy = struct {
    attempts: ?i64 = null,
    evaluate_on_exit: ?[]EvaluateOnExit = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attempts = "attempts",
            .evaluate_on_exit = "evaluateOnExit",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluateOnExit = struct {
    on_status_reason: ?[]const u8 = null,
    on_reason: ?[]const u8 = null,
    on_exit_code: ?[]const u8 = null,
    action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .on_status_reason = "onStatusReason",
            .on_reason = "onReason",
            .on_exit_code = "onExitCode",
            .action = "action",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerOverrides = struct {
    vcpus: ?i64 = null,
    memory: ?i64 = null,
    command: ?[][]const u8 = null,
    instance_type: ?[]const u8 = null,
    environment: ?[]KeyValuePair = null,
    resource_requirements: ?[]ResourceRequirement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vcpus = "vcpus",
            .memory = "memory",
            .command = "command",
            .instance_type = "instanceType",
            .environment = "environment",
            .resource_requirements = "resourceRequirements",
        };
        return @field(mappings, field_name);
    }
};

pub const JobDependency = struct {
    job_id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "jobId",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const EcsProperties = struct {
    task_properties: []EcsTaskProperties,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_properties = "taskProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const EcsTaskProperties = struct {
    containers: []TaskContainerProperties,
    ephemeral_storage: ?EphemeralStorage = null,
    execution_role_arn: ?[]const u8 = null,
    platform_version: ?[]const u8 = null,
    ipc_mode: ?[]const u8 = null,
    task_role_arn: ?[]const u8 = null,
    pid_mode: ?[]const u8 = null,
    network_configuration: ?NetworkConfiguration = null,
    runtime_platform: ?RuntimePlatform = null,
    volumes: ?[]Volume = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .containers = "containers",
            .ephemeral_storage = "ephemeralStorage",
            .execution_role_arn = "executionRoleArn",
            .platform_version = "platformVersion",
            .ipc_mode = "ipcMode",
            .task_role_arn = "taskRoleArn",
            .pid_mode = "pidMode",
            .network_configuration = "networkConfiguration",
            .runtime_platform = "runtimePlatform",
            .volumes = "volumes",
        };
        return @field(mappings, field_name);
    }
};

pub const Volume = struct {
    host: ?Host = null,
    name: ?[]const u8 = null,
    efs_volume_configuration: ?EFSVolumeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "host",
            .name = "name",
            .efs_volume_configuration = "efsVolumeConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const EFSVolumeConfiguration = struct {
    file_system_id: []const u8,
    root_directory: ?[]const u8 = null,
    transit_encryption: ?[]const u8 = null,
    transit_encryption_port: ?i64 = null,
    authorization_config: ?EFSAuthorizationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_system_id = "fileSystemId",
            .root_directory = "rootDirectory",
            .transit_encryption = "transitEncryption",
            .transit_encryption_port = "transitEncryptionPort",
            .authorization_config = "authorizationConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const EFSAuthorizationConfig = struct {
    access_point_id: ?[]const u8 = null,
    iam: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_point_id = "accessPointId",
            .iam = "iam",
        };
        return @field(mappings, field_name);
    }
};

pub const Host = struct {
    source_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_path = "sourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const RuntimePlatform = struct {
    operating_system_family: ?[]const u8 = null,
    cpu_architecture: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .operating_system_family = "operatingSystemFamily",
            .cpu_architecture = "cpuArchitecture",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkConfiguration = struct {
    assign_public_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assign_public_ip = "assignPublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const EphemeralStorage = struct {
    size_in_gib: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .size_in_gib = "sizeInGiB",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskContainerProperties = struct {
    command: ?[][]const u8 = null,
    depends_on: ?[]TaskContainerDependency = null,
    environment: ?[]KeyValuePair = null,
    essential: ?bool = null,
    image: []const u8,
    linux_parameters: ?LinuxParameters = null,
    log_configuration: ?LogConfiguration = null,
    mount_points: ?[]MountPoint = null,
    name: ?[]const u8 = null,
    privileged: ?bool = null,
    readonly_root_filesystem: ?bool = null,
    repository_credentials: ?RepositoryCredentials = null,
    resource_requirements: ?[]ResourceRequirement = null,
    secrets: ?[]Secret = null,
    ulimits: ?[]Ulimit = null,
    user: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .command = "command",
            .depends_on = "dependsOn",
            .environment = "environment",
            .essential = "essential",
            .image = "image",
            .linux_parameters = "linuxParameters",
            .log_configuration = "logConfiguration",
            .mount_points = "mountPoints",
            .name = "name",
            .privileged = "privileged",
            .readonly_root_filesystem = "readonlyRootFilesystem",
            .repository_credentials = "repositoryCredentials",
            .resource_requirements = "resourceRequirements",
            .secrets = "secrets",
            .ulimits = "ulimits",
            .user = "user",
        };
        return @field(mappings, field_name);
    }
};

pub const Ulimit = struct {
    hard_limit: i64,
    name: []const u8,
    soft_limit: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hard_limit = "hardLimit",
            .name = "name",
            .soft_limit = "softLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const Secret = struct {
    name: []const u8,
    value_from: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value_from = "valueFrom",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryCredentials = struct {
    credentials_parameter: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credentials_parameter = "credentialsParameter",
        };
        return @field(mappings, field_name);
    }
};

pub const MountPoint = struct {
    container_path: ?[]const u8 = null,
    read_only: ?bool = null,
    source_volume: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_path = "containerPath",
            .read_only = "readOnly",
            .source_volume = "sourceVolume",
        };
        return @field(mappings, field_name);
    }
};

pub const LogConfiguration = struct {
    log_driver: []const u8,
    options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    secret_options: ?[]Secret = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_driver = "logDriver",
            .options = "options",
            .secret_options = "secretOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const LinuxParameters = struct {
    devices: ?[]Device = null,
    init_process_enabled: ?bool = null,
    shared_memory_size: ?i64 = null,
    tmpfs: ?[]Tmpfs = null,
    max_swap: ?i64 = null,
    swappiness: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .devices = "devices",
            .init_process_enabled = "initProcessEnabled",
            .shared_memory_size = "sharedMemorySize",
            .tmpfs = "tmpfs",
            .max_swap = "maxSwap",
            .swappiness = "swappiness",
        };
        return @field(mappings, field_name);
    }
};

pub const Tmpfs = struct {
    container_path: []const u8,
    size: i64,
    mount_options: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_path = "containerPath",
            .size = "size",
            .mount_options = "mountOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const Device = struct {
    host_path: []const u8,
    container_path: ?[]const u8 = null,
    permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_path = "hostPath",
            .container_path = "containerPath",
            .permissions = "permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskContainerDependency = struct {
    container_name: ?[]const u8 = null,
    condition: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_name = "containerName",
            .condition = "condition",
        };
        return @field(mappings, field_name);
    }
};

pub const EksProperties = struct {
    pod_properties: ?EksPodProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pod_properties = "podProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const EksPodProperties = struct {
    service_account_name: ?[]const u8 = null,
    host_network: ?bool = null,
    dns_policy: ?[]const u8 = null,
    containers: ?[]EksContainer = null,
    init_containers: ?[]EksContainer = null,
    volumes: ?[]EksVolume = null,
    metadata: ?EksMetadata = null,
    share_process_namespace: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_account_name = "serviceAccountName",
            .host_network = "hostNetwork",
            .dns_policy = "dnsPolicy",
            .containers = "containers",
            .init_containers = "initContainers",
            .volumes = "volumes",
            .metadata = "metadata",
            .share_process_namespace = "shareProcessNamespace",
        };
        return @field(mappings, field_name);
    }
};

pub const EksVolume = struct {
    name: []const u8,
    host_path: ?EksHostPath = null,
    empty_dir: ?EksEmptyDir = null,
    secret: ?EksSecret = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .host_path = "hostPath",
            .empty_dir = "emptyDir",
            .secret = "secret",
        };
        return @field(mappings, field_name);
    }
};

pub const EksSecret = struct {
    secret_name: []const u8,
    optional: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .secret_name = "secretName",
            .optional = "optional",
        };
        return @field(mappings, field_name);
    }
};

pub const EksEmptyDir = struct {
    medium: ?[]const u8 = null,
    size_limit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .medium = "medium",
            .size_limit = "sizeLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const EksHostPath = struct {
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "path",
        };
        return @field(mappings, field_name);
    }
};

pub const EksContainer = struct {
    name: ?[]const u8 = null,
    image: []const u8,
    image_pull_policy: ?[]const u8 = null,
    command: ?[][]const u8 = null,
    args: ?[][]const u8 = null,
    env: ?[]EksContainerEnvironmentVariable = null,
    resources: ?EksContainerResourceRequirements = null,
    volume_mounts: ?[]EksContainerVolumeMount = null,
    security_context: ?EksContainerSecurityContext = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .image = "image",
            .image_pull_policy = "imagePullPolicy",
            .command = "command",
            .args = "args",
            .env = "env",
            .resources = "resources",
            .volume_mounts = "volumeMounts",
            .security_context = "securityContext",
        };
        return @field(mappings, field_name);
    }
};

pub const EksContainerSecurityContext = struct {
    run_as_user: ?i64 = null,
    run_as_group: ?i64 = null,
    privileged: ?bool = null,
    read_only_root_filesystem: ?bool = null,
    run_as_non_root: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .run_as_user = "runAsUser",
            .run_as_group = "runAsGroup",
            .privileged = "privileged",
            .read_only_root_filesystem = "readOnlyRootFilesystem",
            .run_as_non_root = "runAsNonRoot",
        };
        return @field(mappings, field_name);
    }
};

pub const EksContainerVolumeMount = struct {
    name: ?[]const u8 = null,
    mount_path: ?[]const u8 = null,
    read_only: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .mount_path = "mountPath",
            .read_only = "readOnly",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeProperties = struct {
    num_nodes: i64,
    main_node: i64,
    node_range_properties: []NodeRangeProperty,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .num_nodes = "numNodes",
            .main_node = "mainNode",
            .node_range_properties = "nodeRangeProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeRangeProperty = struct {
    target_nodes: []const u8,
    container: ?ContainerProperties = null,
    instance_types: ?[][]const u8 = null,
    ecs_properties: ?EcsProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_nodes = "targetNodes",
            .container = "container",
            .instance_types = "instanceTypes",
            .ecs_properties = "ecsProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerProperties = struct {
    image: ?[]const u8 = null,
    vcpus: ?i64 = null,
    memory: ?i64 = null,
    command: ?[][]const u8 = null,
    job_role_arn: ?[]const u8 = null,
    execution_role_arn: ?[]const u8 = null,
    volumes: ?[]Volume = null,
    environment: ?[]KeyValuePair = null,
    mount_points: ?[]MountPoint = null,
    readonly_root_filesystem: ?bool = null,
    privileged: ?bool = null,
    ulimits: ?[]Ulimit = null,
    user: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    resource_requirements: ?[]ResourceRequirement = null,
    linux_parameters: ?LinuxParameters = null,
    log_configuration: ?LogConfiguration = null,
    secrets: ?[]Secret = null,
    network_configuration: ?NetworkConfiguration = null,
    fargate_platform_configuration: ?FargatePlatformConfiguration = null,
    ephemeral_storage: ?EphemeralStorage = null,
    runtime_platform: ?RuntimePlatform = null,
    repository_credentials: ?RepositoryCredentials = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image = "image",
            .vcpus = "vcpus",
            .memory = "memory",
            .command = "command",
            .job_role_arn = "jobRoleArn",
            .execution_role_arn = "executionRoleArn",
            .volumes = "volumes",
            .environment = "environment",
            .mount_points = "mountPoints",
            .readonly_root_filesystem = "readonlyRootFilesystem",
            .privileged = "privileged",
            .ulimits = "ulimits",
            .user = "user",
            .instance_type = "instanceType",
            .resource_requirements = "resourceRequirements",
            .linux_parameters = "linuxParameters",
            .log_configuration = "logConfiguration",
            .secrets = "secrets",
            .network_configuration = "networkConfiguration",
            .fargate_platform_configuration = "fargatePlatformConfiguration",
            .ephemeral_storage = "ephemeralStorage",
            .runtime_platform = "runtimePlatform",
            .repository_credentials = "repositoryCredentials",
        };
        return @field(mappings, field_name);
    }
};

pub const FargatePlatformConfiguration = struct {
    platform_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .platform_version = "platformVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterface = struct {
    attachment_id: ?[]const u8 = null,
    ipv6_address: ?[]const u8 = null,
    private_ipv4_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment_id = "attachmentId",
            .ipv6_address = "ipv6Address",
            .private_ipv4_address = "privateIpv4Address",
        };
        return @field(mappings, field_name);
    }
};

pub const EksAttemptContainerDetail = struct {
    exit_code: ?i64 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .exit_code = "exitCode",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const EksContainerDetail = struct {
    name: ?[]const u8 = null,
    image: ?[]const u8 = null,
    image_pull_policy: ?[]const u8 = null,
    command: ?[][]const u8 = null,
    args: ?[][]const u8 = null,
    env: ?[]EksContainerEnvironmentVariable = null,
    resources: ?EksContainerResourceRequirements = null,
    exit_code: ?i64 = null,
    reason: ?[]const u8 = null,
    volume_mounts: ?[]EksContainerVolumeMount = null,
    security_context: ?EksContainerSecurityContext = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .image = "image",
            .image_pull_policy = "imagePullPolicy",
            .command = "command",
            .args = "args",
            .env = "env",
            .resources = "resources",
            .exit_code = "exitCode",
            .reason = "reason",
            .volume_mounts = "volumeMounts",
            .security_context = "securityContext",
        };
        return @field(mappings, field_name);
    }
};

pub const EksConfiguration = struct {
    eks_cluster_arn: []const u8,
    kubernetes_namespace: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eks_cluster_arn = "eksClusterArn",
            .kubernetes_namespace = "kubernetesNamespace",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeResource = struct {
    type: []const u8,
    allocation_strategy: ?[]const u8 = null,
    minv_cpus: ?i64 = null,
    maxv_cpus: i64,
    desiredv_cpus: ?i64 = null,
    instance_types: ?[][]const u8 = null,
    image_id: ?[]const u8 = null,
    subnets: [][]const u8,
    security_group_ids: ?[][]const u8 = null,
    ec2_key_pair: ?[]const u8 = null,
    instance_role: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    placement_group: ?[]const u8 = null,
    bid_percentage: ?i64 = null,
    spot_iam_fleet_role: ?[]const u8 = null,
    launch_template: ?LaunchTemplateSpecification = null,
    ec2_configuration: ?[]Ec2Configuration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .allocation_strategy = "allocationStrategy",
            .minv_cpus = "minvCpus",
            .maxv_cpus = "maxvCpus",
            .desiredv_cpus = "desiredvCpus",
            .instance_types = "instanceTypes",
            .image_id = "imageId",
            .subnets = "subnets",
            .security_group_ids = "securityGroupIds",
            .ec2_key_pair = "ec2KeyPair",
            .instance_role = "instanceRole",
            .tags = "tags",
            .placement_group = "placementGroup",
            .bid_percentage = "bidPercentage",
            .spot_iam_fleet_role = "spotIamFleetRole",
            .launch_template = "launchTemplate",
            .ec2_configuration = "ec2Configuration",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};
