const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-11-26";
pub const sdk_id: []const u8 = "BCM Data Exports";
pub const arn_namespace: ?[]const u8 = "bcm-data-exports";
pub const endpoint_prefix: []const u8 = "bcm-data-exports";
pub const sigv4_name: []const u8 = "bcm-data-exports";
pub const name: []const u8 = "AWSBillingAndCostManagementDataExports";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-11-26",
    sdk_id: []const u8 = "BCM Data Exports",
    arn_namespace: ?[]const u8 = "bcm-data-exports",
    endpoint_prefix: []const u8 = "bcm-data-exports",
    sigv4_name: []const u8 = "bcm-data-exports",
    name: []const u8 = "AWSBillingAndCostManagementDataExports",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_export: struct {
    action_name: []const u8 = "CreateExport",
    Request: type = struct {
        @"export": Export,
        resource_tags: ?[]ResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"export" = "Export",
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_export) } {
            return .{ .service_metadata = service_metadata, .action = create_export };
        }
    },
    Response: type = struct {
        export_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_export: struct {
    action_name: []const u8 = "DeleteExport",
    Request: type = struct {
        export_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_export) } {
            return .{ .service_metadata = service_metadata, .action = delete_export };
        }
    },
    Response: type = struct {
        export_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_execution: struct {
    action_name: []const u8 = "GetExecution",
    Request: type = struct {
        export_arn: []const u8,
        execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
                .execution_id = "ExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_execution };
        }
    },
    Response: type = struct {
        execution_id: ?[]const u8 = null,
        @"export": ?Export = null,
        execution_status: ?ExecutionStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_id = "ExecutionId",
                .@"export" = "Export",
                .execution_status = "ExecutionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_export: struct {
    action_name: []const u8 = "GetExport",
    Request: type = struct {
        export_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_export) } {
            return .{ .service_metadata = service_metadata, .action = get_export };
        }
    },
    Response: type = struct {
        @"export": ?Export = null,
        export_status: ?ExportStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"export" = "Export",
                .export_status = "ExportStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_table: struct {
    action_name: []const u8 = "GetTable",
    Request: type = struct {
        table_name: []const u8,
        table_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .table_properties = "TableProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "table_properties", field_name))
                return try serializeMap(self.table_properties, self.fieldNameFor("table_properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table) } {
            return .{ .service_metadata = service_metadata, .action = get_table };
        }
    },
    Response: type = struct {
        table_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        table_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        schema: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .description = "Description",
                .table_properties = "TableProperties",
                .schema = "Schema",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "table_properties", field_name))
                return try serializeMap(self.table_properties, self.fieldNameFor("table_properties"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_executions: struct {
    action_name: []const u8 = "ListExecutions",
    Request: type = struct {
        export_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_executions };
        }
    },
    Response: type = struct {
        executions: ?[]struct {
            execution_id: []const u8,
            execution_status: ExecutionStatus,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_id = "ExecutionId",
                    .execution_status = "ExecutionStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .executions = "Executions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_exports: struct {
    action_name: []const u8 = "ListExports",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_exports) } {
            return .{ .service_metadata = service_metadata, .action = list_exports };
        }
    },
    Response: type = struct {
        exports: ?[]struct {
            export_arn: []const u8,
            export_name: []const u8,
            export_status: ExportStatus,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .export_arn = "ExportArn",
                    .export_name = "ExportName",
                    .export_status = "ExportStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exports = "Exports",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tables: struct {
    action_name: []const u8 = "ListTables",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tables) } {
            return .{ .service_metadata = service_metadata, .action = list_tables };
        }
    },
    Response: type = struct {
        tables: ?[]struct {
            table_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            table_properties: ?[]struct {
                name: ?[]const u8 = null,
                valid_values: ?[][]const u8 = null,
                default_value: ?[]const u8 = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .valid_values = "ValidValues",
                        .default_value = "DefaultValue",
                        .description = "Description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_name = "TableName",
                    .description = "Description",
                    .table_properties = "TableProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tables = "Tables",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_tags: ?[]ResourceTag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_tags = "ResourceTags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        resource_tags: []ResourceTag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        resource_tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_tag_keys = "ResourceTagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_export: struct {
    action_name: []const u8 = "UpdateExport",
    Request: type = struct {
        export_arn: []const u8,
        @"export": Export,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
                .@"export" = "Export",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_export) } {
            return .{ .service_metadata = service_metadata, .action = update_export };
        }
    },
    Response: type = struct {
        export_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Export = struct {
    export_arn: ?[]const u8 = null,
    name: []const u8,
    description: ?[]const u8 = null,
    data_query: DataQuery,
    destination_configurations: DestinationConfigurations,
    refresh_cadence: RefreshCadence,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .export_arn = "ExportArn",
            .name = "Name",
            .description = "Description",
            .data_query = "DataQuery",
            .destination_configurations = "DestinationConfigurations",
            .refresh_cadence = "RefreshCadence",
        };
        return @field(mappings, field_name);
    }
};

pub const RefreshCadence = struct {
    frequency: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .frequency = "Frequency",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfigurations = struct {
    s3_destination: S3Destination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_destination = "S3Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Destination = struct {
    s3_bucket: []const u8,
    s3_prefix: []const u8,
    s3_region: []const u8,
    s3_output_configurations: S3OutputConfigurations,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_prefix = "S3Prefix",
            .s3_region = "S3Region",
            .s3_output_configurations = "S3OutputConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const S3OutputConfigurations = struct {
    output_type: []const u8,
    format: []const u8,
    compression: []const u8,
    overwrite: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_type = "OutputType",
            .format = "Format",
            .compression = "Compression",
            .overwrite = "Overwrite",
        };
        return @field(mappings, field_name);
    }
};

pub const DataQuery = struct {
    query_statement: []const u8,
    table_configurations: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,


    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "value", field_name))
            return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
        return false;
    }
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_statement = "QueryStatement",
            .table_configurations = "TableConfigurations",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "table_configurations", field_name))
            return try serializeMap(self.table_configurations, self.fieldNameFor("table_configurations"), options, out_stream);
        return false;
    }
};

pub const ResourceTag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportStatus = struct {
    status_code: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    created_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    last_refreshed_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "StatusCode",
            .status_reason = "StatusReason",
            .created_at = "CreatedAt",
            .last_updated_at = "LastUpdatedAt",
            .last_refreshed_at = "LastRefreshedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionStatus = struct {
    status_code: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    created_at: ?i64 = null,
    completed_at: ?i64 = null,
    last_updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "StatusCode",
            .status_reason = "StatusReason",
            .created_at = "CreatedAt",
            .completed_at = "CompletedAt",
            .last_updated_at = "LastUpdatedAt",
        };
        return @field(mappings, field_name);
    }
};
