const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-07-30";
pub const sdk_id: []const u8 = "billingconductor";
pub const arn_namespace: ?[]const u8 = "billingconductor";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "billingconductor";
pub const name: []const u8 = "AWSBillingConductor";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-07-30",
    sdk_id: []const u8 = "billingconductor",
    arn_namespace: ?[]const u8 = "billingconductor",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "billingconductor",
    name: []const u8 = "AWSBillingConductor",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_billing_group_cost_report: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-billing-group-cost-report",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBillingGroupCostReport",
    Request: type = struct {
        arn: []const u8,
        billing_period_range: ?struct {
            inclusive_start_billing_period: []const u8,
            exclusive_end_billing_period: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .inclusive_start_billing_period = "InclusiveStartBillingPeriod",
                    .exclusive_end_billing_period = "ExclusiveEndBillingPeriod",
                };
                return @field(mappings, field_name);
            }
        } = null,
        group_by: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .billing_period_range = "BillingPeriodRange",
                .group_by = "GroupBy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_billing_group_cost_report) } {
            return .{ .service_metadata = service_metadata, .action = get_billing_group_cost_report };
        }
    },
    Response: type = struct {
        billing_group_cost_report_results: ?[]struct {
            arn: ?[]const u8 = null,
            aws_cost: ?[]const u8 = null,
            proforma_cost: ?[]const u8 = null,
            margin: ?[]const u8 = null,
            margin_percentage: ?[]const u8 = null,
            currency: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .aws_cost = "AWSCost",
                    .proforma_cost = "ProformaCost",
                    .margin = "Margin",
                    .margin_percentage = "MarginPercentage",
                    .currency = "Currency",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_cost_report_results = "BillingGroupCostReportResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_associations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-account-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccountAssociations",
    Request: type = struct {
        billing_period: ?[]const u8 = null,
        filters: ?struct {
            association: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            account_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association = "Association",
                    .account_id = "AccountId",
                    .account_ids = "AccountIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_period = "BillingPeriod",
                .filters = "Filters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_account_associations };
        }
    },
    Response: type = struct {
        linked_accounts: ?[]struct {
            account_id: ?[]const u8 = null,
            billing_group_arn: ?[]const u8 = null,
            account_name: ?[]const u8 = null,
            account_email: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .billing_group_arn = "BillingGroupArn",
                    .account_name = "AccountName",
                    .account_email = "AccountEmail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .linked_accounts = "LinkedAccounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_billing_group_cost_reports: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-billing-group-cost-reports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBillingGroupCostReports",
    Request: type = struct {
        billing_period: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?struct {
            billing_group_arns: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .billing_group_arns = "BillingGroupArns",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_period = "BillingPeriod",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_billing_group_cost_reports) } {
            return .{ .service_metadata = service_metadata, .action = list_billing_group_cost_reports };
        }
    },
    Response: type = struct {
        billing_group_cost_reports: ?[]struct {
            arn: ?[]const u8 = null,
            aws_cost: ?[]const u8 = null,
            proforma_cost: ?[]const u8 = null,
            margin: ?[]const u8 = null,
            margin_percentage: ?[]const u8 = null,
            currency: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .aws_cost = "AWSCost",
                    .proforma_cost = "ProformaCost",
                    .margin = "Margin",
                    .margin_percentage = "MarginPercentage",
                    .currency = "Currency",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_cost_reports = "BillingGroupCostReports",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
