const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-10-20";
pub const sdk_id: []const u8 = "Budgets";
pub const arn_namespace: ?[]const u8 = "budgets";
pub const endpoint_prefix: []const u8 = "budgets";
pub const sigv4_name: []const u8 = "budgets";
pub const name: []const u8 = "AWSBudgetServiceGateway";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-10-20",
    sdk_id: []const u8 = "Budgets",
    arn_namespace: ?[]const u8 = "budgets",
    endpoint_prefix: []const u8 = "budgets",
    sigv4_name: []const u8 = "budgets",
    name: []const u8 = "AWSBudgetServiceGateway",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_budget: struct {
    action_name: []const u8 = "CreateBudget",
    Request: type = struct {
        account_id: []const u8,
        budget: Budget,
        notifications_with_subscribers: ?[]struct {
            notification: Notification,
            subscribers: []Subscriber,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .notification = "Notification",
                    .subscribers = "Subscribers",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget = "Budget",
                .notifications_with_subscribers = "NotificationsWithSubscribers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_budget) } {
            return .{ .service_metadata = service_metadata, .action = create_budget };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CreationLimitExceeded,
        DuplicateRecord,
        InternalError,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const create_budget_action: struct {
    action_name: []const u8 = "CreateBudgetAction",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        notification_type: []const u8,
        action_type: []const u8,
        action_threshold: ActionThreshold,
        definition: Definition,
        execution_role_arn: []const u8,
        approval_model: []const u8,
        subscribers: []Subscriber,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .notification_type = "NotificationType",
                .action_type = "ActionType",
                .action_threshold = "ActionThreshold",
                .definition = "Definition",
                .execution_role_arn = "ExecutionRoleArn",
                .approval_model = "ApprovalModel",
                .subscribers = "Subscribers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_budget_action) } {
            return .{ .service_metadata = service_metadata, .action = create_budget_action };
        }
    },
    Response: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action_id = "ActionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CreationLimitExceeded,
        DuplicateRecord,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const create_notification: struct {
    action_name: []const u8 = "CreateNotification",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        notification: Notification,
        subscribers: []Subscriber,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .notification = "Notification",
                .subscribers = "Subscribers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_notification) } {
            return .{ .service_metadata = service_metadata, .action = create_notification };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CreationLimitExceeded,
        DuplicateRecord,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const create_subscriber: struct {
    action_name: []const u8 = "CreateSubscriber",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        notification: Notification,
        subscriber: Subscriber,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .notification = "Notification",
                .subscriber = "Subscriber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subscriber) } {
            return .{ .service_metadata = service_metadata, .action = create_subscriber };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CreationLimitExceeded,
        DuplicateRecord,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const delete_budget: struct {
    action_name: []const u8 = "DeleteBudget",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_budget) } {
            return .{ .service_metadata = service_metadata, .action = delete_budget };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const delete_budget_action: struct {
    action_name: []const u8 = "DeleteBudgetAction",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action_id = "ActionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_budget_action) } {
            return .{ .service_metadata = service_metadata, .action = delete_budget_action };
        }
    },
    Response: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action: Action,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action = "Action",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        ResourceLocked,
        Throttling,
    },
} = .{};
pub const delete_notification: struct {
    action_name: []const u8 = "DeleteNotification",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        notification: Notification,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .notification = "Notification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_notification) } {
            return .{ .service_metadata = service_metadata, .action = delete_notification };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const delete_subscriber: struct {
    action_name: []const u8 = "DeleteSubscriber",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        notification: Notification,
        subscriber: Subscriber,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .notification = "Notification",
                .subscriber = "Subscriber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subscriber) } {
            return .{ .service_metadata = service_metadata, .action = delete_subscriber };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_budget: struct {
    action_name: []const u8 = "DescribeBudget",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_budget) } {
            return .{ .service_metadata = service_metadata, .action = describe_budget };
        }
    },
    Response: type = struct {
        budget: ?Budget = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .budget = "Budget",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_budget_action: struct {
    action_name: []const u8 = "DescribeBudgetAction",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action_id = "ActionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_budget_action) } {
            return .{ .service_metadata = service_metadata, .action = describe_budget_action };
        }
    },
    Response: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action: Action,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action = "Action",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_budget_action_histories: struct {
    action_name: []const u8 = "DescribeBudgetActionHistories",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action_id: []const u8,
        time_period: ?TimePeriod = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action_id = "ActionId",
                .time_period = "TimePeriod",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_budget_action_histories) } {
            return .{ .service_metadata = service_metadata, .action = describe_budget_action_histories };
        }
    },
    Response: type = struct {
        action_histories: []struct {
            timestamp: i64,
            status: []const u8,
            event_type: []const u8,
            action_history_details: struct {
                message: []const u8,
                action: Action,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .message = "Message",
                        .action = "Action",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .status = "Status",
                    .event_type = "EventType",
                    .action_history_details = "ActionHistoryDetails",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_histories = "ActionHistories",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_budget_actions_for_account: struct {
    action_name: []const u8 = "DescribeBudgetActionsForAccount",
    Request: type = struct {
        account_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_budget_actions_for_account) } {
            return .{ .service_metadata = service_metadata, .action = describe_budget_actions_for_account };
        }
    },
    Response: type = struct {
        actions: []Action,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .actions = "Actions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const describe_budget_actions_for_budget: struct {
    action_name: []const u8 = "DescribeBudgetActionsForBudget",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_budget_actions_for_budget) } {
            return .{ .service_metadata = service_metadata, .action = describe_budget_actions_for_budget };
        }
    },
    Response: type = struct {
        actions: []Action,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .actions = "Actions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_budget_notifications_for_account: struct {
    action_name: []const u8 = "DescribeBudgetNotificationsForAccount",
    Request: type = struct {
        account_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_budget_notifications_for_account) } {
            return .{ .service_metadata = service_metadata, .action = describe_budget_notifications_for_account };
        }
    },
    Response: type = struct {
        budget_notifications_for_account: ?[]struct {
            notifications: ?[]Notification = null,
            budget_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .notifications = "Notifications",
                    .budget_name = "BudgetName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .budget_notifications_for_account = "BudgetNotificationsForAccount",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_budget_performance_history: struct {
    action_name: []const u8 = "DescribeBudgetPerformanceHistory",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        time_period: ?TimePeriod = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .time_period = "TimePeriod",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_budget_performance_history) } {
            return .{ .service_metadata = service_metadata, .action = describe_budget_performance_history };
        }
    },
    Response: type = struct {
        budget_performance_history: ?struct {
            budget_name: ?[]const u8 = null,
            budget_type: ?[]const u8 = null,
            cost_filters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            cost_types: ?CostTypes = null,
            time_unit: ?[]const u8 = null,
            budgeted_and_actual_amounts_list: ?[]struct {
                budgeted_amount: ?Spend = null,
                actual_amount: ?Spend = null,
                time_period: ?TimePeriod = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .budgeted_amount = "BudgetedAmount",
                        .actual_amount = "ActualAmount",
                        .time_period = "TimePeriod",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .budget_name = "BudgetName",
                    .budget_type = "BudgetType",
                    .cost_filters = "CostFilters",
                    .cost_types = "CostTypes",
                    .time_unit = "TimeUnit",
                    .budgeted_and_actual_amounts_list = "BudgetedAndActualAmountsList",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "cost_filters", field_name))
                    return try serializeMap(self.cost_filters, self.fieldNameFor("cost_filters"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .budget_performance_history = "BudgetPerformanceHistory",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_budgets: struct {
    action_name: []const u8 = "DescribeBudgets",
    Request: type = struct {
        account_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_budgets) } {
            return .{ .service_metadata = service_metadata, .action = describe_budgets };
        }
    },
    Response: type = struct {
        budgets: ?[]Budget = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .budgets = "Budgets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_notifications_for_budget: struct {
    action_name: []const u8 = "DescribeNotificationsForBudget",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_notifications_for_budget) } {
            return .{ .service_metadata = service_metadata, .action = describe_notifications_for_budget };
        }
    },
    Response: type = struct {
        notifications: ?[]Notification = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notifications = "Notifications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const describe_subscribers_for_notification: struct {
    action_name: []const u8 = "DescribeSubscribersForNotification",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        notification: Notification,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .notification = "Notification",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_subscribers_for_notification) } {
            return .{ .service_metadata = service_metadata, .action = describe_subscribers_for_notification };
        }
    },
    Response: type = struct {
        subscribers: ?[]Subscriber = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscribers = "Subscribers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const execute_budget_action: struct {
    action_name: []const u8 = "ExecuteBudgetAction",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action_id: []const u8,
        execution_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action_id = "ActionId",
                .execution_type = "ExecutionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_budget_action) } {
            return .{ .service_metadata = service_metadata, .action = execute_budget_action };
        }
    },
    Response: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action_id: []const u8,
        execution_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action_id = "ActionId",
                .execution_type = "ExecutionType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        ResourceLocked,
        Throttling,
    },
} = .{};
pub const update_budget: struct {
    action_name: []const u8 = "UpdateBudget",
    Request: type = struct {
        account_id: []const u8,
        new_budget: Budget,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .new_budget = "NewBudget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_budget) } {
            return .{ .service_metadata = service_metadata, .action = update_budget };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const update_budget_action: struct {
    action_name: []const u8 = "UpdateBudgetAction",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        action_id: []const u8,
        notification_type: ?[]const u8 = null,
        action_threshold: ?ActionThreshold = null,
        definition: ?Definition = null,
        execution_role_arn: ?[]const u8 = null,
        approval_model: ?[]const u8 = null,
        subscribers: ?[]Subscriber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .action_id = "ActionId",
                .notification_type = "NotificationType",
                .action_threshold = "ActionThreshold",
                .definition = "Definition",
                .execution_role_arn = "ExecutionRoleArn",
                .approval_model = "ApprovalModel",
                .subscribers = "Subscribers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_budget_action) } {
            return .{ .service_metadata = service_metadata, .action = update_budget_action };
        }
    },
    Response: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        old_action: Action,
        new_action: Action,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .old_action = "OldAction",
                .new_action = "NewAction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        ResourceLocked,
        Throttling,
    },
} = .{};
pub const update_notification: struct {
    action_name: []const u8 = "UpdateNotification",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        old_notification: Notification,
        new_notification: Notification,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .old_notification = "OldNotification",
                .new_notification = "NewNotification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_notification) } {
            return .{ .service_metadata = service_metadata, .action = update_notification };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateRecord,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const update_subscriber: struct {
    action_name: []const u8 = "UpdateSubscriber",
    Request: type = struct {
        account_id: []const u8,
        budget_name: []const u8,
        notification: Notification,
        old_subscriber: Subscriber,
        new_subscriber: Subscriber,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .budget_name = "BudgetName",
                .notification = "Notification",
                .old_subscriber = "OldSubscriber",
                .new_subscriber = "NewSubscriber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subscriber) } {
            return .{ .service_metadata = service_metadata, .action = update_subscriber };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateRecord,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};

pub const Subscriber = struct {
    subscription_type: []const u8,
    address: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subscription_type = "SubscriptionType",
            .address = "Address",
        };
        return @field(mappings, field_name);
    }
};

pub const Notification = struct {
    notification_type: []const u8,
    comparison_operator: []const u8,
    threshold: f64,
    threshold_type: ?[]const u8 = null,
    notification_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notification_type = "NotificationType",
            .comparison_operator = "ComparisonOperator",
            .threshold = "Threshold",
            .threshold_type = "ThresholdType",
            .notification_state = "NotificationState",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    action_id: []const u8,
    budget_name: []const u8,
    notification_type: []const u8,
    action_type: []const u8,
    action_threshold: ActionThreshold,
    definition: Definition,
    execution_role_arn: []const u8,
    approval_model: []const u8,
    status: []const u8,
    subscribers: []Subscriber,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_id = "ActionId",
            .budget_name = "BudgetName",
            .notification_type = "NotificationType",
            .action_type = "ActionType",
            .action_threshold = "ActionThreshold",
            .definition = "Definition",
            .execution_role_arn = "ExecutionRoleArn",
            .approval_model = "ApprovalModel",
            .status = "Status",
            .subscribers = "Subscribers",
        };
        return @field(mappings, field_name);
    }
};

pub const Definition = struct {
    iam_action_definition: ?IamActionDefinition = null,
    scp_action_definition: ?ScpActionDefinition = null,
    ssm_action_definition: ?SsmActionDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam_action_definition = "IamActionDefinition",
            .scp_action_definition = "ScpActionDefinition",
            .ssm_action_definition = "SsmActionDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const SsmActionDefinition = struct {
    action_sub_type: []const u8,
    region: []const u8,
    instance_ids: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_sub_type = "ActionSubType",
            .region = "Region",
            .instance_ids = "InstanceIds",
        };
        return @field(mappings, field_name);
    }
};

pub const ScpActionDefinition = struct {
    policy_id: []const u8,
    target_ids: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_id = "PolicyId",
            .target_ids = "TargetIds",
        };
        return @field(mappings, field_name);
    }
};

pub const IamActionDefinition = struct {
    policy_arn: []const u8,
    roles: ?[][]const u8 = null,
    groups: ?[][]const u8 = null,
    users: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_arn = "PolicyArn",
            .roles = "Roles",
            .groups = "Groups",
            .users = "Users",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionThreshold = struct {
    action_threshold_value: f64,
    action_threshold_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_threshold_value = "ActionThresholdValue",
            .action_threshold_type = "ActionThresholdType",
        };
        return @field(mappings, field_name);
    }
};

pub const Budget = struct {
    budget_name: []const u8,
    budget_limit: ?Spend = null,
    planned_budget_limits: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Spend = null,
    } = null,
    cost_filters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    cost_types: ?CostTypes = null,
    time_unit: []const u8,
    time_period: ?TimePeriod = null,
    calculated_spend: ?CalculatedSpend = null,
    budget_type: []const u8,
    last_updated_time: ?i64 = null,
    auto_adjust_data: ?AutoAdjustData = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .budget_name = "BudgetName",
            .budget_limit = "BudgetLimit",
            .planned_budget_limits = "PlannedBudgetLimits",
            .cost_filters = "CostFilters",
            .cost_types = "CostTypes",
            .time_unit = "TimeUnit",
            .time_period = "TimePeriod",
            .calculated_spend = "CalculatedSpend",
            .budget_type = "BudgetType",
            .last_updated_time = "LastUpdatedTime",
            .auto_adjust_data = "AutoAdjustData",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "planned_budget_limits", field_name))
            return try serializeMap(self.planned_budget_limits, self.fieldNameFor("planned_budget_limits"), options, out_stream);
        if (std.mem.eql(u8, "cost_filters", field_name))
            return try serializeMap(self.cost_filters, self.fieldNameFor("cost_filters"), options, out_stream);
        return false;
    }
};

pub const AutoAdjustData = struct {
    auto_adjust_type: []const u8,
    historical_options: ?HistoricalOptions = null,
    last_auto_adjust_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_adjust_type = "AutoAdjustType",
            .historical_options = "HistoricalOptions",
            .last_auto_adjust_time = "LastAutoAdjustTime",
        };
        return @field(mappings, field_name);
    }
};

pub const HistoricalOptions = struct {
    budget_adjustment_period: i64,
    look_back_available_periods: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .budget_adjustment_period = "BudgetAdjustmentPeriod",
            .look_back_available_periods = "LookBackAvailablePeriods",
        };
        return @field(mappings, field_name);
    }
};

pub const CalculatedSpend = struct {
    actual_spend: Spend,
    forecasted_spend: ?Spend = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actual_spend = "ActualSpend",
            .forecasted_spend = "ForecastedSpend",
        };
        return @field(mappings, field_name);
    }
};

pub const Spend = struct {
    amount: []const u8,
    unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amount = "Amount",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const TimePeriod = struct {
    start: ?i64 = null,
    end: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start = "Start",
            .end = "End",
        };
        return @field(mappings, field_name);
    }
};

pub const CostTypes = struct {
    include_tax: ?bool = null,
    include_subscription: ?bool = null,
    use_blended: ?bool = null,
    include_refund: ?bool = null,
    include_credit: ?bool = null,
    include_upfront: ?bool = null,
    include_recurring: ?bool = null,
    include_other_subscription: ?bool = null,
    include_support: ?bool = null,
    include_discount: ?bool = null,
    use_amortized: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .include_tax = "IncludeTax",
            .include_subscription = "IncludeSubscription",
            .use_blended = "UseBlended",
            .include_refund = "IncludeRefund",
            .include_credit = "IncludeCredit",
            .include_upfront = "IncludeUpfront",
            .include_recurring = "IncludeRecurring",
            .include_other_subscription = "IncludeOtherSubscription",
            .include_support = "IncludeSupport",
            .include_discount = "IncludeDiscount",
            .use_amortized = "UseAmortized",
        };
        return @field(mappings, field_name);
    }
};
