const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-04-20";
pub const sdk_id: []const u8 = "Chime SDK Identity";
pub const arn_namespace: ?[]const u8 = "chime";
pub const endpoint_prefix: []const u8 = "identity-chime";
pub const sigv4_name: []const u8 = "chime";
pub const name: []const u8 = "ChimeIdentityService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-04-20",
    sdk_id: []const u8 = "Chime SDK Identity",
    arn_namespace: ?[]const u8 = "chime",
    endpoint_prefix: []const u8 = "identity-chime",
    sigv4_name: []const u8 = "chime",
    name: []const u8 = "ChimeIdentityService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_app_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/app-instances",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppInstance",
    Request: type = struct {
        name: []const u8,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_app_instance };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_app_instance_admin: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/app-instances/{AppInstanceArn}/admins",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppInstanceAdmin",
    Request: type = struct {
        app_instance_admin_arn: []const u8,
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin_arn = "AppInstanceAdminArn",
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_instance_admin) } {
            return .{ .service_metadata = service_metadata, .action = create_app_instance_admin };
        }
    },
    Response: type = struct {
        app_instance_admin: ?Identity = null,
        app_instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin = "AppInstanceAdmin",
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_app_instance_bot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/app-instance-bots",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppInstanceBot",
    Request: type = struct {
        app_instance_arn: []const u8,
        name: ?[]const u8 = null,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]Tag = null,
        configuration: Configuration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .name = "Name",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_instance_bot) } {
            return .{ .service_metadata = service_metadata, .action = create_app_instance_bot };
        }
    },
    Response: type = struct {
        app_instance_bot_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_bot_arn = "AppInstanceBotArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_app_instance_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/app-instance-users",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppInstanceUser",
    Request: type = struct {
        app_instance_arn: []const u8,
        app_instance_user_id: []const u8,
        name: []const u8,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]Tag = null,
        expiration_settings: ?ExpirationSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_user_id = "AppInstanceUserId",
                .name = "Name",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .expiration_settings = "ExpirationSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = create_app_instance_user };
        }
    },
    Response: type = struct {
        app_instance_user_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_app_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instances/{AppInstanceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppInstance",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_instance };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_app_instance_admin: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instances/{AppInstanceArn}/admins/{AppInstanceAdminArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppInstanceAdmin",
    Request: type = struct {
        app_instance_admin_arn: []const u8,
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin_arn = "AppInstanceAdminArn",
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_instance_admin) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_instance_admin };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_app_instance_bot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instance-bots/{AppInstanceBotArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppInstanceBot",
    Request: type = struct {
        app_instance_bot_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_bot_arn = "AppInstanceBotArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_instance_bot) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_instance_bot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_app_instance_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instance-users/{AppInstanceUserArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_instance_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const deregister_app_instance_user_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instance-users/{AppInstanceUserArn}/endpoints/{EndpointId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeregisterAppInstanceUserEndpoint",
    Request: type = struct {
        app_instance_user_arn: []const u8,
        endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .endpoint_id = "EndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_app_instance_user_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = deregister_app_instance_user_endpoint };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_app_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppInstance",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_instance) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_instance };
        }
    },
    Response: type = struct {
        app_instance: ?struct {
            app_instance_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_arn = "AppInstanceArn",
                    .name = "Name",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance = "AppInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_app_instance_admin: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}/admins/{AppInstanceAdminArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppInstanceAdmin",
    Request: type = struct {
        app_instance_admin_arn: []const u8,
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin_arn = "AppInstanceAdminArn",
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_instance_admin) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_instance_admin };
        }
    },
    Response: type = struct {
        app_instance_admin: ?struct {
            admin: ?Identity = null,
            app_instance_arn: ?[]const u8 = null,
            created_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .admin = "Admin",
                    .app_instance_arn = "AppInstanceArn",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin = "AppInstanceAdmin",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_app_instance_bot: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instance-bots/{AppInstanceBotArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppInstanceBot",
    Request: type = struct {
        app_instance_bot_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_bot_arn = "AppInstanceBotArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_instance_bot) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_instance_bot };
        }
    },
    Response: type = struct {
        app_instance_bot: ?struct {
            app_instance_bot_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            configuration: ?Configuration = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_bot_arn = "AppInstanceBotArn",
                    .name = "Name",
                    .configuration = "Configuration",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_bot = "AppInstanceBot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instance-users/{AppInstanceUserArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_instance_user };
        }
    },
    Response: type = struct {
        app_instance_user: ?struct {
            app_instance_user_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            expiration_settings: ?ExpirationSettings = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_user_arn = "AppInstanceUserArn",
                    .name = "Name",
                    .metadata = "Metadata",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .expiration_settings = "ExpirationSettings",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user = "AppInstanceUser",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_app_instance_user_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instance-users/{AppInstanceUserArn}/endpoints/{EndpointId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppInstanceUserEndpoint",
    Request: type = struct {
        app_instance_user_arn: []const u8,
        endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .endpoint_id = "EndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_instance_user_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_instance_user_endpoint };
        }
    },
    Response: type = struct {
        app_instance_user_endpoint: ?struct {
            app_instance_user_arn: ?[]const u8 = null,
            endpoint_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            endpoint_attributes: ?EndpointAttributes = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            allow_messages: ?[]const u8 = null,
            endpoint_state: ?EndpointState = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_user_arn = "AppInstanceUserArn",
                    .endpoint_id = "EndpointId",
                    .name = "Name",
                    .type = "Type",
                    .resource_arn = "ResourceArn",
                    .endpoint_attributes = "EndpointAttributes",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .allow_messages = "AllowMessages",
                    .endpoint_state = "EndpointState",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_endpoint = "AppInstanceUserEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_app_instance_retention_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}/retention-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAppInstanceRetentionSettings",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_instance_retention_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_app_instance_retention_settings };
        }
    },
    Response: type = struct {
        app_instance_retention_settings: ?AppInstanceRetentionSettings = null,
        initiate_deletion_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_retention_settings = "AppInstanceRetentionSettings",
                .initiate_deletion_timestamp = "InitiateDeletionTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_app_instance_admins: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}/admins",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInstanceAdmins",
    Request: type = struct {
        app_instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_instance_admins) } {
            return .{ .service_metadata = service_metadata, .action = list_app_instance_admins };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,
        app_instance_admins: ?[]struct {
            admin: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .admin = "Admin",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_admins = "AppInstanceAdmins",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_app_instance_bots: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instance-bots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInstanceBots",
    Request: type = struct {
        app_instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_arn = "app-instance-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_instance_bots) } {
            return .{ .service_metadata = service_metadata, .action = list_app_instance_bots };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,
        app_instance_bots: ?[]struct {
            app_instance_bot_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_bot_arn = "AppInstanceBotArn",
                    .name = "Name",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_bots = "AppInstanceBots",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_app_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInstances",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_app_instances };
        }
    },
    Response: type = struct {
        app_instances: ?[]struct {
            app_instance_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_arn = "AppInstanceArn",
                    .name = "Name",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instances = "AppInstances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_app_instance_user_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instance-users/{AppInstanceUserArn}/endpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInstanceUserEndpoints",
    Request: type = struct {
        app_instance_user_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_instance_user_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_app_instance_user_endpoints };
        }
    },
    Response: type = struct {
        app_instance_user_endpoints: ?[]struct {
            app_instance_user_arn: ?[]const u8 = null,
            endpoint_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            allow_messages: ?[]const u8 = null,
            endpoint_state: ?EndpointState = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_user_arn = "AppInstanceUserArn",
                    .endpoint_id = "EndpointId",
                    .name = "Name",
                    .type = "Type",
                    .allow_messages = "AllowMessages",
                    .endpoint_state = "EndpointState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_endpoints = "AppInstanceUserEndpoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_app_instance_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instance-users",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInstanceUsers",
    Request: type = struct {
        app_instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_arn = "app-instance-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_instance_users) } {
            return .{ .service_metadata = service_metadata, .action = list_app_instance_users };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,
        app_instance_users: ?[]struct {
            app_instance_user_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_user_arn = "AppInstanceUserArn",
                    .name = "Name",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_users = "AppInstanceUsers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_app_instance_retention_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instances/{AppInstanceArn}/retention-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAppInstanceRetentionSettings",
    Request: type = struct {
        app_instance_arn: []const u8,
        app_instance_retention_settings: AppInstanceRetentionSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_retention_settings = "AppInstanceRetentionSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_app_instance_retention_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_app_instance_retention_settings };
        }
    },
    Response: type = struct {
        app_instance_retention_settings: ?AppInstanceRetentionSettings = null,
        initiate_deletion_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_retention_settings = "AppInstanceRetentionSettings",
                .initiate_deletion_timestamp = "InitiateDeletionTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_app_instance_user_expiration_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instance-users/{AppInstanceUserArn}/expiration-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAppInstanceUserExpirationSettings",
    Request: type = struct {
        app_instance_user_arn: []const u8,
        expiration_settings: ?ExpirationSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .expiration_settings = "ExpirationSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_app_instance_user_expiration_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_app_instance_user_expiration_settings };
        }
    },
    Response: type = struct {
        app_instance_user_arn: ?[]const u8 = null,
        expiration_settings: ?ExpirationSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .expiration_settings = "ExpirationSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const register_app_instance_user_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/app-instance-users/{AppInstanceUserArn}/endpoints",
        .success_code = 201,
    };

    action_name: []const u8 = "RegisterAppInstanceUserEndpoint",
    Request: type = struct {
        app_instance_user_arn: []const u8,
        name: ?[]const u8 = null,
        type: []const u8,
        resource_arn: []const u8,
        endpoint_attributes: EndpointAttributes,
        client_request_token: []const u8,
        allow_messages: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .name = "Name",
                .type = "Type",
                .resource_arn = "ResourceArn",
                .endpoint_attributes = "EndpointAttributes",
                .client_request_token = "ClientRequestToken",
                .allow_messages = "AllowMessages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_app_instance_user_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = register_app_instance_user_endpoint };
        }
    },
    Response: type = struct {
        app_instance_user_arn: ?[]const u8 = null,
        endpoint_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .endpoint_id = "EndpointId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=tag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=untag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_app_instance: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instances/{AppInstanceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppInstance",
    Request: type = struct {
        app_instance_arn: []const u8,
        name: []const u8,
        metadata: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .name = "Name",
                .metadata = "Metadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_instance) } {
            return .{ .service_metadata = service_metadata, .action = update_app_instance };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_app_instance_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instance-bots/{AppInstanceBotArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppInstanceBot",
    Request: type = struct {
        app_instance_bot_arn: []const u8,
        name: []const u8,
        metadata: []const u8,
        configuration: ?Configuration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_bot_arn = "AppInstanceBotArn",
                .name = "Name",
                .metadata = "Metadata",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_instance_bot) } {
            return .{ .service_metadata = service_metadata, .action = update_app_instance_bot };
        }
    },
    Response: type = struct {
        app_instance_bot_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_bot_arn = "AppInstanceBotArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_app_instance_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instance-users/{AppInstanceUserArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: []const u8,
        name: []const u8,
        metadata: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .name = "Name",
                .metadata = "Metadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = update_app_instance_user };
        }
    },
    Response: type = struct {
        app_instance_user_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_app_instance_user_endpoint: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instance-users/{AppInstanceUserArn}/endpoints/{EndpointId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppInstanceUserEndpoint",
    Request: type = struct {
        app_instance_user_arn: []const u8,
        endpoint_id: []const u8,
        name: ?[]const u8 = null,
        allow_messages: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .endpoint_id = "EndpointId",
                .name = "Name",
                .allow_messages = "AllowMessages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_instance_user_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_app_instance_user_endpoint };
        }
    },
    Response: type = struct {
        app_instance_user_arn: ?[]const u8 = null,
        endpoint_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .endpoint_id = "EndpointId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};

pub const Configuration = struct {
    lex: LexConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lex = "Lex",
        };
        return @field(mappings, field_name);
    }
};

pub const LexConfiguration = struct {
    responds_to: ?[]const u8 = null,
    invoked_by: ?InvokedBy = null,
    lex_bot_alias_arn: []const u8,
    locale_id: []const u8,
    welcome_intent: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .responds_to = "RespondsTo",
            .invoked_by = "InvokedBy",
            .lex_bot_alias_arn = "LexBotAliasArn",
            .locale_id = "LocaleId",
            .welcome_intent = "WelcomeIntent",
        };
        return @field(mappings, field_name);
    }
};

pub const InvokedBy = struct {
    standard_messages: []const u8,
    targeted_messages: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standard_messages = "StandardMessages",
            .targeted_messages = "TargetedMessages",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointAttributes = struct {
    device_token: []const u8,
    voip_device_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_token = "DeviceToken",
            .voip_device_token = "VoipDeviceToken",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpirationSettings = struct {
    expiration_days: i64,
    expiration_criterion: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expiration_days = "ExpirationDays",
            .expiration_criterion = "ExpirationCriterion",
        };
        return @field(mappings, field_name);
    }
};

pub const AppInstanceRetentionSettings = struct {
    channel_retention_settings: ?ChannelRetentionSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_retention_settings = "ChannelRetentionSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelRetentionSettings = struct {
    retention_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retention_days = "RetentionDays",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointState = struct {
    status: []const u8,
    status_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .status_reason = "StatusReason",
        };
        return @field(mappings, field_name);
    }
};

pub const Identity = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};
