const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-07-15";
pub const sdk_id: []const u8 = "Chime SDK Media Pipelines";
pub const arn_namespace: ?[]const u8 = "chime";
pub const endpoint_prefix: []const u8 = "media-pipelines-chime";
pub const sigv4_name: []const u8 = "chime";
pub const name: []const u8 = "ChimeSDKMediaPipelinesService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-07-15",
    sdk_id: []const u8 = "Chime SDK Media Pipelines",
    arn_namespace: ?[]const u8 = "chime",
    endpoint_prefix: []const u8 = "media-pipelines-chime",
    sigv4_name: []const u8 = "chime",
    name: []const u8 = "ChimeSDKMediaPipelinesService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_media_capture_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sdk-media-capture-pipelines",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMediaCapturePipeline",
    Request: type = struct {
        source_type: []const u8,
        source_arn: []const u8,
        sink_type: []const u8,
        sink_arn: []const u8,
        client_request_token: ?[]const u8 = null,
        chime_sdk_meeting_configuration: ?ChimeSdkMeetingConfiguration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_type = "SourceType",
                .source_arn = "SourceArn",
                .sink_type = "SinkType",
                .sink_arn = "SinkArn",
                .client_request_token = "ClientRequestToken",
                .chime_sdk_meeting_configuration = "ChimeSdkMeetingConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_media_capture_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_media_capture_pipeline };
        }
    },
    Response: type = struct {
        media_capture_pipeline: ?MediaCapturePipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_capture_pipeline = "MediaCapturePipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_media_concatenation_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sdk-media-concatenation-pipelines",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMediaConcatenationPipeline",
    Request: type = struct {
        sources: []ConcatenationSource,
        sinks: []ConcatenationSink,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sources = "Sources",
                .sinks = "Sinks",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_media_concatenation_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_media_concatenation_pipeline };
        }
    },
    Response: type = struct {
        media_concatenation_pipeline: ?MediaConcatenationPipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_concatenation_pipeline = "MediaConcatenationPipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_media_insights_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/media-insights-pipelines",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMediaInsightsPipeline",
    Request: type = struct {
        media_insights_pipeline_configuration_arn: []const u8,
        kinesis_video_stream_source_runtime_configuration: ?KinesisVideoStreamSourceRuntimeConfiguration = null,
        media_insights_runtime_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        kinesis_video_stream_recording_source_runtime_configuration: ?KinesisVideoStreamRecordingSourceRuntimeConfiguration = null,
        s3_recording_sink_runtime_configuration: ?S3RecordingSinkRuntimeConfiguration = null,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_insights_pipeline_configuration_arn = "MediaInsightsPipelineConfigurationArn",
                .kinesis_video_stream_source_runtime_configuration = "KinesisVideoStreamSourceRuntimeConfiguration",
                .media_insights_runtime_metadata = "MediaInsightsRuntimeMetadata",
                .kinesis_video_stream_recording_source_runtime_configuration = "KinesisVideoStreamRecordingSourceRuntimeConfiguration",
                .s3_recording_sink_runtime_configuration = "S3RecordingSinkRuntimeConfiguration",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "media_insights_runtime_metadata", field_name))
                return try serializeMap(self.media_insights_runtime_metadata, self.fieldNameFor("media_insights_runtime_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_media_insights_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_media_insights_pipeline };
        }
    },
    Response: type = struct {
        media_insights_pipeline: MediaInsightsPipeline,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_insights_pipeline = "MediaInsightsPipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_media_insights_pipeline_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/media-insights-pipeline-configurations",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMediaInsightsPipelineConfiguration",
    Request: type = struct {
        media_insights_pipeline_configuration_name: []const u8,
        resource_access_role_arn: []const u8,
        real_time_alert_configuration: ?RealTimeAlertConfiguration = null,
        elements: []MediaInsightsPipelineConfigurationElement,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_insights_pipeline_configuration_name = "MediaInsightsPipelineConfigurationName",
                .resource_access_role_arn = "ResourceAccessRoleArn",
                .real_time_alert_configuration = "RealTimeAlertConfiguration",
                .elements = "Elements",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_media_insights_pipeline_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_media_insights_pipeline_configuration };
        }
    },
    Response: type = struct {
        media_insights_pipeline_configuration: ?MediaInsightsPipelineConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_insights_pipeline_configuration = "MediaInsightsPipelineConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_media_live_connector_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sdk-media-live-connector-pipelines",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMediaLiveConnectorPipeline",
    Request: type = struct {
        sources: []LiveConnectorSourceConfiguration,
        sinks: []LiveConnectorSinkConfiguration,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sources = "Sources",
                .sinks = "Sinks",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_media_live_connector_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_media_live_connector_pipeline };
        }
    },
    Response: type = struct {
        media_live_connector_pipeline: ?MediaLiveConnectorPipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_live_connector_pipeline = "MediaLiveConnectorPipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_media_pipeline_kinesis_video_stream_pool: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/media-pipeline-kinesis-video-stream-pools",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMediaPipelineKinesisVideoStreamPool",
    Request: type = struct {
        stream_configuration: KinesisVideoStreamConfiguration,
        pool_name: []const u8,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_configuration = "StreamConfiguration",
                .pool_name = "PoolName",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_media_pipeline_kinesis_video_stream_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_media_pipeline_kinesis_video_stream_pool };
        }
    },
    Response: type = struct {
        kinesis_video_stream_pool_configuration: ?KinesisVideoStreamPoolConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kinesis_video_stream_pool_configuration = "KinesisVideoStreamPoolConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_media_stream_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sdk-media-stream-pipelines",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMediaStreamPipeline",
    Request: type = struct {
        sources: []MediaStreamSource,
        sinks: []MediaStreamSink,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sources = "Sources",
                .sinks = "Sinks",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_media_stream_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_media_stream_pipeline };
        }
    },
    Response: type = struct {
        media_stream_pipeline: ?MediaStreamPipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_stream_pipeline = "MediaStreamPipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_media_capture_pipeline: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sdk-media-capture-pipelines/{MediaPipelineId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMediaCapturePipeline",
    Request: type = struct {
        media_pipeline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_pipeline_id = "MediaPipelineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_media_capture_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_media_capture_pipeline };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_media_insights_pipeline_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/media-insights-pipeline-configurations/{Identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMediaInsightsPipelineConfiguration",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_media_insights_pipeline_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_media_insights_pipeline_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_media_pipeline: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sdk-media-pipelines/{MediaPipelineId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMediaPipeline",
    Request: type = struct {
        media_pipeline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_pipeline_id = "MediaPipelineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_media_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_media_pipeline };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_media_pipeline_kinesis_video_stream_pool: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/media-pipeline-kinesis-video-stream-pools/{Identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMediaPipelineKinesisVideoStreamPool",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_media_pipeline_kinesis_video_stream_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_media_pipeline_kinesis_video_stream_pool };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_media_capture_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sdk-media-capture-pipelines/{MediaPipelineId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMediaCapturePipeline",
    Request: type = struct {
        media_pipeline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_pipeline_id = "MediaPipelineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_media_capture_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = get_media_capture_pipeline };
        }
    },
    Response: type = struct {
        media_capture_pipeline: ?MediaCapturePipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_capture_pipeline = "MediaCapturePipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_media_insights_pipeline_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/media-insights-pipeline-configurations/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMediaInsightsPipelineConfiguration",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_media_insights_pipeline_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_media_insights_pipeline_configuration };
        }
    },
    Response: type = struct {
        media_insights_pipeline_configuration: ?MediaInsightsPipelineConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_insights_pipeline_configuration = "MediaInsightsPipelineConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_media_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sdk-media-pipelines/{MediaPipelineId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMediaPipeline",
    Request: type = struct {
        media_pipeline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_pipeline_id = "MediaPipelineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_media_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = get_media_pipeline };
        }
    },
    Response: type = struct {
        media_pipeline: ?struct {
            media_capture_pipeline: ?MediaCapturePipeline = null,
            media_live_connector_pipeline: ?MediaLiveConnectorPipeline = null,
            media_concatenation_pipeline: ?MediaConcatenationPipeline = null,
            media_insights_pipeline: ?MediaInsightsPipeline = null,
            media_stream_pipeline: ?MediaStreamPipeline = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .media_capture_pipeline = "MediaCapturePipeline",
                    .media_live_connector_pipeline = "MediaLiveConnectorPipeline",
                    .media_concatenation_pipeline = "MediaConcatenationPipeline",
                    .media_insights_pipeline = "MediaInsightsPipeline",
                    .media_stream_pipeline = "MediaStreamPipeline",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_pipeline = "MediaPipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_media_pipeline_kinesis_video_stream_pool: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/media-pipeline-kinesis-video-stream-pools/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMediaPipelineKinesisVideoStreamPool",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_media_pipeline_kinesis_video_stream_pool) } {
            return .{ .service_metadata = service_metadata, .action = get_media_pipeline_kinesis_video_stream_pool };
        }
    },
    Response: type = struct {
        kinesis_video_stream_pool_configuration: ?KinesisVideoStreamPoolConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kinesis_video_stream_pool_configuration = "KinesisVideoStreamPoolConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_speaker_search_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/media-insights-pipelines/{Identifier}/speaker-search-tasks/{SpeakerSearchTaskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSpeakerSearchTask",
    Request: type = struct {
        identifier: []const u8,
        speaker_search_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .speaker_search_task_id = "SpeakerSearchTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_speaker_search_task) } {
            return .{ .service_metadata = service_metadata, .action = get_speaker_search_task };
        }
    },
    Response: type = struct {
        speaker_search_task: ?SpeakerSearchTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .speaker_search_task = "SpeakerSearchTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_tone_analysis_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/media-insights-pipelines/{Identifier}/voice-tone-analysis-tasks/{VoiceToneAnalysisTaskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceToneAnalysisTask",
    Request: type = struct {
        identifier: []const u8,
        voice_tone_analysis_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .voice_tone_analysis_task_id = "VoiceToneAnalysisTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_tone_analysis_task) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_tone_analysis_task };
        }
    },
    Response: type = struct {
        voice_tone_analysis_task: ?VoiceToneAnalysisTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_tone_analysis_task = "VoiceToneAnalysisTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_media_capture_pipelines: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sdk-media-capture-pipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMediaCapturePipelines",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_media_capture_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_media_capture_pipelines };
        }
    },
    Response: type = struct {
        media_capture_pipelines: ?[]struct {
            media_pipeline_id: ?[]const u8 = null,
            media_pipeline_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .media_pipeline_id = "MediaPipelineId",
                    .media_pipeline_arn = "MediaPipelineArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_capture_pipelines = "MediaCapturePipelines",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_media_insights_pipeline_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/media-insights-pipeline-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMediaInsightsPipelineConfigurations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_media_insights_pipeline_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_media_insights_pipeline_configurations };
        }
    },
    Response: type = struct {
        media_insights_pipeline_configurations: ?[]struct {
            media_insights_pipeline_configuration_name: ?[]const u8 = null,
            media_insights_pipeline_configuration_id: ?[]const u8 = null,
            media_insights_pipeline_configuration_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .media_insights_pipeline_configuration_name = "MediaInsightsPipelineConfigurationName",
                    .media_insights_pipeline_configuration_id = "MediaInsightsPipelineConfigurationId",
                    .media_insights_pipeline_configuration_arn = "MediaInsightsPipelineConfigurationArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_insights_pipeline_configurations = "MediaInsightsPipelineConfigurations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_media_pipeline_kinesis_video_stream_pools: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/media-pipeline-kinesis-video-stream-pools",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMediaPipelineKinesisVideoStreamPools",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_media_pipeline_kinesis_video_stream_pools) } {
            return .{ .service_metadata = service_metadata, .action = list_media_pipeline_kinesis_video_stream_pools };
        }
    },
    Response: type = struct {
        kinesis_video_stream_pools: ?[]struct {
            pool_name: ?[]const u8 = null,
            pool_id: ?[]const u8 = null,
            pool_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pool_name = "PoolName",
                    .pool_id = "PoolId",
                    .pool_arn = "PoolArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kinesis_video_stream_pools = "KinesisVideoStreamPools",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_media_pipelines: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sdk-media-pipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMediaPipelines",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_media_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_media_pipelines };
        }
    },
    Response: type = struct {
        media_pipelines: ?[]struct {
            media_pipeline_id: ?[]const u8 = null,
            media_pipeline_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .media_pipeline_id = "MediaPipelineId",
                    .media_pipeline_arn = "MediaPipelineArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_pipelines = "MediaPipelines",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const start_speaker_search_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/media-insights-pipelines/{Identifier}/speaker-search-tasks?operation=start",
        .success_code = 201,
    };

    action_name: []const u8 = "StartSpeakerSearchTask",
    Request: type = struct {
        identifier: []const u8,
        voice_profile_domain_arn: []const u8,
        kinesis_video_stream_source_task_configuration: ?KinesisVideoStreamSourceTaskConfiguration = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .voice_profile_domain_arn = "VoiceProfileDomainArn",
                .kinesis_video_stream_source_task_configuration = "KinesisVideoStreamSourceTaskConfiguration",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_speaker_search_task) } {
            return .{ .service_metadata = service_metadata, .action = start_speaker_search_task };
        }
    },
    Response: type = struct {
        speaker_search_task: ?SpeakerSearchTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .speaker_search_task = "SpeakerSearchTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const start_voice_tone_analysis_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/media-insights-pipelines/{Identifier}/voice-tone-analysis-tasks?operation=start",
        .success_code = 201,
    };

    action_name: []const u8 = "StartVoiceToneAnalysisTask",
    Request: type = struct {
        identifier: []const u8,
        language_code: []const u8,
        kinesis_video_stream_source_task_configuration: ?KinesisVideoStreamSourceTaskConfiguration = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .language_code = "LanguageCode",
                .kinesis_video_stream_source_task_configuration = "KinesisVideoStreamSourceTaskConfiguration",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_voice_tone_analysis_task) } {
            return .{ .service_metadata = service_metadata, .action = start_voice_tone_analysis_task };
        }
    },
    Response: type = struct {
        voice_tone_analysis_task: ?VoiceToneAnalysisTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_tone_analysis_task = "VoiceToneAnalysisTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const stop_speaker_search_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/media-insights-pipelines/{Identifier}/speaker-search-tasks/{SpeakerSearchTaskId}?operation=stop",
        .success_code = 204,
    };

    action_name: []const u8 = "StopSpeakerSearchTask",
    Request: type = struct {
        identifier: []const u8,
        speaker_search_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .speaker_search_task_id = "SpeakerSearchTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_speaker_search_task) } {
            return .{ .service_metadata = service_metadata, .action = stop_speaker_search_task };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const stop_voice_tone_analysis_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/media-insights-pipelines/{Identifier}/voice-tone-analysis-tasks/{VoiceToneAnalysisTaskId}?operation=stop",
        .success_code = 204,
    };

    action_name: []const u8 = "StopVoiceToneAnalysisTask",
    Request: type = struct {
        identifier: []const u8,
        voice_tone_analysis_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .voice_tone_analysis_task_id = "VoiceToneAnalysisTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_voice_tone_analysis_task) } {
            return .{ .service_metadata = service_metadata, .action = stop_voice_tone_analysis_task };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=tag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=untag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_media_insights_pipeline_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/media-insights-pipeline-configurations/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMediaInsightsPipelineConfiguration",
    Request: type = struct {
        identifier: []const u8,
        resource_access_role_arn: []const u8,
        real_time_alert_configuration: ?RealTimeAlertConfiguration = null,
        elements: []MediaInsightsPipelineConfigurationElement,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .resource_access_role_arn = "ResourceAccessRoleArn",
                .real_time_alert_configuration = "RealTimeAlertConfiguration",
                .elements = "Elements",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_media_insights_pipeline_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_media_insights_pipeline_configuration };
        }
    },
    Response: type = struct {
        media_insights_pipeline_configuration: ?MediaInsightsPipelineConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_insights_pipeline_configuration = "MediaInsightsPipelineConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_media_insights_pipeline_status: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/media-insights-pipeline-status/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMediaInsightsPipelineStatus",
    Request: type = struct {
        identifier: []const u8,
        update_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .update_status = "UpdateStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_media_insights_pipeline_status) } {
            return .{ .service_metadata = service_metadata, .action = update_media_insights_pipeline_status };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_media_pipeline_kinesis_video_stream_pool: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/media-pipeline-kinesis-video-stream-pools/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMediaPipelineKinesisVideoStreamPool",
    Request: type = struct {
        identifier: []const u8,
        stream_configuration: ?struct {
            data_retention_in_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_retention_in_hours = "DataRetentionInHours",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .stream_configuration = "StreamConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_media_pipeline_kinesis_video_stream_pool) } {
            return .{ .service_metadata = service_metadata, .action = update_media_pipeline_kinesis_video_stream_pool };
        }
    },
    Response: type = struct {
        kinesis_video_stream_pool_configuration: ?KinesisVideoStreamPoolConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kinesis_video_stream_pool_configuration = "KinesisVideoStreamPoolConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};

pub const KinesisVideoStreamPoolConfiguration = struct {
    pool_arn: ?[]const u8 = null,
    pool_name: ?[]const u8 = null,
    pool_id: ?[]const u8 = null,
    pool_status: ?[]const u8 = null,
    pool_size: ?i64 = null,
    stream_configuration: ?KinesisVideoStreamConfiguration = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pool_arn = "PoolArn",
            .pool_name = "PoolName",
            .pool_id = "PoolId",
            .pool_status = "PoolStatus",
            .pool_size = "PoolSize",
            .stream_configuration = "StreamConfiguration",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisVideoStreamConfiguration = struct {
    region: []const u8,
    data_retention_in_hours: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "Region",
            .data_retention_in_hours = "DataRetentionInHours",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaInsightsPipelineConfiguration = struct {
    media_insights_pipeline_configuration_name: ?[]const u8 = null,
    media_insights_pipeline_configuration_arn: ?[]const u8 = null,
    resource_access_role_arn: ?[]const u8 = null,
    real_time_alert_configuration: ?RealTimeAlertConfiguration = null,
    elements: ?[]MediaInsightsPipelineConfigurationElement = null,
    media_insights_pipeline_configuration_id: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_insights_pipeline_configuration_name = "MediaInsightsPipelineConfigurationName",
            .media_insights_pipeline_configuration_arn = "MediaInsightsPipelineConfigurationArn",
            .resource_access_role_arn = "ResourceAccessRoleArn",
            .real_time_alert_configuration = "RealTimeAlertConfiguration",
            .elements = "Elements",
            .media_insights_pipeline_configuration_id = "MediaInsightsPipelineConfigurationId",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaInsightsPipelineConfigurationElement = struct {
    type: []const u8,
    amazon_transcribe_call_analytics_processor_configuration: ?AmazonTranscribeCallAnalyticsProcessorConfiguration = null,
    amazon_transcribe_processor_configuration: ?AmazonTranscribeProcessorConfiguration = null,
    kinesis_data_stream_sink_configuration: ?KinesisDataStreamSinkConfiguration = null,
    s3_recording_sink_configuration: ?S3RecordingSinkConfiguration = null,
    voice_analytics_processor_configuration: ?VoiceAnalyticsProcessorConfiguration = null,
    lambda_function_sink_configuration: ?LambdaFunctionSinkConfiguration = null,
    sqs_queue_sink_configuration: ?SqsQueueSinkConfiguration = null,
    sns_topic_sink_configuration: ?SnsTopicSinkConfiguration = null,
    voice_enhancement_sink_configuration: ?VoiceEnhancementSinkConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .amazon_transcribe_call_analytics_processor_configuration = "AmazonTranscribeCallAnalyticsProcessorConfiguration",
            .amazon_transcribe_processor_configuration = "AmazonTranscribeProcessorConfiguration",
            .kinesis_data_stream_sink_configuration = "KinesisDataStreamSinkConfiguration",
            .s3_recording_sink_configuration = "S3RecordingSinkConfiguration",
            .voice_analytics_processor_configuration = "VoiceAnalyticsProcessorConfiguration",
            .lambda_function_sink_configuration = "LambdaFunctionSinkConfiguration",
            .sqs_queue_sink_configuration = "SqsQueueSinkConfiguration",
            .sns_topic_sink_configuration = "SnsTopicSinkConfiguration",
            .voice_enhancement_sink_configuration = "VoiceEnhancementSinkConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceEnhancementSinkConfiguration = struct {
    disabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disabled = "Disabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsTopicSinkConfiguration = struct {
    insights_target: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insights_target = "InsightsTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const SqsQueueSinkConfiguration = struct {
    insights_target: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insights_target = "InsightsTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionSinkConfiguration = struct {
    insights_target: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insights_target = "InsightsTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceAnalyticsProcessorConfiguration = struct {
    speaker_search_status: ?[]const u8 = null,
    voice_tone_analysis_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .speaker_search_status = "SpeakerSearchStatus",
            .voice_tone_analysis_status = "VoiceToneAnalysisStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const S3RecordingSinkConfiguration = struct {
    destination: ?[]const u8 = null,
    recording_file_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
            .recording_file_format = "RecordingFileFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisDataStreamSinkConfiguration = struct {
    insights_target: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insights_target = "InsightsTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonTranscribeProcessorConfiguration = struct {
    language_code: ?[]const u8 = null,
    vocabulary_name: ?[]const u8 = null,
    vocabulary_filter_name: ?[]const u8 = null,
    vocabulary_filter_method: ?[]const u8 = null,
    show_speaker_label: ?bool = null,
    enable_partial_results_stabilization: ?bool = null,
    partial_results_stability: ?[]const u8 = null,
    content_identification_type: ?[]const u8 = null,
    content_redaction_type: ?[]const u8 = null,
    pii_entity_types: ?[]const u8 = null,
    language_model_name: ?[]const u8 = null,
    filter_partial_results: ?bool = null,
    identify_language: ?bool = null,
    language_options: ?[]const u8 = null,
    preferred_language: ?[]const u8 = null,
    vocabulary_names: ?[]const u8 = null,
    vocabulary_filter_names: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .language_code = "LanguageCode",
            .vocabulary_name = "VocabularyName",
            .vocabulary_filter_name = "VocabularyFilterName",
            .vocabulary_filter_method = "VocabularyFilterMethod",
            .show_speaker_label = "ShowSpeakerLabel",
            .enable_partial_results_stabilization = "EnablePartialResultsStabilization",
            .partial_results_stability = "PartialResultsStability",
            .content_identification_type = "ContentIdentificationType",
            .content_redaction_type = "ContentRedactionType",
            .pii_entity_types = "PiiEntityTypes",
            .language_model_name = "LanguageModelName",
            .filter_partial_results = "FilterPartialResults",
            .identify_language = "IdentifyLanguage",
            .language_options = "LanguageOptions",
            .preferred_language = "PreferredLanguage",
            .vocabulary_names = "VocabularyNames",
            .vocabulary_filter_names = "VocabularyFilterNames",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonTranscribeCallAnalyticsProcessorConfiguration = struct {
    language_code: []const u8,
    vocabulary_name: ?[]const u8 = null,
    vocabulary_filter_name: ?[]const u8 = null,
    vocabulary_filter_method: ?[]const u8 = null,
    language_model_name: ?[]const u8 = null,
    enable_partial_results_stabilization: ?bool = null,
    partial_results_stability: ?[]const u8 = null,
    content_identification_type: ?[]const u8 = null,
    content_redaction_type: ?[]const u8 = null,
    pii_entity_types: ?[]const u8 = null,
    filter_partial_results: ?bool = null,
    post_call_analytics_settings: ?PostCallAnalyticsSettings = null,
    call_analytics_stream_categories: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .language_code = "LanguageCode",
            .vocabulary_name = "VocabularyName",
            .vocabulary_filter_name = "VocabularyFilterName",
            .vocabulary_filter_method = "VocabularyFilterMethod",
            .language_model_name = "LanguageModelName",
            .enable_partial_results_stabilization = "EnablePartialResultsStabilization",
            .partial_results_stability = "PartialResultsStability",
            .content_identification_type = "ContentIdentificationType",
            .content_redaction_type = "ContentRedactionType",
            .pii_entity_types = "PiiEntityTypes",
            .filter_partial_results = "FilterPartialResults",
            .post_call_analytics_settings = "PostCallAnalyticsSettings",
            .call_analytics_stream_categories = "CallAnalyticsStreamCategories",
        };
        return @field(mappings, field_name);
    }
};

pub const PostCallAnalyticsSettings = struct {
    output_location: []const u8,
    data_access_role_arn: []const u8,
    content_redaction_output: ?[]const u8 = null,
    output_encryption_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_location = "OutputLocation",
            .data_access_role_arn = "DataAccessRoleArn",
            .content_redaction_output = "ContentRedactionOutput",
            .output_encryption_kms_key_id = "OutputEncryptionKMSKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const RealTimeAlertConfiguration = struct {
    disabled: ?bool = null,
    rules: ?[]RealTimeAlertRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disabled = "Disabled",
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const RealTimeAlertRule = struct {
    type: []const u8,
    keyword_match_configuration: ?KeywordMatchConfiguration = null,
    sentiment_configuration: ?SentimentConfiguration = null,
    issue_detection_configuration: ?IssueDetectionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .keyword_match_configuration = "KeywordMatchConfiguration",
            .sentiment_configuration = "SentimentConfiguration",
            .issue_detection_configuration = "IssueDetectionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IssueDetectionConfiguration = struct {
    rule_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_name = "RuleName",
        };
        return @field(mappings, field_name);
    }
};

pub const SentimentConfiguration = struct {
    rule_name: []const u8,
    sentiment_type: []const u8,
    time_period: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_name = "RuleName",
            .sentiment_type = "SentimentType",
            .time_period = "TimePeriod",
        };
        return @field(mappings, field_name);
    }
};

pub const KeywordMatchConfiguration = struct {
    rule_name: []const u8,
    keywords: [][]const u8,
    negate: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_name = "RuleName",
            .keywords = "Keywords",
            .negate = "Negate",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceToneAnalysisTask = struct {
    voice_tone_analysis_task_id: ?[]const u8 = null,
    voice_tone_analysis_task_status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_tone_analysis_task_id = "VoiceToneAnalysisTaskId",
            .voice_tone_analysis_task_status = "VoiceToneAnalysisTaskStatus",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisVideoStreamSourceTaskConfiguration = struct {
    stream_arn: []const u8,
    channel_id: i64,
    fragment_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_arn = "StreamArn",
            .channel_id = "ChannelId",
            .fragment_number = "FragmentNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const SpeakerSearchTask = struct {
    speaker_search_task_id: ?[]const u8 = null,
    speaker_search_task_status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .speaker_search_task_id = "SpeakerSearchTaskId",
            .speaker_search_task_status = "SpeakerSearchTaskStatus",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamPipeline = struct {
    media_pipeline_id: ?[]const u8 = null,
    media_pipeline_arn: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    status: ?[]const u8 = null,
    sources: ?[]MediaStreamSource = null,
    sinks: ?[]MediaStreamSink = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_pipeline_id = "MediaPipelineId",
            .media_pipeline_arn = "MediaPipelineArn",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .status = "Status",
            .sources = "Sources",
            .sinks = "Sinks",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamSink = struct {
    sink_arn: []const u8,
    sink_type: []const u8,
    reserved_stream_capacity: i64,
    media_stream_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sink_arn = "SinkArn",
            .sink_type = "SinkType",
            .reserved_stream_capacity = "ReservedStreamCapacity",
            .media_stream_type = "MediaStreamType",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamSource = struct {
    source_type: []const u8,
    source_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_type = "SourceType",
            .source_arn = "SourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaInsightsPipeline = struct {
    media_pipeline_id: ?[]const u8 = null,
    media_pipeline_arn: ?[]const u8 = null,
    media_insights_pipeline_configuration_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    kinesis_video_stream_source_runtime_configuration: ?KinesisVideoStreamSourceRuntimeConfiguration = null,
    media_insights_runtime_metadata: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    kinesis_video_stream_recording_source_runtime_configuration: ?KinesisVideoStreamRecordingSourceRuntimeConfiguration = null,
    s3_recording_sink_runtime_configuration: ?S3RecordingSinkRuntimeConfiguration = null,
    created_timestamp: ?i64 = null,
    element_statuses: ?[]MediaInsightsPipelineElementStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_pipeline_id = "MediaPipelineId",
            .media_pipeline_arn = "MediaPipelineArn",
            .media_insights_pipeline_configuration_arn = "MediaInsightsPipelineConfigurationArn",
            .status = "Status",
            .kinesis_video_stream_source_runtime_configuration = "KinesisVideoStreamSourceRuntimeConfiguration",
            .media_insights_runtime_metadata = "MediaInsightsRuntimeMetadata",
            .kinesis_video_stream_recording_source_runtime_configuration = "KinesisVideoStreamRecordingSourceRuntimeConfiguration",
            .s3_recording_sink_runtime_configuration = "S3RecordingSinkRuntimeConfiguration",
            .created_timestamp = "CreatedTimestamp",
            .element_statuses = "ElementStatuses",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "media_insights_runtime_metadata", field_name))
            return try serializeMap(self.media_insights_runtime_metadata, self.fieldNameFor("media_insights_runtime_metadata"), options, out_stream);
        return false;
    }
};

pub const MediaInsightsPipelineElementStatus = struct {
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const S3RecordingSinkRuntimeConfiguration = struct {
    destination: []const u8,
    recording_file_format: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
            .recording_file_format = "RecordingFileFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisVideoStreamRecordingSourceRuntimeConfiguration = struct {
    streams: []RecordingStreamConfiguration,
    fragment_selector: FragmentSelector,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .streams = "Streams",
            .fragment_selector = "FragmentSelector",
        };
        return @field(mappings, field_name);
    }
};

pub const FragmentSelector = struct {
    fragment_selector_type: []const u8,
    timestamp_range: TimestampRange,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fragment_selector_type = "FragmentSelectorType",
            .timestamp_range = "TimestampRange",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestampRange = struct {
    start_timestamp: i64,
    end_timestamp: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_timestamp = "StartTimestamp",
            .end_timestamp = "EndTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordingStreamConfiguration = struct {
    stream_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_arn = "StreamArn",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisVideoStreamSourceRuntimeConfiguration = struct {
    streams: []StreamConfiguration,
    media_encoding: []const u8,
    media_sample_rate: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .streams = "Streams",
            .media_encoding = "MediaEncoding",
            .media_sample_rate = "MediaSampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamConfiguration = struct {
    stream_arn: []const u8,
    fragment_number: ?[]const u8 = null,
    stream_channel_definition: StreamChannelDefinition,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_arn = "StreamArn",
            .fragment_number = "FragmentNumber",
            .stream_channel_definition = "StreamChannelDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamChannelDefinition = struct {
    number_of_channels: i64,
    channel_definitions: ?[]ChannelDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_channels = "NumberOfChannels",
            .channel_definitions = "ChannelDefinitions",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelDefinition = struct {
    channel_id: i64,
    participant_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_id = "ChannelId",
            .participant_role = "ParticipantRole",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaConcatenationPipeline = struct {
    media_pipeline_id: ?[]const u8 = null,
    media_pipeline_arn: ?[]const u8 = null,
    sources: ?[]ConcatenationSource = null,
    sinks: ?[]ConcatenationSink = null,
    status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_pipeline_id = "MediaPipelineId",
            .media_pipeline_arn = "MediaPipelineArn",
            .sources = "Sources",
            .sinks = "Sinks",
            .status = "Status",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const ConcatenationSink = struct {
    type: []const u8,
    s3_bucket_sink_configuration: S3BucketSinkConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .s3_bucket_sink_configuration = "S3BucketSinkConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketSinkConfiguration = struct {
    destination: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const ConcatenationSource = struct {
    type: []const u8,
    media_capture_pipeline_source_configuration: MediaCapturePipelineSourceConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .media_capture_pipeline_source_configuration = "MediaCapturePipelineSourceConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaCapturePipelineSourceConfiguration = struct {
    media_pipeline_arn: []const u8,
    chime_sdk_meeting_configuration: ChimeSdkMeetingConcatenationConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_pipeline_arn = "MediaPipelineArn",
            .chime_sdk_meeting_configuration = "ChimeSdkMeetingConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ChimeSdkMeetingConcatenationConfiguration = struct {
    artifacts_configuration: ArtifactsConcatenationConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .artifacts_configuration = "ArtifactsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactsConcatenationConfiguration = struct {
    audio: AudioConcatenationConfiguration,
    video: VideoConcatenationConfiguration,
    content: ContentConcatenationConfiguration,
    data_channel: DataChannelConcatenationConfiguration,
    transcription_messages: TranscriptionMessagesConcatenationConfiguration,
    meeting_events: MeetingEventsConcatenationConfiguration,
    composited_video: CompositedVideoConcatenationConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio = "Audio",
            .video = "Video",
            .content = "Content",
            .data_channel = "DataChannel",
            .transcription_messages = "TranscriptionMessages",
            .meeting_events = "MeetingEvents",
            .composited_video = "CompositedVideo",
        };
        return @field(mappings, field_name);
    }
};

pub const CompositedVideoConcatenationConfiguration = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const MeetingEventsConcatenationConfiguration = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const TranscriptionMessagesConcatenationConfiguration = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const DataChannelConcatenationConfiguration = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentConcatenationConfiguration = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoConcatenationConfiguration = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioConcatenationConfiguration = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaLiveConnectorPipeline = struct {
    sources: ?[]LiveConnectorSourceConfiguration = null,
    sinks: ?[]LiveConnectorSinkConfiguration = null,
    media_pipeline_id: ?[]const u8 = null,
    media_pipeline_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sources = "Sources",
            .sinks = "Sinks",
            .media_pipeline_id = "MediaPipelineId",
            .media_pipeline_arn = "MediaPipelineArn",
            .status = "Status",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const LiveConnectorSinkConfiguration = struct {
    sink_type: []const u8,
    rtmp_configuration: LiveConnectorRTMPConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sink_type = "SinkType",
            .rtmp_configuration = "RTMPConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LiveConnectorRTMPConfiguration = struct {
    url: []const u8,
    audio_channels: ?[]const u8 = null,
    audio_sample_rate: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .url = "Url",
            .audio_channels = "AudioChannels",
            .audio_sample_rate = "AudioSampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const LiveConnectorSourceConfiguration = struct {
    source_type: []const u8,
    chime_sdk_meeting_live_connector_configuration: ChimeSdkMeetingLiveConnectorConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_type = "SourceType",
            .chime_sdk_meeting_live_connector_configuration = "ChimeSdkMeetingLiveConnectorConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ChimeSdkMeetingLiveConnectorConfiguration = struct {
    arn: []const u8,
    mux_type: []const u8,
    composited_video: ?CompositedVideoArtifactsConfiguration = null,
    source_configuration: ?SourceConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .mux_type = "MuxType",
            .composited_video = "CompositedVideo",
            .source_configuration = "SourceConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConfiguration = struct {
    selected_video_streams: ?SelectedVideoStreams = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_video_streams = "SelectedVideoStreams",
        };
        return @field(mappings, field_name);
    }
};

pub const SelectedVideoStreams = struct {
    attendee_ids: ?[][]const u8 = null,
    external_user_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attendee_ids = "AttendeeIds",
            .external_user_ids = "ExternalUserIds",
        };
        return @field(mappings, field_name);
    }
};

pub const CompositedVideoArtifactsConfiguration = struct {
    layout: ?[]const u8 = null,
    resolution: ?[]const u8 = null,
    grid_view_configuration: GridViewConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .layout = "Layout",
            .resolution = "Resolution",
            .grid_view_configuration = "GridViewConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const GridViewConfiguration = struct {
    content_share_layout: []const u8,
    presenter_only_configuration: ?PresenterOnlyConfiguration = null,
    active_speaker_only_configuration: ?ActiveSpeakerOnlyConfiguration = null,
    horizontal_layout_configuration: ?HorizontalLayoutConfiguration = null,
    vertical_layout_configuration: ?VerticalLayoutConfiguration = null,
    video_attribute: ?VideoAttribute = null,
    canvas_orientation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_share_layout = "ContentShareLayout",
            .presenter_only_configuration = "PresenterOnlyConfiguration",
            .active_speaker_only_configuration = "ActiveSpeakerOnlyConfiguration",
            .horizontal_layout_configuration = "HorizontalLayoutConfiguration",
            .vertical_layout_configuration = "VerticalLayoutConfiguration",
            .video_attribute = "VideoAttribute",
            .canvas_orientation = "CanvasOrientation",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoAttribute = struct {
    corner_radius: ?i64 = null,
    border_color: ?[]const u8 = null,
    highlight_color: ?[]const u8 = null,
    border_thickness: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .corner_radius = "CornerRadius",
            .border_color = "BorderColor",
            .highlight_color = "HighlightColor",
            .border_thickness = "BorderThickness",
        };
        return @field(mappings, field_name);
    }
};

pub const VerticalLayoutConfiguration = struct {
    tile_order: ?[]const u8 = null,
    tile_position: ?[]const u8 = null,
    tile_count: ?i64 = null,
    tile_aspect_ratio: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tile_order = "TileOrder",
            .tile_position = "TilePosition",
            .tile_count = "TileCount",
            .tile_aspect_ratio = "TileAspectRatio",
        };
        return @field(mappings, field_name);
    }
};

pub const HorizontalLayoutConfiguration = struct {
    tile_order: ?[]const u8 = null,
    tile_position: ?[]const u8 = null,
    tile_count: ?i64 = null,
    tile_aspect_ratio: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tile_order = "TileOrder",
            .tile_position = "TilePosition",
            .tile_count = "TileCount",
            .tile_aspect_ratio = "TileAspectRatio",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveSpeakerOnlyConfiguration = struct {
    active_speaker_position: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_speaker_position = "ActiveSpeakerPosition",
        };
        return @field(mappings, field_name);
    }
};

pub const PresenterOnlyConfiguration = struct {
    presenter_position: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .presenter_position = "PresenterPosition",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaCapturePipeline = struct {
    media_pipeline_id: ?[]const u8 = null,
    media_pipeline_arn: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    source_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    sink_type: ?[]const u8 = null,
    sink_arn: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    chime_sdk_meeting_configuration: ?ChimeSdkMeetingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_pipeline_id = "MediaPipelineId",
            .media_pipeline_arn = "MediaPipelineArn",
            .source_type = "SourceType",
            .source_arn = "SourceArn",
            .status = "Status",
            .sink_type = "SinkType",
            .sink_arn = "SinkArn",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .chime_sdk_meeting_configuration = "ChimeSdkMeetingConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ChimeSdkMeetingConfiguration = struct {
    source_configuration: ?SourceConfiguration = null,
    artifacts_configuration: ?ArtifactsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_configuration = "SourceConfiguration",
            .artifacts_configuration = "ArtifactsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactsConfiguration = struct {
    audio: AudioArtifactsConfiguration,
    video: VideoArtifactsConfiguration,
    content: ContentArtifactsConfiguration,
    composited_video: ?CompositedVideoArtifactsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio = "Audio",
            .video = "Video",
            .content = "Content",
            .composited_video = "CompositedVideo",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentArtifactsConfiguration = struct {
    state: []const u8,
    mux_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .mux_type = "MuxType",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoArtifactsConfiguration = struct {
    state: []const u8,
    mux_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .mux_type = "MuxType",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioArtifactsConfiguration = struct {
    mux_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mux_type = "MuxType",
        };
        return @field(mappings, field_name);
    }
};
