const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-07-15";
pub const sdk_id: []const u8 = "Chime SDK Meetings";
pub const arn_namespace: ?[]const u8 = "chime";
pub const endpoint_prefix: []const u8 = "meetings-chime";
pub const sigv4_name: []const u8 = "chime";
pub const name: []const u8 = "ChimeMeetingsSDKService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-07-15",
    sdk_id: []const u8 = "Chime SDK Meetings",
    arn_namespace: ?[]const u8 = "chime",
    endpoint_prefix: []const u8 = "meetings-chime",
    sigv4_name: []const u8 = "chime",
    name: []const u8 = "ChimeMeetingsSDKService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_create_attendee: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/attendees?operation=batch-create",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchCreateAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        attendees: []CreateAttendeeRequestItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendees = "Attendees",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_attendee) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_attendee };
        }
    },
    Response: type = struct {
        attendees: ?[]Attendee = null,
        errors: ?[]CreateAttendeeError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendees = "Attendees",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        LimitExceeded,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        UnprocessableEntity,
    },
} = .{};
pub const batch_update_attendee_capabilities_except: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/meetings/{MeetingId}/attendees/capabilities?operation=batch-update-except",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateAttendeeCapabilitiesExcept",
    Request: type = struct {
        meeting_id: []const u8,
        excluded_attendee_ids: []struct {
            attendee_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attendee_id = "AttendeeId",
                };
                return @field(mappings, field_name);
            }
        },
        capabilities: AttendeeCapabilities,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .excluded_attendee_ids = "ExcludedAttendeeIds",
                .capabilities = "Capabilities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_attendee_capabilities_except) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_attendee_capabilities_except };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_attendee: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/attendees",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        external_user_id: []const u8,
        capabilities: ?AttendeeCapabilities = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .external_user_id = "ExternalUserId",
                .capabilities = "Capabilities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_attendee) } {
            return .{ .service_metadata = service_metadata, .action = create_attendee };
        }
    },
    Response: type = struct {
        attendee: ?Attendee = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendee = "Attendee",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        LimitExceeded,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        UnprocessableEntity,
    },
} = .{};
pub const create_meeting: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMeeting",
    Request: type = struct {
        client_request_token: []const u8,
        media_region: []const u8,
        meeting_host_id: ?[]const u8 = null,
        external_meeting_id: []const u8,
        notifications_configuration: ?NotificationsConfiguration = null,
        meeting_features: ?MeetingFeaturesConfiguration = null,
        primary_meeting_id: ?[]const u8 = null,
        tenant_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .media_region = "MediaRegion",
                .meeting_host_id = "MeetingHostId",
                .external_meeting_id = "ExternalMeetingId",
                .notifications_configuration = "NotificationsConfiguration",
                .meeting_features = "MeetingFeatures",
                .primary_meeting_id = "PrimaryMeetingId",
                .tenant_ids = "TenantIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_meeting) } {
            return .{ .service_metadata = service_metadata, .action = create_meeting };
        }
    },
    Response: type = struct {
        meeting: ?Meeting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting = "Meeting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        LimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_meeting_with_attendees: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings?operation=create-attendees",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMeetingWithAttendees",
    Request: type = struct {
        client_request_token: []const u8,
        media_region: []const u8,
        meeting_host_id: ?[]const u8 = null,
        external_meeting_id: []const u8,
        meeting_features: ?MeetingFeaturesConfiguration = null,
        notifications_configuration: ?NotificationsConfiguration = null,
        attendees: []CreateAttendeeRequestItem,
        primary_meeting_id: ?[]const u8 = null,
        tenant_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .media_region = "MediaRegion",
                .meeting_host_id = "MeetingHostId",
                .external_meeting_id = "ExternalMeetingId",
                .meeting_features = "MeetingFeatures",
                .notifications_configuration = "NotificationsConfiguration",
                .attendees = "Attendees",
                .primary_meeting_id = "PrimaryMeetingId",
                .tenant_ids = "TenantIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_meeting_with_attendees) } {
            return .{ .service_metadata = service_metadata, .action = create_meeting_with_attendees };
        }
    },
    Response: type = struct {
        meeting: ?Meeting = null,
        attendees: ?[]Attendee = null,
        errors: ?[]CreateAttendeeError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting = "Meeting",
                .attendees = "Attendees",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        LimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_attendee: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/meetings/{MeetingId}/attendees/{AttendeeId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        attendee_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendee_id = "AttendeeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_attendee) } {
            return .{ .service_metadata = service_metadata, .action = delete_attendee };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_meeting: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/meetings/{MeetingId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMeeting",
    Request: type = struct {
        meeting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_meeting) } {
            return .{ .service_metadata = service_metadata, .action = delete_meeting };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_attendee: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings/{MeetingId}/attendees/{AttendeeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        attendee_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendee_id = "AttendeeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_attendee) } {
            return .{ .service_metadata = service_metadata, .action = get_attendee };
        }
    },
    Response: type = struct {
        attendee: ?Attendee = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendee = "Attendee",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_meeting: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings/{MeetingId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMeeting",
    Request: type = struct {
        meeting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_meeting) } {
            return .{ .service_metadata = service_metadata, .action = get_meeting };
        }
    },
    Response: type = struct {
        meeting: ?Meeting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting = "Meeting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_attendees: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings/{MeetingId}/attendees",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttendees",
    Request: type = struct {
        meeting_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attendees) } {
            return .{ .service_metadata = service_metadata, .action = list_attendees };
        }
    },
    Response: type = struct {
        attendees: ?[]Attendee = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendees = "Attendees",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        LimitExceeded,
        ResourceNotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const start_meeting_transcription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/transcription?operation=start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMeetingTranscription",
    Request: type = struct {
        meeting_id: []const u8,
        transcription_configuration: struct {
            engine_transcribe_settings: ?struct {
                language_code: ?[]const u8 = null,
                vocabulary_filter_method: ?[]const u8 = null,
                vocabulary_filter_name: ?[]const u8 = null,
                vocabulary_name: ?[]const u8 = null,
                region: ?[]const u8 = null,
                enable_partial_results_stabilization: ?bool = null,
                partial_results_stability: ?[]const u8 = null,
                content_identification_type: ?[]const u8 = null,
                content_redaction_type: ?[]const u8 = null,
                pii_entity_types: ?[]const u8 = null,
                language_model_name: ?[]const u8 = null,
                identify_language: ?bool = null,
                language_options: ?[]const u8 = null,
                preferred_language: ?[]const u8 = null,
                vocabulary_names: ?[]const u8 = null,
                vocabulary_filter_names: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .language_code = "LanguageCode",
                        .vocabulary_filter_method = "VocabularyFilterMethod",
                        .vocabulary_filter_name = "VocabularyFilterName",
                        .vocabulary_name = "VocabularyName",
                        .region = "Region",
                        .enable_partial_results_stabilization = "EnablePartialResultsStabilization",
                        .partial_results_stability = "PartialResultsStability",
                        .content_identification_type = "ContentIdentificationType",
                        .content_redaction_type = "ContentRedactionType",
                        .pii_entity_types = "PiiEntityTypes",
                        .language_model_name = "LanguageModelName",
                        .identify_language = "IdentifyLanguage",
                        .language_options = "LanguageOptions",
                        .preferred_language = "PreferredLanguage",
                        .vocabulary_names = "VocabularyNames",
                        .vocabulary_filter_names = "VocabularyFilterNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            engine_transcribe_medical_settings: ?struct {
                language_code: []const u8,
                specialty: []const u8,
                type: []const u8,
                vocabulary_name: ?[]const u8 = null,
                region: ?[]const u8 = null,
                content_identification_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .language_code = "LanguageCode",
                        .specialty = "Specialty",
                        .type = "Type",
                        .vocabulary_name = "VocabularyName",
                        .region = "Region",
                        .content_identification_type = "ContentIdentificationType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine_transcribe_settings = "EngineTranscribeSettings",
                    .engine_transcribe_medical_settings = "EngineTranscribeMedicalSettings",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .transcription_configuration = "TranscriptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_meeting_transcription) } {
            return .{ .service_metadata = service_metadata, .action = start_meeting_transcription };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        LimitExceeded,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        UnprocessableEntity,
    },
} = .{};
pub const stop_meeting_transcription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/transcription?operation=stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopMeetingTranscription",
    Request: type = struct {
        meeting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_meeting_transcription) } {
            return .{ .service_metadata = service_metadata, .action = stop_meeting_transcription };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        UnprocessableEntity,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=tag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        LimitExceeded,
        ResourceNotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        TooManyTags,
        Unauthorized,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=untag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        LimitExceeded,
        ResourceNotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_attendee_capabilities: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/meetings/{MeetingId}/attendees/{AttendeeId}/capabilities",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAttendeeCapabilities",
    Request: type = struct {
        meeting_id: []const u8,
        attendee_id: []const u8,
        capabilities: AttendeeCapabilities,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendee_id = "AttendeeId",
                .capabilities = "Capabilities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_attendee_capabilities) } {
            return .{ .service_metadata = service_metadata, .action = update_attendee_capabilities };
        }
    },
    Response: type = struct {
        attendee: ?Attendee = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendee = "Attendee",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};

pub const Attendee = struct {
    external_user_id: ?[]const u8 = null,
    attendee_id: ?[]const u8 = null,
    join_token: ?[]const u8 = null,
    capabilities: ?AttendeeCapabilities = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_user_id = "ExternalUserId",
            .attendee_id = "AttendeeId",
            .join_token = "JoinToken",
            .capabilities = "Capabilities",
        };
        return @field(mappings, field_name);
    }
};

pub const AttendeeCapabilities = struct {
    audio: []const u8,
    video: []const u8,
    content: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio = "Audio",
            .video = "Video",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Meeting = struct {
    meeting_id: ?[]const u8 = null,
    meeting_host_id: ?[]const u8 = null,
    external_meeting_id: ?[]const u8 = null,
    media_region: ?[]const u8 = null,
    media_placement: ?MediaPlacement = null,
    meeting_features: ?MeetingFeaturesConfiguration = null,
    primary_meeting_id: ?[]const u8 = null,
    tenant_ids: ?[][]const u8 = null,
    meeting_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .meeting_id = "MeetingId",
            .meeting_host_id = "MeetingHostId",
            .external_meeting_id = "ExternalMeetingId",
            .media_region = "MediaRegion",
            .media_placement = "MediaPlacement",
            .meeting_features = "MeetingFeatures",
            .primary_meeting_id = "PrimaryMeetingId",
            .tenant_ids = "TenantIds",
            .meeting_arn = "MeetingArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MeetingFeaturesConfiguration = struct {
    audio: ?AudioFeatures = null,
    video: ?VideoFeatures = null,
    content: ?ContentFeatures = null,
    attendee: ?AttendeeFeatures = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio = "Audio",
            .video = "Video",
            .content = "Content",
            .attendee = "Attendee",
        };
        return @field(mappings, field_name);
    }
};

pub const AttendeeFeatures = struct {
    max_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_count = "MaxCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentFeatures = struct {
    max_resolution: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_resolution = "MaxResolution",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoFeatures = struct {
    max_resolution: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_resolution = "MaxResolution",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioFeatures = struct {
    echo_reduction: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .echo_reduction = "EchoReduction",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaPlacement = struct {
    audio_host_url: ?[]const u8 = null,
    audio_fallback_url: ?[]const u8 = null,
    signaling_url: ?[]const u8 = null,
    turn_control_url: ?[]const u8 = null,
    screen_data_url: ?[]const u8 = null,
    screen_viewing_url: ?[]const u8 = null,
    screen_sharing_url: ?[]const u8 = null,
    event_ingestion_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_host_url = "AudioHostUrl",
            .audio_fallback_url = "AudioFallbackUrl",
            .signaling_url = "SignalingUrl",
            .turn_control_url = "TurnControlUrl",
            .screen_data_url = "ScreenDataUrl",
            .screen_viewing_url = "ScreenViewingUrl",
            .screen_sharing_url = "ScreenSharingUrl",
            .event_ingestion_url = "EventIngestionUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateAttendeeError = struct {
    external_user_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_user_id = "ExternalUserId",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateAttendeeRequestItem = struct {
    external_user_id: []const u8,
    capabilities: ?AttendeeCapabilities = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_user_id = "ExternalUserId",
            .capabilities = "Capabilities",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationsConfiguration = struct {
    lambda_function_arn: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    sqs_queue_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_function_arn = "LambdaFunctionArn",
            .sns_topic_arn = "SnsTopicArn",
            .sqs_queue_arn = "SqsQueueArn",
        };
        return @field(mappings, field_name);
    }
};
