const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-05-15";
pub const sdk_id: []const u8 = "Chime SDK Messaging";
pub const arn_namespace: ?[]const u8 = "chime";
pub const endpoint_prefix: []const u8 = "messaging-chime";
pub const sigv4_name: []const u8 = "chime";
pub const name: []const u8 = "ChimeMessagingService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-05-15",
    sdk_id: []const u8 = "Chime SDK Messaging",
    arn_namespace: ?[]const u8 = "chime",
    endpoint_prefix: []const u8 = "messaging-chime",
    sigv4_name: []const u8 = "chime",
    name: []const u8 = "ChimeMessagingService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_channel_flow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}/channel-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateChannelFlow",
    Request: type = struct {
        channel_arn: []const u8,
        channel_flow_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_flow_arn = "ChannelFlowArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_channel_flow) } {
            return .{ .service_metadata = service_metadata, .action = associate_channel_flow };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_create_channel_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/memberships?operation=batch-create",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchCreateChannelMembership",
    Request: type = struct {
        channel_arn: []const u8,
        type: ?[]const u8 = null,
        member_arns: [][]const u8,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .type = "Type",
                .member_arns = "MemberArns",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_channel_membership) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_channel_membership };
        }
    },
    Response: type = struct {
        batch_channel_memberships: ?struct {
            invited_by: ?Identity = null,
            type: ?[]const u8 = null,
            members: ?[]Identity = null,
            channel_arn: ?[]const u8 = null,
            sub_channel_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .invited_by = "InvitedBy",
                    .type = "Type",
                    .members = "Members",
                    .channel_arn = "ChannelArn",
                    .sub_channel_id = "SubChannelId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            member_arn: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_arn = "MemberArn",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_channel_memberships = "BatchChannelMemberships",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const channel_flow_callback: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}?operation=channel-flow-callback",
        .success_code = 200,
    };

    action_name: []const u8 = "ChannelFlowCallback",
    Request: type = struct {
        callback_id: []const u8,
        channel_arn: []const u8,
        delete_resource: ?bool = null,
        channel_message: struct {
            message_id: []const u8,
            content: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            push_notification: ?PushNotificationConfiguration = null,
            message_attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MessageAttributeValue = null,
            } = null,
            sub_channel_id: ?[]const u8 = null,
            content_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "MessageId",
                    .content = "Content",
                    .metadata = "Metadata",
                    .push_notification = "PushNotification",
                    .message_attributes = "MessageAttributes",
                    .sub_channel_id = "SubChannelId",
                    .content_type = "ContentType",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "message_attributes", field_name))
                    return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .callback_id = "CallbackId",
                .channel_arn = "ChannelArn",
                .delete_resource = "DeleteResource",
                .channel_message = "ChannelMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(channel_flow_callback) } {
            return .{ .service_metadata = service_metadata, .action = channel_flow_callback };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        callback_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .callback_id = "CallbackId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannel",
    Request: type = struct {
        app_instance_arn: []const u8,
        name: []const u8,
        mode: ?[]const u8 = null,
        privacy: ?[]const u8 = null,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]Tag = null,
        chime_bearer: []const u8,
        channel_id: ?[]const u8 = null,
        member_arns: ?[][]const u8 = null,
        moderator_arns: ?[][]const u8 = null,
        elastic_channel_configuration: ?ElasticChannelConfiguration = null,
        expiration_settings: ?ExpirationSettings = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .name = "Name",
                .mode = "Mode",
                .privacy = "Privacy",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .chime_bearer = "ChimeBearer",
                .channel_id = "ChannelId",
                .member_arns = "MemberArns",
                .moderator_arns = "ModeratorArns",
                .elastic_channel_configuration = "ElasticChannelConfiguration",
                .expiration_settings = "ExpirationSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_channel };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel_ban: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/bans",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannelBan",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel_ban) } {
            return .{ .service_metadata = service_metadata, .action = create_channel_ban };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        member: ?Identity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member = "Member",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channel-flows",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannelFlow",
    Request: type = struct {
        app_instance_arn: []const u8,
        processors: []Processor,
        name: []const u8,
        tags: ?[]Tag = null,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .processors = "Processors",
                .name = "Name",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel_flow) } {
            return .{ .service_metadata = service_metadata, .action = create_channel_flow };
        }
    },
    Response: type = struct {
        channel_flow_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_flow_arn = "ChannelFlowArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/memberships",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannelMembership",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        type: []const u8,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .type = "Type",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_channel_membership };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        member: ?Identity = null,
        sub_channel_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member = "Member",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel_moderator: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/moderators",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannelModerator",
    Request: type = struct {
        channel_arn: []const u8,
        channel_moderator_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_moderator_arn = "ChannelModeratorArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel_moderator) } {
            return .{ .service_metadata = service_metadata, .action = create_channel_moderator };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        channel_moderator: ?Identity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_moderator = "ChannelModerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannel",
    Request: type = struct {
        channel_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_ban: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/bans/{MemberArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelBan",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_ban) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_ban };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_flow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channel-flows/{ChannelFlowArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelFlow",
    Request: type = struct {
        channel_flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_flow_arn = "ChannelFlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_flow) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_flow };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_membership: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/memberships/{MemberArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelMembership",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,

        pub const http_query = .{
            .sub_channel_id = "sub-channel-id",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_membership };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_message: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,

        pub const http_query = .{
            .sub_channel_id = "sub-channel-id",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_message };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_moderator: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/moderators/{ChannelModeratorArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelModerator",
    Request: type = struct {
        channel_arn: []const u8,
        channel_moderator_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_moderator_arn = "ChannelModeratorArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_moderator) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_moderator };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_messaging_streaming_configurations: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instances/{AppInstanceArn}/streaming-configurations",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMessagingStreamingConfigurations",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_messaging_streaming_configurations) } {
            return .{ .service_metadata = service_metadata, .action = delete_messaging_streaming_configurations };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannel",
    Request: type = struct {
        channel_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel };
        }
    },
    Response: type = struct {
        channel: ?struct {
            name: ?[]const u8 = null,
            channel_arn: ?[]const u8 = null,
            mode: ?[]const u8 = null,
            privacy: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            created_by: ?Identity = null,
            created_timestamp: ?i64 = null,
            last_message_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            channel_flow_arn: ?[]const u8 = null,
            elastic_channel_configuration: ?ElasticChannelConfiguration = null,
            expiration_settings: ?ExpirationSettings = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .channel_arn = "ChannelArn",
                    .mode = "Mode",
                    .privacy = "Privacy",
                    .metadata = "Metadata",
                    .created_by = "CreatedBy",
                    .created_timestamp = "CreatedTimestamp",
                    .last_message_timestamp = "LastMessageTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .channel_flow_arn = "ChannelFlowArn",
                    .elastic_channel_configuration = "ElasticChannelConfiguration",
                    .expiration_settings = "ExpirationSettings",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "Channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_ban: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/bans/{MemberArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelBan",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_ban) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_ban };
        }
    },
    Response: type = struct {
        channel_ban: ?struct {
            member: ?Identity = null,
            channel_arn: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            created_by: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member = "Member",
                    .channel_arn = "ChannelArn",
                    .created_timestamp = "CreatedTimestamp",
                    .created_by = "CreatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_ban = "ChannelBan",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_flow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channel-flows/{ChannelFlowArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelFlow",
    Request: type = struct {
        channel_flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_flow_arn = "ChannelFlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_flow) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_flow };
        }
    },
    Response: type = struct {
        channel_flow: ?struct {
            channel_flow_arn: ?[]const u8 = null,
            processors: ?[]Processor = null,
            name: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_flow_arn = "ChannelFlowArn",
                    .processors = "Processors",
                    .name = "Name",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_flow = "ChannelFlow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_membership: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/memberships/{MemberArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelMembership",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,

        pub const http_query = .{
            .sub_channel_id = "sub-channel-id",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_membership) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_membership };
        }
    },
    Response: type = struct {
        channel_membership: ?struct {
            invited_by: ?Identity = null,
            type: ?[]const u8 = null,
            member: ?Identity = null,
            channel_arn: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            sub_channel_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .invited_by = "InvitedBy",
                    .type = "Type",
                    .member = "Member",
                    .channel_arn = "ChannelArn",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .sub_channel_id = "SubChannelId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_membership = "ChannelMembership",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_membership_for_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}?scope=app-instance-user-membership",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelMembershipForAppInstanceUser",
    Request: type = struct {
        channel_arn: []const u8,
        app_instance_user_arn: []const u8,
        chime_bearer: []const u8,

        pub const http_query = .{
            .app_instance_user_arn = "app-instance-user-arn",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .app_instance_user_arn = "AppInstanceUserArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_membership_for_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_membership_for_app_instance_user };
        }
    },
    Response: type = struct {
        channel_membership: ?ChannelMembershipForAppInstanceUserSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_membership = "ChannelMembership",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_moderated_by_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}?scope=app-instance-user-moderated-channel",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelModeratedByAppInstanceUser",
    Request: type = struct {
        channel_arn: []const u8,
        app_instance_user_arn: []const u8,
        chime_bearer: []const u8,

        pub const http_query = .{
            .app_instance_user_arn = "app-instance-user-arn",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .app_instance_user_arn = "AppInstanceUserArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_moderated_by_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_moderated_by_app_instance_user };
        }
    },
    Response: type = struct {
        channel: ?ChannelModeratedByAppInstanceUserSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "Channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_moderator: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/moderators/{ChannelModeratorArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelModerator",
    Request: type = struct {
        channel_arn: []const u8,
        channel_moderator_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_moderator_arn = "ChannelModeratorArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_moderator) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_moderator };
        }
    },
    Response: type = struct {
        channel_moderator: ?struct {
            moderator: ?Identity = null,
            channel_arn: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            created_by: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .moderator = "Moderator",
                    .channel_arn = "ChannelArn",
                    .created_timestamp = "CreatedTimestamp",
                    .created_by = "CreatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_moderator = "ChannelModerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const disassociate_channel_flow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/channel-flow/{ChannelFlowArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateChannelFlow",
    Request: type = struct {
        channel_arn: []const u8,
        channel_flow_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_flow_arn = "ChannelFlowArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_channel_flow) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_channel_flow };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_channel_membership_preferences: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/memberships/{MemberArn}/preferences",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChannelMembershipPreferences",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channel_membership_preferences) } {
            return .{ .service_metadata = service_metadata, .action = get_channel_membership_preferences };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        member: ?Identity = null,
        preferences: ?ChannelMembershipPreferences = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member = "Member",
                .preferences = "Preferences",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_channel_message: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,

        pub const http_query = .{
            .sub_channel_id = "sub-channel-id",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = get_channel_message };
        }
    },
    Response: type = struct {
        channel_message: ?struct {
            channel_arn: ?[]const u8 = null,
            message_id: ?[]const u8 = null,
            content: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            type: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_edited_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            sender: ?Identity = null,
            redacted: ?bool = null,
            persistence: ?[]const u8 = null,
            status: ?ChannelMessageStatusStructure = null,
            message_attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MessageAttributeValue = null,
            } = null,
            sub_channel_id: ?[]const u8 = null,
            content_type: ?[]const u8 = null,
            target: ?[]Target = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_arn = "ChannelArn",
                    .message_id = "MessageId",
                    .content = "Content",
                    .metadata = "Metadata",
                    .type = "Type",
                    .created_timestamp = "CreatedTimestamp",
                    .last_edited_timestamp = "LastEditedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .sender = "Sender",
                    .redacted = "Redacted",
                    .persistence = "Persistence",
                    .status = "Status",
                    .message_attributes = "MessageAttributes",
                    .sub_channel_id = "SubChannelId",
                    .content_type = "ContentType",
                    .target = "Target",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "message_attributes", field_name))
                    return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_message = "ChannelMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_channel_message_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}?scope=message-status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChannelMessageStatus",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,

        pub const http_query = .{
            .sub_channel_id = "sub-channel-id",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channel_message_status) } {
            return .{ .service_metadata = service_metadata, .action = get_channel_message_status };
        }
    },
    Response: type = struct {
        status: ?ChannelMessageStatusStructure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_messaging_session_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/endpoints/messaging-session",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMessagingSessionEndpoint",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_messaging_session_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_messaging_session_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?struct {
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .url = "Url",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "Endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_messaging_streaming_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}/streaming-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMessagingStreamingConfigurations",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_messaging_streaming_configurations) } {
            return .{ .service_metadata = service_metadata, .action = get_messaging_streaming_configurations };
        }
    },
    Response: type = struct {
        streaming_configurations: ?[]StreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_configurations = "StreamingConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_bans: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/bans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelBans",
    Request: type = struct {
        channel_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: []const u8,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_bans) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_bans };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        channel_bans: ?[]struct {
            member: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member = "Member",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .next_token = "NextToken",
                .channel_bans = "ChannelBans",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_flows: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channel-flows",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelFlows",
    Request: type = struct {
        app_instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_arn = "app-instance-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_flows) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_flows };
        }
    },
    Response: type = struct {
        channel_flows: ?[]struct {
            channel_flow_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            processors: ?[]Processor = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_flow_arn = "ChannelFlowArn",
                    .name = "Name",
                    .processors = "Processors",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_flows = "ChannelFlows",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_memberships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/memberships",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelMemberships",
    Request: type = struct {
        channel_arn: []const u8,
        type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,

        pub const http_query = .{
            .type = "type",
            .max_results = "max-results",
            .next_token = "next-token",
            .sub_channel_id = "sub-channel-id",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .type = "Type",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_memberships) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_memberships };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        channel_memberships: ?[]struct {
            member: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member = "Member",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_memberships = "ChannelMemberships",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_memberships_for_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels?scope=app-instance-user-memberships",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelMembershipsForAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: []const u8,

        pub const http_query = .{
            .app_instance_user_arn = "app-instance-user-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_memberships_for_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_memberships_for_app_instance_user };
        }
    },
    Response: type = struct {
        channel_memberships: ?[]ChannelMembershipForAppInstanceUserSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_memberships = "ChannelMemberships",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_messages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/messages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelMessages",
    Request: type = struct {
        channel_arn: []const u8,
        sort_order: ?[]const u8 = null,
        not_before: ?i64 = null,
        not_after: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,

        pub const http_query = .{
            .sort_order = "sort-order",
            .not_before = "not-before",
            .not_after = "not-after",
            .max_results = "max-results",
            .next_token = "next-token",
            .sub_channel_id = "sub-channel-id",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .sort_order = "SortOrder",
                .not_before = "NotBefore",
                .not_after = "NotAfter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_messages) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_messages };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        channel_messages: ?[]struct {
            message_id: ?[]const u8 = null,
            content: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            type: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            last_edited_timestamp: ?i64 = null,
            sender: ?Identity = null,
            redacted: ?bool = null,
            status: ?ChannelMessageStatusStructure = null,
            message_attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MessageAttributeValue = null,
            } = null,
            content_type: ?[]const u8 = null,
            target: ?[]Target = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "MessageId",
                    .content = "Content",
                    .metadata = "Metadata",
                    .type = "Type",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .last_edited_timestamp = "LastEditedTimestamp",
                    .sender = "Sender",
                    .redacted = "Redacted",
                    .status = "Status",
                    .message_attributes = "MessageAttributes",
                    .content_type = "ContentType",
                    .target = "Target",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "message_attributes", field_name))
                    return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
                return false;
            }
        } = null,
        sub_channel_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .next_token = "NextToken",
                .channel_messages = "ChannelMessages",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_moderators: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/moderators",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelModerators",
    Request: type = struct {
        channel_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: []const u8,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_moderators) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_moderators };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        channel_moderators: ?[]struct {
            moderator: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .moderator = "Moderator",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .next_token = "NextToken",
                .channel_moderators = "ChannelModerators",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannels",
    Request: type = struct {
        app_instance_arn: []const u8,
        privacy: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: []const u8,

        pub const http_query = .{
            .app_instance_arn = "app-instance-arn",
            .privacy = "privacy",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .privacy = "Privacy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_channels };
        }
    },
    Response: type = struct {
        channels: ?[]ChannelSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channels_associated_with_channel_flow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels?scope=channel-flow-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelsAssociatedWithChannelFlow",
    Request: type = struct {
        channel_flow_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .channel_flow_arn = "channel-flow-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_flow_arn = "ChannelFlowArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels_associated_with_channel_flow) } {
            return .{ .service_metadata = service_metadata, .action = list_channels_associated_with_channel_flow };
        }
    },
    Response: type = struct {
        channels: ?[]struct {
            name: ?[]const u8 = null,
            channel_arn: ?[]const u8 = null,
            mode: ?[]const u8 = null,
            privacy: ?[]const u8 = null,
            metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .channel_arn = "ChannelArn",
                    .mode = "Mode",
                    .privacy = "Privacy",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channels_moderated_by_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels?scope=app-instance-user-moderated-channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelsModeratedByAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: []const u8,

        pub const http_query = .{
            .app_instance_user_arn = "app-instance-user-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels_moderated_by_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = list_channels_moderated_by_app_instance_user };
        }
    },
    Response: type = struct {
        channels: ?[]ChannelModeratedByAppInstanceUserSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_sub_channels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/subchannels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSubChannels",
    Request: type = struct {
        channel_arn: []const u8,
        chime_bearer: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .chime_bearer = "ChimeBearer",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sub_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_sub_channels };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        sub_channels: ?[]struct {
            sub_channel_id: ?[]const u8 = null,
            membership_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sub_channel_id = "SubChannelId",
                    .membership_count = "MembershipCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .sub_channels = "SubChannels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_channel_expiration_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}/expiration-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "PutChannelExpirationSettings",
    Request: type = struct {
        channel_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        expiration_settings: ?ExpirationSettings = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .chime_bearer = "ChimeBearer",
                .expiration_settings = "ExpirationSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_channel_expiration_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_channel_expiration_settings };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        expiration_settings: ?ExpirationSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .expiration_settings = "ExpirationSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_channel_membership_preferences: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}/memberships/{MemberArn}/preferences",
        .success_code = 200,
    };

    action_name: []const u8 = "PutChannelMembershipPreferences",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: []const u8,
        preferences: ChannelMembershipPreferences,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
                .preferences = "Preferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_channel_membership_preferences) } {
            return .{ .service_metadata = service_metadata, .action = put_channel_membership_preferences };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        member: ?Identity = null,
        preferences: ?ChannelMembershipPreferences = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member = "Member",
                .preferences = "Preferences",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_messaging_streaming_configurations: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instances/{AppInstanceArn}/streaming-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "PutMessagingStreamingConfigurations",
    Request: type = struct {
        app_instance_arn: []const u8,
        streaming_configurations: []StreamingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .streaming_configurations = "StreamingConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_messaging_streaming_configurations) } {
            return .{ .service_metadata = service_metadata, .action = put_messaging_streaming_configurations };
        }
    },
    Response: type = struct {
        streaming_configurations: ?[]StreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_configurations = "StreamingConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const redact_channel_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}?operation=redact",
        .success_code = 200,
    };

    action_name: []const u8 = "RedactChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(redact_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = redact_channel_message };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        message_id: ?[]const u8 = null,
        sub_channel_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const search_channels: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels?operation=search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchChannels",
    Request: type = struct {
        chime_bearer: ?[]const u8 = null,
        fields: []struct {
            key: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                    .operator = "Operator",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .chime_bearer = "ChimeBearer",
                .fields = "Fields",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_channels) } {
            return .{ .service_metadata = service_metadata, .action = search_channels };
        }
    },
    Response: type = struct {
        channels: ?[]ChannelSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const send_channel_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/messages",
        .success_code = 201,
    };

    action_name: []const u8 = "SendChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        content: []const u8,
        type: []const u8,
        persistence: []const u8,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        chime_bearer: []const u8,
        push_notification: ?PushNotificationConfiguration = null,
        message_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MessageAttributeValue = null,
        } = null,
        sub_channel_id: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        target: ?[]Target = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .content = "Content",
                .type = "Type",
                .persistence = "Persistence",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .chime_bearer = "ChimeBearer",
                .push_notification = "PushNotification",
                .message_attributes = "MessageAttributes",
                .sub_channel_id = "SubChannelId",
                .content_type = "ContentType",
                .target = "Target",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "message_attributes", field_name))
                return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = send_channel_message };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        message_id: ?[]const u8 = null,
        status: ?ChannelMessageStatusStructure = null,
        sub_channel_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .status = "Status",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=tag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=untag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannel",
    Request: type = struct {
        channel_arn: []const u8,
        name: ?[]const u8 = null,
        mode: ?[]const u8 = null,
        metadata: ?[]const u8 = null,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .name = "Name",
                .mode = "Mode",
                .metadata = "Metadata",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_channel };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_channel_flow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channel-flows/{ChannelFlowArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannelFlow",
    Request: type = struct {
        channel_flow_arn: []const u8,
        processors: []Processor,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_flow_arn = "ChannelFlowArn",
                .processors = "Processors",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel_flow) } {
            return .{ .service_metadata = service_metadata, .action = update_channel_flow };
        }
    },
    Response: type = struct {
        channel_flow_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_flow_arn = "ChannelFlowArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_channel_message: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        content: []const u8,
        metadata: ?[]const u8 = null,
        chime_bearer: []const u8,
        sub_channel_id: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .content = "Content",
                .metadata = "Metadata",
                .chime_bearer = "ChimeBearer",
                .sub_channel_id = "SubChannelId",
                .content_type = "ContentType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = update_channel_message };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        message_id: ?[]const u8 = null,
        status: ?ChannelMessageStatusStructure = null,
        sub_channel_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .status = "Status",
                .sub_channel_id = "SubChannelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_channel_read_marker: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}/readMarker",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannelReadMarker",
    Request: type = struct {
        channel_arn: []const u8,
        chime_bearer: []const u8,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel_read_marker) } {
            return .{ .service_metadata = service_metadata, .action = update_channel_read_marker };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};

pub const ChannelMessageStatusStructure = struct {
    value: ?[]const u8 = null,
    detail: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .detail = "Detail",
        };
        return @field(mappings, field_name);
    }
};

pub const Processor = struct {
    name: []const u8,
    configuration: ProcessorConfiguration,
    execution_order: i64,
    fallback_action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .configuration = "Configuration",
            .execution_order = "ExecutionOrder",
            .fallback_action = "FallbackAction",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessorConfiguration = struct {
    lambda: LambdaConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda = "Lambda",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaConfiguration = struct {
    resource_arn: []const u8,
    invocation_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .invocation_type = "InvocationType",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Target = struct {
    member_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .member_arn = "MemberArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageAttributeValue = struct {
    string_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_values = "StringValues",
        };
        return @field(mappings, field_name);
    }
};

pub const PushNotificationConfiguration = struct {
    title: ?[]const u8 = null,
    body: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "Title",
            .body = "Body",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelSummary = struct {
    name: ?[]const u8 = null,
    channel_arn: ?[]const u8 = null,
    mode: ?[]const u8 = null,
    privacy: ?[]const u8 = null,
    metadata: ?[]const u8 = null,
    last_message_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .channel_arn = "ChannelArn",
            .mode = "Mode",
            .privacy = "Privacy",
            .metadata = "Metadata",
            .last_message_timestamp = "LastMessageTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingConfiguration = struct {
    data_type: []const u8,
    resource_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_type = "DataType",
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelMembershipPreferences = struct {
    push_notifications: ?PushNotificationPreferences = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .push_notifications = "PushNotifications",
        };
        return @field(mappings, field_name);
    }
};

pub const PushNotificationPreferences = struct {
    allow_notifications: []const u8,
    filter_rule: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_notifications = "AllowNotifications",
            .filter_rule = "FilterRule",
        };
        return @field(mappings, field_name);
    }
};

pub const Identity = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpirationSettings = struct {
    expiration_days: i64,
    expiration_criterion: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expiration_days = "ExpirationDays",
            .expiration_criterion = "ExpirationCriterion",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelModeratedByAppInstanceUserSummary = struct {
    channel_summary: ?ChannelSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_summary = "ChannelSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelMembershipForAppInstanceUserSummary = struct {
    channel_summary: ?ChannelSummary = null,
    app_instance_user_membership_summary: ?AppInstanceUserMembershipSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_summary = "ChannelSummary",
            .app_instance_user_membership_summary = "AppInstanceUserMembershipSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const AppInstanceUserMembershipSummary = struct {
    type: ?[]const u8 = null,
    read_marker_timestamp: ?i64 = null,
    sub_channel_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .read_marker_timestamp = "ReadMarkerTimestamp",
            .sub_channel_id = "SubChannelId",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticChannelConfiguration = struct {
    maximum_sub_channels: i64,
    target_memberships_per_sub_channel: i64,
    minimum_membership_percentage: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_sub_channels = "MaximumSubChannels",
            .target_memberships_per_sub_channel = "TargetMembershipsPerSubChannel",
            .minimum_membership_percentage = "MinimumMembershipPercentage",
        };
        return @field(mappings, field_name);
    }
};
