const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-08-03";
pub const sdk_id: []const u8 = "Chime SDK Voice";
pub const arn_namespace: ?[]const u8 = "chime";
pub const endpoint_prefix: []const u8 = "voice-chime";
pub const sigv4_name: []const u8 = "chime";
pub const name: []const u8 = "ChimeSDKTelephonyService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-08-03",
    sdk_id: []const u8 = "Chime SDK Voice",
    arn_namespace: ?[]const u8 = "chime",
    endpoint_prefix: []const u8 = "voice-chime",
    sigv4_name: []const u8 = "chime",
    name: []const u8 = "ChimeSDKTelephonyService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_phone_numbers_with_voice_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}?operation=associate-phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociatePhoneNumbersWithVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,
        e164_phone_numbers: [][]const u8,
        force_associate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .e164_phone_numbers = "E164PhoneNumbers",
                .force_associate = "ForceAssociate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_phone_numbers_with_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = associate_phone_numbers_with_voice_connector };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const associate_phone_numbers_with_voice_connector_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}?operation=associate-phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociatePhoneNumbersWithVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,
        e164_phone_numbers: [][]const u8,
        force_associate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
                .e164_phone_numbers = "E164PhoneNumbers",
                .force_associate = "ForceAssociate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_phone_numbers_with_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = associate_phone_numbers_with_voice_connector_group };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_delete_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-numbers?operation=batch-delete",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeletePhoneNumber",
    Request: type = struct {
        phone_number_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_ids = "PhoneNumberIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_phone_number };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_update_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-numbers?operation=batch-update",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdatePhoneNumber",
    Request: type = struct {
        update_phone_number_request_items: []struct {
            phone_number_id: []const u8,
            product_type: ?[]const u8 = null,
            calling_name: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .phone_number_id = "PhoneNumberId",
                    .product_type = "ProductType",
                    .calling_name = "CallingName",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_phone_number_request_items = "UpdatePhoneNumberRequestItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_phone_number };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_phone_number_order: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-number-orders",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePhoneNumberOrder",
    Request: type = struct {
        product_type: []const u8,
        e164_phone_numbers: [][]const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_type = "ProductType",
                .e164_phone_numbers = "E164PhoneNumbers",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_phone_number_order) } {
            return .{ .service_metadata = service_metadata, .action = create_phone_number_order };
        }
    },
    Response: type = struct {
        phone_number_order: ?PhoneNumberOrder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_order = "PhoneNumberOrder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_proxy_session: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateProxySession",
    Request: type = struct {
        voice_connector_id: []const u8,
        participant_phone_numbers: [][]const u8,
        name: ?[]const u8 = null,
        expiry_minutes: ?i64 = null,
        capabilities: [][]const u8,
        number_selection_behavior: ?[]const u8 = null,
        geo_match_level: ?[]const u8 = null,
        geo_match_params: ?GeoMatchParams = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .participant_phone_numbers = "ParticipantPhoneNumbers",
                .name = "Name",
                .expiry_minutes = "ExpiryMinutes",
                .capabilities = "Capabilities",
                .number_selection_behavior = "NumberSelectionBehavior",
                .geo_match_level = "GeoMatchLevel",
                .geo_match_params = "GeoMatchParams",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_proxy_session) } {
            return .{ .service_metadata = service_metadata, .action = create_proxy_session };
        }
    },
    Response: type = struct {
        proxy_session: ?ProxySession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy_session = "ProxySession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_sip_media_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sip-media-applications",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSipMediaApplication",
    Request: type = struct {
        aws_region: []const u8,
        name: []const u8,
        endpoints: []SipMediaApplicationEndpoint,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_region = "AwsRegion",
                .name = "Name",
                .endpoints = "Endpoints",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sip_media_application) } {
            return .{ .service_metadata = service_metadata, .action = create_sip_media_application };
        }
    },
    Response: type = struct {
        sip_media_application: ?SipMediaApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application = "SipMediaApplication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_sip_media_application_call: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/calls",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSipMediaApplicationCall",
    Request: type = struct {
        from_phone_number: []const u8,
        to_phone_number: []const u8,
        sip_media_application_id: []const u8,
        sip_headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        arguments_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_phone_number = "FromPhoneNumber",
                .to_phone_number = "ToPhoneNumber",
                .sip_media_application_id = "SipMediaApplicationId",
                .sip_headers = "SipHeaders",
                .arguments_map = "ArgumentsMap",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "sip_headers", field_name))
                return try serializeMap(self.sip_headers, self.fieldNameFor("sip_headers"), options, out_stream);
            if (std.mem.eql(u8, "arguments_map", field_name))
                return try serializeMap(self.arguments_map, self.fieldNameFor("arguments_map"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sip_media_application_call) } {
            return .{ .service_metadata = service_metadata, .action = create_sip_media_application_call };
        }
    },
    Response: type = struct {
        sip_media_application_call: ?SipMediaApplicationCall = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_call = "SipMediaApplicationCall",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_sip_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sip-rules",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSipRule",
    Request: type = struct {
        name: []const u8,
        trigger_type: []const u8,
        trigger_value: []const u8,
        disabled: ?bool = null,
        target_applications: ?[]SipRuleTargetApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .trigger_type = "TriggerType",
                .trigger_value = "TriggerValue",
                .disabled = "Disabled",
                .target_applications = "TargetApplications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sip_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_sip_rule };
        }
    },
    Response: type = struct {
        sip_rule: ?SipRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule = "SipRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_voice_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVoiceConnector",
    Request: type = struct {
        name: []const u8,
        aws_region: ?[]const u8 = null,
        require_encryption: bool,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .aws_region = "AwsRegion",
                .require_encryption = "RequireEncryption",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = create_voice_connector };
        }
    },
    Response: type = struct {
        voice_connector: ?VoiceConnector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_voice_connector_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connector-groups",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVoiceConnectorGroup",
    Request: type = struct {
        name: []const u8,
        voice_connector_items: ?[]VoiceConnectorItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .voice_connector_items = "VoiceConnectorItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = create_voice_connector_group };
        }
    },
    Response: type = struct {
        voice_connector_group: ?VoiceConnectorGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group = "VoiceConnectorGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_voice_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-profiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVoiceProfile",
    Request: type = struct {
        speaker_search_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .speaker_search_task_id = "SpeakerSearchTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_voice_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_voice_profile };
        }
    },
    Response: type = struct {
        voice_profile: ?VoiceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile = "VoiceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        Gone,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_voice_profile_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-profile-domains",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVoiceProfileDomain",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        server_side_encryption_configuration: ServerSideEncryptionConfiguration,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_voice_profile_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_voice_profile_domain };
        }
    },
    Response: type = struct {
        voice_profile_domain: ?VoiceProfileDomain = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_domain = "VoiceProfileDomain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_phone_number: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/phone-numbers/{PhoneNumberId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeletePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = delete_phone_number };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_proxy_session: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions/{ProxySessionId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteProxySession",
    Request: type = struct {
        voice_connector_id: []const u8,
        proxy_session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .proxy_session_id = "ProxySessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_proxy_session) } {
            return .{ .service_metadata = service_metadata, .action = delete_proxy_session };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_sip_media_application: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sip-media-applications/{SipMediaApplicationId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSipMediaApplication",
    Request: type = struct {
        sip_media_application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sip_media_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_sip_media_application };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_sip_rule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sip-rules/{SipRuleId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSipRule",
    Request: type = struct {
        sip_rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule_id = "SipRuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sip_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_sip_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_emergency_calling_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/emergency-calling-configuration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorEmergencyCallingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_emergency_calling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_emergency_calling_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_origination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/origination",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorOrigination",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_origination) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_origination };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_proxy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/programmable-numbers/proxy",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorProxy",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_proxy) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_proxy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_streaming_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/streaming-configuration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorStreamingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_streaming_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_streaming_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_termination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorTermination",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_termination) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_termination };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_termination_credentials: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination/credentials?operation=delete",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorTerminationCredentials",
    Request: type = struct {
        voice_connector_id: []const u8,
        usernames: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .usernames = "Usernames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_termination_credentials) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_termination_credentials };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-profiles/{VoiceProfileId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceProfile",
    Request: type = struct {
        voice_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_id = "VoiceProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_profile_domain: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-profile-domains/{VoiceProfileDomainId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceProfileDomain",
    Request: type = struct {
        voice_profile_domain_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_domain_id = "VoiceProfileDomainId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_profile_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_profile_domain };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const disassociate_phone_numbers_from_voice_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}?operation=disassociate-phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociatePhoneNumbersFromVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,
        e164_phone_numbers: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .e164_phone_numbers = "E164PhoneNumbers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_phone_numbers_from_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_phone_numbers_from_voice_connector };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const disassociate_phone_numbers_from_voice_connector_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}?operation=disassociate-phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociatePhoneNumbersFromVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,
        e164_phone_numbers: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
                .e164_phone_numbers = "E164PhoneNumbers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_phone_numbers_from_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_phone_numbers_from_voice_connector_group };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_global_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGlobalSettings",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_global_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_global_settings };
        }
    },
    Response: type = struct {
        voice_connector: ?VoiceConnectorSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_phone_number: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-numbers/{PhoneNumberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = get_phone_number };
        }
    },
    Response: type = struct {
        phone_number: ?PhoneNumber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_phone_number_order: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-number-orders/{PhoneNumberOrderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPhoneNumberOrder",
    Request: type = struct {
        phone_number_order_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_order_id = "PhoneNumberOrderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_phone_number_order) } {
            return .{ .service_metadata = service_metadata, .action = get_phone_number_order };
        }
    },
    Response: type = struct {
        phone_number_order: ?PhoneNumberOrder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_order = "PhoneNumberOrder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_phone_number_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/settings/phone-number",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPhoneNumberSettings",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_phone_number_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_phone_number_settings };
        }
    },
    Response: type = struct {
        calling_name: ?[]const u8 = null,
        calling_name_updated_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calling_name = "CallingName",
                .calling_name_updated_timestamp = "CallingNameUpdatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_proxy_session: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions/{ProxySessionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProxySession",
    Request: type = struct {
        voice_connector_id: []const u8,
        proxy_session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .proxy_session_id = "ProxySessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_proxy_session) } {
            return .{ .service_metadata = service_metadata, .action = get_proxy_session };
        }
    },
    Response: type = struct {
        proxy_session: ?ProxySession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy_session = "ProxySession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_sip_media_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-media-applications/{SipMediaApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSipMediaApplication",
    Request: type = struct {
        sip_media_application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sip_media_application) } {
            return .{ .service_metadata = service_metadata, .action = get_sip_media_application };
        }
    },
    Response: type = struct {
        sip_media_application: ?SipMediaApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application = "SipMediaApplication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_sip_media_application_alexa_skill_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/alexa-skill-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSipMediaApplicationAlexaSkillConfiguration",
    Request: type = struct {
        sip_media_application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sip_media_application_alexa_skill_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_sip_media_application_alexa_skill_configuration };
        }
    },
    Response: type = struct {
        sip_media_application_alexa_skill_configuration: ?SipMediaApplicationAlexaSkillConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_alexa_skill_configuration = "SipMediaApplicationAlexaSkillConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_sip_media_application_logging_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/logging-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSipMediaApplicationLoggingConfiguration",
    Request: type = struct {
        sip_media_application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sip_media_application_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_sip_media_application_logging_configuration };
        }
    },
    Response: type = struct {
        sip_media_application_logging_configuration: ?SipMediaApplicationLoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_logging_configuration = "SipMediaApplicationLoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_sip_rule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-rules/{SipRuleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSipRule",
    Request: type = struct {
        sip_rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule_id = "SipRuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sip_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_sip_rule };
        }
    },
    Response: type = struct {
        sip_rule: ?SipRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule = "SipRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_speaker_search_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/speaker-search-tasks/{SpeakerSearchTaskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSpeakerSearchTask",
    Request: type = struct {
        voice_connector_id: []const u8,
        speaker_search_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .speaker_search_task_id = "SpeakerSearchTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_speaker_search_task) } {
            return .{ .service_metadata = service_metadata, .action = get_speaker_search_task };
        }
    },
    Response: type = struct {
        speaker_search_task: ?SpeakerSearchTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .speaker_search_task = "SpeakerSearchTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector };
        }
    },
    Response: type = struct {
        voice_connector: ?VoiceConnector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_emergency_calling_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/emergency-calling-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorEmergencyCallingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_emergency_calling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_emergency_calling_configuration };
        }
    },
    Response: type = struct {
        emergency_calling_configuration: ?EmergencyCallingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .emergency_calling_configuration = "EmergencyCallingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_group };
        }
    },
    Response: type = struct {
        voice_connector_group: ?VoiceConnectorGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group = "VoiceConnectorGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_logging_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/logging-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorLoggingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_origination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/origination",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorOrigination",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_origination) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_origination };
        }
    },
    Response: type = struct {
        origination: ?Origination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination = "Origination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_proxy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/programmable-numbers/proxy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorProxy",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_proxy) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_proxy };
        }
    },
    Response: type = struct {
        proxy: ?Proxy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy = "Proxy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_streaming_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/streaming-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorStreamingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_streaming_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_streaming_configuration };
        }
    },
    Response: type = struct {
        streaming_configuration: ?StreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_configuration = "StreamingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_termination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorTermination",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_termination) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_termination };
        }
    },
    Response: type = struct {
        termination: ?Termination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .termination = "Termination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_termination_health: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination/health",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorTerminationHealth",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_termination_health) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_termination_health };
        }
    },
    Response: type = struct {
        termination_health: ?struct {
            timestamp: ?i64 = null,
            source: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .source = "Source",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .termination_health = "TerminationHealth",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-profiles/{VoiceProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceProfile",
    Request: type = struct {
        voice_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_id = "VoiceProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_profile };
        }
    },
    Response: type = struct {
        voice_profile: ?VoiceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile = "VoiceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_profile_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-profile-domains/{VoiceProfileDomainId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceProfileDomain",
    Request: type = struct {
        voice_profile_domain_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_domain_id = "VoiceProfileDomainId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_profile_domain) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_profile_domain };
        }
    },
    Response: type = struct {
        voice_profile_domain: ?VoiceProfileDomain = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_domain = "VoiceProfileDomain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_tone_analysis_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/voice-tone-analysis-tasks/{VoiceToneAnalysisTaskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceToneAnalysisTask",
    Request: type = struct {
        voice_connector_id: []const u8,
        voice_tone_analysis_task_id: []const u8,
        is_caller: bool,

        pub const http_query = .{
            .is_caller = "isCaller",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .voice_tone_analysis_task_id = "VoiceToneAnalysisTaskId",
                .is_caller = "IsCaller",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_tone_analysis_task) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_tone_analysis_task };
        }
    },
    Response: type = struct {
        voice_tone_analysis_task: ?VoiceToneAnalysisTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_tone_analysis_task = "VoiceToneAnalysisTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_available_voice_connector_regions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connector-regions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAvailableVoiceConnectorRegions",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_voice_connector_regions) } {
            return .{ .service_metadata = service_metadata, .action = list_available_voice_connector_regions };
        }
    },
    Response: type = struct {
        voice_connector_regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_regions = "VoiceConnectorRegions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_phone_number_orders: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-number-orders",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPhoneNumberOrders",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_phone_number_orders) } {
            return .{ .service_metadata = service_metadata, .action = list_phone_number_orders };
        }
    },
    Response: type = struct {
        phone_number_orders: ?[]PhoneNumberOrder = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_orders = "PhoneNumberOrders",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_phone_numbers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPhoneNumbers",
    Request: type = struct {
        status: ?[]const u8 = null,
        product_type: ?[]const u8 = null,
        filter_name: ?[]const u8 = null,
        filter_value: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .status = "status",
            .product_type = "product-type",
            .filter_name = "filter-name",
            .filter_value = "filter-value",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .product_type = "ProductType",
                .filter_name = "FilterName",
                .filter_value = "FilterValue",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = list_phone_numbers };
        }
    },
    Response: type = struct {
        phone_numbers: ?[]PhoneNumber = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_numbers = "PhoneNumbers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_proxy_sessions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProxySessions",
    Request: type = struct {
        voice_connector_id: []const u8,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status = "status",
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .status = "Status",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_proxy_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_proxy_sessions };
        }
    },
    Response: type = struct {
        proxy_sessions: ?[]ProxySession = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy_sessions = "ProxySessions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_sip_media_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-media-applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSipMediaApplications",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sip_media_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_sip_media_applications };
        }
    },
    Response: type = struct {
        sip_media_applications: ?[]SipMediaApplication = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_applications = "SipMediaApplications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_sip_rules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-rules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSipRules",
    Request: type = struct {
        sip_media_application_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .sip_media_application_id = "sip-media-application",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sip_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_sip_rules };
        }
    },
    Response: type = struct {
        sip_rules: ?[]SipRule = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rules = "SipRules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_supported_phone_number_countries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-number-countries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSupportedPhoneNumberCountries",
    Request: type = struct {
        product_type: []const u8,

        pub const http_query = .{
            .product_type = "product-type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_type = "ProductType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_supported_phone_number_countries) } {
            return .{ .service_metadata = service_metadata, .action = list_supported_phone_number_countries };
        }
    },
    Response: type = struct {
        phone_number_countries: ?[]struct {
            country_code: ?[]const u8 = null,
            supported_phone_number_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .country_code = "CountryCode",
                    .supported_phone_number_types = "SupportedPhoneNumberTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_countries = "PhoneNumberCountries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const list_voice_connector_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connector-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVoiceConnectorGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_voice_connector_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_voice_connector_groups };
        }
    },
    Response: type = struct {
        voice_connector_groups: ?[]VoiceConnectorGroup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_groups = "VoiceConnectorGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_voice_connectors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVoiceConnectors",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_voice_connectors) } {
            return .{ .service_metadata = service_metadata, .action = list_voice_connectors };
        }
    },
    Response: type = struct {
        voice_connectors: ?[]VoiceConnector = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connectors = "VoiceConnectors",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_voice_connector_termination_credentials: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination/credentials",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVoiceConnectorTerminationCredentials",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_voice_connector_termination_credentials) } {
            return .{ .service_metadata = service_metadata, .action = list_voice_connector_termination_credentials };
        }
    },
    Response: type = struct {
        usernames: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usernames = "Usernames",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_voice_profile_domains: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-profile-domains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVoiceProfileDomains",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_voice_profile_domains) } {
            return .{ .service_metadata = service_metadata, .action = list_voice_profile_domains };
        }
    },
    Response: type = struct {
        voice_profile_domains: ?[]struct {
            voice_profile_domain_id: ?[]const u8 = null,
            voice_profile_domain_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .voice_profile_domain_id = "VoiceProfileDomainId",
                    .voice_profile_domain_arn = "VoiceProfileDomainArn",
                    .name = "Name",
                    .description = "Description",
                    .created_timestamp = "CreatedTimestamp",
                    .updated_timestamp = "UpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_domains = "VoiceProfileDomains",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_voice_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVoiceProfiles",
    Request: type = struct {
        voice_profile_domain_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .voice_profile_domain_id = "voice-profile-domain-id",
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_domain_id = "VoiceProfileDomainId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_voice_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_voice_profiles };
        }
    },
    Response: type = struct {
        voice_profiles: ?[]struct {
            voice_profile_id: ?[]const u8 = null,
            voice_profile_arn: ?[]const u8 = null,
            voice_profile_domain_id: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            updated_timestamp: ?i64 = null,
            expiration_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .voice_profile_id = "VoiceProfileId",
                    .voice_profile_arn = "VoiceProfileArn",
                    .voice_profile_domain_id = "VoiceProfileDomainId",
                    .created_timestamp = "CreatedTimestamp",
                    .updated_timestamp = "UpdatedTimestamp",
                    .expiration_timestamp = "ExpirationTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profiles = "VoiceProfiles",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_sip_media_application_alexa_skill_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/alexa-skill-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSipMediaApplicationAlexaSkillConfiguration",
    Request: type = struct {
        sip_media_application_id: []const u8,
        sip_media_application_alexa_skill_configuration: ?SipMediaApplicationAlexaSkillConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .sip_media_application_alexa_skill_configuration = "SipMediaApplicationAlexaSkillConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_sip_media_application_alexa_skill_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_sip_media_application_alexa_skill_configuration };
        }
    },
    Response: type = struct {
        sip_media_application_alexa_skill_configuration: ?SipMediaApplicationAlexaSkillConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_alexa_skill_configuration = "SipMediaApplicationAlexaSkillConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_sip_media_application_logging_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/logging-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSipMediaApplicationLoggingConfiguration",
    Request: type = struct {
        sip_media_application_id: []const u8,
        sip_media_application_logging_configuration: ?SipMediaApplicationLoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .sip_media_application_logging_configuration = "SipMediaApplicationLoggingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_sip_media_application_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_sip_media_application_logging_configuration };
        }
    },
    Response: type = struct {
        sip_media_application_logging_configuration: ?SipMediaApplicationLoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_logging_configuration = "SipMediaApplicationLoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_emergency_calling_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/emergency-calling-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorEmergencyCallingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,
        emergency_calling_configuration: EmergencyCallingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .emergency_calling_configuration = "EmergencyCallingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_emergency_calling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_emergency_calling_configuration };
        }
    },
    Response: type = struct {
        emergency_calling_configuration: ?EmergencyCallingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .emergency_calling_configuration = "EmergencyCallingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_logging_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/logging-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorLoggingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,
        logging_configuration: LoggingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_origination: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/origination",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorOrigination",
    Request: type = struct {
        voice_connector_id: []const u8,
        origination: Origination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .origination = "Origination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_origination) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_origination };
        }
    },
    Response: type = struct {
        origination: ?Origination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination = "Origination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_proxy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/programmable-numbers/proxy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorProxy",
    Request: type = struct {
        voice_connector_id: []const u8,
        default_session_expiry_minutes: i64,
        phone_number_pool_countries: [][]const u8,
        fall_back_phone_number: ?[]const u8 = null,
        disabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .default_session_expiry_minutes = "DefaultSessionExpiryMinutes",
                .phone_number_pool_countries = "PhoneNumberPoolCountries",
                .fall_back_phone_number = "FallBackPhoneNumber",
                .disabled = "Disabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_proxy) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_proxy };
        }
    },
    Response: type = struct {
        proxy: ?Proxy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy = "Proxy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_streaming_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/streaming-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorStreamingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,
        streaming_configuration: StreamingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .streaming_configuration = "StreamingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_streaming_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_streaming_configuration };
        }
    },
    Response: type = struct {
        streaming_configuration: ?StreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_configuration = "StreamingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_termination: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorTermination",
    Request: type = struct {
        voice_connector_id: []const u8,
        termination: Termination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .termination = "Termination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_termination) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_termination };
        }
    },
    Response: type = struct {
        termination: ?Termination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .termination = "Termination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_termination_credentials: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination/credentials?operation=put",
        .success_code = 204,
    };

    action_name: []const u8 = "PutVoiceConnectorTerminationCredentials",
    Request: type = struct {
        voice_connector_id: []const u8,
        credentials: ?[]struct {
            username: ?[]const u8 = null,
            password: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .username = "Username",
                    .password = "Password",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_termination_credentials) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_termination_credentials };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const restore_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-numbers/{PhoneNumberId}?operation=restore",
        .success_code = 200,
    };

    action_name: []const u8 = "RestorePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = restore_phone_number };
        }
    },
    Response: type = struct {
        phone_number: ?PhoneNumber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const search_available_phone_numbers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/search?type=phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchAvailablePhoneNumbers",
    Request: type = struct {
        area_code: ?[]const u8 = null,
        city: ?[]const u8 = null,
        country: ?[]const u8 = null,
        state: ?[]const u8 = null,
        toll_free_prefix: ?[]const u8 = null,
        phone_number_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .area_code = "area-code",
            .city = "city",
            .country = "country",
            .state = "state",
            .toll_free_prefix = "toll-free-prefix",
            .phone_number_type = "phone-number-type",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .area_code = "AreaCode",
                .city = "City",
                .country = "Country",
                .state = "State",
                .toll_free_prefix = "TollFreePrefix",
                .phone_number_type = "PhoneNumberType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_available_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = search_available_phone_numbers };
        }
    },
    Response: type = struct {
        e164_phone_numbers: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .e164_phone_numbers = "E164PhoneNumbers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const start_speaker_search_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/speaker-search-tasks",
        .success_code = 201,
    };

    action_name: []const u8 = "StartSpeakerSearchTask",
    Request: type = struct {
        voice_connector_id: []const u8,
        transaction_id: []const u8,
        voice_profile_domain_id: []const u8,
        client_request_token: ?[]const u8 = null,
        call_leg: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .transaction_id = "TransactionId",
                .voice_profile_domain_id = "VoiceProfileDomainId",
                .client_request_token = "ClientRequestToken",
                .call_leg = "CallLeg",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_speaker_search_task) } {
            return .{ .service_metadata = service_metadata, .action = start_speaker_search_task };
        }
    },
    Response: type = struct {
        speaker_search_task: ?SpeakerSearchTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .speaker_search_task = "SpeakerSearchTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        Gone,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
        UnprocessableEntity,
    },
} = .{};
pub const start_voice_tone_analysis_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/voice-tone-analysis-tasks",
        .success_code = 201,
    };

    action_name: []const u8 = "StartVoiceToneAnalysisTask",
    Request: type = struct {
        voice_connector_id: []const u8,
        transaction_id: []const u8,
        language_code: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .transaction_id = "TransactionId",
                .language_code = "LanguageCode",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_voice_tone_analysis_task) } {
            return .{ .service_metadata = service_metadata, .action = start_voice_tone_analysis_task };
        }
    },
    Response: type = struct {
        voice_tone_analysis_task: ?VoiceToneAnalysisTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_tone_analysis_task = "VoiceToneAnalysisTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        Gone,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
        UnprocessableEntity,
    },
} = .{};
pub const stop_speaker_search_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/speaker-search-tasks/{SpeakerSearchTaskId}?operation=stop",
        .success_code = 204,
    };

    action_name: []const u8 = "StopSpeakerSearchTask",
    Request: type = struct {
        voice_connector_id: []const u8,
        speaker_search_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .speaker_search_task_id = "SpeakerSearchTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_speaker_search_task) } {
            return .{ .service_metadata = service_metadata, .action = stop_speaker_search_task };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
        UnprocessableEntity,
    },
} = .{};
pub const stop_voice_tone_analysis_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/voice-tone-analysis-tasks/{VoiceToneAnalysisTaskId}?operation=stop",
        .success_code = 204,
    };

    action_name: []const u8 = "StopVoiceToneAnalysisTask",
    Request: type = struct {
        voice_connector_id: []const u8,
        voice_tone_analysis_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .voice_tone_analysis_task_id = "VoiceToneAnalysisTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_voice_tone_analysis_task) } {
            return .{ .service_metadata = service_metadata, .action = stop_voice_tone_analysis_task };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
        UnprocessableEntity,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=tag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=untag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const update_global_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/settings",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateGlobalSettings",
    Request: type = struct {
        voice_connector: ?VoiceConnectorSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_global_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_global_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-numbers/{PhoneNumberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,
        product_type: ?[]const u8 = null,
        calling_name: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .product_type = "ProductType",
                .calling_name = "CallingName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = update_phone_number };
        }
    },
    Response: type = struct {
        phone_number: ?PhoneNumber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_phone_number_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/settings/phone-number",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdatePhoneNumberSettings",
    Request: type = struct {
        calling_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calling_name = "CallingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_phone_number_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_phone_number_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_proxy_session: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions/{ProxySessionId}",
        .success_code = 201,
    };

    action_name: []const u8 = "UpdateProxySession",
    Request: type = struct {
        voice_connector_id: []const u8,
        proxy_session_id: []const u8,
        capabilities: [][]const u8,
        expiry_minutes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .proxy_session_id = "ProxySessionId",
                .capabilities = "Capabilities",
                .expiry_minutes = "ExpiryMinutes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_proxy_session) } {
            return .{ .service_metadata = service_metadata, .action = update_proxy_session };
        }
    },
    Response: type = struct {
        proxy_session: ?ProxySession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy_session = "ProxySession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_sip_media_application: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sip-media-applications/{SipMediaApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSipMediaApplication",
    Request: type = struct {
        sip_media_application_id: []const u8,
        name: ?[]const u8 = null,
        endpoints: ?[]SipMediaApplicationEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .name = "Name",
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sip_media_application) } {
            return .{ .service_metadata = service_metadata, .action = update_sip_media_application };
        }
    },
    Response: type = struct {
        sip_media_application: ?SipMediaApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application = "SipMediaApplication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_sip_media_application_call: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/calls/{TransactionId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateSipMediaApplicationCall",
    Request: type = struct {
        sip_media_application_id: []const u8,
        transaction_id: []const u8,
        arguments: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .transaction_id = "TransactionId",
                .arguments = "Arguments",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "arguments", field_name))
                return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sip_media_application_call) } {
            return .{ .service_metadata = service_metadata, .action = update_sip_media_application_call };
        }
    },
    Response: type = struct {
        sip_media_application_call: ?SipMediaApplicationCall = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_call = "SipMediaApplicationCall",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_sip_rule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sip-rules/{SipRuleId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateSipRule",
    Request: type = struct {
        sip_rule_id: []const u8,
        name: []const u8,
        disabled: ?bool = null,
        target_applications: ?[]SipRuleTargetApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule_id = "SipRuleId",
                .name = "Name",
                .disabled = "Disabled",
                .target_applications = "TargetApplications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sip_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_sip_rule };
        }
    },
    Response: type = struct {
        sip_rule: ?SipRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule = "SipRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_voice_connector: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,
        name: []const u8,
        require_encryption: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .name = "Name",
                .require_encryption = "RequireEncryption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = update_voice_connector };
        }
    },
    Response: type = struct {
        voice_connector: ?VoiceConnector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_voice_connector_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,
        name: []const u8,
        voice_connector_items: []VoiceConnectorItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
                .name = "Name",
                .voice_connector_items = "VoiceConnectorItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = update_voice_connector_group };
        }
    },
    Response: type = struct {
        voice_connector_group: ?VoiceConnectorGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group = "VoiceConnectorGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_voice_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-profiles/{VoiceProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVoiceProfile",
    Request: type = struct {
        voice_profile_id: []const u8,
        speaker_search_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_id = "VoiceProfileId",
                .speaker_search_task_id = "SpeakerSearchTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_voice_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_voice_profile };
        }
    },
    Response: type = struct {
        voice_profile: ?VoiceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile = "VoiceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        Gone,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_voice_profile_domain: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-profile-domains/{VoiceProfileDomainId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVoiceProfileDomain",
    Request: type = struct {
        voice_profile_domain_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_domain_id = "VoiceProfileDomainId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_voice_profile_domain) } {
            return .{ .service_metadata = service_metadata, .action = update_voice_profile_domain };
        }
    },
    Response: type = struct {
        voice_profile_domain: ?VoiceProfileDomain = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_profile_domain = "VoiceProfileDomain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const validate_e911_address: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/emergency-calling/address",
        .success_code = 202,
    };

    action_name: []const u8 = "ValidateE911Address",
    Request: type = struct {
        aws_account_id: []const u8,
        street_number: []const u8,
        street_info: []const u8,
        city: []const u8,
        state: []const u8,
        country: []const u8,
        postal_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .street_number = "StreetNumber",
                .street_info = "StreetInfo",
                .city = "City",
                .state = "State",
                .country = "Country",
                .postal_code = "PostalCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_e911_address) } {
            return .{ .service_metadata = service_metadata, .action = validate_e911_address };
        }
    },
    Response: type = struct {
        validation_result: ?i64 = null,
        address_external_id: ?[]const u8 = null,
        address: ?struct {
            street_name: ?[]const u8 = null,
            street_suffix: ?[]const u8 = null,
            post_directional: ?[]const u8 = null,
            pre_directional: ?[]const u8 = null,
            street_number: ?[]const u8 = null,
            city: ?[]const u8 = null,
            state: ?[]const u8 = null,
            postal_code: ?[]const u8 = null,
            postal_code_plus4: ?[]const u8 = null,
            country: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .street_name = "streetName",
                    .street_suffix = "streetSuffix",
                    .post_directional = "postDirectional",
                    .pre_directional = "preDirectional",
                    .street_number = "streetNumber",
                    .city = "city",
                    .state = "state",
                    .postal_code = "postalCode",
                    .postal_code_plus4 = "postalCodePlus4",
                    .country = "country",
                };
                return @field(mappings, field_name);
            }
        } = null,
        candidate_address_list: ?[]struct {
            street_info: ?[]const u8 = null,
            street_number: ?[]const u8 = null,
            city: ?[]const u8 = null,
            state: ?[]const u8 = null,
            postal_code: ?[]const u8 = null,
            postal_code_plus4: ?[]const u8 = null,
            country: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .street_info = "streetInfo",
                    .street_number = "streetNumber",
                    .city = "city",
                    .state = "state",
                    .postal_code = "postalCode",
                    .postal_code_plus4 = "postalCodePlus4",
                    .country = "country",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .validation_result = "ValidationResult",
                .address_external_id = "AddressExternalId",
                .address = "Address",
                .candidate_address_list = "CandidateAddressList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};

pub const VoiceProfileDomain = struct {
    voice_profile_domain_id: ?[]const u8 = null,
    voice_profile_domain_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    server_side_encryption_configuration: ?ServerSideEncryptionConfiguration = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_profile_domain_id = "VoiceProfileDomainId",
            .voice_profile_domain_arn = "VoiceProfileDomainArn",
            .name = "Name",
            .description = "Description",
            .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerSideEncryptionConfiguration = struct {
    kms_key_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceProfile = struct {
    voice_profile_id: ?[]const u8 = null,
    voice_profile_arn: ?[]const u8 = null,
    voice_profile_domain_id: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    expiration_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_profile_id = "VoiceProfileId",
            .voice_profile_arn = "VoiceProfileArn",
            .voice_profile_domain_id = "VoiceProfileDomainId",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .expiration_timestamp = "ExpirationTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceConnectorGroup = struct {
    voice_connector_group_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    voice_connector_items: ?[]VoiceConnectorItem = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    voice_connector_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_group_id = "VoiceConnectorGroupId",
            .name = "Name",
            .voice_connector_items = "VoiceConnectorItems",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .voice_connector_group_arn = "VoiceConnectorGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceConnectorItem = struct {
    voice_connector_id: []const u8,
    priority: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_id = "VoiceConnectorId",
            .priority = "Priority",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceConnector = struct {
    voice_connector_id: ?[]const u8 = null,
    aws_region: ?[]const u8 = null,
    name: ?[]const u8 = null,
    outbound_host_name: ?[]const u8 = null,
    require_encryption: ?bool = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    voice_connector_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_id = "VoiceConnectorId",
            .aws_region = "AwsRegion",
            .name = "Name",
            .outbound_host_name = "OutboundHostName",
            .require_encryption = "RequireEncryption",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .voice_connector_arn = "VoiceConnectorArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SipRule = struct {
    sip_rule_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    disabled: ?bool = null,
    trigger_type: ?[]const u8 = null,
    trigger_value: ?[]const u8 = null,
    target_applications: ?[]SipRuleTargetApplication = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sip_rule_id = "SipRuleId",
            .name = "Name",
            .disabled = "Disabled",
            .trigger_type = "TriggerType",
            .trigger_value = "TriggerValue",
            .target_applications = "TargetApplications",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const SipRuleTargetApplication = struct {
    sip_media_application_id: ?[]const u8 = null,
    priority: ?i64 = null,
    aws_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sip_media_application_id = "SipMediaApplicationId",
            .priority = "Priority",
            .aws_region = "AwsRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplicationCall = struct {
    transaction_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transaction_id = "TransactionId",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplication = struct {
    sip_media_application_id: ?[]const u8 = null,
    aws_region: ?[]const u8 = null,
    name: ?[]const u8 = null,
    endpoints: ?[]SipMediaApplicationEndpoint = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    sip_media_application_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sip_media_application_id = "SipMediaApplicationId",
            .aws_region = "AwsRegion",
            .name = "Name",
            .endpoints = "Endpoints",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .sip_media_application_arn = "SipMediaApplicationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplicationEndpoint = struct {
    lambda_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_arn = "LambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ProxySession = struct {
    voice_connector_id: ?[]const u8 = null,
    proxy_session_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    expiry_minutes: ?i64 = null,
    capabilities: ?[][]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    ended_timestamp: ?i64 = null,
    participants: ?[]Participant = null,
    number_selection_behavior: ?[]const u8 = null,
    geo_match_level: ?[]const u8 = null,
    geo_match_params: ?GeoMatchParams = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_id = "VoiceConnectorId",
            .proxy_session_id = "ProxySessionId",
            .name = "Name",
            .status = "Status",
            .expiry_minutes = "ExpiryMinutes",
            .capabilities = "Capabilities",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .ended_timestamp = "EndedTimestamp",
            .participants = "Participants",
            .number_selection_behavior = "NumberSelectionBehavior",
            .geo_match_level = "GeoMatchLevel",
            .geo_match_params = "GeoMatchParams",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoMatchParams = struct {
    country: []const u8,
    area_code: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country = "Country",
            .area_code = "AreaCode",
        };
        return @field(mappings, field_name);
    }
};

pub const Participant = struct {
    phone_number: ?[]const u8 = null,
    proxy_phone_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number = "PhoneNumber",
            .proxy_phone_number = "ProxyPhoneNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumber = struct {
    phone_number_id: ?[]const u8 = null,
    e164_phone_number: ?[]const u8 = null,
    country: ?[]const u8 = null,
    type: ?[]const u8 = null,
    product_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    capabilities: ?PhoneNumberCapabilities = null,
    associations: ?[]PhoneNumberAssociation = null,
    calling_name: ?[]const u8 = null,
    calling_name_status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    deletion_timestamp: ?i64 = null,
    order_id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number_id = "PhoneNumberId",
            .e164_phone_number = "E164PhoneNumber",
            .country = "Country",
            .type = "Type",
            .product_type = "ProductType",
            .status = "Status",
            .capabilities = "Capabilities",
            .associations = "Associations",
            .calling_name = "CallingName",
            .calling_name_status = "CallingNameStatus",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .deletion_timestamp = "DeletionTimestamp",
            .order_id = "OrderId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberAssociation = struct {
    value: ?[]const u8 = null,
    name: ?[]const u8 = null,
    associated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .name = "Name",
            .associated_timestamp = "AssociatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberCapabilities = struct {
    inbound_call: ?bool = null,
    outbound_call: ?bool = null,
    inbound_sms: ?bool = null,
    outbound_sms: ?bool = null,
    inbound_mms: ?bool = null,
    outbound_mms: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inbound_call = "InboundCall",
            .outbound_call = "OutboundCall",
            .inbound_sms = "InboundSMS",
            .outbound_sms = "OutboundSMS",
            .inbound_mms = "InboundMMS",
            .outbound_mms = "OutboundMMS",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceConnectorSettings = struct {
    cdr_bucket: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cdr_bucket = "CdrBucket",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceToneAnalysisTask = struct {
    voice_tone_analysis_task_id: ?[]const u8 = null,
    voice_tone_analysis_task_status: ?[]const u8 = null,
    call_details: ?CallDetails = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    started_timestamp: ?i64 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_tone_analysis_task_id = "VoiceToneAnalysisTaskId",
            .voice_tone_analysis_task_status = "VoiceToneAnalysisTaskStatus",
            .call_details = "CallDetails",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .started_timestamp = "StartedTimestamp",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const CallDetails = struct {
    voice_connector_id: ?[]const u8 = null,
    transaction_id: ?[]const u8 = null,
    is_caller: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_id = "VoiceConnectorId",
            .transaction_id = "TransactionId",
            .is_caller = "IsCaller",
        };
        return @field(mappings, field_name);
    }
};

pub const SpeakerSearchTask = struct {
    speaker_search_task_id: ?[]const u8 = null,
    speaker_search_task_status: ?[]const u8 = null,
    call_details: ?CallDetails = null,
    speaker_search_details: ?SpeakerSearchDetails = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    started_timestamp: ?i64 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .speaker_search_task_id = "SpeakerSearchTaskId",
            .speaker_search_task_status = "SpeakerSearchTaskStatus",
            .call_details = "CallDetails",
            .speaker_search_details = "SpeakerSearchDetails",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .started_timestamp = "StartedTimestamp",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const SpeakerSearchDetails = struct {
    results: ?[]SpeakerSearchResult = null,
    voiceprint_generation_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .results = "Results",
            .voiceprint_generation_status = "VoiceprintGenerationStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const SpeakerSearchResult = struct {
    confidence_score: ?f32 = null,
    voice_profile_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confidence_score = "ConfidenceScore",
            .voice_profile_id = "VoiceProfileId",
        };
        return @field(mappings, field_name);
    }
};

pub const Termination = struct {
    cps_limit: ?i64 = null,
    default_phone_number: ?[]const u8 = null,
    calling_regions: ?[][]const u8 = null,
    cidr_allowed_list: ?[][]const u8 = null,
    disabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cps_limit = "CpsLimit",
            .default_phone_number = "DefaultPhoneNumber",
            .calling_regions = "CallingRegions",
            .cidr_allowed_list = "CidrAllowedList",
            .disabled = "Disabled",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingConfiguration = struct {
    data_retention_in_hours: i64,
    disabled: bool,
    streaming_notification_targets: ?[]StreamingNotificationTarget = null,
    media_insights_configuration: ?MediaInsightsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_retention_in_hours = "DataRetentionInHours",
            .disabled = "Disabled",
            .streaming_notification_targets = "StreamingNotificationTargets",
            .media_insights_configuration = "MediaInsightsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaInsightsConfiguration = struct {
    disabled: ?bool = null,
    configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disabled = "Disabled",
            .configuration_arn = "ConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingNotificationTarget = struct {
    notification_target: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notification_target = "NotificationTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const Proxy = struct {
    default_session_expiry_minutes: ?i64 = null,
    disabled: ?bool = null,
    fall_back_phone_number: ?[]const u8 = null,
    phone_number_countries: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_session_expiry_minutes = "DefaultSessionExpiryMinutes",
            .disabled = "Disabled",
            .fall_back_phone_number = "FallBackPhoneNumber",
            .phone_number_countries = "PhoneNumberCountries",
        };
        return @field(mappings, field_name);
    }
};

pub const Origination = struct {
    routes: ?[]OriginationRoute = null,
    disabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .routes = "Routes",
            .disabled = "Disabled",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginationRoute = struct {
    host: ?[]const u8 = null,
    port: ?i64 = null,
    protocol: ?[]const u8 = null,
    priority: ?i64 = null,
    weight: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .protocol = "Protocol",
            .priority = "Priority",
            .weight = "Weight",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfiguration = struct {
    enable_sip_logs: ?bool = null,
    enable_media_metric_logs: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_sip_logs = "EnableSIPLogs",
            .enable_media_metric_logs = "EnableMediaMetricLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const EmergencyCallingConfiguration = struct {
    dnis: ?[]DNISEmergencyCallingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dnis = "DNIS",
        };
        return @field(mappings, field_name);
    }
};

pub const DNISEmergencyCallingConfiguration = struct {
    emergency_phone_number: []const u8,
    test_phone_number: ?[]const u8 = null,
    calling_country: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .emergency_phone_number = "EmergencyPhoneNumber",
            .test_phone_number = "TestPhoneNumber",
            .calling_country = "CallingCountry",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplicationLoggingConfiguration = struct {
    enable_sip_media_application_message_logs: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_sip_media_application_message_logs = "EnableSipMediaApplicationMessageLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplicationAlexaSkillConfiguration = struct {
    alexa_skill_status: []const u8,
    alexa_skill_ids: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alexa_skill_status = "AlexaSkillStatus",
            .alexa_skill_ids = "AlexaSkillIds",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberOrder = struct {
    phone_number_order_id: ?[]const u8 = null,
    product_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    order_type: ?[]const u8 = null,
    ordered_phone_numbers: ?[]OrderedPhoneNumber = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number_order_id = "PhoneNumberOrderId",
            .product_type = "ProductType",
            .status = "Status",
            .order_type = "OrderType",
            .ordered_phone_numbers = "OrderedPhoneNumbers",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const OrderedPhoneNumber = struct {
    e164_phone_number: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .e164_phone_number = "E164PhoneNumber",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberError = struct {
    phone_number_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number_id = "PhoneNumberId",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};
