const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-09-23";
pub const sdk_id: []const u8 = "Cloud9";
pub const arn_namespace: ?[]const u8 = "cloud9";
pub const endpoint_prefix: []const u8 = "cloud9";
pub const sigv4_name: []const u8 = "cloud9";
pub const name: []const u8 = "AWSCloud9WorkspaceManagementService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-09-23",
    sdk_id: []const u8 = "Cloud9",
    arn_namespace: ?[]const u8 = "cloud9",
    endpoint_prefix: []const u8 = "cloud9",
    sigv4_name: []const u8 = "cloud9",
    name: []const u8 = "AWSCloud9WorkspaceManagementService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_environment_ec2: struct {
    action_name: []const u8 = "CreateEnvironmentEC2",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        instance_type: []const u8,
        subnet_id: ?[]const u8 = null,
        image_id: []const u8,
        automatic_stop_time_minutes: ?i64 = null,
        owner_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        connection_type: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .client_request_token = "clientRequestToken",
                .instance_type = "instanceType",
                .subnet_id = "subnetId",
                .image_id = "imageId",
                .automatic_stop_time_minutes = "automaticStopTimeMinutes",
                .owner_arn = "ownerArn",
                .tags = "tags",
                .connection_type = "connectionType",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment_ec2) } {
            return .{ .service_metadata = service_metadata, .action = create_environment_ec2 };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_environment_membership: struct {
    action_name: []const u8 = "CreateEnvironmentMembership",
    Request: type = struct {
        environment_id: []const u8,
        user_arn: []const u8,
        permissions: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .user_arn = "userArn",
                .permissions = "permissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_environment_membership };
        }
    },
    Response: type = struct {
        membership: EnvironmentMember,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .membership = "membership",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_environment: struct {
    action_name: []const u8 = "DeleteEnvironment",
    Request: type = struct {
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_environment_membership: struct {
    action_name: []const u8 = "DeleteEnvironmentMembership",
    Request: type = struct {
        environment_id: []const u8,
        user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .user_arn = "userArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment_membership };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_environment_memberships: struct {
    action_name: []const u8 = "DescribeEnvironmentMemberships",
    Request: type = struct {
        user_arn: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        permissions: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
                .environment_id = "environmentId",
                .permissions = "permissions",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_environment_memberships) } {
            return .{ .service_metadata = service_metadata, .action = describe_environment_memberships };
        }
    },
    Response: type = struct {
        memberships: ?[]EnvironmentMember = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .memberships = "memberships",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_environments: struct {
    action_name: []const u8 = "DescribeEnvironments",
    Request: type = struct {
        environment_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_ids = "environmentIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_environments) } {
            return .{ .service_metadata = service_metadata, .action = describe_environments };
        }
    },
    Response: type = struct {
        environments: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            type: []const u8,
            connection_type: ?[]const u8 = null,
            arn: []const u8,
            owner_arn: []const u8,
            lifecycle: ?struct {
                status: ?[]const u8 = null,
                reason: ?[]const u8 = null,
                failure_resource: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "status",
                        .reason = "reason",
                        .failure_resource = "failureResource",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            managed_credentials_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .type = "type",
                    .connection_type = "connectionType",
                    .arn = "arn",
                    .owner_arn = "ownerArn",
                    .lifecycle = "lifecycle",
                    .managed_credentials_status = "managedCredentialsStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environments = "environments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_environment_status: struct {
    action_name: []const u8 = "DescribeEnvironmentStatus",
    Request: type = struct {
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_environment_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_environment_status };
        }
    },
    Response: type = struct {
        status: []const u8,
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_environments: struct {
    action_name: []const u8 = "ListEnvironments",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_environments };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        environment_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .environment_ids = "environmentIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentAccess,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentAccess,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_environment: struct {
    action_name: []const u8 = "UpdateEnvironment",
    Request: type = struct {
        environment_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        managed_credentials_action: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .name = "name",
                .description = "description",
                .managed_credentials_action = "managedCredentialsAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_environment_membership: struct {
    action_name: []const u8 = "UpdateEnvironmentMembership",
    Request: type = struct {
        environment_id: []const u8,
        user_arn: []const u8,
        permissions: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .user_arn = "userArn",
                .permissions = "permissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment_membership) } {
            return .{ .service_metadata = service_metadata, .action = update_environment_membership };
        }
    },
    Response: type = struct {
        membership: ?EnvironmentMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .membership = "membership",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const EnvironmentMember = struct {
    permissions: []const u8,
    user_id: []const u8,
    user_arn: []const u8,
    environment_id: []const u8,
    last_access: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .permissions = "permissions",
            .user_id = "userId",
            .user_arn = "userArn",
            .environment_id = "environmentId",
            .last_access = "lastAccess",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
