const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-09-30";
pub const sdk_id: []const u8 = "CloudControl";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "cloudcontrolapi";
pub const sigv4_name: []const u8 = "cloudcontrolapi";
pub const name: []const u8 = "CloudApiService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2021-09-30",
    sdk_id: []const u8 = "CloudControl",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "cloudcontrolapi",
    sigv4_name: []const u8 = "cloudcontrolapi",
    name: []const u8 = "CloudApiService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const cancel_resource_request: struct {
    action_name: []const u8 = "CancelResourceRequest",
    Request: type = struct {
        request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_token = "RequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_resource_request) } {
            return .{ .service_metadata = service_metadata, .action = cancel_resource_request };
        }
    },
    Response: type = struct {
        progress_event: ?ProgressEvent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_event = "ProgressEvent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        RequestTokenNotFound,
    },
} = .{};
pub const create_resource: struct {
    action_name: []const u8 = "CreateResource",
    Request: type = struct {
        type_name: []const u8,
        type_version_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        desired_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .type_version_id = "TypeVersionId",
                .role_arn = "RoleArn",
                .client_token = "ClientToken",
                .desired_state = "DesiredState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource) } {
            return .{ .service_metadata = service_metadata, .action = create_resource };
        }
    },
    Response: type = struct {
        progress_event: ?ProgressEvent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_event = "ProgressEvent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ClientTokenConflict,
        ConcurrentOperation,
        GeneralService,
        HandlerFailure,
        HandlerInternalFailure,
        InvalidCredentials,
        InvalidRequest,
        NetworkFailure,
        NotStabilized,
        NotUpdatable,
        PrivateType,
        ResourceConflict,
        ResourceNotFound,
        ServiceInternalError,
        ServiceLimitExceeded,
        Throttling,
        TypeNotFound,
        UnsupportedAction,
    },
} = .{};
pub const delete_resource: struct {
    action_name: []const u8 = "DeleteResource",
    Request: type = struct {
        type_name: []const u8,
        type_version_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .type_version_id = "TypeVersionId",
                .role_arn = "RoleArn",
                .client_token = "ClientToken",
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource };
        }
    },
    Response: type = struct {
        progress_event: ?ProgressEvent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_event = "ProgressEvent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ClientTokenConflict,
        ConcurrentOperation,
        GeneralService,
        HandlerFailure,
        HandlerInternalFailure,
        InvalidCredentials,
        InvalidRequest,
        NetworkFailure,
        NotStabilized,
        NotUpdatable,
        PrivateType,
        ResourceConflict,
        ResourceNotFound,
        ServiceInternalError,
        ServiceLimitExceeded,
        Throttling,
        TypeNotFound,
        UnsupportedAction,
    },
} = .{};
pub const get_resource: struct {
    action_name: []const u8 = "GetResource",
    Request: type = struct {
        type_name: []const u8,
        type_version_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .type_version_id = "TypeVersionId",
                .role_arn = "RoleArn",
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_resource };
        }
    },
    Response: type = struct {
        type_name: ?[]const u8 = null,
        resource_description: ?ResourceDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .resource_description = "ResourceDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        GeneralService,
        HandlerFailure,
        HandlerInternalFailure,
        InvalidCredentials,
        InvalidRequest,
        NetworkFailure,
        NotStabilized,
        NotUpdatable,
        PrivateType,
        ResourceConflict,
        ResourceNotFound,
        ServiceInternalError,
        ServiceLimitExceeded,
        Throttling,
        TypeNotFound,
        UnsupportedAction,
    },
} = .{};
pub const get_resource_request_status: struct {
    action_name: []const u8 = "GetResourceRequestStatus",
    Request: type = struct {
        request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_token = "RequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_request_status) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_request_status };
        }
    },
    Response: type = struct {
        progress_event: ?ProgressEvent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_event = "ProgressEvent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RequestTokenNotFound,
    },
} = .{};
pub const list_resource_requests: struct {
    action_name: []const u8 = "ListResourceRequests",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        resource_request_status_filter: ?struct {
            operations: ?[][]const u8 = null,
            operation_statuses: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operations = "Operations",
                    .operation_statuses = "OperationStatuses",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .resource_request_status_filter = "ResourceRequestStatusFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_requests) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_requests };
        }
    },
    Response: type = struct {
        resource_request_status_summaries: ?[]ProgressEvent = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_request_status_summaries = "ResourceRequestStatusSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_resources: struct {
    action_name: []const u8 = "ListResources",
    Request: type = struct {
        type_name: []const u8,
        type_version_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_model: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .type_version_id = "TypeVersionId",
                .role_arn = "RoleArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .resource_model = "ResourceModel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_resources };
        }
    },
    Response: type = struct {
        type_name: ?[]const u8 = null,
        resource_descriptions: ?[]ResourceDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .resource_descriptions = "ResourceDescriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        GeneralService,
        HandlerFailure,
        HandlerInternalFailure,
        InvalidCredentials,
        InvalidRequest,
        NetworkFailure,
        NotStabilized,
        NotUpdatable,
        PrivateType,
        ResourceConflict,
        ResourceNotFound,
        ServiceInternalError,
        ServiceLimitExceeded,
        Throttling,
        TypeNotFound,
        UnsupportedAction,
    },
} = .{};
pub const update_resource: struct {
    action_name: []const u8 = "UpdateResource",
    Request: type = struct {
        type_name: []const u8,
        type_version_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        identifier: []const u8,
        patch_document: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .type_version_id = "TypeVersionId",
                .role_arn = "RoleArn",
                .client_token = "ClientToken",
                .identifier = "Identifier",
                .patch_document = "PatchDocument",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_resource };
        }
    },
    Response: type = struct {
        progress_event: ?ProgressEvent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_event = "ProgressEvent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ClientTokenConflict,
        ConcurrentOperation,
        GeneralService,
        HandlerFailure,
        HandlerInternalFailure,
        InvalidCredentials,
        InvalidRequest,
        NetworkFailure,
        NotStabilized,
        NotUpdatable,
        PrivateType,
        ResourceConflict,
        ResourceNotFound,
        ServiceInternalError,
        ServiceLimitExceeded,
        Throttling,
        TypeNotFound,
        UnsupportedAction,
    },
} = .{};

pub const ProgressEvent = struct {
    type_name: ?[]const u8 = null,
    identifier: ?[]const u8 = null,
    request_token: ?[]const u8 = null,
    operation: ?[]const u8 = null,
    operation_status: ?[]const u8 = null,
    event_time: ?i64 = null,
    resource_model: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    retry_after: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type_name = "TypeName",
            .identifier = "Identifier",
            .request_token = "RequestToken",
            .operation = "Operation",
            .operation_status = "OperationStatus",
            .event_time = "EventTime",
            .resource_model = "ResourceModel",
            .status_message = "StatusMessage",
            .error_code = "ErrorCode",
            .retry_after = "RetryAfter",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDescription = struct {
    identifier: ?[]const u8 = null,
    properties: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }
};
