const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-01-11";
pub const sdk_id: []const u8 = "CloudDirectory";
pub const arn_namespace: ?[]const u8 = "clouddirectory";
pub const endpoint_prefix: []const u8 = "clouddirectory";
pub const sigv4_name: []const u8 = "clouddirectory";
pub const name: []const u8 = "AmazonCloudDirectory_20170111";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-01-11",
    sdk_id: []const u8 = "CloudDirectory",
    arn_namespace: ?[]const u8 = "clouddirectory",
    endpoint_prefix: []const u8 = "clouddirectory",
    sigv4_name: []const u8 = "clouddirectory",
    name: []const u8 = "AmazonCloudDirectory_20170111",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_facet_to_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/object/facets",
        .success_code = 200,
    };

    action_name: []const u8 = "AddFacetToObject",
    Request: type = struct {
        directory_arn: []const u8,
        schema_facet: SchemaFacet,
        object_attribute_list: ?[]AttributeKeyAndValue = null,
        object_reference: ObjectReference,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .schema_facet = "SchemaFacet",
                .object_attribute_list = "ObjectAttributeList",
                .object_reference = "ObjectReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_facet_to_object) } {
            return .{ .service_metadata = service_metadata, .action = add_facet_to_object };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const apply_schema: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/schema/apply",
        .success_code = 200,
    };

    action_name: []const u8 = "ApplySchema",
    Request: type = struct {
        published_schema_arn: []const u8,
        directory_arn: []const u8,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .published_schema_arn = "PublishedSchemaArn",
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_schema) } {
            return .{ .service_metadata = service_metadata, .action = apply_schema };
        }
    },
    Response: type = struct {
        applied_schema_arn: ?[]const u8 = null,
        directory_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applied_schema_arn = "AppliedSchemaArn",
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidAttachment,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        SchemaAlreadyExists,
        Validation,
    },
} = .{};
pub const attach_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/object/attach",
        .success_code = 200,
    };

    action_name: []const u8 = "AttachObject",
    Request: type = struct {
        directory_arn: []const u8,
        parent_reference: ObjectReference,
        child_reference: ObjectReference,
        link_name: []const u8,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .parent_reference = "ParentReference",
                .child_reference = "ChildReference",
                .link_name = "LinkName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_object) } {
            return .{ .service_metadata = service_metadata, .action = attach_object };
        }
    },
    Response: type = struct {
        attached_object_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attached_object_identifier = "AttachedObjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidAttachment,
        LimitExceeded,
        LinkNameAlreadyInUse,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const attach_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/policy/attach",
        .success_code = 200,
    };

    action_name: []const u8 = "AttachPolicy",
    Request: type = struct {
        directory_arn: []const u8,
        policy_reference: ObjectReference,
        object_reference: ObjectReference,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .policy_reference = "PolicyReference",
                .object_reference = "ObjectReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_policy) } {
            return .{ .service_metadata = service_metadata, .action = attach_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        NotPolicy,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const attach_to_index: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/index/attach",
        .success_code = 200,
    };

    action_name: []const u8 = "AttachToIndex",
    Request: type = struct {
        directory_arn: []const u8,
        index_reference: ObjectReference,
        target_reference: ObjectReference,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .index_reference = "IndexReference",
                .target_reference = "TargetReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_to_index) } {
            return .{ .service_metadata = service_metadata, .action = attach_to_index };
        }
    },
    Response: type = struct {
        attached_object_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attached_object_identifier = "AttachedObjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        IndexedAttributeMissing,
        InternalService,
        InvalidArn,
        InvalidAttachment,
        LimitExceeded,
        LinkNameAlreadyInUse,
        NotIndex,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const attach_typed_link: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/attach",
        .success_code = 200,
    };

    action_name: []const u8 = "AttachTypedLink",
    Request: type = struct {
        directory_arn: []const u8,
        source_object_reference: ObjectReference,
        target_object_reference: ObjectReference,
        typed_link_facet: TypedLinkSchemaAndFacetName,
        attributes: []AttributeNameAndValue,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .source_object_reference = "SourceObjectReference",
                .target_object_reference = "TargetObjectReference",
                .typed_link_facet = "TypedLinkFacet",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_typed_link) } {
            return .{ .service_metadata = service_metadata, .action = attach_typed_link };
        }
    },
    Response: type = struct {
        typed_link_specifier: ?TypedLinkSpecifier = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .typed_link_specifier = "TypedLinkSpecifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidAttachment,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const batch_read: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/batchread",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchRead",
    Request: type = struct {
        directory_arn: []const u8,
        operations: []struct {
            list_object_attributes: ?struct {
                object_reference: ObjectReference,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,
                facet_filter: ?SchemaFacet = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                        .facet_filter = "FacetFilter",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_object_children: ?struct {
                object_reference: ObjectReference,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_attached_indices: ?struct {
                target_reference: ObjectReference,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .target_reference = "TargetReference",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_object_parent_paths: ?struct {
                object_reference: ObjectReference,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            get_object_information: ?struct {
                object_reference: ObjectReference,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            get_object_attributes: ?struct {
                object_reference: ObjectReference,
                schema_facet: SchemaFacet,
                attribute_names: [][]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .schema_facet = "SchemaFacet",
                        .attribute_names = "AttributeNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_object_parents: ?struct {
                object_reference: ObjectReference,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_object_policies: ?struct {
                object_reference: ObjectReference,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_policy_attachments: ?struct {
                policy_reference: ObjectReference,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .policy_reference = "PolicyReference",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lookup_policy: ?struct {
                object_reference: ObjectReference,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_index: ?struct {
                ranges_on_indexed_values: ?[]ObjectAttributeRange = null,
                index_reference: ObjectReference,
                max_results: ?i64 = null,
                next_token: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ranges_on_indexed_values = "RangesOnIndexedValues",
                        .index_reference = "IndexReference",
                        .max_results = "MaxResults",
                        .next_token = "NextToken",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_outgoing_typed_links: ?struct {
                object_reference: ObjectReference,
                filter_attribute_ranges: ?[]TypedLinkAttributeRange = null,
                filter_typed_link: ?TypedLinkSchemaAndFacetName = null,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .filter_attribute_ranges = "FilterAttributeRanges",
                        .filter_typed_link = "FilterTypedLink",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_incoming_typed_links: ?struct {
                object_reference: ObjectReference,
                filter_attribute_ranges: ?[]TypedLinkAttributeRange = null,
                filter_typed_link: ?TypedLinkSchemaAndFacetName = null,
                next_token: ?[]const u8 = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .filter_attribute_ranges = "FilterAttributeRanges",
                        .filter_typed_link = "FilterTypedLink",
                        .next_token = "NextToken",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            get_link_attributes: ?struct {
                typed_link_specifier: TypedLinkSpecifier,
                attribute_names: [][]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .typed_link_specifier = "TypedLinkSpecifier",
                        .attribute_names = "AttributeNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .list_object_attributes = "ListObjectAttributes",
                    .list_object_children = "ListObjectChildren",
                    .list_attached_indices = "ListAttachedIndices",
                    .list_object_parent_paths = "ListObjectParentPaths",
                    .get_object_information = "GetObjectInformation",
                    .get_object_attributes = "GetObjectAttributes",
                    .list_object_parents = "ListObjectParents",
                    .list_object_policies = "ListObjectPolicies",
                    .list_policy_attachments = "ListPolicyAttachments",
                    .lookup_policy = "LookupPolicy",
                    .list_index = "ListIndex",
                    .list_outgoing_typed_links = "ListOutgoingTypedLinks",
                    .list_incoming_typed_links = "ListIncomingTypedLinks",
                    .get_link_attributes = "GetLinkAttributes",
                };
                return @field(mappings, field_name);
            }
        },
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .operations = "Operations",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_read) } {
            return .{ .service_metadata = service_metadata, .action = batch_read };
        }
    },
    Response: type = struct {
        responses: ?[]struct {
            successful_response: ?struct {
                list_object_attributes: ?struct {
                    attributes: ?[]AttributeKeyAndValue = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .attributes = "Attributes",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_object_children: ?struct {
                    children: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?[]const u8 = null,
                    } = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .children = "Children",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "children", field_name))
                            return try serializeMap(self.children, self.fieldNameFor("children"), options, out_stream);
                        return false;
                    }
                } = null,
                get_object_information: ?struct {
                    schema_facets: ?[]SchemaFacet = null,
                    object_identifier: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .schema_facets = "SchemaFacets",
                            .object_identifier = "ObjectIdentifier",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                get_object_attributes: ?struct {
                    attributes: ?[]AttributeKeyAndValue = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .attributes = "Attributes",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_attached_indices: ?struct {
                    index_attachments: ?[]IndexAttachment = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .index_attachments = "IndexAttachments",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_object_parent_paths: ?struct {
                    path_to_object_identifiers_list: ?[]PathToObjectIdentifiers = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .path_to_object_identifiers_list = "PathToObjectIdentifiersList",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_object_policies: ?struct {
                    attached_policy_ids: ?[][]const u8 = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .attached_policy_ids = "AttachedPolicyIds",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_policy_attachments: ?struct {
                    object_identifiers: ?[][]const u8 = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .object_identifiers = "ObjectIdentifiers",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                lookup_policy: ?struct {
                    policy_to_path_list: ?[]PolicyToPath = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .policy_to_path_list = "PolicyToPathList",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_index: ?struct {
                    index_attachments: ?[]IndexAttachment = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .index_attachments = "IndexAttachments",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_outgoing_typed_links: ?struct {
                    typed_link_specifiers: ?[]TypedLinkSpecifier = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .typed_link_specifiers = "TypedLinkSpecifiers",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_incoming_typed_links: ?struct {
                    link_specifiers: ?[]TypedLinkSpecifier = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .link_specifiers = "LinkSpecifiers",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                get_link_attributes: ?struct {
                    attributes: ?[]AttributeKeyAndValue = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .attributes = "Attributes",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                list_object_parents: ?struct {
                    parent_links: ?[]ObjectIdentifierAndLinkNameTuple = null,
                    next_token: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .parent_links = "ParentLinks",
                            .next_token = "NextToken",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .list_object_attributes = "ListObjectAttributes",
                        .list_object_children = "ListObjectChildren",
                        .get_object_information = "GetObjectInformation",
                        .get_object_attributes = "GetObjectAttributes",
                        .list_attached_indices = "ListAttachedIndices",
                        .list_object_parent_paths = "ListObjectParentPaths",
                        .list_object_policies = "ListObjectPolicies",
                        .list_policy_attachments = "ListPolicyAttachments",
                        .lookup_policy = "LookupPolicy",
                        .list_index = "ListIndex",
                        .list_outgoing_typed_links = "ListOutgoingTypedLinks",
                        .list_incoming_typed_links = "ListIncomingTypedLinks",
                        .get_link_attributes = "GetLinkAttributes",
                        .list_object_parents = "ListObjectParents",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            exception_response: ?struct {
                type: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .message = "Message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .successful_response = "SuccessfulResponse",
                    .exception_response = "ExceptionResponse",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .responses = "Responses",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const batch_write: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/batchwrite",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchWrite",
    Request: type = struct {
        directory_arn: []const u8,
        operations: []struct {
            create_object: ?struct {
                schema_facet: []SchemaFacet,
                object_attribute_list: []AttributeKeyAndValue,
                parent_reference: ?ObjectReference = null,
                link_name: ?[]const u8 = null,
                batch_reference_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .schema_facet = "SchemaFacet",
                        .object_attribute_list = "ObjectAttributeList",
                        .parent_reference = "ParentReference",
                        .link_name = "LinkName",
                        .batch_reference_name = "BatchReferenceName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attach_object: ?struct {
                parent_reference: ObjectReference,
                child_reference: ObjectReference,
                link_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .parent_reference = "ParentReference",
                        .child_reference = "ChildReference",
                        .link_name = "LinkName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            detach_object: ?struct {
                parent_reference: ObjectReference,
                link_name: []const u8,
                batch_reference_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .parent_reference = "ParentReference",
                        .link_name = "LinkName",
                        .batch_reference_name = "BatchReferenceName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            update_object_attributes: ?struct {
                object_reference: ObjectReference,
                attribute_updates: []ObjectAttributeUpdate,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                        .attribute_updates = "AttributeUpdates",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            delete_object: ?struct {
                object_reference: ObjectReference,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_reference = "ObjectReference",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            add_facet_to_object: ?struct {
                schema_facet: SchemaFacet,
                object_attribute_list: []AttributeKeyAndValue,
                object_reference: ObjectReference,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .schema_facet = "SchemaFacet",
                        .object_attribute_list = "ObjectAttributeList",
                        .object_reference = "ObjectReference",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            remove_facet_from_object: ?struct {
                schema_facet: SchemaFacet,
                object_reference: ObjectReference,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .schema_facet = "SchemaFacet",
                        .object_reference = "ObjectReference",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attach_policy: ?struct {
                policy_reference: ObjectReference,
                object_reference: ObjectReference,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .policy_reference = "PolicyReference",
                        .object_reference = "ObjectReference",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            detach_policy: ?struct {
                policy_reference: ObjectReference,
                object_reference: ObjectReference,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .policy_reference = "PolicyReference",
                        .object_reference = "ObjectReference",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            create_index: ?struct {
                ordered_indexed_attribute_list: []AttributeKey,
                is_unique: bool,
                parent_reference: ?ObjectReference = null,
                link_name: ?[]const u8 = null,
                batch_reference_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ordered_indexed_attribute_list = "OrderedIndexedAttributeList",
                        .is_unique = "IsUnique",
                        .parent_reference = "ParentReference",
                        .link_name = "LinkName",
                        .batch_reference_name = "BatchReferenceName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attach_to_index: ?struct {
                index_reference: ObjectReference,
                target_reference: ObjectReference,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index_reference = "IndexReference",
                        .target_reference = "TargetReference",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            detach_from_index: ?struct {
                index_reference: ObjectReference,
                target_reference: ObjectReference,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index_reference = "IndexReference",
                        .target_reference = "TargetReference",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attach_typed_link: ?struct {
                source_object_reference: ObjectReference,
                target_object_reference: ObjectReference,
                typed_link_facet: TypedLinkSchemaAndFacetName,
                attributes: []AttributeNameAndValue,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .source_object_reference = "SourceObjectReference",
                        .target_object_reference = "TargetObjectReference",
                        .typed_link_facet = "TypedLinkFacet",
                        .attributes = "Attributes",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            detach_typed_link: ?struct {
                typed_link_specifier: TypedLinkSpecifier,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .typed_link_specifier = "TypedLinkSpecifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            update_link_attributes: ?struct {
                typed_link_specifier: TypedLinkSpecifier,
                attribute_updates: []LinkAttributeUpdate,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .typed_link_specifier = "TypedLinkSpecifier",
                        .attribute_updates = "AttributeUpdates",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .create_object = "CreateObject",
                    .attach_object = "AttachObject",
                    .detach_object = "DetachObject",
                    .update_object_attributes = "UpdateObjectAttributes",
                    .delete_object = "DeleteObject",
                    .add_facet_to_object = "AddFacetToObject",
                    .remove_facet_from_object = "RemoveFacetFromObject",
                    .attach_policy = "AttachPolicy",
                    .detach_policy = "DetachPolicy",
                    .create_index = "CreateIndex",
                    .attach_to_index = "AttachToIndex",
                    .detach_from_index = "DetachFromIndex",
                    .attach_typed_link = "AttachTypedLink",
                    .detach_typed_link = "DetachTypedLink",
                    .update_link_attributes = "UpdateLinkAttributes",
                };
                return @field(mappings, field_name);
            }
        },
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .operations = "Operations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_write) } {
            return .{ .service_metadata = service_metadata, .action = batch_write };
        }
    },
    Response: type = struct {
        responses: ?[]struct {
            create_object: ?struct {
                object_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_identifier = "ObjectIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attach_object: ?struct {
                attached_object_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attached_object_identifier = "attachedObjectIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            detach_object: ?struct {
                detached_object_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .detached_object_identifier = "detachedObjectIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            update_object_attributes: ?struct {
                object_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_identifier = "ObjectIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            delete_object: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            } = null,
            add_facet_to_object: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            } = null,
            remove_facet_from_object: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            } = null,
            attach_policy: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            } = null,
            detach_policy: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            } = null,
            create_index: ?struct {
                object_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .object_identifier = "ObjectIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attach_to_index: ?struct {
                attached_object_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attached_object_identifier = "AttachedObjectIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            detach_from_index: ?struct {
                detached_object_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .detached_object_identifier = "DetachedObjectIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attach_typed_link: ?struct {
                typed_link_specifier: ?TypedLinkSpecifier = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .typed_link_specifier = "TypedLinkSpecifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            detach_typed_link: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            } = null,
            update_link_attributes: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .create_object = "CreateObject",
                    .attach_object = "AttachObject",
                    .detach_object = "DetachObject",
                    .update_object_attributes = "UpdateObjectAttributes",
                    .delete_object = "DeleteObject",
                    .add_facet_to_object = "AddFacetToObject",
                    .remove_facet_from_object = "RemoveFacetFromObject",
                    .attach_policy = "AttachPolicy",
                    .detach_policy = "DetachPolicy",
                    .create_index = "CreateIndex",
                    .attach_to_index = "AttachToIndex",
                    .detach_from_index = "DetachFromIndex",
                    .attach_typed_link = "AttachTypedLink",
                    .detach_typed_link = "DetachTypedLink",
                    .update_link_attributes = "UpdateLinkAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .responses = "Responses",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BatchWrite,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const create_directory: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/directory/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDirectory",
    Request: type = struct {
        name: []const u8,
        schema_arn: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .schema_arn = "SchemaArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_directory) } {
            return .{ .service_metadata = service_metadata, .action = create_directory };
        }
    },
    Response: type = struct {
        directory_arn: []const u8,
        name: []const u8,
        object_identifier: []const u8,
        applied_schema_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .name = "Name",
                .object_identifier = "ObjectIdentifier",
                .applied_schema_arn = "AppliedSchemaArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryAlreadyExists,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const create_facet: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/facet/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFacet",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        attributes: ?[]FacetAttribute = null,
        object_type: ?[]const u8 = null,
        facet_style: ?[]const u8 = null,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
                .attributes = "Attributes",
                .object_type = "ObjectType",
                .facet_style = "FacetStyle",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_facet) } {
            return .{ .service_metadata = service_metadata, .action = create_facet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetAlreadyExists,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidRule,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const create_index: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/index",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIndex",
    Request: type = struct {
        directory_arn: []const u8,
        ordered_indexed_attribute_list: []AttributeKey,
        is_unique: bool,
        parent_reference: ?ObjectReference = null,
        link_name: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .ordered_indexed_attribute_list = "OrderedIndexedAttributeList",
                .is_unique = "IsUnique",
                .parent_reference = "ParentReference",
                .link_name = "LinkName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_index) } {
            return .{ .service_metadata = service_metadata, .action = create_index };
        }
    },
    Response: type = struct {
        object_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_identifier = "ObjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        LinkNameAlreadyInUse,
        ResourceNotFound,
        RetryableConflict,
        UnsupportedIndexType,
        Validation,
    },
} = .{};
pub const create_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/object",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateObject",
    Request: type = struct {
        directory_arn: []const u8,
        schema_facets: []SchemaFacet,
        object_attribute_list: ?[]AttributeKeyAndValue = null,
        parent_reference: ?ObjectReference = null,
        link_name: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .schema_facets = "SchemaFacets",
                .object_attribute_list = "ObjectAttributeList",
                .parent_reference = "ParentReference",
                .link_name = "LinkName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_object) } {
            return .{ .service_metadata = service_metadata, .action = create_object };
        }
    },
    Response: type = struct {
        object_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_identifier = "ObjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        LinkNameAlreadyInUse,
        ResourceNotFound,
        RetryableConflict,
        UnsupportedIndexType,
        Validation,
    },
} = .{};
pub const create_schema: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/schema/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSchema",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_schema) } {
            return .{ .service_metadata = service_metadata, .action = create_schema };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        LimitExceeded,
        RetryableConflict,
        SchemaAlreadyExists,
        Validation,
    },
} = .{};
pub const create_typed_link_facet: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/facet/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTypedLinkFacet",
    Request: type = struct {
        schema_arn: []const u8,
        facet: struct {
            name: []const u8,
            attributes: []TypedLinkAttributeDefinition,
            identity_attribute_order: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .attributes = "Attributes",
                    .identity_attribute_order = "IdentityAttributeOrder",
                };
                return @field(mappings, field_name);
            }
        },
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .facet = "Facet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_typed_link_facet) } {
            return .{ .service_metadata = service_metadata, .action = create_typed_link_facet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetAlreadyExists,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidRule,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const delete_directory: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/directory",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDirectory",
    Request: type = struct {
        directory_arn: []const u8,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_directory) } {
            return .{ .service_metadata = service_metadata, .action = delete_directory };
        }
    },
    Response: type = struct {
        directory_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryDeleted,
        DirectoryNotDisabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const delete_facet: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/facet/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFacet",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_facet) } {
            return .{ .service_metadata = service_metadata, .action = delete_facet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetInUse,
        FacetNotFound,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const delete_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/object/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteObject",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_object) } {
            return .{ .service_metadata = service_metadata, .action = delete_object };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ObjectNotDetached,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const delete_schema: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/schema",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSchema",
    Request: type = struct {
        schema_arn: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        StillContainsLinks,
        Validation,
    },
} = .{};
pub const delete_typed_link_facet: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/facet/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTypedLinkFacet",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_typed_link_facet) } {
            return .{ .service_metadata = service_metadata, .action = delete_typed_link_facet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetNotFound,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const detach_from_index: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/index/detach",
        .success_code = 200,
    };

    action_name: []const u8 = "DetachFromIndex",
    Request: type = struct {
        directory_arn: []const u8,
        index_reference: ObjectReference,
        target_reference: ObjectReference,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .index_reference = "IndexReference",
                .target_reference = "TargetReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_from_index) } {
            return .{ .service_metadata = service_metadata, .action = detach_from_index };
        }
    },
    Response: type = struct {
        detached_object_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detached_object_identifier = "DetachedObjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        NotIndex,
        ObjectAlreadyDetached,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const detach_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/object/detach",
        .success_code = 200,
    };

    action_name: []const u8 = "DetachObject",
    Request: type = struct {
        directory_arn: []const u8,
        parent_reference: ObjectReference,
        link_name: []const u8,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .parent_reference = "ParentReference",
                .link_name = "LinkName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_object) } {
            return .{ .service_metadata = service_metadata, .action = detach_object };
        }
    },
    Response: type = struct {
        detached_object_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detached_object_identifier = "DetachedObjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        NotNode,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const detach_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/policy/detach",
        .success_code = 200,
    };

    action_name: []const u8 = "DetachPolicy",
    Request: type = struct {
        directory_arn: []const u8,
        policy_reference: ObjectReference,
        object_reference: ObjectReference,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .policy_reference = "PolicyReference",
                .object_reference = "ObjectReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_policy) } {
            return .{ .service_metadata = service_metadata, .action = detach_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        NotPolicy,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const detach_typed_link: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/detach",
        .success_code = 200,
    };

    action_name: []const u8 = "DetachTypedLink",
    Request: type = struct {
        directory_arn: []const u8,
        typed_link_specifier: TypedLinkSpecifier,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .typed_link_specifier = "TypedLinkSpecifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_typed_link) } {
            return .{ .service_metadata = service_metadata, .action = detach_typed_link };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const disable_directory: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/directory/disable",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableDirectory",
    Request: type = struct {
        directory_arn: []const u8,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_directory) } {
            return .{ .service_metadata = service_metadata, .action = disable_directory };
        }
    },
    Response: type = struct {
        directory_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryDeleted,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const enable_directory: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/directory/enable",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableDirectory",
    Request: type = struct {
        directory_arn: []const u8,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_directory) } {
            return .{ .service_metadata = service_metadata, .action = enable_directory };
        }
    },
    Response: type = struct {
        directory_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryDeleted,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const get_applied_schema_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/schema/getappliedschema",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAppliedSchemaVersion",
    Request: type = struct {
        schema_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_applied_schema_version) } {
            return .{ .service_metadata = service_metadata, .action = get_applied_schema_version };
        }
    },
    Response: type = struct {
        applied_schema_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applied_schema_arn = "AppliedSchemaArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const get_directory: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/directory/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDirectory",
    Request: type = struct {
        directory_arn: []const u8,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_directory) } {
            return .{ .service_metadata = service_metadata, .action = get_directory };
        }
    },
    Response: type = struct {
        directory: Directory,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory = "Directory",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        LimitExceeded,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const get_facet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/facet",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFacet",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_facet) } {
            return .{ .service_metadata = service_metadata, .action = get_facet };
        }
    },
    Response: type = struct {
        facet: ?struct {
            name: ?[]const u8 = null,
            object_type: ?[]const u8 = null,
            facet_style: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .object_type = "ObjectType",
                    .facet_style = "FacetStyle",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .facet = "Facet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetNotFound,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const get_link_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/attributes/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLinkAttributes",
    Request: type = struct {
        directory_arn: []const u8,
        typed_link_specifier: TypedLinkSpecifier,
        attribute_names: [][]const u8,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .typed_link_specifier = "TypedLinkSpecifier",
                .attribute_names = "AttributeNames",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_link_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_link_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]AttributeKeyAndValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const get_object_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/object/attributes/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectAttributes",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        consistency_level: ?[]const u8 = null,
        schema_facet: SchemaFacet,
        attribute_names: [][]const u8,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .consistency_level = "ConsistencyLevel",
                .schema_facet = "SchemaFacet",
                .attribute_names = "AttributeNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_object_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]AttributeKeyAndValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const get_object_information: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/object/information",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectInformation",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_information) } {
            return .{ .service_metadata = service_metadata, .action = get_object_information };
        }
    },
    Response: type = struct {
        schema_facets: ?[]SchemaFacet = null,
        object_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_facets = "SchemaFacets",
                .object_identifier = "ObjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const get_schema_as_json: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/schema/json",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSchemaAsJson",
    Request: type = struct {
        schema_arn: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_as_json) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_as_json };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        document: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document = "Document",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const get_typed_link_facet_information: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/facet/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTypedLinkFacetInformation",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_typed_link_facet_information) } {
            return .{ .service_metadata = service_metadata, .action = get_typed_link_facet_information };
        }
    },
    Response: type = struct {
        identity_attribute_order: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_attribute_order = "IdentityAttributeOrder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetNotFound,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_applied_schema_arns: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/schema/applied",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppliedSchemaArns",
    Request: type = struct {
        directory_arn: []const u8,
        schema_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .schema_arn = "SchemaArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applied_schema_arns) } {
            return .{ .service_metadata = service_metadata, .action = list_applied_schema_arns };
        }
    },
    Response: type = struct {
        schema_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arns = "SchemaArns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_attached_indices: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/object/indices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttachedIndices",
    Request: type = struct {
        directory_arn: []const u8,
        target_reference: ObjectReference,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .target_reference = "TargetReference",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attached_indices) } {
            return .{ .service_metadata = service_metadata, .action = list_attached_indices };
        }
    },
    Response: type = struct {
        index_attachments: ?[]IndexAttachment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_attachments = "IndexAttachments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_development_schema_arns: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/schema/development",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDevelopmentSchemaArns",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_development_schema_arns) } {
            return .{ .service_metadata = service_metadata, .action = list_development_schema_arns };
        }
    },
    Response: type = struct {
        schema_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arns = "SchemaArns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_directories: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/directory/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDirectories",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .state = "state",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_directories) } {
            return .{ .service_metadata = service_metadata, .action = list_directories };
        }
    },
    Response: type = struct {
        directories: []Directory,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directories = "Directories",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_facet_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/facet/attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFacetAttributes",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_facet_attributes) } {
            return .{ .service_metadata = service_metadata, .action = list_facet_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]FacetAttribute = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetNotFound,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_facet_names: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/facet/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFacetNames",
    Request: type = struct {
        schema_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_facet_names) } {
            return .{ .service_metadata = service_metadata, .action = list_facet_names };
        }
    },
    Response: type = struct {
        facet_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .facet_names = "FacetNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_incoming_typed_links: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/incoming",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIncomingTypedLinks",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        filter_attribute_ranges: ?[]TypedLinkAttributeRange = null,
        filter_typed_link: ?TypedLinkSchemaAndFacetName = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .filter_attribute_ranges = "FilterAttributeRanges",
                .filter_typed_link = "FilterTypedLink",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_incoming_typed_links) } {
            return .{ .service_metadata = service_metadata, .action = list_incoming_typed_links };
        }
    },
    Response: type = struct {
        link_specifiers: ?[]TypedLinkSpecifier = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link_specifiers = "LinkSpecifiers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_index: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/index/targets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIndex",
    Request: type = struct {
        directory_arn: []const u8,
        ranges_on_indexed_values: ?[]ObjectAttributeRange = null,
        index_reference: ObjectReference,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .ranges_on_indexed_values = "RangesOnIndexedValues",
                .index_reference = "IndexReference",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_index) } {
            return .{ .service_metadata = service_metadata, .action = list_index };
        }
    },
    Response: type = struct {
        index_attachments: ?[]IndexAttachment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_attachments = "IndexAttachments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        NotIndex,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_managed_schema_arns: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/schema/managed",
        .success_code = 200,
    };

    action_name: []const u8 = "ListManagedSchemaArns",
    Request: type = struct {
        schema_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_managed_schema_arns) } {
            return .{ .service_metadata = service_metadata, .action = list_managed_schema_arns };
        }
    },
    Response: type = struct {
        schema_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arns = "SchemaArns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_object_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/object/attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjectAttributes",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        consistency_level: ?[]const u8 = null,
        facet_filter: ?SchemaFacet = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .consistency_level = "ConsistencyLevel",
                .facet_filter = "FacetFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_object_attributes) } {
            return .{ .service_metadata = service_metadata, .action = list_object_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]AttributeKeyAndValue = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_object_children: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/object/children",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjectChildren",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_object_children) } {
            return .{ .service_metadata = service_metadata, .action = list_object_children };
        }
    },
    Response: type = struct {
        children: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .children = "Children",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "children", field_name))
                return try serializeMap(self.children, self.fieldNameFor("children"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        NotNode,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_object_parent_paths: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/object/parentpaths",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjectParentPaths",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_object_parent_paths) } {
            return .{ .service_metadata = service_metadata, .action = list_object_parent_paths };
        }
    },
    Response: type = struct {
        path_to_object_identifiers_list: ?[]PathToObjectIdentifiers = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .path_to_object_identifiers_list = "PathToObjectIdentifiersList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_object_parents: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/object/parent",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjectParents",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        consistency_level: ?[]const u8 = null,
        include_all_links_to_each_parent: ?bool = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .consistency_level = "ConsistencyLevel",
                .include_all_links_to_each_parent = "IncludeAllLinksToEachParent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_object_parents) } {
            return .{ .service_metadata = service_metadata, .action = list_object_parents };
        }
    },
    Response: type = struct {
        parents: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,
        parent_links: ?[]ObjectIdentifierAndLinkNameTuple = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parents = "Parents",
                .next_token = "NextToken",
                .parent_links = "ParentLinks",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parents", field_name))
                return try serializeMap(self.parents, self.fieldNameFor("parents"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CannotListParentOfRoot,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_object_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/object/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjectPolicies",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_object_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_object_policies };
        }
    },
    Response: type = struct {
        attached_policy_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attached_policy_ids = "AttachedPolicyIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_outgoing_typed_links: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/outgoing",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOutgoingTypedLinks",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        filter_attribute_ranges: ?[]TypedLinkAttributeRange = null,
        filter_typed_link: ?TypedLinkSchemaAndFacetName = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .filter_attribute_ranges = "FilterAttributeRanges",
                .filter_typed_link = "FilterTypedLink",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_outgoing_typed_links) } {
            return .{ .service_metadata = service_metadata, .action = list_outgoing_typed_links };
        }
    },
    Response: type = struct {
        typed_link_specifiers: ?[]TypedLinkSpecifier = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .typed_link_specifiers = "TypedLinkSpecifiers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_policy_attachments: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/policy/attachment",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPolicyAttachments",
    Request: type = struct {
        directory_arn: []const u8,
        policy_reference: ObjectReference,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        consistency_level: ?[]const u8 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
            .consistency_level = "x-amz-consistency-level",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .policy_reference = "PolicyReference",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .consistency_level = "ConsistencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_policy_attachments) } {
            return .{ .service_metadata = service_metadata, .action = list_policy_attachments };
        }
    },
    Response: type = struct {
        object_identifiers: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_identifiers = "ObjectIdentifiers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        NotPolicy,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_published_schema_arns: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/schema/published",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPublishedSchemaArns",
    Request: type = struct {
        schema_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_published_schema_arns) } {
            return .{ .service_metadata = service_metadata, .action = list_published_schema_arns };
        }
    },
    Response: type = struct {
        schema_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arns = "SchemaArns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidTaggingRequest,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_typed_link_facet_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/facet/attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTypedLinkFacetAttributes",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_typed_link_facet_attributes) } {
            return .{ .service_metadata = service_metadata, .action = list_typed_link_facet_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]TypedLinkAttributeDefinition = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetNotFound,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const list_typed_link_facet_names: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/facet/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTypedLinkFacetNames",
    Request: type = struct {
        schema_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_typed_link_facet_names) } {
            return .{ .service_metadata = service_metadata, .action = list_typed_link_facet_names };
        }
    },
    Response: type = struct {
        facet_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .facet_names = "FacetNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const lookup_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/policy/lookup",
        .success_code = 200,
    };

    action_name: []const u8 = "LookupPolicy",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(lookup_policy) } {
            return .{ .service_metadata = service_metadata, .action = lookup_policy };
        }
    },
    Response: type = struct {
        policy_to_path_list: ?[]PolicyToPath = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_to_path_list = "PolicyToPathList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        InternalService,
        InvalidArn,
        InvalidNextToken,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const publish_schema: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/schema/publish",
        .success_code = 200,
    };

    action_name: []const u8 = "PublishSchema",
    Request: type = struct {
        development_schema_arn: []const u8,
        version: []const u8,
        minor_version: ?[]const u8 = null,
        name: ?[]const u8 = null,
        pub const http_header = .{
            .development_schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .development_schema_arn = "DevelopmentSchemaArn",
                .version = "Version",
                .minor_version = "MinorVersion",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_schema) } {
            return .{ .service_metadata = service_metadata, .action = publish_schema };
        }
    },
    Response: type = struct {
        published_schema_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .published_schema_arn = "PublishedSchemaArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        SchemaAlreadyPublished,
        Validation,
    },
} = .{};
pub const put_schema_from_json: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/schema/json",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSchemaFromJson",
    Request: type = struct {
        schema_arn: []const u8,
        document: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .document = "Document",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_schema_from_json) } {
            return .{ .service_metadata = service_metadata, .action = put_schema_from_json };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidRule,
        InvalidSchemaDoc,
        LimitExceeded,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const remove_facet_from_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/object/facets/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveFacetFromObject",
    Request: type = struct {
        directory_arn: []const u8,
        schema_facet: SchemaFacet,
        object_reference: ObjectReference,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .schema_facet = "SchemaFacet",
                .object_reference = "ObjectReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_facet_from_object) } {
            return .{ .service_metadata = service_metadata, .action = remove_facet_from_object };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/tags/add",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidTaggingRequest,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/tags/remove",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        InvalidTaggingRequest,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const update_facet: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/facet",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFacet",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        attribute_updates: ?[]struct {
            attribute: ?FacetAttribute = null,
            action: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "Attribute",
                    .action = "Action",
                };
                return @field(mappings, field_name);
            }
        } = null,
        object_type: ?[]const u8 = null,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
                .attribute_updates = "AttributeUpdates",
                .object_type = "ObjectType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_facet) } {
            return .{ .service_metadata = service_metadata, .action = update_facet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetNotFound,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidFacetUpdate,
        InvalidRule,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const update_link_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/attributes/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLinkAttributes",
    Request: type = struct {
        directory_arn: []const u8,
        typed_link_specifier: TypedLinkSpecifier,
        attribute_updates: []LinkAttributeUpdate,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .typed_link_specifier = "TypedLinkSpecifier",
                .attribute_updates = "AttributeUpdates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_link_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_link_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const update_object_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/object/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateObjectAttributes",
    Request: type = struct {
        directory_arn: []const u8,
        object_reference: ObjectReference,
        attribute_updates: []ObjectAttributeUpdate,
        pub const http_header = .{
            .directory_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_arn = "DirectoryArn",
                .object_reference = "ObjectReference",
                .attribute_updates = "AttributeUpdates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_object_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_object_attributes };
        }
    },
    Response: type = struct {
        object_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_identifier = "ObjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DirectoryNotEnabled,
        FacetValidation,
        InternalService,
        InvalidArn,
        LimitExceeded,
        LinkNameAlreadyInUse,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const update_schema: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/schema/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSchema",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_schema) } {
            return .{ .service_metadata = service_metadata, .action = update_schema };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidArn,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const update_typed_link_facet: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/typedlink/facet",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTypedLinkFacet",
    Request: type = struct {
        schema_arn: []const u8,
        name: []const u8,
        attribute_updates: []struct {
            attribute: TypedLinkAttributeDefinition,
            action: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "Attribute",
                    .action = "Action",
                };
                return @field(mappings, field_name);
            }
        },
        identity_attribute_order: [][]const u8,
        pub const http_header = .{
            .schema_arn = "x-amz-data-partition",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .name = "Name",
                .attribute_updates = "AttributeUpdates",
                .identity_attribute_order = "IdentityAttributeOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_typed_link_facet) } {
            return .{ .service_metadata = service_metadata, .action = update_typed_link_facet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FacetNotFound,
        FacetValidation,
        InternalService,
        InvalidArn,
        InvalidFacetUpdate,
        InvalidRule,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};
pub const upgrade_applied_schema: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/schema/upgradeapplied",
        .success_code = 200,
    };

    action_name: []const u8 = "UpgradeAppliedSchema",
    Request: type = struct {
        published_schema_arn: []const u8,
        directory_arn: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .published_schema_arn = "PublishedSchemaArn",
                .directory_arn = "DirectoryArn",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upgrade_applied_schema) } {
            return .{ .service_metadata = service_metadata, .action = upgrade_applied_schema };
        }
    },
    Response: type = struct {
        upgraded_schema_arn: ?[]const u8 = null,
        directory_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upgraded_schema_arn = "UpgradedSchemaArn",
                .directory_arn = "DirectoryArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleSchema,
        InternalService,
        InvalidArn,
        InvalidAttachment,
        ResourceNotFound,
        RetryableConflict,
        SchemaAlreadyExists,
        Validation,
    },
} = .{};
pub const upgrade_published_schema: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/amazonclouddirectory/2017-01-11/schema/upgradepublished",
        .success_code = 200,
    };

    action_name: []const u8 = "UpgradePublishedSchema",
    Request: type = struct {
        development_schema_arn: []const u8,
        published_schema_arn: []const u8,
        minor_version: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .development_schema_arn = "DevelopmentSchemaArn",
                .published_schema_arn = "PublishedSchemaArn",
                .minor_version = "MinorVersion",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upgrade_published_schema) } {
            return .{ .service_metadata = service_metadata, .action = upgrade_published_schema };
        }
    },
    Response: type = struct {
        upgraded_schema_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upgraded_schema_arn = "UpgradedSchemaArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleSchema,
        InternalService,
        InvalidArn,
        InvalidAttachment,
        LimitExceeded,
        ResourceNotFound,
        RetryableConflict,
        Validation,
    },
} = .{};

pub const TypedLinkAttributeDefinition = struct {
    name: []const u8,
    type: []const u8,
    default_value: ?TypedAttributeValue = null,
    is_immutable: ?bool = null,
    rules: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Rule = null,
    } = null,
    required_behavior: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .default_value = "DefaultValue",
            .is_immutable = "IsImmutable",
            .rules = "Rules",
            .required_behavior = "RequiredBehavior",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "rules", field_name))
            return try serializeMap(self.rules, self.fieldNameFor("rules"), options, out_stream);
        return false;
    }
};

pub const Rule = struct {
    type: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const TypedAttributeValue = union {
    string_value: ?[]const u8,
    binary_value: ?[]const u8,
    boolean_value: ?bool,
    number_value: ?[]const u8,
    datetime_value: ?i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "StringValue",
            .binary_value = "BinaryValue",
            .boolean_value = "BooleanValue",
            .number_value = "NumberValue",
            .datetime_value = "DatetimeValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectAttributeUpdate = struct {
    object_attribute_key: ?AttributeKey = null,
    object_attribute_action: ?ObjectAttributeAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_attribute_key = "ObjectAttributeKey",
            .object_attribute_action = "ObjectAttributeAction",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectAttributeAction = struct {
    object_attribute_action_type: ?[]const u8 = null,
    object_attribute_update_value: ?TypedAttributeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_attribute_action_type = "ObjectAttributeActionType",
            .object_attribute_update_value = "ObjectAttributeUpdateValue",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeKey = struct {
    schema_arn: []const u8,
    facet_name: []const u8,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_arn = "SchemaArn",
            .facet_name = "FacetName",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectReference = struct {
    selector: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selector = "Selector",
        };
        return @field(mappings, field_name);
    }
};

pub const LinkAttributeUpdate = struct {
    attribute_key: ?AttributeKey = null,
    attribute_action: ?LinkAttributeAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_key = "AttributeKey",
            .attribute_action = "AttributeAction",
        };
        return @field(mappings, field_name);
    }
};

pub const LinkAttributeAction = struct {
    attribute_action_type: ?[]const u8 = null,
    attribute_update_value: ?TypedAttributeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_action_type = "AttributeActionType",
            .attribute_update_value = "AttributeUpdateValue",
        };
        return @field(mappings, field_name);
    }
};

pub const TypedLinkSpecifier = struct {
    typed_link_facet: TypedLinkSchemaAndFacetName,
    source_object_reference: ObjectReference,
    target_object_reference: ObjectReference,
    identity_attribute_values: []AttributeNameAndValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .typed_link_facet = "TypedLinkFacet",
            .source_object_reference = "SourceObjectReference",
            .target_object_reference = "TargetObjectReference",
            .identity_attribute_values = "IdentityAttributeValues",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeNameAndValue = struct {
    attribute_name: []const u8,
    value: TypedAttributeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TypedLinkSchemaAndFacetName = struct {
    schema_arn: []const u8,
    typed_link_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_arn = "SchemaArn",
            .typed_link_name = "TypedLinkName",
        };
        return @field(mappings, field_name);
    }
};

pub const FacetAttribute = struct {
    name: []const u8,
    attribute_definition: ?FacetAttributeDefinition = null,
    attribute_reference: ?FacetAttributeReference = null,
    required_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .attribute_definition = "AttributeDefinition",
            .attribute_reference = "AttributeReference",
            .required_behavior = "RequiredBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const FacetAttributeReference = struct {
    target_facet_name: []const u8,
    target_attribute_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_facet_name = "TargetFacetName",
            .target_attribute_name = "TargetAttributeName",
        };
        return @field(mappings, field_name);
    }
};

pub const FacetAttributeDefinition = struct {
    type: []const u8,
    default_value: ?TypedAttributeValue = null,
    is_immutable: ?bool = null,
    rules: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Rule = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .default_value = "DefaultValue",
            .is_immutable = "IsImmutable",
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "rules", field_name))
            return try serializeMap(self.rules, self.fieldNameFor("rules"), options, out_stream);
        return false;
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaFacet = struct {
    schema_arn: ?[]const u8 = null,
    facet_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_arn = "SchemaArn",
            .facet_name = "FacetName",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyToPath = struct {
    path: ?[]const u8 = null,
    policies: ?[]PolicyAttachment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .policies = "Policies",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyAttachment = struct {
    policy_id: ?[]const u8 = null,
    object_identifier: ?[]const u8 = null,
    policy_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_id = "PolicyId",
            .object_identifier = "ObjectIdentifier",
            .policy_type = "PolicyType",
        };
        return @field(mappings, field_name);
    }
};

pub const TypedLinkAttributeRange = struct {
    attribute_name: ?[]const u8 = null,
    range: TypedAttributeValueRange,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .range = "Range",
        };
        return @field(mappings, field_name);
    }
};

pub const TypedAttributeValueRange = struct {
    start_mode: []const u8,
    start_value: ?TypedAttributeValue = null,
    end_mode: []const u8,
    end_value: ?TypedAttributeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_mode = "StartMode",
            .start_value = "StartValue",
            .end_mode = "EndMode",
            .end_value = "EndValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectIdentifierAndLinkNameTuple = struct {
    object_identifier: ?[]const u8 = null,
    link_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_identifier = "ObjectIdentifier",
            .link_name = "LinkName",
        };
        return @field(mappings, field_name);
    }
};

pub const PathToObjectIdentifiers = struct {
    path: ?[]const u8 = null,
    object_identifiers: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .object_identifiers = "ObjectIdentifiers",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeKeyAndValue = struct {
    key: AttributeKey,
    value: TypedAttributeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const IndexAttachment = struct {
    indexed_attributes: ?[]AttributeKeyAndValue = null,
    object_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .indexed_attributes = "IndexedAttributes",
            .object_identifier = "ObjectIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectAttributeRange = struct {
    attribute_key: ?AttributeKey = null,
    range: ?TypedAttributeValueRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_key = "AttributeKey",
            .range = "Range",
        };
        return @field(mappings, field_name);
    }
};

pub const Directory = struct {
    name: ?[]const u8 = null,
    directory_arn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    creation_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .directory_arn = "DirectoryArn",
            .state = "State",
            .creation_date_time = "CreationDateTime",
        };
        return @field(mappings, field_name);
    }
};
