const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-07-26";
pub const sdk_id: []const u8 = "CloudFront KeyValueStore";
pub const arn_namespace: ?[]const u8 = "key-value-store";
pub const endpoint_prefix: []const u8 = "cloudfront-keyvaluestore";
pub const sigv4_name: []const u8 = "cloudfront-keyvaluestore";
pub const name: []const u8 = "CloudFrontKeyValueStore";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-07-26",
    sdk_id: []const u8 = "CloudFront KeyValueStore",
    arn_namespace: ?[]const u8 = "key-value-store",
    endpoint_prefix: []const u8 = "cloudfront-keyvaluestore",
    sigv4_name: []const u8 = "cloudfront-keyvaluestore",
    name: []const u8 = "CloudFrontKeyValueStore",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_key: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/key-value-stores/{KvsARN}/keys/{Key}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKey",
    Request: type = struct {
        kvs_arn: []const u8,
        key: []const u8,
        if_match: []const u8,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kvs_arn = "KvsARN",
                .key = "Key",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_key };
        }
    },
    Response: type = struct {
        item_count: i64,
        total_size_in_bytes: i64,
        e_tag: []const u8,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .item_count = "ItemCount",
                .total_size_in_bytes = "TotalSizeInBytes",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const describe_key_value_store: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/key-value-stores/{KvsARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeKeyValueStore",
    Request: type = struct {
        kvs_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kvs_arn = "KvsARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_key_value_store) } {
            return .{ .service_metadata = service_metadata, .action = describe_key_value_store };
        }
    },
    Response: type = struct {
        item_count: i64,
        total_size_in_bytes: i64,
        kvs_arn: []const u8,
        created: i64,
        e_tag: []const u8,
        last_modified: ?i64 = null,
        status: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .item_count = "ItemCount",
                .total_size_in_bytes = "TotalSizeInBytes",
                .kvs_arn = "KvsARN",
                .created = "Created",
                .e_tag = "ETag",
                .last_modified = "LastModified",
                .status = "Status",
                .failure_reason = "FailureReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const get_key: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/key-value-stores/{KvsARN}/keys/{Key}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKey",
    Request: type = struct {
        kvs_arn: []const u8,
        key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kvs_arn = "KvsARN",
                .key = "Key",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_key) } {
            return .{ .service_metadata = service_metadata, .action = get_key };
        }
    },
    Response: type = struct {
        key: []const u8,
        value: []const u8,
        item_count: i64,
        total_size_in_bytes: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key = "Key",
                .value = "Value",
                .item_count = "ItemCount",
                .total_size_in_bytes = "TotalSizeInBytes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_keys: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/key-value-stores/{KvsARN}/keys",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKeys",
    Request: type = struct {
        kvs_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kvs_arn = "KvsARN",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_keys };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        items: ?[]struct {
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .items = "Items",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_key: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/key-value-stores/{KvsARN}/keys/{Key}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutKey",
    Request: type = struct {
        key: []const u8,
        value: []const u8,
        kvs_arn: []const u8,
        if_match: []const u8,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key = "Key",
                .value = "Value",
                .kvs_arn = "KvsARN",
                .if_match = "IfMatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_key) } {
            return .{ .service_metadata = service_metadata, .action = put_key };
        }
    },
    Response: type = struct {
        item_count: i64,
        total_size_in_bytes: i64,
        e_tag: []const u8,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .item_count = "ItemCount",
                .total_size_in_bytes = "TotalSizeInBytes",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const update_keys: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/key-value-stores/{KvsARN}/keys",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKeys",
    Request: type = struct {
        kvs_arn: []const u8,
        if_match: []const u8,
        puts: ?[]struct {
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        deletes: ?[]struct {
            key: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pub const http_header = .{
            .if_match = "If-Match",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kvs_arn = "KvsARN",
                .if_match = "IfMatch",
                .puts = "Puts",
                .deletes = "Deletes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_keys) } {
            return .{ .service_metadata = service_metadata, .action = update_keys };
        }
    },
    Response: type = struct {
        item_count: i64,
        total_size_in_bytes: i64,
        e_tag: []const u8,
        pub const http_header = .{
            .e_tag = "ETag",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .item_count = "ItemCount",
                .total_size_in_bytes = "TotalSizeInBytes",
                .e_tag = "ETag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
