const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-05-30";
pub const sdk_id: []const u8 = "CloudHSM";
pub const arn_namespace: ?[]const u8 = "cloudhsm";
pub const endpoint_prefix: []const u8 = "cloudhsm";
pub const sigv4_name: []const u8 = "cloudhsm";
pub const name: []const u8 = "CloudHsmFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2014-05-30",
    sdk_id: []const u8 = "CloudHSM",
    arn_namespace: ?[]const u8 = "cloudhsm",
    endpoint_prefix: []const u8 = "cloudhsm",
    sigv4_name: []const u8 = "cloudhsm",
    name: []const u8 = "CloudHsmFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_list: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const create_hapg: struct {
    action_name: []const u8 = "CreateHapg",
    Request: type = struct {
        label: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label = "Label",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hapg) } {
            return .{ .service_metadata = service_metadata, .action = create_hapg };
        }
    },
    Response: type = struct {
        hapg_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hapg_arn = "HapgArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const create_hsm: struct {
    action_name: []const u8 = "CreateHsm",
    Request: type = struct {
        subnet_id: []const u8,
        ssh_key: []const u8,
        eni_ip: ?[]const u8 = null,
        iam_role_arn: []const u8,
        external_id: ?[]const u8 = null,
        subscription_type: []const u8,
        client_token: ?[]const u8 = null,
        syslog_ip: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_id = "SubnetId",
                .ssh_key = "SshKey",
                .eni_ip = "EniIp",
                .iam_role_arn = "IamRoleArn",
                .external_id = "ExternalId",
                .subscription_type = "SubscriptionType",
                .client_token = "ClientToken",
                .syslog_ip = "SyslogIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hsm) } {
            return .{ .service_metadata = service_metadata, .action = create_hsm };
        }
    },
    Response: type = struct {
        hsm_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_arn = "HsmArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const create_luna_client: struct {
    action_name: []const u8 = "CreateLunaClient",
    Request: type = struct {
        label: ?[]const u8 = null,
        certificate: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label = "Label",
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_luna_client) } {
            return .{ .service_metadata = service_metadata, .action = create_luna_client };
        }
    },
    Response: type = struct {
        client_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_arn = "ClientArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const delete_hapg: struct {
    action_name: []const u8 = "DeleteHapg",
    Request: type = struct {
        hapg_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hapg_arn = "HapgArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_hapg) } {
            return .{ .service_metadata = service_metadata, .action = delete_hapg };
        }
    },
    Response: type = struct {
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const delete_hsm: struct {
    action_name: []const u8 = "DeleteHsm",
    Request: type = struct {
        hsm_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_arn = "HsmArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_hsm) } {
            return .{ .service_metadata = service_metadata, .action = delete_hsm };
        }
    },
    Response: type = struct {
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const delete_luna_client: struct {
    action_name: []const u8 = "DeleteLunaClient",
    Request: type = struct {
        client_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_arn = "ClientArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_luna_client) } {
            return .{ .service_metadata = service_metadata, .action = delete_luna_client };
        }
    },
    Response: type = struct {
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const describe_hapg: struct {
    action_name: []const u8 = "DescribeHapg",
    Request: type = struct {
        hapg_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hapg_arn = "HapgArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hapg) } {
            return .{ .service_metadata = service_metadata, .action = describe_hapg };
        }
    },
    Response: type = struct {
        hapg_arn: ?[]const u8 = null,
        hapg_serial: ?[]const u8 = null,
        hsms_last_action_failed: ?[][]const u8 = null,
        hsms_pending_deletion: ?[][]const u8 = null,
        hsms_pending_registration: ?[][]const u8 = null,
        label: ?[]const u8 = null,
        last_modified_timestamp: ?[]const u8 = null,
        partition_serial_list: ?[][]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hapg_arn = "HapgArn",
                .hapg_serial = "HapgSerial",
                .hsms_last_action_failed = "HsmsLastActionFailed",
                .hsms_pending_deletion = "HsmsPendingDeletion",
                .hsms_pending_registration = "HsmsPendingRegistration",
                .label = "Label",
                .last_modified_timestamp = "LastModifiedTimestamp",
                .partition_serial_list = "PartitionSerialList",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const describe_hsm: struct {
    action_name: []const u8 = "DescribeHsm",
    Request: type = struct {
        hsm_arn: ?[]const u8 = null,
        hsm_serial_number: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_arn = "HsmArn",
                .hsm_serial_number = "HsmSerialNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hsm) } {
            return .{ .service_metadata = service_metadata, .action = describe_hsm };
        }
    },
    Response: type = struct {
        hsm_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_details: ?[]const u8 = null,
        availability_zone: ?[]const u8 = null,
        eni_id: ?[]const u8 = null,
        eni_ip: ?[]const u8 = null,
        subscription_type: ?[]const u8 = null,
        subscription_start_date: ?[]const u8 = null,
        subscription_end_date: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        subnet_id: ?[]const u8 = null,
        iam_role_arn: ?[]const u8 = null,
        serial_number: ?[]const u8 = null,
        vendor_name: ?[]const u8 = null,
        hsm_type: ?[]const u8 = null,
        software_version: ?[]const u8 = null,
        ssh_public_key: ?[]const u8 = null,
        ssh_key_last_updated: ?[]const u8 = null,
        server_cert_uri: ?[]const u8 = null,
        server_cert_last_updated: ?[]const u8 = null,
        partitions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_arn = "HsmArn",
                .status = "Status",
                .status_details = "StatusDetails",
                .availability_zone = "AvailabilityZone",
                .eni_id = "EniId",
                .eni_ip = "EniIp",
                .subscription_type = "SubscriptionType",
                .subscription_start_date = "SubscriptionStartDate",
                .subscription_end_date = "SubscriptionEndDate",
                .vpc_id = "VpcId",
                .subnet_id = "SubnetId",
                .iam_role_arn = "IamRoleArn",
                .serial_number = "SerialNumber",
                .vendor_name = "VendorName",
                .hsm_type = "HsmType",
                .software_version = "SoftwareVersion",
                .ssh_public_key = "SshPublicKey",
                .ssh_key_last_updated = "SshKeyLastUpdated",
                .server_cert_uri = "ServerCertUri",
                .server_cert_last_updated = "ServerCertLastUpdated",
                .partitions = "Partitions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const describe_luna_client: struct {
    action_name: []const u8 = "DescribeLunaClient",
    Request: type = struct {
        client_arn: ?[]const u8 = null,
        certificate_fingerprint: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_arn = "ClientArn",
                .certificate_fingerprint = "CertificateFingerprint",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_luna_client) } {
            return .{ .service_metadata = service_metadata, .action = describe_luna_client };
        }
    },
    Response: type = struct {
        client_arn: ?[]const u8 = null,
        certificate: ?[]const u8 = null,
        certificate_fingerprint: ?[]const u8 = null,
        last_modified_timestamp: ?[]const u8 = null,
        label: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_arn = "ClientArn",
                .certificate = "Certificate",
                .certificate_fingerprint = "CertificateFingerprint",
                .last_modified_timestamp = "LastModifiedTimestamp",
                .label = "Label",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const get_config: struct {
    action_name: []const u8 = "GetConfig",
    Request: type = struct {
        client_arn: []const u8,
        client_version: []const u8,
        hapg_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_arn = "ClientArn",
                .client_version = "ClientVersion",
                .hapg_list = "HapgList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_config) } {
            return .{ .service_metadata = service_metadata, .action = get_config };
        }
    },
    Response: type = struct {
        config_type: ?[]const u8 = null,
        config_file: ?[]const u8 = null,
        config_cred: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_type = "ConfigType",
                .config_file = "ConfigFile",
                .config_cred = "ConfigCred",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const list_available_zones: struct {
    action_name: []const u8 = "ListAvailableZones",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_zones) } {
            return .{ .service_metadata = service_metadata, .action = list_available_zones };
        }
    },
    Response: type = struct {
        az_list: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .az_list = "AZList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const list_hapgs: struct {
    action_name: []const u8 = "ListHapgs",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hapgs) } {
            return .{ .service_metadata = service_metadata, .action = list_hapgs };
        }
    },
    Response: type = struct {
        hapg_list: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hapg_list = "HapgList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const list_hsms: struct {
    action_name: []const u8 = "ListHsms",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hsms) } {
            return .{ .service_metadata = service_metadata, .action = list_hsms };
        }
    },
    Response: type = struct {
        hsm_list: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_list = "HsmList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const list_luna_clients: struct {
    action_name: []const u8 = "ListLunaClients",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_luna_clients) } {
            return .{ .service_metadata = service_metadata, .action = list_luna_clients };
        }
    },
    Response: type = struct {
        client_list: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_list = "ClientList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const modify_hapg: struct {
    action_name: []const u8 = "ModifyHapg",
    Request: type = struct {
        hapg_arn: []const u8,
        label: ?[]const u8 = null,
        partition_serial_list: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hapg_arn = "HapgArn",
                .label = "Label",
                .partition_serial_list = "PartitionSerialList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_hapg) } {
            return .{ .service_metadata = service_metadata, .action = modify_hapg };
        }
    },
    Response: type = struct {
        hapg_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hapg_arn = "HapgArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const modify_hsm: struct {
    action_name: []const u8 = "ModifyHsm",
    Request: type = struct {
        hsm_arn: []const u8,
        subnet_id: ?[]const u8 = null,
        eni_ip: ?[]const u8 = null,
        iam_role_arn: ?[]const u8 = null,
        external_id: ?[]const u8 = null,
        syslog_ip: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_arn = "HsmArn",
                .subnet_id = "SubnetId",
                .eni_ip = "EniIp",
                .iam_role_arn = "IamRoleArn",
                .external_id = "ExternalId",
                .syslog_ip = "SyslogIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_hsm) } {
            return .{ .service_metadata = service_metadata, .action = modify_hsm };
        }
    },
    Response: type = struct {
        hsm_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_arn = "HsmArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};
pub const modify_luna_client: struct {
    action_name: []const u8 = "ModifyLunaClient",
    Request: type = struct {
        client_arn: []const u8,
        certificate: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_arn = "ClientArn",
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_luna_client) } {
            return .{ .service_metadata = service_metadata, .action = modify_luna_client };
        }
    },
    Response: type = struct {
        client_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_arn = "ClientArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmService,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_key_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_key_list = "TagKeyList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmInternal,
        CloudHsmService,
        InvalidRequest,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
