const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-04-28";
pub const sdk_id: []const u8 = "CloudHSM V2";
pub const arn_namespace: ?[]const u8 = "cloudhsm";
pub const endpoint_prefix: []const u8 = "cloudhsmv2";
pub const sigv4_name: []const u8 = "cloudhsm";
pub const name: []const u8 = "BaldrApiService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-04-28",
    sdk_id: []const u8 = "CloudHSM V2",
    arn_namespace: ?[]const u8 = "cloudhsm",
    endpoint_prefix: []const u8 = "cloudhsmv2",
    sigv4_name: []const u8 = "cloudhsm",
    name: []const u8 = "BaldrApiService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const copy_backup_to_region: struct {
    action_name: []const u8 = "CopyBackupToRegion",
    Request: type = struct {
        destination_region: []const u8,
        backup_id: []const u8,
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_region = "DestinationRegion",
                .backup_id = "BackupId",
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_backup_to_region) } {
            return .{ .service_metadata = service_metadata, .action = copy_backup_to_region };
        }
    },
    Response: type = struct {
        destination_backup: ?struct {
            create_timestamp: ?i64 = null,
            source_region: ?[]const u8 = null,
            source_backup: ?[]const u8 = null,
            source_cluster: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .create_timestamp = "CreateTimestamp",
                    .source_region = "SourceRegion",
                    .source_backup = "SourceBackup",
                    .source_cluster = "SourceCluster",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_backup = "DestinationBackup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
        CloudHsmTag,
    },
} = .{};
pub const create_cluster: struct {
    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        backup_retention_policy: ?BackupRetentionPolicy = null,
        hsm_type: []const u8,
        source_backup_id: ?[]const u8 = null,
        subnet_ids: [][]const u8,
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_retention_policy = "BackupRetentionPolicy",
                .hsm_type = "HsmType",
                .source_backup_id = "SourceBackupId",
                .subnet_ids = "SubnetIds",
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
        CloudHsmTag,
    },
} = .{};
pub const create_hsm: struct {
    action_name: []const u8 = "CreateHsm",
    Request: type = struct {
        cluster_id: []const u8,
        availability_zone: []const u8,
        ip_address: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .availability_zone = "AvailabilityZone",
                .ip_address = "IpAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hsm) } {
            return .{ .service_metadata = service_metadata, .action = create_hsm };
        }
    },
    Response: type = struct {
        hsm: ?Hsm = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm = "Hsm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
    },
} = .{};
pub const delete_backup: struct {
    action_name: []const u8 = "DeleteBackup",
    Request: type = struct {
        backup_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup };
        }
    },
    Response: type = struct {
        backup: ?Backup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup = "Backup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
    },
} = .{};
pub const delete_cluster: struct {
    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
        CloudHsmTag,
    },
} = .{};
pub const delete_hsm: struct {
    action_name: []const u8 = "DeleteHsm",
    Request: type = struct {
        cluster_id: []const u8,
        hsm_id: ?[]const u8 = null,
        eni_id: ?[]const u8 = null,
        eni_ip: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .hsm_id = "HsmId",
                .eni_id = "EniId",
                .eni_ip = "EniIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_hsm) } {
            return .{ .service_metadata = service_metadata, .action = delete_hsm };
        }
    },
    Response: type = struct {
        hsm_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_id = "HsmId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
    },
} = .{};
pub const describe_backups: struct {
    action_name: []const u8 = "DescribeBackups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        sort_ascending: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
                .sort_ascending = "SortAscending",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_backups) } {
            return .{ .service_metadata = service_metadata, .action = describe_backups };
        }
    },
    Response: type = struct {
        backups: ?[]Backup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backups = "Backups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
        CloudHsmTag,
    },
} = .{};
pub const describe_clusters: struct {
    action_name: []const u8 = "DescribeClusters",
    Request: type = struct {
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_clusters };
        }
    },
    Response: type = struct {
        clusters: ?[]Cluster = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .clusters = "Clusters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmService,
        CloudHsmTag,
    },
} = .{};
pub const initialize_cluster: struct {
    action_name: []const u8 = "InitializeCluster",
    Request: type = struct {
        cluster_id: []const u8,
        signed_cert: []const u8,
        trust_anchor: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .signed_cert = "SignedCert",
                .trust_anchor = "TrustAnchor",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initialize_cluster) } {
            return .{ .service_metadata = service_metadata, .action = initialize_cluster };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,
        state_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "State",
                .state_message = "StateMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
    },
} = .{};
pub const list_tags: struct {
    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tag_list: []Tag,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
        CloudHsmTag,
    },
} = .{};
pub const modify_backup_attributes: struct {
    action_name: []const u8 = "ModifyBackupAttributes",
    Request: type = struct {
        backup_id: []const u8,
        never_expires: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .never_expires = "NeverExpires",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_backup_attributes) } {
            return .{ .service_metadata = service_metadata, .action = modify_backup_attributes };
        }
    },
    Response: type = struct {
        backup: ?Backup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup = "Backup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
    },
} = .{};
pub const modify_cluster: struct {
    action_name: []const u8 = "ModifyCluster",
    Request: type = struct {
        backup_retention_policy: BackupRetentionPolicy,
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_retention_policy = "BackupRetentionPolicy",
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
    },
} = .{};
pub const restore_backup: struct {
    action_name: []const u8 = "RestoreBackup",
    Request: type = struct {
        backup_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_backup) } {
            return .{ .service_metadata = service_metadata, .action = restore_backup };
        }
    },
    Response: type = struct {
        backup: ?Backup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup = "Backup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_id: []const u8,
        tag_list: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
        CloudHsmTag,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_id: []const u8,
        tag_key_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_key_list = "TagKeyList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmAccessDenied,
        CloudHsmInternalFailure,
        CloudHsmInvalidRequest,
        CloudHsmResourceNotFound,
        CloudHsmService,
        CloudHsmTag,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Backup = struct {
    backup_id: []const u8,
    backup_state: ?[]const u8 = null,
    cluster_id: ?[]const u8 = null,
    create_timestamp: ?i64 = null,
    copy_timestamp: ?i64 = null,
    never_expires: ?bool = null,
    source_region: ?[]const u8 = null,
    source_backup: ?[]const u8 = null,
    source_cluster: ?[]const u8 = null,
    delete_timestamp: ?i64 = null,
    tag_list: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_id = "BackupId",
            .backup_state = "BackupState",
            .cluster_id = "ClusterId",
            .create_timestamp = "CreateTimestamp",
            .copy_timestamp = "CopyTimestamp",
            .never_expires = "NeverExpires",
            .source_region = "SourceRegion",
            .source_backup = "SourceBackup",
            .source_cluster = "SourceCluster",
            .delete_timestamp = "DeleteTimestamp",
            .tag_list = "TagList",
        };
        return @field(mappings, field_name);
    }
};

pub const Cluster = struct {
    backup_policy: ?[]const u8 = null,
    backup_retention_policy: ?BackupRetentionPolicy = null,
    cluster_id: ?[]const u8 = null,
    create_timestamp: ?i64 = null,
    hsms: ?[]Hsm = null,
    hsm_type: ?[]const u8 = null,
    pre_co_password: ?[]const u8 = null,
    security_group: ?[]const u8 = null,
    source_backup_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    state_message: ?[]const u8 = null,
    subnet_mapping: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    vpc_id: ?[]const u8 = null,
    certificates: ?Certificates = null,
    tag_list: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_policy = "BackupPolicy",
            .backup_retention_policy = "BackupRetentionPolicy",
            .cluster_id = "ClusterId",
            .create_timestamp = "CreateTimestamp",
            .hsms = "Hsms",
            .hsm_type = "HsmType",
            .pre_co_password = "PreCoPassword",
            .security_group = "SecurityGroup",
            .source_backup_id = "SourceBackupId",
            .state = "State",
            .state_message = "StateMessage",
            .subnet_mapping = "SubnetMapping",
            .vpc_id = "VpcId",
            .certificates = "Certificates",
            .tag_list = "TagList",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "subnet_mapping", field_name))
            return try serializeMap(self.subnet_mapping, self.fieldNameFor("subnet_mapping"), options, out_stream);
        return false;
    }
};

pub const Certificates = struct {
    cluster_csr: ?[]const u8 = null,
    hsm_certificate: ?[]const u8 = null,
    aws_hardware_certificate: ?[]const u8 = null,
    manufacturer_hardware_certificate: ?[]const u8 = null,
    cluster_certificate: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_csr = "ClusterCsr",
            .hsm_certificate = "HsmCertificate",
            .aws_hardware_certificate = "AwsHardwareCertificate",
            .manufacturer_hardware_certificate = "ManufacturerHardwareCertificate",
            .cluster_certificate = "ClusterCertificate",
        };
        return @field(mappings, field_name);
    }
};

pub const Hsm = struct {
    availability_zone: ?[]const u8 = null,
    cluster_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    eni_id: ?[]const u8 = null,
    eni_ip: ?[]const u8 = null,
    hsm_id: []const u8,
    state: ?[]const u8 = null,
    state_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "AvailabilityZone",
            .cluster_id = "ClusterId",
            .subnet_id = "SubnetId",
            .eni_id = "EniId",
            .eni_ip = "EniIp",
            .hsm_id = "HsmId",
            .state = "State",
            .state_message = "StateMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupRetentionPolicy = struct {
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
