const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2013-01-01";
pub const sdk_id: []const u8 = "CloudSearch Domain";
pub const arn_namespace: ?[]const u8 = "cloudsearch";
pub const endpoint_prefix: []const u8 = "cloudsearchdomain";
pub const sigv4_name: []const u8 = "cloudsearch";
pub const name: []const u8 = "AmazonCloudSearch2013";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2013-01-01",
    sdk_id: []const u8 = "CloudSearch Domain",
    arn_namespace: ?[]const u8 = "cloudsearch",
    endpoint_prefix: []const u8 = "cloudsearchdomain",
    sigv4_name: []const u8 = "cloudsearch",
    name: []const u8 = "AmazonCloudSearch2013",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const search: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-01-01/search?format=sdk&pretty=true",
        .success_code = 200,
    };

    action_name: []const u8 = "Search",
    Request: type = struct {
        cursor: ?[]const u8 = null,
        expr: ?[]const u8 = null,
        facet: ?[]const u8 = null,
        filter_query: ?[]const u8 = null,
        highlight: ?[]const u8 = null,
        partial: ?bool = null,
        query: []const u8,
        query_options: ?[]const u8 = null,
        query_parser: ?[]const u8 = null,
        @"return": ?[]const u8 = null,
        size: ?i64 = null,
        sort: ?[]const u8 = null,
        start: ?i64 = null,
        stats: ?[]const u8 = null,

        pub const http_query = .{
            .cursor = "cursor",
            .expr = "expr",
            .facet = "facet",
            .filter_query = "fq",
            .highlight = "highlight",
            .partial = "partial",
            .query = "q",
            .query_options = "q.options",
            .query_parser = "q.parser",
            .@"return" = "return",
            .size = "size",
            .sort = "sort",
            .start = "start",
            .stats = "stats",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cursor = "cursor",
                .expr = "expr",
                .facet = "facet",
                .filter_query = "filterQuery",
                .highlight = "highlight",
                .partial = "partial",
                .query = "query",
                .query_options = "queryOptions",
                .query_parser = "queryParser",
                .@"return" = "return",
                .size = "size",
                .sort = "sort",
                .start = "start",
                .stats = "stats",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search) } {
            return .{ .service_metadata = service_metadata, .action = search };
        }
    },
    Response: type = struct {
        status: ?struct {
            timems: ?i64 = null,
            rid: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timems = "timems",
                    .rid = "rid",
                };
                return @field(mappings, field_name);
            }
        } = null,
        hits: ?struct {
            found: ?i64 = null,
            start: ?i64 = null,
            cursor: ?[]const u8 = null,
            hit: ?[]struct {
                id: ?[]const u8 = null,
                fields: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[][]const u8 = null,
                } = null,
                exprs: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                highlights: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "id",
                        .fields = "fields",
                        .exprs = "exprs",
                        .highlights = "highlights",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "fields", field_name))
                        return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
                    if (std.mem.eql(u8, "exprs", field_name))
                        return try serializeMap(self.exprs, self.fieldNameFor("exprs"), options, out_stream);
                    if (std.mem.eql(u8, "highlights", field_name))
                        return try serializeMap(self.highlights, self.fieldNameFor("highlights"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .found = "found",
                    .start = "start",
                    .cursor = "cursor",
                    .hit = "hit",
                };
                return @field(mappings, field_name);
            }
        } = null,
        facets: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                buckets: ?[]struct {
                    value: ?[]const u8 = null,
                    count: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value = "value",
                            .count = "count",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .buckets = "buckets",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        stats: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                min: ?[]const u8 = null,
                max: ?[]const u8 = null,
                count: ?i64 = null,
                missing: ?i64 = null,
                sum: ?f64 = null,
                sum_of_squares: ?f64 = null,
                mean: ?[]const u8 = null,
                stddev: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .min = "min",
                        .max = "max",
                        .count = "count",
                        .missing = "missing",
                        .sum = "sum",
                        .sum_of_squares = "sumOfSquares",
                        .mean = "mean",
                        .stddev = "stddev",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .hits = "hits",
                .facets = "facets",
                .stats = "stats",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "facets", field_name))
                return try serializeMap(self.facets, self.fieldNameFor("facets"), options, out_stream);
            if (std.mem.eql(u8, "stats", field_name))
                return try serializeMap(self.stats, self.fieldNameFor("stats"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Search,
    },
} = .{};
pub const suggest: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-01-01/suggest?format=sdk&pretty=true",
        .success_code = 200,
    };

    action_name: []const u8 = "Suggest",
    Request: type = struct {
        query: []const u8,
        suggester: []const u8,
        size: ?i64 = null,

        pub const http_query = .{
            .query = "q",
            .suggester = "suggester",
            .size = "size",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query = "query",
                .suggester = "suggester",
                .size = "size",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(suggest) } {
            return .{ .service_metadata = service_metadata, .action = suggest };
        }
    },
    Response: type = struct {
        status: ?struct {
            timems: ?i64 = null,
            rid: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timems = "timems",
                    .rid = "rid",
                };
                return @field(mappings, field_name);
            }
        } = null,
        suggest: ?struct {
            query: ?[]const u8 = null,
            found: ?i64 = null,
            suggestions: ?[]struct {
                suggestion: ?[]const u8 = null,
                score: ?i64 = null,
                id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .suggestion = "suggestion",
                        .score = "score",
                        .id = "id",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .query = "query",
                    .found = "found",
                    .suggestions = "suggestions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .suggest = "suggest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Search,
    },
} = .{};
pub const upload_documents: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-01-01/documents/batch?format=sdk",
        .success_code = 200,
    };

    action_name: []const u8 = "UploadDocuments",
    Request: type = struct {
        documents: []const u8,
        content_type: []const u8,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "documents";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .documents = "documents",
                .content_type = "contentType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upload_documents) } {
            return .{ .service_metadata = service_metadata, .action = upload_documents };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        adds: ?i64 = null,
        deletes: ?i64 = null,
        warnings: ?[]struct {
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .adds = "adds",
                .deletes = "deletes",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DocumentService,
    },
} = .{};
