const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2013-11-01";
pub const sdk_id: []const u8 = "CloudTrail";
pub const arn_namespace: ?[]const u8 = "cloudtrail";
pub const endpoint_prefix: []const u8 = "cloudtrail";
pub const sigv4_name: []const u8 = "cloudtrail";
pub const name: []const u8 = "CloudTrail_20131101";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2013-11-01",
    sdk_id: []const u8 = "CloudTrail",
    arn_namespace: ?[]const u8 = "cloudtrail",
    endpoint_prefix: []const u8 = "cloudtrail",
    sigv4_name: []const u8 = "cloudtrail",
    name: []const u8 = "CloudTrail_20131101",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags: struct {
    action_name: []const u8 = "AddTags",
    Request: type = struct {
        resource_id: []const u8,
        tags_list: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags_list = "TagsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelARNInvalid,
        ChannelNotFound,
        CloudTrailARNInvalid,
        Conflict,
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InvalidTagParameter,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        ResourceNotFound,
        ResourceTypeNotSupported,
        TagsLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const cancel_query: struct {
    action_name: []const u8 = "CancelQuery",
    Request: type = struct {
        event_data_store: ?[]const u8 = null,
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
                .query_id = "QueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_query) } {
            return .{ .service_metadata = service_metadata, .action = cancel_query };
        }
    },
    Response: type = struct {
        query_id: []const u8,
        query_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
                .query_status = "QueryStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InactiveQuery,
        InvalidParameter,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        QueryIdNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const create_channel: struct {
    action_name: []const u8 = "CreateChannel",
    Request: type = struct {
        name: []const u8,
        source: []const u8,
        destinations: []Destination,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .source = "Source",
                .destinations = "Destinations",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_channel };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        source: ?[]const u8 = null,
        destinations: ?[]Destination = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .name = "Name",
                .source = "Source",
                .destinations = "Destinations",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelAlreadyExists,
        ChannelMaxLimitExceeded,
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InvalidEventDataStoreCategory,
        InvalidParameter,
        InvalidSource,
        InvalidTagParameter,
        OperationNotPermitted,
        TagsLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const create_event_data_store: struct {
    action_name: []const u8 = "CreateEventDataStore",
    Request: type = struct {
        name: []const u8,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,
        multi_region_enabled: ?bool = null,
        organization_enabled: ?bool = null,
        retention_period: ?i64 = null,
        termination_protection_enabled: ?bool = null,
        tags_list: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        start_ingestion: ?bool = null,
        billing_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .advanced_event_selectors = "AdvancedEventSelectors",
                .multi_region_enabled = "MultiRegionEnabled",
                .organization_enabled = "OrganizationEnabled",
                .retention_period = "RetentionPeriod",
                .termination_protection_enabled = "TerminationProtectionEnabled",
                .tags_list = "TagsList",
                .kms_key_id = "KmsKeyId",
                .start_ingestion = "StartIngestion",
                .billing_mode = "BillingMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_data_store) } {
            return .{ .service_metadata = service_metadata, .action = create_event_data_store };
        }
    },
    Response: type = struct {
        event_data_store_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,
        multi_region_enabled: ?bool = null,
        organization_enabled: ?bool = null,
        retention_period: ?i64 = null,
        termination_protection_enabled: ?bool = null,
        tags_list: ?[]Tag = null,
        created_timestamp: ?i64 = null,
        updated_timestamp: ?i64 = null,
        kms_key_id: ?[]const u8 = null,
        billing_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store_arn = "EventDataStoreArn",
                .name = "Name",
                .status = "Status",
                .advanced_event_selectors = "AdvancedEventSelectors",
                .multi_region_enabled = "MultiRegionEnabled",
                .organization_enabled = "OrganizationEnabled",
                .retention_period = "RetentionPeriod",
                .termination_protection_enabled = "TerminationProtectionEnabled",
                .tags_list = "TagsList",
                .created_timestamp = "CreatedTimestamp",
                .updated_timestamp = "UpdatedTimestamp",
                .kms_key_id = "KmsKeyId",
                .billing_mode = "BillingMode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailAccessNotEnabled,
        Conflict,
        EventDataStoreAlreadyExists,
        EventDataStoreMaxLimitExceeded,
        InsufficientDependencyServiceAccessPermission,
        InsufficientEncryptionPolicy,
        InvalidEventSelectors,
        InvalidKmsKeyId,
        InvalidParameter,
        InvalidTagParameter,
        Kms,
        KmsKeyNotFound,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        UnsupportedOperation,
    },
} = .{};
pub const create_trail: struct {
    action_name: []const u8 = "CreateTrail",
    Request: type = struct {
        name: []const u8,
        s3_bucket_name: []const u8,
        s3_key_prefix: ?[]const u8 = null,
        sns_topic_name: ?[]const u8 = null,
        include_global_service_events: ?bool = null,
        is_multi_region_trail: ?bool = null,
        enable_log_file_validation: ?bool = null,
        cloud_watch_logs_log_group_arn: ?[]const u8 = null,
        cloud_watch_logs_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        is_organization_trail: ?bool = null,
        tags_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .s3_bucket_name = "S3BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .sns_topic_name = "SnsTopicName",
                .include_global_service_events = "IncludeGlobalServiceEvents",
                .is_multi_region_trail = "IsMultiRegionTrail",
                .enable_log_file_validation = "EnableLogFileValidation",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
                .kms_key_id = "KmsKeyId",
                .is_organization_trail = "IsOrganizationTrail",
                .tags_list = "TagsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trail) } {
            return .{ .service_metadata = service_metadata, .action = create_trail };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        sns_topic_name: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        include_global_service_events: ?bool = null,
        is_multi_region_trail: ?bool = null,
        trail_arn: ?[]const u8 = null,
        log_file_validation_enabled: ?bool = null,
        cloud_watch_logs_log_group_arn: ?[]const u8 = null,
        cloud_watch_logs_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        is_organization_trail: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .s3_bucket_name = "S3BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .sns_topic_name = "SnsTopicName",
                .sns_topic_arn = "SnsTopicARN",
                .include_global_service_events = "IncludeGlobalServiceEvents",
                .is_multi_region_trail = "IsMultiRegionTrail",
                .trail_arn = "TrailARN",
                .log_file_validation_enabled = "LogFileValidationEnabled",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
                .kms_key_id = "KmsKeyId",
                .is_organization_trail = "IsOrganizationTrail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailAccessNotEnabled,
        CloudTrailInvalidClientTokenId,
        CloudWatchLogsDeliveryUnavailable,
        Conflict,
        InsufficientDependencyServiceAccessPermission,
        InsufficientEncryptionPolicy,
        InsufficientS3BucketPolicy,
        InsufficientSnsTopicPolicy,
        InvalidCloudWatchLogsLogGroupArn,
        InvalidCloudWatchLogsRoleArn,
        InvalidKmsKeyId,
        InvalidParameterCombination,
        InvalidS3BucketName,
        InvalidS3Prefix,
        InvalidSnsTopicName,
        InvalidTagParameter,
        InvalidTrailName,
        Kms,
        KmsKeyDisabled,
        KmsKeyNotFound,
        MaximumNumberOfTrailsExceeded,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        S3BucketDoesNotExist,
        TagsLimitExceeded,
        Throttling,
        TrailAlreadyExists,
        TrailNotProvided,
        UnsupportedOperation,
    },
} = .{};
pub const delete_channel: struct {
    action_name: []const u8 = "DeleteChannel",
    Request: type = struct {
        channel: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "Channel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelARNInvalid,
        ChannelNotFound,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const delete_event_data_store: struct {
    action_name: []const u8 = "DeleteEventDataStore",
    Request: type = struct {
        event_data_store: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_data_store) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_data_store };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelExistsForEDS,
        Conflict,
        EventDataStoreARNInvalid,
        EventDataStoreFederationEnabled,
        EventDataStoreHasOngoingImport,
        EventDataStoreNotFound,
        EventDataStoreTerminationProtected,
        InactiveEventDataStore,
        InsufficientDependencyServiceAccessPermission,
        InvalidParameter,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ResourceARNNotValid,
        ResourceNotFound,
        ResourcePolicyNotFound,
        ResourceTypeNotSupported,
        UnsupportedOperation,
    },
} = .{};
pub const delete_trail: struct {
    action_name: []const u8 = "DeleteTrail",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trail) } {
            return .{ .service_metadata = service_metadata, .action = delete_trail };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        Conflict,
        InsufficientDependencyServiceAccessPermission,
        InvalidHomeRegion,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        Throttling,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const deregister_organization_delegated_admin: struct {
    action_name: []const u8 = "DeregisterOrganizationDelegatedAdmin",
    Request: type = struct {
        delegated_admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_admin_account_id = "DelegatedAdminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_organization_delegated_admin) } {
            return .{ .service_metadata = service_metadata, .action = deregister_organization_delegated_admin };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountNotFound,
        AccountNotRegistered,
        CloudTrailAccessNotEnabled,
        Conflict,
        InsufficientDependencyServiceAccessPermission,
        InvalidParameter,
        NotOrganizationManagementAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        UnsupportedOperation,
    },
} = .{};
pub const describe_query: struct {
    action_name: []const u8 = "DescribeQuery",
    Request: type = struct {
        event_data_store: ?[]const u8 = null,
        query_id: ?[]const u8 = null,
        query_alias: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
                .query_id = "QueryId",
                .query_alias = "QueryAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_query) } {
            return .{ .service_metadata = service_metadata, .action = describe_query };
        }
    },
    Response: type = struct {
        query_id: ?[]const u8 = null,
        query_string: ?[]const u8 = null,
        query_status: ?[]const u8 = null,
        query_statistics: ?struct {
            events_matched: ?i64 = null,
            events_scanned: ?i64 = null,
            bytes_scanned: ?i64 = null,
            execution_time_in_millis: ?i64 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .events_matched = "EventsMatched",
                    .events_scanned = "EventsScanned",
                    .bytes_scanned = "BytesScanned",
                    .execution_time_in_millis = "ExecutionTimeInMillis",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        error_message: ?[]const u8 = null,
        delivery_s3_uri: ?[]const u8 = null,
        delivery_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
                .query_string = "QueryString",
                .query_status = "QueryStatus",
                .query_statistics = "QueryStatistics",
                .error_message = "ErrorMessage",
                .delivery_s3_uri = "DeliveryS3Uri",
                .delivery_status = "DeliveryStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InvalidParameter,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        QueryIdNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_trails: struct {
    action_name: []const u8 = "DescribeTrails",
    Request: type = struct {
        trail_name_list: ?[][]const u8 = null,
        include_shadow_trails: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name_list = "trailNameList",
                .include_shadow_trails = "includeShadowTrails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trails) } {
            return .{ .service_metadata = service_metadata, .action = describe_trails };
        }
    },
    Response: type = struct {
        trail_list: ?[]Trail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_list = "trailList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTrailName,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const disable_federation: struct {
    action_name: []const u8 = "DisableFederation",
    Request: type = struct {
        event_data_store: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_federation) } {
            return .{ .service_metadata = service_metadata, .action = disable_federation };
        }
    },
    Response: type = struct {
        event_data_store_arn: ?[]const u8 = null,
        federation_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store_arn = "EventDataStoreArn",
                .federation_status = "FederationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CloudTrailAccessNotEnabled,
        ConcurrentModification,
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InsufficientDependencyServiceAccessPermission,
        InvalidParameter,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        UnsupportedOperation,
    },
} = .{};
pub const enable_federation: struct {
    action_name: []const u8 = "EnableFederation",
    Request: type = struct {
        event_data_store: []const u8,
        federation_role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
                .federation_role_arn = "FederationRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_federation) } {
            return .{ .service_metadata = service_metadata, .action = enable_federation };
        }
    },
    Response: type = struct {
        event_data_store_arn: ?[]const u8 = null,
        federation_status: ?[]const u8 = null,
        federation_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store_arn = "EventDataStoreArn",
                .federation_status = "FederationStatus",
                .federation_role_arn = "FederationRoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        CloudTrailAccessNotEnabled,
        ConcurrentModification,
        EventDataStoreARNInvalid,
        EventDataStoreFederationEnabled,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InsufficientDependencyServiceAccessPermission,
        InvalidParameter,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        UnsupportedOperation,
    },
} = .{};
pub const get_channel: struct {
    action_name: []const u8 = "GetChannel",
    Request: type = struct {
        channel: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "Channel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_channel };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        source: ?[]const u8 = null,
        source_config: ?struct {
            apply_to_all_regions: ?bool = null,
            advanced_event_selectors: ?[]AdvancedEventSelector = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .apply_to_all_regions = "ApplyToAllRegions",
                    .advanced_event_selectors = "AdvancedEventSelectors",
                };
                return @field(mappings, field_name);
            }
        } = null,
        destinations: ?[]Destination = null,
        ingestion_status: ?struct {
            latest_ingestion_success_time: ?i64 = null,
            latest_ingestion_success_event_id: ?[]const u8 = null,
            latest_ingestion_error_code: ?[]const u8 = null,
            latest_ingestion_attempt_time: ?i64 = null,
            latest_ingestion_attempt_event_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .latest_ingestion_success_time = "LatestIngestionSuccessTime",
                    .latest_ingestion_success_event_id = "LatestIngestionSuccessEventID",
                    .latest_ingestion_error_code = "LatestIngestionErrorCode",
                    .latest_ingestion_attempt_time = "LatestIngestionAttemptTime",
                    .latest_ingestion_attempt_event_id = "LatestIngestionAttemptEventID",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .name = "Name",
                .source = "Source",
                .source_config = "SourceConfig",
                .destinations = "Destinations",
                .ingestion_status = "IngestionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelARNInvalid,
        ChannelNotFound,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const get_event_data_store: struct {
    action_name: []const u8 = "GetEventDataStore",
    Request: type = struct {
        event_data_store: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_data_store) } {
            return .{ .service_metadata = service_metadata, .action = get_event_data_store };
        }
    },
    Response: type = struct {
        event_data_store_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,
        multi_region_enabled: ?bool = null,
        organization_enabled: ?bool = null,
        retention_period: ?i64 = null,
        termination_protection_enabled: ?bool = null,
        created_timestamp: ?i64 = null,
        updated_timestamp: ?i64 = null,
        kms_key_id: ?[]const u8 = null,
        billing_mode: ?[]const u8 = null,
        federation_status: ?[]const u8 = null,
        federation_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store_arn = "EventDataStoreArn",
                .name = "Name",
                .status = "Status",
                .advanced_event_selectors = "AdvancedEventSelectors",
                .multi_region_enabled = "MultiRegionEnabled",
                .organization_enabled = "OrganizationEnabled",
                .retention_period = "RetentionPeriod",
                .termination_protection_enabled = "TerminationProtectionEnabled",
                .created_timestamp = "CreatedTimestamp",
                .updated_timestamp = "UpdatedTimestamp",
                .kms_key_id = "KmsKeyId",
                .billing_mode = "BillingMode",
                .federation_status = "FederationStatus",
                .federation_role_arn = "FederationRoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InvalidParameter,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const get_event_selectors: struct {
    action_name: []const u8 = "GetEventSelectors",
    Request: type = struct {
        trail_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name = "TrailName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_selectors) } {
            return .{ .service_metadata = service_metadata, .action = get_event_selectors };
        }
    },
    Response: type = struct {
        trail_arn: ?[]const u8 = null,
        event_selectors: ?[]EventSelector = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_arn = "TrailARN",
                .event_selectors = "EventSelectors",
                .advanced_event_selectors = "AdvancedEventSelectors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_import: struct {
    action_name: []const u8 = "GetImport",
    Request: type = struct {
        import_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "ImportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_import) } {
            return .{ .service_metadata = service_metadata, .action = get_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        destinations: ?[][]const u8 = null,
        import_source: ?ImportSource = null,
        start_event_time: ?i64 = null,
        end_event_time: ?i64 = null,
        import_status: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        updated_timestamp: ?i64 = null,
        import_statistics: ?ImportStatistics = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "ImportId",
                .destinations = "Destinations",
                .import_source = "ImportSource",
                .start_event_time = "StartEventTime",
                .end_event_time = "EndEventTime",
                .import_status = "ImportStatus",
                .created_timestamp = "CreatedTimestamp",
                .updated_timestamp = "UpdatedTimestamp",
                .import_statistics = "ImportStatistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImportNotFound,
        InvalidParameter,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const get_insight_selectors: struct {
    action_name: []const u8 = "GetInsightSelectors",
    Request: type = struct {
        trail_name: ?[]const u8 = null,
        event_data_store: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name = "TrailName",
                .event_data_store = "EventDataStore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insight_selectors) } {
            return .{ .service_metadata = service_metadata, .action = get_insight_selectors };
        }
    },
    Response: type = struct {
        trail_arn: ?[]const u8 = null,
        insight_selectors: ?[]InsightSelector = null,
        event_data_store_arn: ?[]const u8 = null,
        insights_destination: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_arn = "TrailARN",
                .insight_selectors = "InsightSelectors",
                .event_data_store_arn = "EventDataStoreArn",
                .insights_destination = "InsightsDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        InsightNotEnabled,
        InvalidParameterCombination,
        InvalidParameter,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        Throttling,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_query_results: struct {
    action_name: []const u8 = "GetQueryResults",
    Request: type = struct {
        event_data_store: ?[]const u8 = null,
        query_id: []const u8,
        next_token: ?[]const u8 = null,
        max_query_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
                .query_id = "QueryId",
                .next_token = "NextToken",
                .max_query_results = "MaxQueryResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_results) } {
            return .{ .service_metadata = service_metadata, .action = get_query_results };
        }
    },
    Response: type = struct {
        query_status: ?[]const u8 = null,
        query_statistics: ?struct {
            results_count: ?i64 = null,
            total_results_count: ?i64 = null,
            bytes_scanned: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .results_count = "ResultsCount",
                    .total_results_count = "TotalResultsCount",
                    .bytes_scanned = "BytesScanned",
                };
                return @field(mappings, field_name);
            }
        } = null,
        query_result_rows: ?[][][]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_status = "QueryStatus",
                .query_statistics = "QueryStatistics",
                .query_result_rows = "QueryResultRows",
                .next_token = "NextToken",
                .error_message = "ErrorMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "query_result_rows", field_name))
                return try serializeMap(self.query_result_rows, self.fieldNameFor("query_result_rows"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InsufficientEncryptionPolicy,
        InvalidMaxResults,
        InvalidNextToken,
        InvalidParameter,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        QueryIdNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_resource_policy: struct {
    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        resource_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ResourceARNNotValid,
        ResourceNotFound,
        ResourcePolicyNotFound,
        ResourceTypeNotSupported,
        UnsupportedOperation,
    },
} = .{};
pub const get_trail: struct {
    action_name: []const u8 = "GetTrail",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trail) } {
            return .{ .service_metadata = service_metadata, .action = get_trail };
        }
    },
    Response: type = struct {
        trail: ?Trail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail = "Trail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        InvalidTrailName,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_trail_status: struct {
    action_name: []const u8 = "GetTrailStatus",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trail_status) } {
            return .{ .service_metadata = service_metadata, .action = get_trail_status };
        }
    },
    Response: type = struct {
        is_logging: ?bool = null,
        latest_delivery_error: ?[]const u8 = null,
        latest_notification_error: ?[]const u8 = null,
        latest_delivery_time: ?i64 = null,
        latest_notification_time: ?i64 = null,
        start_logging_time: ?i64 = null,
        stop_logging_time: ?i64 = null,
        latest_cloud_watch_logs_delivery_error: ?[]const u8 = null,
        latest_cloud_watch_logs_delivery_time: ?i64 = null,
        latest_digest_delivery_time: ?i64 = null,
        latest_digest_delivery_error: ?[]const u8 = null,
        latest_delivery_attempt_time: ?[]const u8 = null,
        latest_notification_attempt_time: ?[]const u8 = null,
        latest_notification_attempt_succeeded: ?[]const u8 = null,
        latest_delivery_attempt_succeeded: ?[]const u8 = null,
        time_logging_started: ?[]const u8 = null,
        time_logging_stopped: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_logging = "IsLogging",
                .latest_delivery_error = "LatestDeliveryError",
                .latest_notification_error = "LatestNotificationError",
                .latest_delivery_time = "LatestDeliveryTime",
                .latest_notification_time = "LatestNotificationTime",
                .start_logging_time = "StartLoggingTime",
                .stop_logging_time = "StopLoggingTime",
                .latest_cloud_watch_logs_delivery_error = "LatestCloudWatchLogsDeliveryError",
                .latest_cloud_watch_logs_delivery_time = "LatestCloudWatchLogsDeliveryTime",
                .latest_digest_delivery_time = "LatestDigestDeliveryTime",
                .latest_digest_delivery_error = "LatestDigestDeliveryError",
                .latest_delivery_attempt_time = "LatestDeliveryAttemptTime",
                .latest_notification_attempt_time = "LatestNotificationAttemptTime",
                .latest_notification_attempt_succeeded = "LatestNotificationAttemptSucceeded",
                .latest_delivery_attempt_succeeded = "LatestDeliveryAttemptSucceeded",
                .time_logging_started = "TimeLoggingStarted",
                .time_logging_stopped = "TimeLoggingStopped",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        InvalidTrailName,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const list_channels: struct {
    action_name: []const u8 = "ListChannels",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_channels };
        }
    },
    Response: type = struct {
        channels: ?[]struct {
            channel_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_arn = "ChannelArn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const list_event_data_stores: struct {
    action_name: []const u8 = "ListEventDataStores",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_data_stores) } {
            return .{ .service_metadata = service_metadata, .action = list_event_data_stores };
        }
    },
    Response: type = struct {
        event_data_stores: ?[]struct {
            event_data_store_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            termination_protection_enabled: ?bool = null,
            status: ?[]const u8 = null,
            advanced_event_selectors: ?[]AdvancedEventSelector = null,
            multi_region_enabled: ?bool = null,
            organization_enabled: ?bool = null,
            retention_period: ?i64 = null,
            created_timestamp: ?i64 = null,
            updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_data_store_arn = "EventDataStoreArn",
                    .name = "Name",
                    .termination_protection_enabled = "TerminationProtectionEnabled",
                    .status = "Status",
                    .advanced_event_selectors = "AdvancedEventSelectors",
                    .multi_region_enabled = "MultiRegionEnabled",
                    .organization_enabled = "OrganizationEnabled",
                    .retention_period = "RetentionPeriod",
                    .created_timestamp = "CreatedTimestamp",
                    .updated_timestamp = "UpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_stores = "EventDataStores",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidMaxResults,
        InvalidNextToken,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const list_import_failures: struct {
    action_name: []const u8 = "ListImportFailures",
    Request: type = struct {
        import_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "ImportId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_import_failures) } {
            return .{ .service_metadata = service_metadata, .action = list_import_failures };
        }
    },
    Response: type = struct {
        failures: ?[]struct {
            location: ?[]const u8 = null,
            status: ?[]const u8 = null,
            error_type: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location = "Location",
                    .status = "Status",
                    .error_type = "ErrorType",
                    .error_message = "ErrorMessage",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const list_imports: struct {
    action_name: []const u8 = "ListImports",
    Request: type = struct {
        max_results: ?i64 = null,
        destination: ?[]const u8 = null,
        import_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .destination = "Destination",
                .import_status = "ImportStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_imports) } {
            return .{ .service_metadata = service_metadata, .action = list_imports };
        }
    },
    Response: type = struct {
        imports: ?[]struct {
            import_id: ?[]const u8 = null,
            import_status: ?[]const u8 = null,
            destinations: ?[][]const u8 = null,
            created_timestamp: ?i64 = null,
            updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .import_id = "ImportId",
                    .import_status = "ImportStatus",
                    .destinations = "Destinations",
                    .created_timestamp = "CreatedTimestamp",
                    .updated_timestamp = "UpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .imports = "Imports",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventDataStoreARNInvalid,
        InvalidNextToken,
        InvalidParameter,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const list_insights_metric_data: struct {
    action_name: []const u8 = "ListInsightsMetricData",
    Request: type = struct {
        event_source: []const u8,
        event_name: []const u8,
        insight_type: []const u8,
        error_code: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        period: ?i64 = null,
        data_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_source = "EventSource",
                .event_name = "EventName",
                .insight_type = "InsightType",
                .error_code = "ErrorCode",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .period = "Period",
                .data_type = "DataType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_insights_metric_data) } {
            return .{ .service_metadata = service_metadata, .action = list_insights_metric_data };
        }
    },
    Response: type = struct {
        event_source: ?[]const u8 = null,
        event_name: ?[]const u8 = null,
        insight_type: ?[]const u8 = null,
        error_code: ?[]const u8 = null,
        timestamps: ?[]i64 = null,
        values: ?[]f64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_source = "EventSource",
                .event_name = "EventName",
                .insight_type = "InsightType",
                .error_code = "ErrorCode",
                .timestamps = "Timestamps",
                .values = "Values",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const list_public_keys: struct {
    action_name: []const u8 = "ListPublicKeys",
    Request: type = struct {
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "StartTime",
                .end_time = "EndTime",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_public_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_public_keys };
        }
    },
    Response: type = struct {
        public_key_list: ?[]struct {
            value: ?[]const u8 = null,
            validity_start_time: ?i64 = null,
            validity_end_time: ?i64 = null,
            fingerprint: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .value = "Value",
                    .validity_start_time = "ValidityStartTime",
                    .validity_end_time = "ValidityEndTime",
                    .fingerprint = "Fingerprint",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key_list = "PublicKeyList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTimeRange,
        InvalidToken,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const list_queries: struct {
    action_name: []const u8 = "ListQueries",
    Request: type = struct {
        event_data_store: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        query_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .query_status = "QueryStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queries) } {
            return .{ .service_metadata = service_metadata, .action = list_queries };
        }
    },
    Response: type = struct {
        queries: ?[]struct {
            query_id: ?[]const u8 = null,
            query_status: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .query_id = "QueryId",
                    .query_status = "QueryStatus",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queries = "Queries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InvalidDateRange,
        InvalidMaxResults,
        InvalidNextToken,
        InvalidParameter,
        InvalidQueryStatus,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const list_tags: struct {
    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource_id_list: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id_list = "ResourceIdList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        resource_tag_list: ?[]struct {
            resource_id: ?[]const u8 = null,
            tags_list: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "ResourceId",
                    .tags_list = "TagsList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_tag_list = "ResourceTagList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelARNInvalid,
        CloudTrailARNInvalid,
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InvalidToken,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        ResourceNotFound,
        ResourceTypeNotSupported,
        UnsupportedOperation,
    },
} = .{};
pub const list_trails: struct {
    action_name: []const u8 = "ListTrails",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_trails) } {
            return .{ .service_metadata = service_metadata, .action = list_trails };
        }
    },
    Response: type = struct {
        trails: ?[]struct {
            trail_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            home_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trail_arn = "TrailARN",
                    .name = "Name",
                    .home_region = "HomeRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trails = "Trails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const lookup_events: struct {
    action_name: []const u8 = "LookupEvents",
    Request: type = struct {
        lookup_attributes: ?[]struct {
            attribute_key: []const u8,
            attribute_value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_key = "AttributeKey",
                    .attribute_value = "AttributeValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        event_category: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lookup_attributes = "LookupAttributes",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .event_category = "EventCategory",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(lookup_events) } {
            return .{ .service_metadata = service_metadata, .action = lookup_events };
        }
    },
    Response: type = struct {
        events: ?[]struct {
            event_id: ?[]const u8 = null,
            event_name: ?[]const u8 = null,
            read_only: ?[]const u8 = null,
            access_key_id: ?[]const u8 = null,
            event_time: ?i64 = null,
            event_source: ?[]const u8 = null,
            username: ?[]const u8 = null,
            resources: ?[]struct {
                resource_type: ?[]const u8 = null,
                resource_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "ResourceType",
                        .resource_name = "ResourceName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            cloud_trail_event: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_id = "EventId",
                    .event_name = "EventName",
                    .read_only = "ReadOnly",
                    .access_key_id = "AccessKeyId",
                    .event_time = "EventTime",
                    .event_source = "EventSource",
                    .username = "Username",
                    .resources = "Resources",
                    .cloud_trail_event = "CloudTrailEvent",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "Events",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEventCategory,
        InvalidLookupAttributes,
        InvalidMaxResults,
        InvalidNextToken,
        InvalidTimeRange,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const put_event_selectors: struct {
    action_name: []const u8 = "PutEventSelectors",
    Request: type = struct {
        trail_name: []const u8,
        event_selectors: ?[]EventSelector = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name = "TrailName",
                .event_selectors = "EventSelectors",
                .advanced_event_selectors = "AdvancedEventSelectors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_event_selectors) } {
            return .{ .service_metadata = service_metadata, .action = put_event_selectors };
        }
    },
    Response: type = struct {
        trail_arn: ?[]const u8 = null,
        event_selectors: ?[]EventSelector = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_arn = "TrailARN",
                .event_selectors = "EventSelectors",
                .advanced_event_selectors = "AdvancedEventSelectors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        Conflict,
        InsufficientDependencyServiceAccessPermission,
        InvalidEventSelectors,
        InvalidHomeRegion,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        Throttling,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const put_insight_selectors: struct {
    action_name: []const u8 = "PutInsightSelectors",
    Request: type = struct {
        trail_name: ?[]const u8 = null,
        insight_selectors: []InsightSelector,
        event_data_store: ?[]const u8 = null,
        insights_destination: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name = "TrailName",
                .insight_selectors = "InsightSelectors",
                .event_data_store = "EventDataStore",
                .insights_destination = "InsightsDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_insight_selectors) } {
            return .{ .service_metadata = service_metadata, .action = put_insight_selectors };
        }
    },
    Response: type = struct {
        trail_arn: ?[]const u8 = null,
        insight_selectors: ?[]InsightSelector = null,
        event_data_store_arn: ?[]const u8 = null,
        insights_destination: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_arn = "TrailARN",
                .insight_selectors = "InsightSelectors",
                .event_data_store_arn = "EventDataStoreArn",
                .insights_destination = "InsightsDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        InsufficientEncryptionPolicy,
        InsufficientS3BucketPolicy,
        InvalidHomeRegion,
        InvalidInsightSelectors,
        InvalidParameterCombination,
        InvalidParameter,
        InvalidTrailName,
        Kms,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        S3BucketDoesNotExist,
        Throttling,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        resource_policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        resource_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ResourceARNNotValid,
        ResourceNotFound,
        ResourcePolicyNotValid,
        ResourceTypeNotSupported,
        UnsupportedOperation,
    },
} = .{};
pub const register_organization_delegated_admin: struct {
    action_name: []const u8 = "RegisterOrganizationDelegatedAdmin",
    Request: type = struct {
        member_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_account_id = "MemberAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_organization_delegated_admin) } {
            return .{ .service_metadata = service_metadata, .action = register_organization_delegated_admin };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountNotFound,
        AccountRegistered,
        CannotDelegateManagementAccount,
        CloudTrailAccessNotEnabled,
        Conflict,
        DelegatedAdminAccountLimitExceeded,
        InsufficientDependencyServiceAccessPermission,
        InvalidParameter,
        NotOrganizationManagementAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        UnsupportedOperation,
    },
} = .{};
pub const remove_tags: struct {
    action_name: []const u8 = "RemoveTags",
    Request: type = struct {
        resource_id: []const u8,
        tags_list: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags_list = "TagsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelARNInvalid,
        ChannelNotFound,
        CloudTrailARNInvalid,
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InvalidTagParameter,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        ResourceNotFound,
        ResourceTypeNotSupported,
        UnsupportedOperation,
    },
} = .{};
pub const restore_event_data_store: struct {
    action_name: []const u8 = "RestoreEventDataStore",
    Request: type = struct {
        event_data_store: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_event_data_store) } {
            return .{ .service_metadata = service_metadata, .action = restore_event_data_store };
        }
    },
    Response: type = struct {
        event_data_store_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,
        multi_region_enabled: ?bool = null,
        organization_enabled: ?bool = null,
        retention_period: ?i64 = null,
        termination_protection_enabled: ?bool = null,
        created_timestamp: ?i64 = null,
        updated_timestamp: ?i64 = null,
        kms_key_id: ?[]const u8 = null,
        billing_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store_arn = "EventDataStoreArn",
                .name = "Name",
                .status = "Status",
                .advanced_event_selectors = "AdvancedEventSelectors",
                .multi_region_enabled = "MultiRegionEnabled",
                .organization_enabled = "OrganizationEnabled",
                .retention_period = "RetentionPeriod",
                .termination_protection_enabled = "TerminationProtectionEnabled",
                .created_timestamp = "CreatedTimestamp",
                .updated_timestamp = "UpdatedTimestamp",
                .kms_key_id = "KmsKeyId",
                .billing_mode = "BillingMode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailAccessNotEnabled,
        EventDataStoreARNInvalid,
        EventDataStoreMaxLimitExceeded,
        EventDataStoreNotFound,
        InsufficientDependencyServiceAccessPermission,
        InvalidEventDataStoreStatus,
        InvalidParameter,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        UnsupportedOperation,
    },
} = .{};
pub const start_event_data_store_ingestion: struct {
    action_name: []const u8 = "StartEventDataStoreIngestion",
    Request: type = struct {
        event_data_store: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_event_data_store_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = start_event_data_store_ingestion };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InsufficientDependencyServiceAccessPermission,
        InvalidEventDataStoreCategory,
        InvalidEventDataStoreStatus,
        InvalidParameter,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const start_import: struct {
    action_name: []const u8 = "StartImport",
    Request: type = struct {
        destinations: ?[][]const u8 = null,
        import_source: ?ImportSource = null,
        start_event_time: ?i64 = null,
        end_event_time: ?i64 = null,
        import_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destinations = "Destinations",
                .import_source = "ImportSource",
                .start_event_time = "StartEventTime",
                .end_event_time = "EndEventTime",
                .import_id = "ImportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_import) } {
            return .{ .service_metadata = service_metadata, .action = start_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        destinations: ?[][]const u8 = null,
        import_source: ?ImportSource = null,
        start_event_time: ?i64 = null,
        end_event_time: ?i64 = null,
        import_status: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        updated_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "ImportId",
                .destinations = "Destinations",
                .import_source = "ImportSource",
                .start_event_time = "StartEventTime",
                .end_event_time = "EndEventTime",
                .import_status = "ImportStatus",
                .created_timestamp = "CreatedTimestamp",
                .updated_timestamp = "UpdatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountHasOngoingImport,
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        ImportNotFound,
        InactiveEventDataStore,
        InsufficientEncryptionPolicy,
        InvalidEventDataStoreCategory,
        InvalidEventDataStoreStatus,
        InvalidImportSource,
        InvalidParameter,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const start_logging: struct {
    action_name: []const u8 = "StartLogging",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_logging) } {
            return .{ .service_metadata = service_metadata, .action = start_logging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        Conflict,
        InsufficientDependencyServiceAccessPermission,
        InvalidHomeRegion,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        Throttling,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const start_query: struct {
    action_name: []const u8 = "StartQuery",
    Request: type = struct {
        query_statement: ?[]const u8 = null,
        delivery_s3_uri: ?[]const u8 = null,
        query_alias: ?[]const u8 = null,
        query_parameters: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_statement = "QueryStatement",
                .delivery_s3_uri = "DeliveryS3Uri",
                .query_alias = "QueryAlias",
                .query_parameters = "QueryParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_query) } {
            return .{ .service_metadata = service_metadata, .action = start_query };
        }
    },
    Response: type = struct {
        query_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InsufficientEncryptionPolicy,
        InsufficientS3BucketPolicy,
        InvalidParameter,
        InvalidQueryStatement,
        InvalidS3BucketName,
        InvalidS3Prefix,
        MaxConcurrentQueries,
        NoManagementAccountSLRExists,
        OperationNotPermitted,
        S3BucketDoesNotExist,
        UnsupportedOperation,
    },
} = .{};
pub const stop_event_data_store_ingestion: struct {
    action_name: []const u8 = "StopEventDataStoreIngestion",
    Request: type = struct {
        event_data_store: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_event_data_store_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = stop_event_data_store_ingestion };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InsufficientDependencyServiceAccessPermission,
        InvalidEventDataStoreCategory,
        InvalidEventDataStoreStatus,
        InvalidParameter,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const stop_import: struct {
    action_name: []const u8 = "StopImport",
    Request: type = struct {
        import_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "ImportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_import) } {
            return .{ .service_metadata = service_metadata, .action = stop_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        import_source: ?ImportSource = null,
        destinations: ?[][]const u8 = null,
        import_status: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        updated_timestamp: ?i64 = null,
        start_event_time: ?i64 = null,
        end_event_time: ?i64 = null,
        import_statistics: ?ImportStatistics = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "ImportId",
                .import_source = "ImportSource",
                .destinations = "Destinations",
                .import_status = "ImportStatus",
                .created_timestamp = "CreatedTimestamp",
                .updated_timestamp = "UpdatedTimestamp",
                .start_event_time = "StartEventTime",
                .end_event_time = "EndEventTime",
                .import_statistics = "ImportStatistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImportNotFound,
        InvalidParameter,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const stop_logging: struct {
    action_name: []const u8 = "StopLogging",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_logging) } {
            return .{ .service_metadata = service_metadata, .action = stop_logging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        Conflict,
        InsufficientDependencyServiceAccessPermission,
        InvalidHomeRegion,
        InvalidTrailName,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        Throttling,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const update_channel: struct {
    action_name: []const u8 = "UpdateChannel",
    Request: type = struct {
        channel: []const u8,
        destinations: ?[]Destination = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "Channel",
                .destinations = "Destinations",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_channel };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        source: ?[]const u8 = null,
        destinations: ?[]Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .name = "Name",
                .source = "Source",
                .destinations = "Destinations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelAlreadyExists,
        ChannelARNInvalid,
        ChannelNotFound,
        EventDataStoreARNInvalid,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InvalidEventDataStoreCategory,
        InvalidParameter,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const update_event_data_store: struct {
    action_name: []const u8 = "UpdateEventDataStore",
    Request: type = struct {
        event_data_store: []const u8,
        name: ?[]const u8 = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,
        multi_region_enabled: ?bool = null,
        organization_enabled: ?bool = null,
        retention_period: ?i64 = null,
        termination_protection_enabled: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        billing_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store = "EventDataStore",
                .name = "Name",
                .advanced_event_selectors = "AdvancedEventSelectors",
                .multi_region_enabled = "MultiRegionEnabled",
                .organization_enabled = "OrganizationEnabled",
                .retention_period = "RetentionPeriod",
                .termination_protection_enabled = "TerminationProtectionEnabled",
                .kms_key_id = "KmsKeyId",
                .billing_mode = "BillingMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_event_data_store) } {
            return .{ .service_metadata = service_metadata, .action = update_event_data_store };
        }
    },
    Response: type = struct {
        event_data_store_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,
        multi_region_enabled: ?bool = null,
        organization_enabled: ?bool = null,
        retention_period: ?i64 = null,
        termination_protection_enabled: ?bool = null,
        created_timestamp: ?i64 = null,
        updated_timestamp: ?i64 = null,
        kms_key_id: ?[]const u8 = null,
        billing_mode: ?[]const u8 = null,
        federation_status: ?[]const u8 = null,
        federation_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_data_store_arn = "EventDataStoreArn",
                .name = "Name",
                .status = "Status",
                .advanced_event_selectors = "AdvancedEventSelectors",
                .multi_region_enabled = "MultiRegionEnabled",
                .organization_enabled = "OrganizationEnabled",
                .retention_period = "RetentionPeriod",
                .termination_protection_enabled = "TerminationProtectionEnabled",
                .created_timestamp = "CreatedTimestamp",
                .updated_timestamp = "UpdatedTimestamp",
                .kms_key_id = "KmsKeyId",
                .billing_mode = "BillingMode",
                .federation_status = "FederationStatus",
                .federation_role_arn = "FederationRoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailAccessNotEnabled,
        EventDataStoreAlreadyExists,
        EventDataStoreARNInvalid,
        EventDataStoreHasOngoingImport,
        EventDataStoreNotFound,
        InactiveEventDataStore,
        InsufficientDependencyServiceAccessPermission,
        InsufficientEncryptionPolicy,
        InvalidEventSelectors,
        InvalidInsightSelectors,
        InvalidKmsKeyId,
        InvalidParameter,
        Kms,
        KmsKeyNotFound,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        UnsupportedOperation,
    },
} = .{};
pub const update_trail: struct {
    action_name: []const u8 = "UpdateTrail",
    Request: type = struct {
        name: []const u8,
        s3_bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        sns_topic_name: ?[]const u8 = null,
        include_global_service_events: ?bool = null,
        is_multi_region_trail: ?bool = null,
        enable_log_file_validation: ?bool = null,
        cloud_watch_logs_log_group_arn: ?[]const u8 = null,
        cloud_watch_logs_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        is_organization_trail: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .s3_bucket_name = "S3BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .sns_topic_name = "SnsTopicName",
                .include_global_service_events = "IncludeGlobalServiceEvents",
                .is_multi_region_trail = "IsMultiRegionTrail",
                .enable_log_file_validation = "EnableLogFileValidation",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
                .kms_key_id = "KmsKeyId",
                .is_organization_trail = "IsOrganizationTrail",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_trail) } {
            return .{ .service_metadata = service_metadata, .action = update_trail };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        sns_topic_name: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        include_global_service_events: ?bool = null,
        is_multi_region_trail: ?bool = null,
        trail_arn: ?[]const u8 = null,
        log_file_validation_enabled: ?bool = null,
        cloud_watch_logs_log_group_arn: ?[]const u8 = null,
        cloud_watch_logs_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        is_organization_trail: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .s3_bucket_name = "S3BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .sns_topic_name = "SnsTopicName",
                .sns_topic_arn = "SnsTopicARN",
                .include_global_service_events = "IncludeGlobalServiceEvents",
                .is_multi_region_trail = "IsMultiRegionTrail",
                .trail_arn = "TrailARN",
                .log_file_validation_enabled = "LogFileValidationEnabled",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
                .kms_key_id = "KmsKeyId",
                .is_organization_trail = "IsOrganizationTrail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailAccessNotEnabled,
        CloudTrailARNInvalid,
        CloudTrailInvalidClientTokenId,
        CloudWatchLogsDeliveryUnavailable,
        Conflict,
        InsufficientDependencyServiceAccessPermission,
        InsufficientEncryptionPolicy,
        InsufficientS3BucketPolicy,
        InsufficientSnsTopicPolicy,
        InvalidCloudWatchLogsLogGroupArn,
        InvalidCloudWatchLogsRoleArn,
        InvalidEventSelectors,
        InvalidHomeRegion,
        InvalidKmsKeyId,
        InvalidParameterCombination,
        InvalidParameter,
        InvalidS3BucketName,
        InvalidS3Prefix,
        InvalidSnsTopicName,
        InvalidTrailName,
        Kms,
        KmsKeyDisabled,
        KmsKeyNotFound,
        NoManagementAccountSLRExists,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        S3BucketDoesNotExist,
        Throttling,
        TrailNotFound,
        TrailNotProvided,
        UnsupportedOperation,
    },
} = .{};

pub const AdvancedEventSelector = struct {
    name: ?[]const u8 = null,
    field_selectors: []AdvancedFieldSelector,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .field_selectors = "FieldSelectors",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedFieldSelector = struct {
    field: []const u8,
    equals: ?[][]const u8 = null,
    starts_with: ?[][]const u8 = null,
    ends_with: ?[][]const u8 = null,
    not_equals: ?[][]const u8 = null,
    not_starts_with: ?[][]const u8 = null,
    not_ends_with: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field = "Field",
            .equals = "Equals",
            .starts_with = "StartsWith",
            .ends_with = "EndsWith",
            .not_equals = "NotEquals",
            .not_starts_with = "NotStartsWith",
            .not_ends_with = "NotEndsWith",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = struct {
    type: []const u8,
    location: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .location = "Location",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportStatistics = struct {
    prefixes_found: ?i64 = null,
    prefixes_completed: ?i64 = null,
    files_completed: ?i64 = null,
    events_completed: ?i64 = null,
    failed_entries: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefixes_found = "PrefixesFound",
            .prefixes_completed = "PrefixesCompleted",
            .files_completed = "FilesCompleted",
            .events_completed = "EventsCompleted",
            .failed_entries = "FailedEntries",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportSource = struct {
    s3: S3ImportSource,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "S3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ImportSource = struct {
    s3_location_uri: []const u8,
    s3_bucket_region: []const u8,
    s3_bucket_access_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_location_uri = "S3LocationUri",
            .s3_bucket_region = "S3BucketRegion",
            .s3_bucket_access_role_arn = "S3BucketAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightSelector = struct {
    insight_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insight_type = "InsightType",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSelector = struct {
    read_write_type: ?[]const u8 = null,
    include_management_events: ?bool = null,
    data_resources: ?[]DataResource = null,
    exclude_management_event_sources: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_write_type = "ReadWriteType",
            .include_management_events = "IncludeManagementEvents",
            .data_resources = "DataResources",
            .exclude_management_event_sources = "ExcludeManagementEventSources",
        };
        return @field(mappings, field_name);
    }
};

pub const DataResource = struct {
    type: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const Trail = struct {
    name: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,
    sns_topic_name: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    include_global_service_events: ?bool = null,
    is_multi_region_trail: ?bool = null,
    home_region: ?[]const u8 = null,
    trail_arn: ?[]const u8 = null,
    log_file_validation_enabled: ?bool = null,
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    cloud_watch_logs_role_arn: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    has_custom_event_selectors: ?bool = null,
    has_insight_selectors: ?bool = null,
    is_organization_trail: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .s3_bucket_name = "S3BucketName",
            .s3_key_prefix = "S3KeyPrefix",
            .sns_topic_name = "SnsTopicName",
            .sns_topic_arn = "SnsTopicARN",
            .include_global_service_events = "IncludeGlobalServiceEvents",
            .is_multi_region_trail = "IsMultiRegionTrail",
            .home_region = "HomeRegion",
            .trail_arn = "TrailARN",
            .log_file_validation_enabled = "LogFileValidationEnabled",
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
            .kms_key_id = "KmsKeyId",
            .has_custom_event_selectors = "HasCustomEventSelectors",
            .has_insight_selectors = "HasInsightSelectors",
            .is_organization_trail = "IsOrganizationTrail",
        };
        return @field(mappings, field_name);
    }
};
