const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-08-11";
pub const sdk_id: []const u8 = "CloudTrail Data";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "cloudtrail-data";
pub const sigv4_name: []const u8 = "cloudtrail-data";
pub const name: []const u8 = "CloudTrailDataService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-08-11",
    sdk_id: []const u8 = "CloudTrail Data",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "cloudtrail-data",
    sigv4_name: []const u8 = "cloudtrail-data",
    name: []const u8 = "CloudTrailDataService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const put_audit_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutAuditEvents",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAuditEvents",
    Request: type = struct {
        audit_events: []struct {
            id: []const u8,
            event_data: []const u8,
            event_data_checksum: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .event_data = "eventData",
                    .event_data_checksum = "eventDataChecksum",
                };
                return @field(mappings, field_name);
            }
        },
        channel_arn: []const u8,
        external_id: ?[]const u8 = null,

        pub const http_query = .{
            .channel_arn = "channelArn",
            .external_id = "externalId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .audit_events = "auditEvents",
                .channel_arn = "channelArn",
                .external_id = "externalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_audit_events) } {
            return .{ .service_metadata = service_metadata, .action = put_audit_events };
        }
    },
    Response: type = struct {
        successful: []struct {
            id: []const u8,
            event_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .event_id = "eventID",
                };
                return @field(mappings, field_name);
            }
        },
        failed: []struct {
            id: []const u8,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "successful",
                .failed = "failed",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ChannelInsufficientPermission,
        ChannelNotFound,
        ChannelUnsupportedSchema,
        DuplicatedAuditEventId,
        InvalidChannelARN,
        UnsupportedOperation,
    },
} = .{};
