const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-10-07";
pub const sdk_id: []const u8 = "CloudWatch Events";
pub const arn_namespace: ?[]const u8 = "events";
pub const endpoint_prefix: []const u8 = "events";
pub const sigv4_name: []const u8 = "events";
pub const name: []const u8 = "AWSEvents";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-10-07",
    sdk_id: []const u8 = "CloudWatch Events",
    arn_namespace: ?[]const u8 = "events",
    endpoint_prefix: []const u8 = "events",
    sigv4_name: []const u8 = "events",
    name: []const u8 = "AWSEvents",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const activate_event_source: struct {
    action_name: []const u8 = "ActivateEventSource",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_event_source) } {
            return .{ .service_metadata = service_metadata, .action = activate_event_source };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        InvalidState,
        OperationDisabled,
        ResourceNotFound,
    },
} = .{};
pub const cancel_replay: struct {
    action_name: []const u8 = "CancelReplay",
    Request: type = struct {
        replay_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replay_name = "ReplayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_replay) } {
            return .{ .service_metadata = service_metadata, .action = cancel_replay };
        }
    },
    Response: type = struct {
        replay_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replay_arn = "ReplayArn",
                .state = "State",
                .state_reason = "StateReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        IllegalStatus,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const create_api_destination: struct {
    action_name: []const u8 = "CreateApiDestination",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        connection_arn: []const u8,
        invocation_endpoint: []const u8,
        http_method: []const u8,
        invocation_rate_limit_per_second: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .connection_arn = "ConnectionArn",
                .invocation_endpoint = "InvocationEndpoint",
                .http_method = "HttpMethod",
                .invocation_rate_limit_per_second = "InvocationRateLimitPerSecond",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_api_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_api_destination };
        }
    },
    Response: type = struct {
        api_destination_arn: ?[]const u8 = null,
        api_destination_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_destination_arn = "ApiDestinationArn",
                .api_destination_state = "ApiDestinationState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const create_archive: struct {
    action_name: []const u8 = "CreateArchive",
    Request: type = struct {
        archive_name: []const u8,
        event_source_arn: []const u8,
        description: ?[]const u8 = null,
        event_pattern: ?[]const u8 = null,
        retention_days: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .archive_name = "ArchiveName",
                .event_source_arn = "EventSourceArn",
                .description = "Description",
                .event_pattern = "EventPattern",
                .retention_days = "RetentionDays",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_archive) } {
            return .{ .service_metadata = service_metadata, .action = create_archive };
        }
    },
    Response: type = struct {
        archive_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .archive_arn = "ArchiveArn",
                .state = "State",
                .state_reason = "StateReason",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        InvalidEventPattern,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const create_connection: struct {
    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        authorization_type: []const u8,
        auth_parameters: struct {
            basic_auth_parameters: ?struct {
                username: []const u8,
                password: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .username = "Username",
                        .password = "Password",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            o_auth_parameters: ?struct {
                client_parameters: struct {
                    client_id: []const u8,
                    client_secret: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .client_id = "ClientID",
                            .client_secret = "ClientSecret",
                        };
                        return @field(mappings, field_name);
                    }
                },
                authorization_endpoint: []const u8,
                http_method: []const u8,
                o_auth_http_parameters: ?ConnectionHttpParameters = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .client_parameters = "ClientParameters",
                        .authorization_endpoint = "AuthorizationEndpoint",
                        .http_method = "HttpMethod",
                        .o_auth_http_parameters = "OAuthHttpParameters",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            api_key_auth_parameters: ?struct {
                api_key_name: []const u8,
                api_key_value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .api_key_name = "ApiKeyName",
                        .api_key_value = "ApiKeyValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            invocation_http_parameters: ?ConnectionHttpParameters = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .basic_auth_parameters = "BasicAuthParameters",
                    .o_auth_parameters = "OAuthParameters",
                    .api_key_auth_parameters = "ApiKeyAuthParameters",
                    .invocation_http_parameters = "InvocationHttpParameters",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .authorization_type = "AuthorizationType",
                .auth_parameters = "AuthParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {
        connection_arn: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .connection_state = "ConnectionState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        LimitExceeded,
        ResourceAlreadyExists,
    },
} = .{};
pub const create_event_bus: struct {
    action_name: []const u8 = "CreateEventBus",
    Request: type = struct {
        name: []const u8,
        event_source_name: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .event_source_name = "EventSourceName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_bus) } {
            return .{ .service_metadata = service_metadata, .action = create_event_bus };
        }
    },
    Response: type = struct {
        event_bus_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_bus_arn = "EventBusArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        InvalidState,
        LimitExceeded,
        OperationDisabled,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const create_partner_event_source: struct {
    action_name: []const u8 = "CreatePartnerEventSource",
    Request: type = struct {
        name: []const u8,
        account: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .account = "Account",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_partner_event_source) } {
            return .{ .service_metadata = service_metadata, .action = create_partner_event_source };
        }
    },
    Response: type = struct {
        event_source_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_source_arn = "EventSourceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        LimitExceeded,
        OperationDisabled,
        ResourceAlreadyExists,
    },
} = .{};
pub const deactivate_event_source: struct {
    action_name: []const u8 = "DeactivateEventSource",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deactivate_event_source) } {
            return .{ .service_metadata = service_metadata, .action = deactivate_event_source };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        InvalidState,
        OperationDisabled,
        ResourceNotFound,
    },
} = .{};
pub const deauthorize_connection: struct {
    action_name: []const u8 = "DeauthorizeConnection",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deauthorize_connection) } {
            return .{ .service_metadata = service_metadata, .action = deauthorize_connection };
        }
    },
    Response: type = struct {
        connection_arn: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        last_authorized_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .connection_state = "ConnectionState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .last_authorized_time = "LastAuthorizedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const delete_api_destination: struct {
    action_name: []const u8 = "DeleteApiDestination",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_api_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_api_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const delete_archive: struct {
    action_name: []const u8 = "DeleteArchive",
    Request: type = struct {
        archive_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .archive_name = "ArchiveName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_archive) } {
            return .{ .service_metadata = service_metadata, .action = delete_archive };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {
        connection_arn: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        last_authorized_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .connection_state = "ConnectionState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .last_authorized_time = "LastAuthorizedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const delete_event_bus: struct {
    action_name: []const u8 = "DeleteEventBus",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_bus) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_bus };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
    },
} = .{};
pub const delete_partner_event_source: struct {
    action_name: []const u8 = "DeletePartnerEventSource",
    Request: type = struct {
        name: []const u8,
        account: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .account = "Account",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_partner_event_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_partner_event_source };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        OperationDisabled,
    },
} = .{};
pub const delete_rule: struct {
    action_name: []const u8 = "DeleteRule",
    Request: type = struct {
        name: []const u8,
        event_bus_name: ?[]const u8 = null,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .event_bus_name = "EventBusName",
                .force = "Force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ManagedRule,
        ResourceNotFound,
    },
} = .{};
pub const describe_api_destination: struct {
    action_name: []const u8 = "DescribeApiDestination",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_api_destination) } {
            return .{ .service_metadata = service_metadata, .action = describe_api_destination };
        }
    },
    Response: type = struct {
        api_destination_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        api_destination_state: ?[]const u8 = null,
        connection_arn: ?[]const u8 = null,
        invocation_endpoint: ?[]const u8 = null,
        http_method: ?[]const u8 = null,
        invocation_rate_limit_per_second: ?i64 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_destination_arn = "ApiDestinationArn",
                .name = "Name",
                .description = "Description",
                .api_destination_state = "ApiDestinationState",
                .connection_arn = "ConnectionArn",
                .invocation_endpoint = "InvocationEndpoint",
                .http_method = "HttpMethod",
                .invocation_rate_limit_per_second = "InvocationRateLimitPerSecond",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const describe_archive: struct {
    action_name: []const u8 = "DescribeArchive",
    Request: type = struct {
        archive_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .archive_name = "ArchiveName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_archive) } {
            return .{ .service_metadata = service_metadata, .action = describe_archive };
        }
    },
    Response: type = struct {
        archive_arn: ?[]const u8 = null,
        archive_name: ?[]const u8 = null,
        event_source_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        event_pattern: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        retention_days: ?i64 = null,
        size_bytes: ?i64 = null,
        event_count: ?i64 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .archive_arn = "ArchiveArn",
                .archive_name = "ArchiveName",
                .event_source_arn = "EventSourceArn",
                .description = "Description",
                .event_pattern = "EventPattern",
                .state = "State",
                .state_reason = "StateReason",
                .retention_days = "RetentionDays",
                .size_bytes = "SizeBytes",
                .event_count = "EventCount",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const describe_connection: struct {
    action_name: []const u8 = "DescribeConnection",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connection) } {
            return .{ .service_metadata = service_metadata, .action = describe_connection };
        }
    },
    Response: type = struct {
        connection_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        authorization_type: ?[]const u8 = null,
        secret_arn: ?[]const u8 = null,
        auth_parameters: ?struct {
            basic_auth_parameters: ?struct {
                username: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .username = "Username",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            o_auth_parameters: ?struct {
                client_parameters: ?struct {
                    client_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .client_id = "ClientID",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                authorization_endpoint: ?[]const u8 = null,
                http_method: ?[]const u8 = null,
                o_auth_http_parameters: ?ConnectionHttpParameters = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .client_parameters = "ClientParameters",
                        .authorization_endpoint = "AuthorizationEndpoint",
                        .http_method = "HttpMethod",
                        .o_auth_http_parameters = "OAuthHttpParameters",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            api_key_auth_parameters: ?struct {
                api_key_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .api_key_name = "ApiKeyName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            invocation_http_parameters: ?ConnectionHttpParameters = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .basic_auth_parameters = "BasicAuthParameters",
                    .o_auth_parameters = "OAuthParameters",
                    .api_key_auth_parameters = "ApiKeyAuthParameters",
                    .invocation_http_parameters = "InvocationHttpParameters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        last_authorized_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .name = "Name",
                .description = "Description",
                .connection_state = "ConnectionState",
                .state_reason = "StateReason",
                .authorization_type = "AuthorizationType",
                .secret_arn = "SecretArn",
                .auth_parameters = "AuthParameters",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .last_authorized_time = "LastAuthorizedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const describe_event_bus: struct {
    action_name: []const u8 = "DescribeEventBus",
    Request: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_bus) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_bus };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const describe_event_source: struct {
    action_name: []const u8 = "DescribeEventSource",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_source) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_by: ?[]const u8 = null,
        creation_time: ?i64 = null,
        expiration_time: ?i64 = null,
        name: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .created_by = "CreatedBy",
                .creation_time = "CreationTime",
                .expiration_time = "ExpirationTime",
                .name = "Name",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        OperationDisabled,
        ResourceNotFound,
    },
} = .{};
pub const describe_partner_event_source: struct {
    action_name: []const u8 = "DescribePartnerEventSource",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_partner_event_source) } {
            return .{ .service_metadata = service_metadata, .action = describe_partner_event_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        OperationDisabled,
        ResourceNotFound,
    },
} = .{};
pub const describe_replay: struct {
    action_name: []const u8 = "DescribeReplay",
    Request: type = struct {
        replay_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replay_name = "ReplayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replay) } {
            return .{ .service_metadata = service_metadata, .action = describe_replay };
        }
    },
    Response: type = struct {
        replay_name: ?[]const u8 = null,
        replay_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        event_source_arn: ?[]const u8 = null,
        destination: ?ReplayDestination = null,
        event_start_time: ?i64 = null,
        event_end_time: ?i64 = null,
        event_last_replayed_time: ?i64 = null,
        replay_start_time: ?i64 = null,
        replay_end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replay_name = "ReplayName",
                .replay_arn = "ReplayArn",
                .description = "Description",
                .state = "State",
                .state_reason = "StateReason",
                .event_source_arn = "EventSourceArn",
                .destination = "Destination",
                .event_start_time = "EventStartTime",
                .event_end_time = "EventEndTime",
                .event_last_replayed_time = "EventLastReplayedTime",
                .replay_start_time = "ReplayStartTime",
                .replay_end_time = "ReplayEndTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const describe_rule: struct {
    action_name: []const u8 = "DescribeRule",
    Request: type = struct {
        name: []const u8,
        event_bus_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .event_bus_name = "EventBusName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_rule) } {
            return .{ .service_metadata = service_metadata, .action = describe_rule };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        event_pattern: ?[]const u8 = null,
        schedule_expression: ?[]const u8 = null,
        state: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        managed_by: ?[]const u8 = null,
        event_bus_name: ?[]const u8 = null,
        created_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .event_pattern = "EventPattern",
                .schedule_expression = "ScheduleExpression",
                .state = "State",
                .description = "Description",
                .role_arn = "RoleArn",
                .managed_by = "ManagedBy",
                .event_bus_name = "EventBusName",
                .created_by = "CreatedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const disable_rule: struct {
    action_name: []const u8 = "DisableRule",
    Request: type = struct {
        name: []const u8,
        event_bus_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .event_bus_name = "EventBusName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_rule) } {
            return .{ .service_metadata = service_metadata, .action = disable_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ManagedRule,
        ResourceNotFound,
    },
} = .{};
pub const enable_rule: struct {
    action_name: []const u8 = "EnableRule",
    Request: type = struct {
        name: []const u8,
        event_bus_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .event_bus_name = "EventBusName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_rule) } {
            return .{ .service_metadata = service_metadata, .action = enable_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ManagedRule,
        ResourceNotFound,
    },
} = .{};
pub const list_api_destinations: struct {
    action_name: []const u8 = "ListApiDestinations",
    Request: type = struct {
        name_prefix: ?[]const u8 = null,
        connection_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_prefix = "NamePrefix",
                .connection_arn = "ConnectionArn",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_api_destinations) } {
            return .{ .service_metadata = service_metadata, .action = list_api_destinations };
        }
    },
    Response: type = struct {
        api_destinations: ?[]struct {
            api_destination_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            api_destination_state: ?[]const u8 = null,
            connection_arn: ?[]const u8 = null,
            invocation_endpoint: ?[]const u8 = null,
            http_method: ?[]const u8 = null,
            invocation_rate_limit_per_second: ?i64 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .api_destination_arn = "ApiDestinationArn",
                    .name = "Name",
                    .api_destination_state = "ApiDestinationState",
                    .connection_arn = "ConnectionArn",
                    .invocation_endpoint = "InvocationEndpoint",
                    .http_method = "HttpMethod",
                    .invocation_rate_limit_per_second = "InvocationRateLimitPerSecond",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_destinations = "ApiDestinations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
    },
} = .{};
pub const list_archives: struct {
    action_name: []const u8 = "ListArchives",
    Request: type = struct {
        name_prefix: ?[]const u8 = null,
        event_source_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_prefix = "NamePrefix",
                .event_source_arn = "EventSourceArn",
                .state = "State",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_archives) } {
            return .{ .service_metadata = service_metadata, .action = list_archives };
        }
    },
    Response: type = struct {
        archives: ?[]struct {
            archive_name: ?[]const u8 = null,
            event_source_arn: ?[]const u8 = null,
            state: ?[]const u8 = null,
            state_reason: ?[]const u8 = null,
            retention_days: ?i64 = null,
            size_bytes: ?i64 = null,
            event_count: ?i64 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .archive_name = "ArchiveName",
                    .event_source_arn = "EventSourceArn",
                    .state = "State",
                    .state_reason = "StateReason",
                    .retention_days = "RetentionDays",
                    .size_bytes = "SizeBytes",
                    .event_count = "EventCount",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .archives = "Archives",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const list_connections: struct {
    action_name: []const u8 = "ListConnections",
    Request: type = struct {
        name_prefix: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_prefix = "NamePrefix",
                .connection_state = "ConnectionState",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connections) } {
            return .{ .service_metadata = service_metadata, .action = list_connections };
        }
    },
    Response: type = struct {
        connections: ?[]struct {
            connection_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            connection_state: ?[]const u8 = null,
            state_reason: ?[]const u8 = null,
            authorization_type: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            last_authorized_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connection_arn = "ConnectionArn",
                    .name = "Name",
                    .connection_state = "ConnectionState",
                    .state_reason = "StateReason",
                    .authorization_type = "AuthorizationType",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .last_authorized_time = "LastAuthorizedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "Connections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
    },
} = .{};
pub const list_event_buses: struct {
    action_name: []const u8 = "ListEventBuses",
    Request: type = struct {
        name_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_prefix = "NamePrefix",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_buses) } {
            return .{ .service_metadata = service_metadata, .action = list_event_buses };
        }
    },
    Response: type = struct {
        event_buses: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            policy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                    .policy = "Policy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_buses = "EventBuses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
    },
} = .{};
pub const list_event_sources: struct {
    action_name: []const u8 = "ListEventSources",
    Request: type = struct {
        name_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_prefix = "NamePrefix",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_event_sources };
        }
    },
    Response: type = struct {
        event_sources: ?[]struct {
            arn: ?[]const u8 = null,
            created_by: ?[]const u8 = null,
            creation_time: ?i64 = null,
            expiration_time: ?i64 = null,
            name: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .created_by = "CreatedBy",
                    .creation_time = "CreationTime",
                    .expiration_time = "ExpirationTime",
                    .name = "Name",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_sources = "EventSources",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        OperationDisabled,
    },
} = .{};
pub const list_partner_event_source_accounts: struct {
    action_name: []const u8 = "ListPartnerEventSourceAccounts",
    Request: type = struct {
        event_source_name: []const u8,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_source_name = "EventSourceName",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_partner_event_source_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_partner_event_source_accounts };
        }
    },
    Response: type = struct {
        partner_event_source_accounts: ?[]struct {
            account: ?[]const u8 = null,
            creation_time: ?i64 = null,
            expiration_time: ?i64 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account = "Account",
                    .creation_time = "CreationTime",
                    .expiration_time = "ExpirationTime",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partner_event_source_accounts = "PartnerEventSourceAccounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        OperationDisabled,
        ResourceNotFound,
    },
} = .{};
pub const list_partner_event_sources: struct {
    action_name: []const u8 = "ListPartnerEventSources",
    Request: type = struct {
        name_prefix: []const u8,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_prefix = "NamePrefix",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_partner_event_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_partner_event_sources };
        }
    },
    Response: type = struct {
        partner_event_sources: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partner_event_sources = "PartnerEventSources",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        OperationDisabled,
    },
} = .{};
pub const list_replays: struct {
    action_name: []const u8 = "ListReplays",
    Request: type = struct {
        name_prefix: ?[]const u8 = null,
        state: ?[]const u8 = null,
        event_source_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_prefix = "NamePrefix",
                .state = "State",
                .event_source_arn = "EventSourceArn",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_replays) } {
            return .{ .service_metadata = service_metadata, .action = list_replays };
        }
    },
    Response: type = struct {
        replays: ?[]struct {
            replay_name: ?[]const u8 = null,
            event_source_arn: ?[]const u8 = null,
            state: ?[]const u8 = null,
            state_reason: ?[]const u8 = null,
            event_start_time: ?i64 = null,
            event_end_time: ?i64 = null,
            event_last_replayed_time: ?i64 = null,
            replay_start_time: ?i64 = null,
            replay_end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replay_name = "ReplayName",
                    .event_source_arn = "EventSourceArn",
                    .state = "State",
                    .state_reason = "StateReason",
                    .event_start_time = "EventStartTime",
                    .event_end_time = "EventEndTime",
                    .event_last_replayed_time = "EventLastReplayedTime",
                    .replay_start_time = "ReplayStartTime",
                    .replay_end_time = "ReplayEndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replays = "Replays",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
    },
} = .{};
pub const list_rule_names_by_target: struct {
    action_name: []const u8 = "ListRuleNamesByTarget",
    Request: type = struct {
        target_arn: []const u8,
        event_bus_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetArn",
                .event_bus_name = "EventBusName",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rule_names_by_target) } {
            return .{ .service_metadata = service_metadata, .action = list_rule_names_by_target };
        }
    },
    Response: type = struct {
        rule_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_names = "RuleNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const list_rules: struct {
    action_name: []const u8 = "ListRules",
    Request: type = struct {
        name_prefix: ?[]const u8 = null,
        event_bus_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_prefix = "NamePrefix",
                .event_bus_name = "EventBusName",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_rules };
        }
    },
    Response: type = struct {
        rules: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            event_pattern: ?[]const u8 = null,
            state: ?[]const u8 = null,
            description: ?[]const u8 = null,
            schedule_expression: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            managed_by: ?[]const u8 = null,
            event_bus_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                    .event_pattern = "EventPattern",
                    .state = "State",
                    .description = "Description",
                    .schedule_expression = "ScheduleExpression",
                    .role_arn = "RoleArn",
                    .managed_by = "ManagedBy",
                    .event_bus_name = "EventBusName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const list_targets_by_rule: struct {
    action_name: []const u8 = "ListTargetsByRule",
    Request: type = struct {
        rule: []const u8,
        event_bus_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
                .event_bus_name = "EventBusName",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_targets_by_rule) } {
            return .{ .service_metadata = service_metadata, .action = list_targets_by_rule };
        }
    },
    Response: type = struct {
        targets: ?[]Target = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .targets = "Targets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const put_events: struct {
    action_name: []const u8 = "PutEvents",
    Request: type = struct {
        entries: []struct {
            time: ?i64 = null,
            source: ?[]const u8 = null,
            resources: ?[][]const u8 = null,
            detail_type: ?[]const u8 = null,
            detail: ?[]const u8 = null,
            event_bus_name: ?[]const u8 = null,
            trace_header: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time = "Time",
                    .source = "Source",
                    .resources = "Resources",
                    .detail_type = "DetailType",
                    .detail = "Detail",
                    .event_bus_name = "EventBusName",
                    .trace_header = "TraceHeader",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_events) } {
            return .{ .service_metadata = service_metadata, .action = put_events };
        }
    },
    Response: type = struct {
        failed_entry_count: ?i64 = null,
        entries: ?[]struct {
            event_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_id = "EventId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_entry_count = "FailedEntryCount",
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
    },
} = .{};
pub const put_partner_events: struct {
    action_name: []const u8 = "PutPartnerEvents",
    Request: type = struct {
        entries: []struct {
            time: ?i64 = null,
            source: ?[]const u8 = null,
            resources: ?[][]const u8 = null,
            detail_type: ?[]const u8 = null,
            detail: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time = "Time",
                    .source = "Source",
                    .resources = "Resources",
                    .detail_type = "DetailType",
                    .detail = "Detail",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_partner_events) } {
            return .{ .service_metadata = service_metadata, .action = put_partner_events };
        }
    },
    Response: type = struct {
        failed_entry_count: ?i64 = null,
        entries: ?[]struct {
            event_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_id = "EventId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_entry_count = "FailedEntryCount",
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        OperationDisabled,
    },
} = .{};
pub const put_permission: struct {
    action_name: []const u8 = "PutPermission",
    Request: type = struct {
        event_bus_name: ?[]const u8 = null,
        action: ?[]const u8 = null,
        principal: ?[]const u8 = null,
        statement_id: ?[]const u8 = null,
        condition: ?struct {
            type: []const u8,
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_bus_name = "EventBusName",
                .action = "Action",
                .principal = "Principal",
                .statement_id = "StatementId",
                .condition = "Condition",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_permission) } {
            return .{ .service_metadata = service_metadata, .action = put_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        OperationDisabled,
        PolicyLengthExceeded,
        ResourceNotFound,
    },
} = .{};
pub const put_rule: struct {
    action_name: []const u8 = "PutRule",
    Request: type = struct {
        name: []const u8,
        schedule_expression: ?[]const u8 = null,
        event_pattern: ?[]const u8 = null,
        state: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        event_bus_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .schedule_expression = "ScheduleExpression",
                .event_pattern = "EventPattern",
                .state = "State",
                .description = "Description",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .event_bus_name = "EventBusName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_rule) } {
            return .{ .service_metadata = service_metadata, .action = put_rule };
        }
    },
    Response: type = struct {
        rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_arn = "RuleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        InvalidEventPattern,
        LimitExceeded,
        ManagedRule,
        ResourceNotFound,
    },
} = .{};
pub const put_targets: struct {
    action_name: []const u8 = "PutTargets",
    Request: type = struct {
        rule: []const u8,
        event_bus_name: ?[]const u8 = null,
        targets: []Target,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
                .event_bus_name = "EventBusName",
                .targets = "Targets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_targets) } {
            return .{ .service_metadata = service_metadata, .action = put_targets };
        }
    },
    Response: type = struct {
        failed_entry_count: ?i64 = null,
        failed_entries: ?[]struct {
            target_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .target_id = "TargetId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_entry_count = "FailedEntryCount",
                .failed_entries = "FailedEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        LimitExceeded,
        ManagedRule,
        ResourceNotFound,
    },
} = .{};
pub const remove_permission: struct {
    action_name: []const u8 = "RemovePermission",
    Request: type = struct {
        statement_id: ?[]const u8 = null,
        remove_all_permissions: ?bool = null,
        event_bus_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_id = "StatementId",
                .remove_all_permissions = "RemoveAllPermissions",
                .event_bus_name = "EventBusName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_permission) } {
            return .{ .service_metadata = service_metadata, .action = remove_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        OperationDisabled,
        ResourceNotFound,
    },
} = .{};
pub const remove_targets: struct {
    action_name: []const u8 = "RemoveTargets",
    Request: type = struct {
        rule: []const u8,
        event_bus_name: ?[]const u8 = null,
        ids: [][]const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
                .event_bus_name = "EventBusName",
                .ids = "Ids",
                .force = "Force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_targets) } {
            return .{ .service_metadata = service_metadata, .action = remove_targets };
        }
    },
    Response: type = struct {
        failed_entry_count: ?i64 = null,
        failed_entries: ?[]struct {
            target_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .target_id = "TargetId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_entry_count = "FailedEntryCount",
                .failed_entries = "FailedEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ManagedRule,
        ResourceNotFound,
    },
} = .{};
pub const start_replay: struct {
    action_name: []const u8 = "StartReplay",
    Request: type = struct {
        replay_name: []const u8,
        description: ?[]const u8 = null,
        event_source_arn: []const u8,
        event_start_time: i64,
        event_end_time: i64,
        destination: ReplayDestination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replay_name = "ReplayName",
                .description = "Description",
                .event_source_arn = "EventSourceArn",
                .event_start_time = "EventStartTime",
                .event_end_time = "EventEndTime",
                .destination = "Destination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_replay) } {
            return .{ .service_metadata = service_metadata, .action = start_replay };
        }
    },
    Response: type = struct {
        replay_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        replay_start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replay_arn = "ReplayArn",
                .state = "State",
                .state_reason = "StateReason",
                .replay_start_time = "ReplayStartTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidEventPattern,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ManagedRule,
        ResourceNotFound,
    },
} = .{};
pub const test_event_pattern: struct {
    action_name: []const u8 = "TestEventPattern",
    Request: type = struct {
        event_pattern: []const u8,
        event: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_pattern = "EventPattern",
                .event = "Event",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_event_pattern) } {
            return .{ .service_metadata = service_metadata, .action = test_event_pattern };
        }
    },
    Response: type = struct {
        result: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "Result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidEventPattern,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        ManagedRule,
        ResourceNotFound,
    },
} = .{};
pub const update_api_destination: struct {
    action_name: []const u8 = "UpdateApiDestination",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        connection_arn: ?[]const u8 = null,
        invocation_endpoint: ?[]const u8 = null,
        http_method: ?[]const u8 = null,
        invocation_rate_limit_per_second: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .connection_arn = "ConnectionArn",
                .invocation_endpoint = "InvocationEndpoint",
                .http_method = "HttpMethod",
                .invocation_rate_limit_per_second = "InvocationRateLimitPerSecond",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_api_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_api_destination };
        }
    },
    Response: type = struct {
        api_destination_arn: ?[]const u8 = null,
        api_destination_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_destination_arn = "ApiDestinationArn",
                .api_destination_state = "ApiDestinationState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_archive: struct {
    action_name: []const u8 = "UpdateArchive",
    Request: type = struct {
        archive_name: []const u8,
        description: ?[]const u8 = null,
        event_pattern: ?[]const u8 = null,
        retention_days: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .archive_name = "ArchiveName",
                .description = "Description",
                .event_pattern = "EventPattern",
                .retention_days = "RetentionDays",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_archive) } {
            return .{ .service_metadata = service_metadata, .action = update_archive };
        }
    },
    Response: type = struct {
        archive_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .archive_arn = "ArchiveArn",
                .state = "State",
                .state_reason = "StateReason",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        InvalidEventPattern,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_connection: struct {
    action_name: []const u8 = "UpdateConnection",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        authorization_type: ?[]const u8 = null,
        auth_parameters: ?struct {
            basic_auth_parameters: ?struct {
                username: ?[]const u8 = null,
                password: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .username = "Username",
                        .password = "Password",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            o_auth_parameters: ?struct {
                client_parameters: ?struct {
                    client_id: ?[]const u8 = null,
                    client_secret: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .client_id = "ClientID",
                            .client_secret = "ClientSecret",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                authorization_endpoint: ?[]const u8 = null,
                http_method: ?[]const u8 = null,
                o_auth_http_parameters: ?ConnectionHttpParameters = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .client_parameters = "ClientParameters",
                        .authorization_endpoint = "AuthorizationEndpoint",
                        .http_method = "HttpMethod",
                        .o_auth_http_parameters = "OAuthHttpParameters",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            api_key_auth_parameters: ?struct {
                api_key_name: ?[]const u8 = null,
                api_key_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .api_key_name = "ApiKeyName",
                        .api_key_value = "ApiKeyValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            invocation_http_parameters: ?ConnectionHttpParameters = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .basic_auth_parameters = "BasicAuthParameters",
                    .o_auth_parameters = "OAuthParameters",
                    .api_key_auth_parameters = "ApiKeyAuthParameters",
                    .invocation_http_parameters = "InvocationHttpParameters",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .authorization_type = "AuthorizationType",
                .auth_parameters = "AuthParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connection) } {
            return .{ .service_metadata = service_metadata, .action = update_connection };
        }
    },
    Response: type = struct {
        connection_arn: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        last_authorized_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .connection_state = "ConnectionState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .last_authorized_time = "LastAuthorizedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Internal,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};

pub const ConnectionHttpParameters = struct {
    header_parameters: ?[]ConnectionHeaderParameter = null,
    query_string_parameters: ?[]ConnectionQueryStringParameter = null,
    body_parameters: ?[]ConnectionBodyParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_parameters = "HeaderParameters",
            .query_string_parameters = "QueryStringParameters",
            .body_parameters = "BodyParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionBodyParameter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    is_value_secret: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .is_value_secret = "IsValueSecret",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionQueryStringParameter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    is_value_secret: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .is_value_secret = "IsValueSecret",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionHeaderParameter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    is_value_secret: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .is_value_secret = "IsValueSecret",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplayDestination = struct {
    arn: []const u8,
    filter_arns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .filter_arns = "FilterArns",
        };
        return @field(mappings, field_name);
    }
};

pub const Target = struct {
    id: []const u8,
    arn: []const u8,
    role_arn: ?[]const u8 = null,
    input: ?[]const u8 = null,
    input_path: ?[]const u8 = null,
    input_transformer: ?InputTransformer = null,
    kinesis_parameters: ?KinesisParameters = null,
    run_command_parameters: ?RunCommandParameters = null,
    ecs_parameters: ?EcsParameters = null,
    batch_parameters: ?BatchParameters = null,
    sqs_parameters: ?SqsParameters = null,
    http_parameters: ?HttpParameters = null,
    redshift_data_parameters: ?RedshiftDataParameters = null,
    sage_maker_pipeline_parameters: ?SageMakerPipelineParameters = null,
    dead_letter_config: ?DeadLetterConfig = null,
    retry_policy: ?RetryPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .role_arn = "RoleArn",
            .input = "Input",
            .input_path = "InputPath",
            .input_transformer = "InputTransformer",
            .kinesis_parameters = "KinesisParameters",
            .run_command_parameters = "RunCommandParameters",
            .ecs_parameters = "EcsParameters",
            .batch_parameters = "BatchParameters",
            .sqs_parameters = "SqsParameters",
            .http_parameters = "HttpParameters",
            .redshift_data_parameters = "RedshiftDataParameters",
            .sage_maker_pipeline_parameters = "SageMakerPipelineParameters",
            .dead_letter_config = "DeadLetterConfig",
            .retry_policy = "RetryPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const RetryPolicy = struct {
    maximum_retry_attempts: ?i64 = null,
    maximum_event_age_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_retry_attempts = "MaximumRetryAttempts",
            .maximum_event_age_in_seconds = "MaximumEventAgeInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const DeadLetterConfig = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const SageMakerPipelineParameters = struct {
    pipeline_parameter_list: ?[]SageMakerPipelineParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pipeline_parameter_list = "PipelineParameterList",
        };
        return @field(mappings, field_name);
    }
};

pub const SageMakerPipelineParameter = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftDataParameters = struct {
    secret_manager_arn: ?[]const u8 = null,
    database: []const u8,
    db_user: ?[]const u8 = null,
    sql: []const u8,
    statement_name: ?[]const u8 = null,
    with_event: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .secret_manager_arn = "SecretManagerArn",
            .database = "Database",
            .db_user = "DbUser",
            .sql = "Sql",
            .statement_name = "StatementName",
            .with_event = "WithEvent",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpParameters = struct {
    path_parameter_values: ?[][]const u8 = null,
    header_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    query_string_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path_parameter_values = "PathParameterValues",
            .header_parameters = "HeaderParameters",
            .query_string_parameters = "QueryStringParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "header_parameters", field_name))
            return try serializeMap(self.header_parameters, self.fieldNameFor("header_parameters"), options, out_stream);
        if (std.mem.eql(u8, "query_string_parameters", field_name))
            return try serializeMap(self.query_string_parameters, self.fieldNameFor("query_string_parameters"), options, out_stream);
        return false;
    }
};

pub const SqsParameters = struct {
    message_group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_group_id = "MessageGroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchParameters = struct {
    job_definition: []const u8,
    job_name: []const u8,
    array_properties: ?BatchArrayProperties = null,
    retry_strategy: ?BatchRetryStrategy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_definition = "JobDefinition",
            .job_name = "JobName",
            .array_properties = "ArrayProperties",
            .retry_strategy = "RetryStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchRetryStrategy = struct {
    attempts: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attempts = "Attempts",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchArrayProperties = struct {
    size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .size = "Size",
        };
        return @field(mappings, field_name);
    }
};

pub const EcsParameters = struct {
    task_definition_arn: []const u8,
    task_count: ?i64 = null,
    launch_type: ?[]const u8 = null,
    network_configuration: ?NetworkConfiguration = null,
    platform_version: ?[]const u8 = null,
    group: ?[]const u8 = null,
    capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
    enable_ecs_managed_tags: ?bool = null,
    enable_execute_command: ?bool = null,
    placement_constraints: ?[]PlacementConstraint = null,
    placement_strategy: ?[]PlacementStrategy = null,
    propagate_tags: ?[]const u8 = null,
    reference_id: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_definition_arn = "TaskDefinitionArn",
            .task_count = "TaskCount",
            .launch_type = "LaunchType",
            .network_configuration = "NetworkConfiguration",
            .platform_version = "PlatformVersion",
            .group = "Group",
            .capacity_provider_strategy = "CapacityProviderStrategy",
            .enable_ecs_managed_tags = "EnableECSManagedTags",
            .enable_execute_command = "EnableExecuteCommand",
            .placement_constraints = "PlacementConstraints",
            .placement_strategy = "PlacementStrategy",
            .propagate_tags = "PropagateTags",
            .reference_id = "ReferenceId",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementStrategy = struct {
    type: ?[]const u8 = null,
    field: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .field = "field",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementConstraint = struct {
    type: ?[]const u8 = null,
    expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .expression = "expression",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityProviderStrategyItem = struct {
    capacity_provider: []const u8,
    weight: ?i64 = null,
    base: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_provider = "capacityProvider",
            .weight = "weight",
            .base = "base",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkConfiguration = struct {
    awsvpc_configuration: ?AwsVpcConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .awsvpc_configuration = "awsvpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsVpcConfiguration = struct {
    subnets: [][]const u8,
    security_groups: ?[][]const u8 = null,
    assign_public_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnets = "Subnets",
            .security_groups = "SecurityGroups",
            .assign_public_ip = "AssignPublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const RunCommandParameters = struct {
    run_command_targets: []RunCommandTarget,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .run_command_targets = "RunCommandTargets",
        };
        return @field(mappings, field_name);
    }
};

pub const RunCommandTarget = struct {
    key: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisParameters = struct {
    partition_key_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .partition_key_path = "PartitionKeyPath",
        };
        return @field(mappings, field_name);
    }
};

pub const InputTransformer = struct {
    input_paths_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    input_template: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_paths_map = "InputPathsMap",
            .input_template = "InputTemplate",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "input_paths_map", field_name))
            return try serializeMap(self.input_paths_map, self.fieldNameFor("input_paths_map"), options, out_stream);
        return false;
    }
};
