const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-04-13";
pub const sdk_id: []const u8 = "CodeCommit";
pub const arn_namespace: ?[]const u8 = "codecommit";
pub const endpoint_prefix: []const u8 = "codecommit";
pub const sigv4_name: []const u8 = "codecommit";
pub const name: []const u8 = "CodeCommit_20150413";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-04-13",
    sdk_id: []const u8 = "CodeCommit",
    arn_namespace: ?[]const u8 = "codecommit",
    endpoint_prefix: []const u8 = "codecommit",
    sigv4_name: []const u8 = "codecommit",
    name: []const u8 = "CodeCommit_20150413",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_approval_rule_template_with_repository: struct {
    action_name: []const u8 = "AssociateApprovalRuleTemplateWithRepository",
    Request: type = struct {
        approval_rule_template_name: []const u8,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_approval_rule_template_with_repository) } {
            return .{ .service_metadata = service_metadata, .action = associate_approval_rule_template_with_repository };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalRuleTemplateName,
        InvalidRepositoryName,
        MaximumRuleTemplatesAssociatedWithRepository,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const batch_associate_approval_rule_template_with_repositories: struct {
    action_name: []const u8 = "BatchAssociateApprovalRuleTemplateWithRepositories",
    Request: type = struct {
        approval_rule_template_name: []const u8,
        repository_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
                .repository_names = "repositoryNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_associate_approval_rule_template_with_repositories) } {
            return .{ .service_metadata = service_metadata, .action = batch_associate_approval_rule_template_with_repositories };
        }
    },
    Response: type = struct {
        associated_repository_names: [][]const u8,
        errors: []struct {
            repository_name: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .repository_name = "repositoryName",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associated_repository_names = "associatedRepositoryNames",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalRuleTemplateName,
        MaximumRepositoryNamesExceeded,
        RepositoryNamesRequired,
    },
} = .{};
pub const batch_describe_merge_conflicts: struct {
    action_name: []const u8 = "BatchDescribeMergeConflicts",
    Request: type = struct {
        repository_name: []const u8,
        destination_commit_specifier: []const u8,
        source_commit_specifier: []const u8,
        merge_option: []const u8,
        max_merge_hunks: ?i64 = null,
        max_conflict_files: ?i64 = null,
        file_paths: ?[][]const u8 = null,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .source_commit_specifier = "sourceCommitSpecifier",
                .merge_option = "mergeOption",
                .max_merge_hunks = "maxMergeHunks",
                .max_conflict_files = "maxConflictFiles",
                .file_paths = "filePaths",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_describe_merge_conflicts) } {
            return .{ .service_metadata = service_metadata, .action = batch_describe_merge_conflicts };
        }
    },
    Response: type = struct {
        conflicts: []struct {
            conflict_metadata: ?ConflictMetadata = null,
            merge_hunks: ?[]MergeHunk = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .conflict_metadata = "conflictMetadata",
                    .merge_hunks = "mergeHunks",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        errors: ?[]struct {
            file_path: []const u8,
            exception_name: []const u8,
            message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_path = "filePath",
                    .exception_name = "exceptionName",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        } = null,
        destination_commit_id: []const u8,
        source_commit_id: []const u8,
        base_commit_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conflicts = "conflicts",
                .next_token = "nextToken",
                .errors = "errors",
                .destination_commit_id = "destinationCommitId",
                .source_commit_id = "sourceCommitId",
                .base_commit_id = "baseCommitId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommit,
        InvalidConflictDetailLevel,
        InvalidConflictResolutionStrategy,
        InvalidContinuationToken,
        InvalidMaxConflictFiles,
        InvalidMaxMergeHunks,
        InvalidMergeOption,
        InvalidRepositoryName,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        MergeOptionRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const batch_disassociate_approval_rule_template_from_repositories: struct {
    action_name: []const u8 = "BatchDisassociateApprovalRuleTemplateFromRepositories",
    Request: type = struct {
        approval_rule_template_name: []const u8,
        repository_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
                .repository_names = "repositoryNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disassociate_approval_rule_template_from_repositories) } {
            return .{ .service_metadata = service_metadata, .action = batch_disassociate_approval_rule_template_from_repositories };
        }
    },
    Response: type = struct {
        disassociated_repository_names: [][]const u8,
        errors: []struct {
            repository_name: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .repository_name = "repositoryName",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .disassociated_repository_names = "disassociatedRepositoryNames",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalRuleTemplateName,
        MaximumRepositoryNamesExceeded,
        RepositoryNamesRequired,
    },
} = .{};
pub const batch_get_commits: struct {
    action_name: []const u8 = "BatchGetCommits",
    Request: type = struct {
        commit_ids: [][]const u8,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_ids = "commitIds",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_commits) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_commits };
        }
    },
    Response: type = struct {
        commits: ?[]Commit = null,
        errors: ?[]struct {
            commit_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .commit_id = "commitId",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commits = "commits",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitIdsLimitExceeded,
        CommitIdsListRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const batch_get_repositories: struct {
    action_name: []const u8 = "BatchGetRepositories",
    Request: type = struct {
        repository_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_names = "repositoryNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_repositories) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_repositories };
        }
    },
    Response: type = struct {
        repositories: ?[]RepositoryMetadata = null,
        repositories_not_found: ?[][]const u8 = null,
        errors: ?[]struct {
            repository_id: ?[]const u8 = null,
            repository_name: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .repository_id = "repositoryId",
                    .repository_name = "repositoryName",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repositories = "repositories",
                .repositories_not_found = "repositoriesNotFound",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryName,
        MaximumRepositoryNamesExceeded,
        RepositoryNamesRequired,
    },
} = .{};
pub const create_approval_rule_template: struct {
    action_name: []const u8 = "CreateApprovalRuleTemplate",
    Request: type = struct {
        approval_rule_template_name: []const u8,
        approval_rule_template_content: []const u8,
        approval_rule_template_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
                .approval_rule_template_content = "approvalRuleTemplateContent",
                .approval_rule_template_description = "approvalRuleTemplateDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_approval_rule_template) } {
            return .{ .service_metadata = service_metadata, .action = create_approval_rule_template };
        }
    },
    Response: type = struct {
        approval_rule_template: ApprovalRuleTemplate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template = "approvalRuleTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateContentRequired,
        ApprovalRuleTemplateNameAlreadyExists,
        ApprovalRuleTemplateNameRequired,
        InvalidApprovalRuleTemplateContent,
        InvalidApprovalRuleTemplateDescription,
        InvalidApprovalRuleTemplateName,
        NumberOfRuleTemplatesExceeded,
    },
} = .{};
pub const create_branch: struct {
    action_name: []const u8 = "CreateBranch",
    Request: type = struct {
        repository_name: []const u8,
        branch_name: []const u8,
        commit_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .branch_name = "branchName",
                .commit_id = "commitId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_branch) } {
            return .{ .service_metadata = service_metadata, .action = create_branch };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BranchNameExists,
        BranchNameRequired,
        CommitDoesNotExist,
        CommitIdRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidBranchName,
        InvalidCommitId,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const create_commit: struct {
    action_name: []const u8 = "CreateCommit",
    Request: type = struct {
        repository_name: []const u8,
        branch_name: []const u8,
        parent_commit_id: ?[]const u8 = null,
        author_name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,
        keep_empty_folders: ?bool = null,
        put_files: ?[]struct {
            file_path: []const u8,
            file_mode: ?[]const u8 = null,
            file_content: ?[]const u8 = null,
            source_file: ?struct {
                file_path: []const u8,
                is_move: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .file_path = "filePath",
                        .is_move = "isMove",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_path = "filePath",
                    .file_mode = "fileMode",
                    .file_content = "fileContent",
                    .source_file = "sourceFile",
                };
                return @field(mappings, field_name);
            }
        } = null,
        delete_files: ?[]DeleteFileEntry = null,
        set_file_modes: ?[]SetFileModeEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .branch_name = "branchName",
                .parent_commit_id = "parentCommitId",
                .author_name = "authorName",
                .email = "email",
                .commit_message = "commitMessage",
                .keep_empty_folders = "keepEmptyFolders",
                .put_files = "putFiles",
                .delete_files = "deleteFiles",
                .set_file_modes = "setFileModes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_commit) } {
            return .{ .service_metadata = service_metadata, .action = create_commit };
        }
    },
    Response: type = struct {
        commit_id: ?[]const u8 = null,
        tree_id: ?[]const u8 = null,
        files_added: ?[]FileMetadata = null,
        files_updated: ?[]FileMetadata = null,
        files_deleted: ?[]FileMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .tree_id = "treeId",
                .files_added = "filesAdded",
                .files_updated = "filesUpdated",
                .files_deleted = "filesDeleted",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BranchDoesNotExist,
        BranchNameIsTagName,
        BranchNameRequired,
        CommitMessageLengthExceeded,
        DirectoryNameConflictsWithFileName,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileContentAndSourceFileSpecified,
        FileContentSizeLimitExceeded,
        FileDoesNotExist,
        FileEntryRequired,
        FileModeRequired,
        FileNameConflictsWithDirectoryName,
        FilePathConflictsWithSubmodulePath,
        FolderContentSizeLimitExceeded,
        InvalidBranchName,
        InvalidDeletionParameter,
        InvalidEmail,
        InvalidFileMode,
        InvalidParentCommitId,
        InvalidPath,
        InvalidRepositoryName,
        MaximumFileEntriesExceeded,
        NameLengthExceeded,
        NoChange,
        ParentCommitDoesNotExist,
        ParentCommitIdOutdated,
        ParentCommitIdRequired,
        PathRequired,
        PutFileEntryConflict,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        RestrictedSourceFile,
        SamePathRequest,
        SourceFileOrContentRequired,
    },
} = .{};
pub const create_pull_request: struct {
    action_name: []const u8 = "CreatePullRequest",
    Request: type = struct {
        title: []const u8,
        description: ?[]const u8 = null,
        targets: []struct {
            repository_name: []const u8,
            source_reference: []const u8,
            destination_reference: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .repository_name = "repositoryName",
                    .source_reference = "sourceReference",
                    .destination_reference = "destinationReference",
                };
                return @field(mappings, field_name);
            }
        },
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .title = "title",
                .description = "description",
                .targets = "targets",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pull_request) } {
            return .{ .service_metadata = service_metadata, .action = create_pull_request };
        }
    },
    Response: type = struct {
        pull_request: PullRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request = "pullRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientRequestTokenRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        IdempotencyParameterMismatch,
        InvalidClientRequestToken,
        InvalidDescription,
        InvalidReferenceName,
        InvalidRepositoryName,
        InvalidTarget,
        InvalidTargets,
        InvalidTitle,
        MaximumOpenPullRequestsExceeded,
        MultipleRepositoriesInPullRequest,
        ReferenceDoesNotExist,
        ReferenceNameRequired,
        ReferenceTypeNotSupported,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        SourceAndDestinationAreSame,
        TargetRequired,
        TargetsRequired,
        TitleRequired,
    },
} = .{};
pub const create_pull_request_approval_rule: struct {
    action_name: []const u8 = "CreatePullRequestApprovalRule",
    Request: type = struct {
        pull_request_id: []const u8,
        approval_rule_name: []const u8,
        approval_rule_content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .approval_rule_name = "approvalRuleName",
                .approval_rule_content = "approvalRuleContent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pull_request_approval_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_pull_request_approval_rule };
        }
    },
    Response: type = struct {
        approval_rule: ApprovalRule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule = "approvalRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleContentRequired,
        ApprovalRuleNameAlreadyExists,
        ApprovalRuleNameRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalRuleContent,
        InvalidApprovalRuleName,
        InvalidPullRequestId,
        NumberOfRulesExceeded,
        PullRequestAlreadyClosed,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
    },
} = .{};
pub const create_repository: struct {
    action_name: []const u8 = "CreateRepository",
    Request: type = struct {
        repository_name: []const u8,
        repository_description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .repository_description = "repositoryDescription",
                .tags = "tags",
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_repository) } {
            return .{ .service_metadata = service_metadata, .action = create_repository };
        }
    },
    Response: type = struct {
        repository_metadata: ?RepositoryMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_metadata = "repositoryMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyInvalidId,
        EncryptionKeyInvalidUsage,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryDescription,
        InvalidRepositoryName,
        InvalidSystemTagUsage,
        InvalidTagsMap,
        RepositoryLimitExceeded,
        RepositoryNameExists,
        RepositoryNameRequired,
        TagPolicy,
        TooManyTags,
    },
} = .{};
pub const create_unreferenced_merge_commit: struct {
    action_name: []const u8 = "CreateUnreferencedMergeCommit",
    Request: type = struct {
        repository_name: []const u8,
        source_commit_specifier: []const u8,
        destination_commit_specifier: []const u8,
        merge_option: []const u8,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,
        author_name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,
        keep_empty_folders: ?bool = null,
        conflict_resolution: ?ConflictResolution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .source_commit_specifier = "sourceCommitSpecifier",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .merge_option = "mergeOption",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
                .author_name = "authorName",
                .email = "email",
                .commit_message = "commitMessage",
                .keep_empty_folders = "keepEmptyFolders",
                .conflict_resolution = "conflictResolution",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_unreferenced_merge_commit) } {
            return .{ .service_metadata = service_metadata, .action = create_unreferenced_merge_commit };
        }
    },
    Response: type = struct {
        commit_id: ?[]const u8 = null,
        tree_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .tree_id = "treeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitMessageLengthExceeded,
        CommitRequired,
        ConcurrentReferenceUpdate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileContentSizeLimitExceeded,
        FileModeRequired,
        FolderContentSizeLimitExceeded,
        InvalidCommit,
        InvalidConflictDetailLevel,
        InvalidConflictResolution,
        InvalidConflictResolutionStrategy,
        InvalidEmail,
        InvalidFileMode,
        InvalidMergeOption,
        InvalidPath,
        InvalidReplacementContent,
        InvalidReplacementType,
        InvalidRepositoryName,
        ManualMergeRequired,
        MaximumConflictResolutionEntriesExceeded,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        MergeOptionRequired,
        MultipleConflictResolutionEntries,
        NameLengthExceeded,
        PathRequired,
        ReplacementContentRequired,
        ReplacementTypeRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const delete_approval_rule_template: struct {
    action_name: []const u8 = "DeleteApprovalRuleTemplate",
    Request: type = struct {
        approval_rule_template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_approval_rule_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_approval_rule_template };
        }
    },
    Response: type = struct {
        approval_rule_template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_id = "approvalRuleTemplateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateInUse,
        ApprovalRuleTemplateNameRequired,
        InvalidApprovalRuleTemplateName,
    },
} = .{};
pub const delete_branch: struct {
    action_name: []const u8 = "DeleteBranch",
    Request: type = struct {
        repository_name: []const u8,
        branch_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .branch_name = "branchName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_branch) } {
            return .{ .service_metadata = service_metadata, .action = delete_branch };
        }
    },
    Response: type = struct {
        deleted_branch: ?BranchInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted_branch = "deletedBranch",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BranchNameRequired,
        DefaultBranchCannotBeDeleted,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidBranchName,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const delete_comment_content: struct {
    action_name: []const u8 = "DeleteCommentContent",
    Request: type = struct {
        comment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment_id = "commentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_comment_content) } {
            return .{ .service_metadata = service_metadata, .action = delete_comment_content };
        }
    },
    Response: type = struct {
        comment: ?Comment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment = "comment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommentDeleted,
        CommentDoesNotExist,
        CommentIdRequired,
        InvalidCommentId,
    },
} = .{};
pub const delete_file: struct {
    action_name: []const u8 = "DeleteFile",
    Request: type = struct {
        repository_name: []const u8,
        branch_name: []const u8,
        file_path: []const u8,
        parent_commit_id: []const u8,
        keep_empty_folders: ?bool = null,
        commit_message: ?[]const u8 = null,
        name: ?[]const u8 = null,
        email: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .branch_name = "branchName",
                .file_path = "filePath",
                .parent_commit_id = "parentCommitId",
                .keep_empty_folders = "keepEmptyFolders",
                .commit_message = "commitMessage",
                .name = "name",
                .email = "email",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_file) } {
            return .{ .service_metadata = service_metadata, .action = delete_file };
        }
    },
    Response: type = struct {
        commit_id: []const u8,
        blob_id: []const u8,
        tree_id: []const u8,
        file_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .blob_id = "blobId",
                .tree_id = "treeId",
                .file_path = "filePath",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BranchDoesNotExist,
        BranchNameIsTagName,
        BranchNameRequired,
        CommitMessageLengthExceeded,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileDoesNotExist,
        InvalidBranchName,
        InvalidEmail,
        InvalidParentCommitId,
        InvalidPath,
        InvalidRepositoryName,
        NameLengthExceeded,
        ParentCommitDoesNotExist,
        ParentCommitIdOutdated,
        ParentCommitIdRequired,
        PathRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const delete_pull_request_approval_rule: struct {
    action_name: []const u8 = "DeletePullRequestApprovalRule",
    Request: type = struct {
        pull_request_id: []const u8,
        approval_rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .approval_rule_name = "approvalRuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pull_request_approval_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_pull_request_approval_rule };
        }
    },
    Response: type = struct {
        approval_rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_id = "approvalRuleId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleNameRequired,
        CannotDeleteApprovalRuleFromTemplate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalRuleName,
        InvalidPullRequestId,
        PullRequestAlreadyClosed,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
    },
} = .{};
pub const delete_repository: struct {
    action_name: []const u8 = "DeleteRepository",
    Request: type = struct {
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_repository) } {
            return .{ .service_metadata = service_metadata, .action = delete_repository };
        }
    },
    Response: type = struct {
        repository_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_id = "repositoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryName,
        RepositoryNameRequired,
    },
} = .{};
pub const describe_merge_conflicts: struct {
    action_name: []const u8 = "DescribeMergeConflicts",
    Request: type = struct {
        repository_name: []const u8,
        destination_commit_specifier: []const u8,
        source_commit_specifier: []const u8,
        merge_option: []const u8,
        max_merge_hunks: ?i64 = null,
        file_path: []const u8,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .source_commit_specifier = "sourceCommitSpecifier",
                .merge_option = "mergeOption",
                .max_merge_hunks = "maxMergeHunks",
                .file_path = "filePath",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_merge_conflicts) } {
            return .{ .service_metadata = service_metadata, .action = describe_merge_conflicts };
        }
    },
    Response: type = struct {
        conflict_metadata: ConflictMetadata,
        merge_hunks: []MergeHunk,
        next_token: ?[]const u8 = null,
        destination_commit_id: []const u8,
        source_commit_id: []const u8,
        base_commit_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conflict_metadata = "conflictMetadata",
                .merge_hunks = "mergeHunks",
                .next_token = "nextToken",
                .destination_commit_id = "destinationCommitId",
                .source_commit_id = "sourceCommitId",
                .base_commit_id = "baseCommitId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileDoesNotExist,
        InvalidCommit,
        InvalidConflictDetailLevel,
        InvalidConflictResolutionStrategy,
        InvalidContinuationToken,
        InvalidMaxMergeHunks,
        InvalidMergeOption,
        InvalidPath,
        InvalidRepositoryName,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        MergeOptionRequired,
        PathRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const describe_pull_request_events: struct {
    action_name: []const u8 = "DescribePullRequestEvents",
    Request: type = struct {
        pull_request_id: []const u8,
        pull_request_event_type: ?[]const u8 = null,
        actor_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .pull_request_event_type = "pullRequestEventType",
                .actor_arn = "actorArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pull_request_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_pull_request_events };
        }
    },
    Response: type = struct {
        pull_request_events: []struct {
            pull_request_id: ?[]const u8 = null,
            event_date: ?i64 = null,
            pull_request_event_type: ?[]const u8 = null,
            actor_arn: ?[]const u8 = null,
            pull_request_created_event_metadata: ?struct {
                repository_name: ?[]const u8 = null,
                source_commit_id: ?[]const u8 = null,
                destination_commit_id: ?[]const u8 = null,
                merge_base: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .repository_name = "repositoryName",
                        .source_commit_id = "sourceCommitId",
                        .destination_commit_id = "destinationCommitId",
                        .merge_base = "mergeBase",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            pull_request_status_changed_event_metadata: ?struct {
                pull_request_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pull_request_status = "pullRequestStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            pull_request_source_reference_updated_event_metadata: ?struct {
                repository_name: ?[]const u8 = null,
                before_commit_id: ?[]const u8 = null,
                after_commit_id: ?[]const u8 = null,
                merge_base: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .repository_name = "repositoryName",
                        .before_commit_id = "beforeCommitId",
                        .after_commit_id = "afterCommitId",
                        .merge_base = "mergeBase",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            pull_request_merged_state_changed_event_metadata: ?struct {
                repository_name: ?[]const u8 = null,
                destination_reference: ?[]const u8 = null,
                merge_metadata: ?MergeMetadata = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .repository_name = "repositoryName",
                        .destination_reference = "destinationReference",
                        .merge_metadata = "mergeMetadata",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            approval_rule_event_metadata: ?struct {
                approval_rule_name: ?[]const u8 = null,
                approval_rule_id: ?[]const u8 = null,
                approval_rule_content: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .approval_rule_name = "approvalRuleName",
                        .approval_rule_id = "approvalRuleId",
                        .approval_rule_content = "approvalRuleContent",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            approval_state_changed_event_metadata: ?struct {
                revision_id: ?[]const u8 = null,
                approval_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .revision_id = "revisionId",
                        .approval_status = "approvalStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            approval_rule_overridden_event_metadata: ?struct {
                revision_id: ?[]const u8 = null,
                override_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .revision_id = "revisionId",
                        .override_status = "overrideStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pull_request_id = "pullRequestId",
                    .event_date = "eventDate",
                    .pull_request_event_type = "pullRequestEventType",
                    .actor_arn = "actorArn",
                    .pull_request_created_event_metadata = "pullRequestCreatedEventMetadata",
                    .pull_request_status_changed_event_metadata = "pullRequestStatusChangedEventMetadata",
                    .pull_request_source_reference_updated_event_metadata = "pullRequestSourceReferenceUpdatedEventMetadata",
                    .pull_request_merged_state_changed_event_metadata = "pullRequestMergedStateChangedEventMetadata",
                    .approval_rule_event_metadata = "approvalRuleEventMetadata",
                    .approval_state_changed_event_metadata = "approvalStateChangedEventMetadata",
                    .approval_rule_overridden_event_metadata = "approvalRuleOverriddenEventMetadata",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_events = "pullRequestEvents",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActorDoesNotExist,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidActorArn,
        InvalidContinuationToken,
        InvalidMaxResults,
        InvalidPullRequestEventType,
        InvalidPullRequestId,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
    },
} = .{};
pub const disassociate_approval_rule_template_from_repository: struct {
    action_name: []const u8 = "DisassociateApprovalRuleTemplateFromRepository",
    Request: type = struct {
        approval_rule_template_name: []const u8,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_approval_rule_template_from_repository) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_approval_rule_template_from_repository };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalRuleTemplateName,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const evaluate_pull_request_approval_rules: struct {
    action_name: []const u8 = "EvaluatePullRequestApprovalRules",
    Request: type = struct {
        pull_request_id: []const u8,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(evaluate_pull_request_approval_rules) } {
            return .{ .service_metadata = service_metadata, .action = evaluate_pull_request_approval_rules };
        }
    },
    Response: type = struct {
        evaluation: struct {
            approved: ?bool = null,
            overridden: ?bool = null,
            approval_rules_satisfied: ?[][]const u8 = null,
            approval_rules_not_satisfied: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .approved = "approved",
                    .overridden = "overridden",
                    .approval_rules_satisfied = "approvalRulesSatisfied",
                    .approval_rules_not_satisfied = "approvalRulesNotSatisfied",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation = "evaluation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidPullRequestId,
        InvalidRevisionId,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        RevisionIdRequired,
        RevisionNotCurrent,
    },
} = .{};
pub const get_approval_rule_template: struct {
    action_name: []const u8 = "GetApprovalRuleTemplate",
    Request: type = struct {
        approval_rule_template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_approval_rule_template) } {
            return .{ .service_metadata = service_metadata, .action = get_approval_rule_template };
        }
    },
    Response: type = struct {
        approval_rule_template: ApprovalRuleTemplate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template = "approvalRuleTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameRequired,
        InvalidApprovalRuleTemplateName,
    },
} = .{};
pub const get_blob: struct {
    action_name: []const u8 = "GetBlob",
    Request: type = struct {
        repository_name: []const u8,
        blob_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .blob_id = "blobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_blob) } {
            return .{ .service_metadata = service_metadata, .action = get_blob };
        }
    },
    Response: type = struct {
        content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "content",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BlobIdDoesNotExist,
        BlobIdRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileTooLarge,
        InvalidBlobId,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_branch: struct {
    action_name: []const u8 = "GetBranch",
    Request: type = struct {
        repository_name: ?[]const u8 = null,
        branch_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .branch_name = "branchName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_branch) } {
            return .{ .service_metadata = service_metadata, .action = get_branch };
        }
    },
    Response: type = struct {
        branch: ?BranchInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch = "branch",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BranchDoesNotExist,
        BranchNameRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidBranchName,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_comment: struct {
    action_name: []const u8 = "GetComment",
    Request: type = struct {
        comment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment_id = "commentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_comment) } {
            return .{ .service_metadata = service_metadata, .action = get_comment };
        }
    },
    Response: type = struct {
        comment: ?Comment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment = "comment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommentDeleted,
        CommentDoesNotExist,
        CommentIdRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommentId,
    },
} = .{};
pub const get_comment_reactions: struct {
    action_name: []const u8 = "GetCommentReactions",
    Request: type = struct {
        comment_id: []const u8,
        reaction_user_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment_id = "commentId",
                .reaction_user_arn = "reactionUserArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_comment_reactions) } {
            return .{ .service_metadata = service_metadata, .action = get_comment_reactions };
        }
    },
    Response: type = struct {
        reactions_for_comment: []struct {
            reaction: ?struct {
                emoji: ?[]const u8 = null,
                short_code: ?[]const u8 = null,
                unicode: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .emoji = "emoji",
                        .short_code = "shortCode",
                        .unicode = "unicode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            reaction_users: ?[][]const u8 = null,
            reactions_from_deleted_users_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reaction = "reaction",
                    .reaction_users = "reactionUsers",
                    .reactions_from_deleted_users_count = "reactionsFromDeletedUsersCount",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reactions_for_comment = "reactionsForComment",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommentDeleted,
        CommentDoesNotExist,
        CommentIdRequired,
        InvalidCommentId,
        InvalidContinuationToken,
        InvalidMaxResults,
        InvalidReactionUserArn,
    },
} = .{};
pub const get_comments_for_compared_commit: struct {
    action_name: []const u8 = "GetCommentsForComparedCommit",
    Request: type = struct {
        repository_name: []const u8,
        before_commit_id: ?[]const u8 = null,
        after_commit_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .before_commit_id = "beforeCommitId",
                .after_commit_id = "afterCommitId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_comments_for_compared_commit) } {
            return .{ .service_metadata = service_metadata, .action = get_comments_for_compared_commit };
        }
    },
    Response: type = struct {
        comments_for_compared_commit_data: ?[]struct {
            repository_name: ?[]const u8 = null,
            before_commit_id: ?[]const u8 = null,
            after_commit_id: ?[]const u8 = null,
            before_blob_id: ?[]const u8 = null,
            after_blob_id: ?[]const u8 = null,
            location: ?Location = null,
            comments: ?[]Comment = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .repository_name = "repositoryName",
                    .before_commit_id = "beforeCommitId",
                    .after_commit_id = "afterCommitId",
                    .before_blob_id = "beforeBlobId",
                    .after_blob_id = "afterBlobId",
                    .location = "location",
                    .comments = "comments",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comments_for_compared_commit_data = "commentsForComparedCommitData",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitIdRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommitId,
        InvalidContinuationToken,
        InvalidMaxResults,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_comments_for_pull_request: struct {
    action_name: []const u8 = "GetCommentsForPullRequest",
    Request: type = struct {
        pull_request_id: []const u8,
        repository_name: ?[]const u8 = null,
        before_commit_id: ?[]const u8 = null,
        after_commit_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .repository_name = "repositoryName",
                .before_commit_id = "beforeCommitId",
                .after_commit_id = "afterCommitId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_comments_for_pull_request) } {
            return .{ .service_metadata = service_metadata, .action = get_comments_for_pull_request };
        }
    },
    Response: type = struct {
        comments_for_pull_request_data: ?[]struct {
            pull_request_id: ?[]const u8 = null,
            repository_name: ?[]const u8 = null,
            before_commit_id: ?[]const u8 = null,
            after_commit_id: ?[]const u8 = null,
            before_blob_id: ?[]const u8 = null,
            after_blob_id: ?[]const u8 = null,
            location: ?Location = null,
            comments: ?[]Comment = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pull_request_id = "pullRequestId",
                    .repository_name = "repositoryName",
                    .before_commit_id = "beforeCommitId",
                    .after_commit_id = "afterCommitId",
                    .before_blob_id = "beforeBlobId",
                    .after_blob_id = "afterBlobId",
                    .location = "location",
                    .comments = "comments",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comments_for_pull_request_data = "commentsForPullRequestData",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitIdRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommitId,
        InvalidContinuationToken,
        InvalidMaxResults,
        InvalidPullRequestId,
        InvalidRepositoryName,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        RepositoryNotAssociatedWithPullRequest,
    },
} = .{};
pub const get_commit: struct {
    action_name: []const u8 = "GetCommit",
    Request: type = struct {
        repository_name: []const u8,
        commit_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .commit_id = "commitId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_commit) } {
            return .{ .service_metadata = service_metadata, .action = get_commit };
        }
    },
    Response: type = struct {
        commit: Commit,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit = "commit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitIdDoesNotExist,
        CommitIdRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommitId,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_differences: struct {
    action_name: []const u8 = "GetDifferences",
    Request: type = struct {
        repository_name: []const u8,
        before_commit_specifier: ?[]const u8 = null,
        after_commit_specifier: []const u8,
        before_path: ?[]const u8 = null,
        after_path: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .before_commit_specifier = "beforeCommitSpecifier",
                .after_commit_specifier = "afterCommitSpecifier",
                .before_path = "beforePath",
                .after_path = "afterPath",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_differences) } {
            return .{ .service_metadata = service_metadata, .action = get_differences };
        }
    },
    Response: type = struct {
        differences: ?[]struct {
            before_blob: ?BlobMetadata = null,
            after_blob: ?BlobMetadata = null,
            change_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .before_blob = "beforeBlob",
                    .after_blob = "afterBlob",
                    .change_type = "changeType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .differences = "differences",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommit,
        InvalidCommitId,
        InvalidContinuationToken,
        InvalidMaxResults,
        InvalidPath,
        InvalidRepositoryName,
        PathDoesNotExist,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_file: struct {
    action_name: []const u8 = "GetFile",
    Request: type = struct {
        repository_name: []const u8,
        commit_specifier: ?[]const u8 = null,
        file_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .commit_specifier = "commitSpecifier",
                .file_path = "filePath",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_file) } {
            return .{ .service_metadata = service_metadata, .action = get_file };
        }
    },
    Response: type = struct {
        commit_id: []const u8,
        blob_id: []const u8,
        file_path: []const u8,
        file_mode: []const u8,
        file_size: i64,
        file_content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .blob_id = "blobId",
                .file_path = "filePath",
                .file_mode = "fileMode",
                .file_size = "fileSize",
                .file_content = "fileContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileDoesNotExist,
        FileTooLarge,
        InvalidCommit,
        InvalidPath,
        InvalidRepositoryName,
        PathRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_folder: struct {
    action_name: []const u8 = "GetFolder",
    Request: type = struct {
        repository_name: []const u8,
        commit_specifier: ?[]const u8 = null,
        folder_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .commit_specifier = "commitSpecifier",
                .folder_path = "folderPath",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_folder) } {
            return .{ .service_metadata = service_metadata, .action = get_folder };
        }
    },
    Response: type = struct {
        commit_id: []const u8,
        folder_path: []const u8,
        tree_id: ?[]const u8 = null,
        sub_folders: ?[]struct {
            tree_id: ?[]const u8 = null,
            absolute_path: ?[]const u8 = null,
            relative_path: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tree_id = "treeId",
                    .absolute_path = "absolutePath",
                    .relative_path = "relativePath",
                };
                return @field(mappings, field_name);
            }
        } = null,
        files: ?[]struct {
            blob_id: ?[]const u8 = null,
            absolute_path: ?[]const u8 = null,
            relative_path: ?[]const u8 = null,
            file_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .blob_id = "blobId",
                    .absolute_path = "absolutePath",
                    .relative_path = "relativePath",
                    .file_mode = "fileMode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        symbolic_links: ?[]struct {
            blob_id: ?[]const u8 = null,
            absolute_path: ?[]const u8 = null,
            relative_path: ?[]const u8 = null,
            file_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .blob_id = "blobId",
                    .absolute_path = "absolutePath",
                    .relative_path = "relativePath",
                    .file_mode = "fileMode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sub_modules: ?[]struct {
            commit_id: ?[]const u8 = null,
            absolute_path: ?[]const u8 = null,
            relative_path: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .commit_id = "commitId",
                    .absolute_path = "absolutePath",
                    .relative_path = "relativePath",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .folder_path = "folderPath",
                .tree_id = "treeId",
                .sub_folders = "subFolders",
                .files = "files",
                .symbolic_links = "symbolicLinks",
                .sub_modules = "subModules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FolderDoesNotExist,
        InvalidCommit,
        InvalidPath,
        InvalidRepositoryName,
        PathRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_merge_commit: struct {
    action_name: []const u8 = "GetMergeCommit",
    Request: type = struct {
        repository_name: []const u8,
        source_commit_specifier: []const u8,
        destination_commit_specifier: []const u8,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .source_commit_specifier = "sourceCommitSpecifier",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_merge_commit) } {
            return .{ .service_metadata = service_metadata, .action = get_merge_commit };
        }
    },
    Response: type = struct {
        source_commit_id: ?[]const u8 = null,
        destination_commit_id: ?[]const u8 = null,
        base_commit_id: ?[]const u8 = null,
        merged_commit_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_commit_id = "sourceCommitId",
                .destination_commit_id = "destinationCommitId",
                .base_commit_id = "baseCommitId",
                .merged_commit_id = "mergedCommitId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommit,
        InvalidConflictDetailLevel,
        InvalidConflictResolutionStrategy,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_merge_conflicts: struct {
    action_name: []const u8 = "GetMergeConflicts",
    Request: type = struct {
        repository_name: []const u8,
        destination_commit_specifier: []const u8,
        source_commit_specifier: []const u8,
        merge_option: []const u8,
        conflict_detail_level: ?[]const u8 = null,
        max_conflict_files: ?i64 = null,
        conflict_resolution_strategy: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .source_commit_specifier = "sourceCommitSpecifier",
                .merge_option = "mergeOption",
                .conflict_detail_level = "conflictDetailLevel",
                .max_conflict_files = "maxConflictFiles",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_merge_conflicts) } {
            return .{ .service_metadata = service_metadata, .action = get_merge_conflicts };
        }
    },
    Response: type = struct {
        mergeable: bool,
        destination_commit_id: []const u8,
        source_commit_id: []const u8,
        base_commit_id: ?[]const u8 = null,
        conflict_metadata_list: []ConflictMetadata,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mergeable = "mergeable",
                .destination_commit_id = "destinationCommitId",
                .source_commit_id = "sourceCommitId",
                .base_commit_id = "baseCommitId",
                .conflict_metadata_list = "conflictMetadataList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommit,
        InvalidConflictDetailLevel,
        InvalidConflictResolutionStrategy,
        InvalidContinuationToken,
        InvalidDestinationCommitSpecifier,
        InvalidMaxConflictFiles,
        InvalidMergeOption,
        InvalidRepositoryName,
        InvalidSourceCommitSpecifier,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        MergeOptionRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const get_merge_options: struct {
    action_name: []const u8 = "GetMergeOptions",
    Request: type = struct {
        repository_name: []const u8,
        source_commit_specifier: []const u8,
        destination_commit_specifier: []const u8,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .source_commit_specifier = "sourceCommitSpecifier",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_merge_options) } {
            return .{ .service_metadata = service_metadata, .action = get_merge_options };
        }
    },
    Response: type = struct {
        merge_options: [][]const u8,
        source_commit_id: []const u8,
        destination_commit_id: []const u8,
        base_commit_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .merge_options = "mergeOptions",
                .source_commit_id = "sourceCommitId",
                .destination_commit_id = "destinationCommitId",
                .base_commit_id = "baseCommitId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommit,
        InvalidConflictDetailLevel,
        InvalidConflictResolutionStrategy,
        InvalidRepositoryName,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const get_pull_request: struct {
    action_name: []const u8 = "GetPullRequest",
    Request: type = struct {
        pull_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pull_request) } {
            return .{ .service_metadata = service_metadata, .action = get_pull_request };
        }
    },
    Response: type = struct {
        pull_request: PullRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request = "pullRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidPullRequestId,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
    },
} = .{};
pub const get_pull_request_approval_states: struct {
    action_name: []const u8 = "GetPullRequestApprovalStates",
    Request: type = struct {
        pull_request_id: []const u8,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pull_request_approval_states) } {
            return .{ .service_metadata = service_metadata, .action = get_pull_request_approval_states };
        }
    },
    Response: type = struct {
        approvals: ?[]struct {
            user_arn: ?[]const u8 = null,
            approval_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_arn = "userArn",
                    .approval_state = "approvalState",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approvals = "approvals",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidPullRequestId,
        InvalidRevisionId,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        RevisionIdRequired,
    },
} = .{};
pub const get_pull_request_override_state: struct {
    action_name: []const u8 = "GetPullRequestOverrideState",
    Request: type = struct {
        pull_request_id: []const u8,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pull_request_override_state) } {
            return .{ .service_metadata = service_metadata, .action = get_pull_request_override_state };
        }
    },
    Response: type = struct {
        overridden: ?bool = null,
        overrider: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .overridden = "overridden",
                .overrider = "overrider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidPullRequestId,
        InvalidRevisionId,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        RevisionIdRequired,
    },
} = .{};
pub const get_repository: struct {
    action_name: []const u8 = "GetRepository",
    Request: type = struct {
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository) } {
            return .{ .service_metadata = service_metadata, .action = get_repository };
        }
    },
    Response: type = struct {
        repository_metadata: ?RepositoryMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_metadata = "repositoryMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const get_repository_triggers: struct {
    action_name: []const u8 = "GetRepositoryTriggers",
    Request: type = struct {
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_triggers) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_triggers };
        }
    },
    Response: type = struct {
        configuration_id: ?[]const u8 = null,
        triggers: ?[]RepositoryTrigger = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_id = "configurationId",
                .triggers = "triggers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const list_approval_rule_templates: struct {
    action_name: []const u8 = "ListApprovalRuleTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_approval_rule_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_approval_rule_templates };
        }
    },
    Response: type = struct {
        approval_rule_template_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_names = "approvalRuleTemplateNames",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidContinuationToken,
        InvalidMaxResults,
    },
} = .{};
pub const list_associated_approval_rule_templates_for_repository: struct {
    action_name: []const u8 = "ListAssociatedApprovalRuleTemplatesForRepository",
    Request: type = struct {
        repository_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associated_approval_rule_templates_for_repository) } {
            return .{ .service_metadata = service_metadata, .action = list_associated_approval_rule_templates_for_repository };
        }
    },
    Response: type = struct {
        approval_rule_template_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_names = "approvalRuleTemplateNames",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidContinuationToken,
        InvalidMaxResults,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const list_branches: struct {
    action_name: []const u8 = "ListBranches",
    Request: type = struct {
        repository_name: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_branches) } {
            return .{ .service_metadata = service_metadata, .action = list_branches };
        }
    },
    Response: type = struct {
        branches: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branches = "branches",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidContinuationToken,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const list_file_commit_history: struct {
    action_name: []const u8 = "ListFileCommitHistory",
    Request: type = struct {
        repository_name: []const u8,
        commit_specifier: ?[]const u8 = null,
        file_path: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .commit_specifier = "commitSpecifier",
                .file_path = "filePath",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_file_commit_history) } {
            return .{ .service_metadata = service_metadata, .action = list_file_commit_history };
        }
    },
    Response: type = struct {
        revision_dag: []struct {
            commit: ?Commit = null,
            blob_id: ?[]const u8 = null,
            path: ?[]const u8 = null,
            revision_children: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .commit = "commit",
                    .blob_id = "blobId",
                    .path = "path",
                    .revision_children = "revisionChildren",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .revision_dag = "revisionDag",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitDoesNotExist,
        CommitRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommit,
        InvalidContinuationToken,
        InvalidMaxResults,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const list_pull_requests: struct {
    action_name: []const u8 = "ListPullRequests",
    Request: type = struct {
        repository_name: []const u8,
        author_arn: ?[]const u8 = null,
        pull_request_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .author_arn = "authorArn",
                .pull_request_status = "pullRequestStatus",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pull_requests) } {
            return .{ .service_metadata = service_metadata, .action = list_pull_requests };
        }
    },
    Response: type = struct {
        pull_request_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_ids = "pullRequestIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorDoesNotExist,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidAuthorArn,
        InvalidContinuationToken,
        InvalidMaxResults,
        InvalidPullRequestStatus,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const list_repositories: struct {
    action_name: []const u8 = "ListRepositories",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .sort_by = "sortBy",
                .order = "order",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_repositories) } {
            return .{ .service_metadata = service_metadata, .action = list_repositories };
        }
    },
    Response: type = struct {
        repositories: ?[]struct {
            repository_name: ?[]const u8 = null,
            repository_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .repository_name = "repositoryName",
                    .repository_id = "repositoryId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repositories = "repositories",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidContinuationToken,
        InvalidOrder,
        InvalidSortBy,
    },
} = .{};
pub const list_repositories_for_approval_rule_template: struct {
    action_name: []const u8 = "ListRepositoriesForApprovalRuleTemplate",
    Request: type = struct {
        approval_rule_template_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_repositories_for_approval_rule_template) } {
            return .{ .service_metadata = service_metadata, .action = list_repositories_for_approval_rule_template };
        }
    },
    Response: type = struct {
        repository_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_names = "repositoryNames",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalRuleTemplateName,
        InvalidContinuationToken,
        InvalidMaxResults,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidRepositoryName,
        InvalidResourceArn,
        RepositoryDoesNotExist,
        ResourceArnRequired,
    },
} = .{};
pub const merge_branches_by_fast_forward: struct {
    action_name: []const u8 = "MergeBranchesByFastForward",
    Request: type = struct {
        repository_name: []const u8,
        source_commit_specifier: []const u8,
        destination_commit_specifier: []const u8,
        target_branch: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .source_commit_specifier = "sourceCommitSpecifier",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .target_branch = "targetBranch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_branches_by_fast_forward) } {
            return .{ .service_metadata = service_metadata, .action = merge_branches_by_fast_forward };
        }
    },
    Response: type = struct {
        commit_id: ?[]const u8 = null,
        tree_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .tree_id = "treeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BranchDoesNotExist,
        BranchNameIsTagName,
        BranchNameRequired,
        CommitDoesNotExist,
        CommitRequired,
        ConcurrentReferenceUpdate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidBranchName,
        InvalidCommit,
        InvalidRepositoryName,
        InvalidTargetBranch,
        ManualMergeRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const merge_branches_by_squash: struct {
    action_name: []const u8 = "MergeBranchesBySquash",
    Request: type = struct {
        repository_name: []const u8,
        source_commit_specifier: []const u8,
        destination_commit_specifier: []const u8,
        target_branch: ?[]const u8 = null,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,
        author_name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,
        keep_empty_folders: ?bool = null,
        conflict_resolution: ?ConflictResolution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .source_commit_specifier = "sourceCommitSpecifier",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .target_branch = "targetBranch",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
                .author_name = "authorName",
                .email = "email",
                .commit_message = "commitMessage",
                .keep_empty_folders = "keepEmptyFolders",
                .conflict_resolution = "conflictResolution",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_branches_by_squash) } {
            return .{ .service_metadata = service_metadata, .action = merge_branches_by_squash };
        }
    },
    Response: type = struct {
        commit_id: ?[]const u8 = null,
        tree_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .tree_id = "treeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BranchDoesNotExist,
        BranchNameIsTagName,
        BranchNameRequired,
        CommitDoesNotExist,
        CommitMessageLengthExceeded,
        CommitRequired,
        ConcurrentReferenceUpdate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileContentSizeLimitExceeded,
        FileModeRequired,
        FolderContentSizeLimitExceeded,
        InvalidBranchName,
        InvalidCommit,
        InvalidConflictDetailLevel,
        InvalidConflictResolution,
        InvalidConflictResolutionStrategy,
        InvalidEmail,
        InvalidFileMode,
        InvalidPath,
        InvalidReplacementContent,
        InvalidReplacementType,
        InvalidRepositoryName,
        InvalidTargetBranch,
        ManualMergeRequired,
        MaximumConflictResolutionEntriesExceeded,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        MultipleConflictResolutionEntries,
        NameLengthExceeded,
        PathRequired,
        ReplacementContentRequired,
        ReplacementTypeRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const merge_branches_by_three_way: struct {
    action_name: []const u8 = "MergeBranchesByThreeWay",
    Request: type = struct {
        repository_name: []const u8,
        source_commit_specifier: []const u8,
        destination_commit_specifier: []const u8,
        target_branch: ?[]const u8 = null,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,
        author_name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,
        keep_empty_folders: ?bool = null,
        conflict_resolution: ?ConflictResolution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .source_commit_specifier = "sourceCommitSpecifier",
                .destination_commit_specifier = "destinationCommitSpecifier",
                .target_branch = "targetBranch",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
                .author_name = "authorName",
                .email = "email",
                .commit_message = "commitMessage",
                .keep_empty_folders = "keepEmptyFolders",
                .conflict_resolution = "conflictResolution",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_branches_by_three_way) } {
            return .{ .service_metadata = service_metadata, .action = merge_branches_by_three_way };
        }
    },
    Response: type = struct {
        commit_id: ?[]const u8 = null,
        tree_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .tree_id = "treeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BranchDoesNotExist,
        BranchNameIsTagName,
        BranchNameRequired,
        CommitDoesNotExist,
        CommitMessageLengthExceeded,
        CommitRequired,
        ConcurrentReferenceUpdate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileContentSizeLimitExceeded,
        FileModeRequired,
        FolderContentSizeLimitExceeded,
        InvalidBranchName,
        InvalidCommit,
        InvalidConflictDetailLevel,
        InvalidConflictResolution,
        InvalidConflictResolutionStrategy,
        InvalidEmail,
        InvalidFileMode,
        InvalidPath,
        InvalidReplacementContent,
        InvalidReplacementType,
        InvalidRepositoryName,
        InvalidTargetBranch,
        ManualMergeRequired,
        MaximumConflictResolutionEntriesExceeded,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        MultipleConflictResolutionEntries,
        NameLengthExceeded,
        PathRequired,
        ReplacementContentRequired,
        ReplacementTypeRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        TipsDivergenceExceeded,
    },
} = .{};
pub const merge_pull_request_by_fast_forward: struct {
    action_name: []const u8 = "MergePullRequestByFastForward",
    Request: type = struct {
        pull_request_id: []const u8,
        repository_name: []const u8,
        source_commit_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .repository_name = "repositoryName",
                .source_commit_id = "sourceCommitId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_pull_request_by_fast_forward) } {
            return .{ .service_metadata = service_metadata, .action = merge_pull_request_by_fast_forward };
        }
    },
    Response: type = struct {
        pull_request: ?PullRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request = "pullRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentReferenceUpdate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidCommitId,
        InvalidPullRequestId,
        InvalidRepositoryName,
        ManualMergeRequired,
        PullRequestAlreadyClosed,
        PullRequestApprovalRulesNotSatisfied,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        ReferenceDoesNotExist,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        RepositoryNotAssociatedWithPullRequest,
        TipOfSourceReferenceIsDifferent,
    },
} = .{};
pub const merge_pull_request_by_squash: struct {
    action_name: []const u8 = "MergePullRequestBySquash",
    Request: type = struct {
        pull_request_id: []const u8,
        repository_name: []const u8,
        source_commit_id: ?[]const u8 = null,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,
        author_name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        keep_empty_folders: ?bool = null,
        conflict_resolution: ?ConflictResolution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .repository_name = "repositoryName",
                .source_commit_id = "sourceCommitId",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
                .commit_message = "commitMessage",
                .author_name = "authorName",
                .email = "email",
                .keep_empty_folders = "keepEmptyFolders",
                .conflict_resolution = "conflictResolution",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_pull_request_by_squash) } {
            return .{ .service_metadata = service_metadata, .action = merge_pull_request_by_squash };
        }
    },
    Response: type = struct {
        pull_request: ?PullRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request = "pullRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitMessageLengthExceeded,
        ConcurrentReferenceUpdate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileContentSizeLimitExceeded,
        FolderContentSizeLimitExceeded,
        InvalidCommitId,
        InvalidConflictDetailLevel,
        InvalidConflictResolution,
        InvalidConflictResolutionStrategy,
        InvalidEmail,
        InvalidFileMode,
        InvalidPath,
        InvalidPullRequestId,
        InvalidReplacementContent,
        InvalidReplacementType,
        InvalidRepositoryName,
        ManualMergeRequired,
        MaximumConflictResolutionEntriesExceeded,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        MultipleConflictResolutionEntries,
        NameLengthExceeded,
        PathRequired,
        PullRequestAlreadyClosed,
        PullRequestApprovalRulesNotSatisfied,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        ReplacementContentRequired,
        ReplacementTypeRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        RepositoryNotAssociatedWithPullRequest,
        TipOfSourceReferenceIsDifferent,
        TipsDivergenceExceeded,
    },
} = .{};
pub const merge_pull_request_by_three_way: struct {
    action_name: []const u8 = "MergePullRequestByThreeWay",
    Request: type = struct {
        pull_request_id: []const u8,
        repository_name: []const u8,
        source_commit_id: ?[]const u8 = null,
        conflict_detail_level: ?[]const u8 = null,
        conflict_resolution_strategy: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,
        author_name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        keep_empty_folders: ?bool = null,
        conflict_resolution: ?ConflictResolution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .repository_name = "repositoryName",
                .source_commit_id = "sourceCommitId",
                .conflict_detail_level = "conflictDetailLevel",
                .conflict_resolution_strategy = "conflictResolutionStrategy",
                .commit_message = "commitMessage",
                .author_name = "authorName",
                .email = "email",
                .keep_empty_folders = "keepEmptyFolders",
                .conflict_resolution = "conflictResolution",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_pull_request_by_three_way) } {
            return .{ .service_metadata = service_metadata, .action = merge_pull_request_by_three_way };
        }
    },
    Response: type = struct {
        pull_request: ?PullRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request = "pullRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommitMessageLengthExceeded,
        ConcurrentReferenceUpdate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileContentSizeLimitExceeded,
        FolderContentSizeLimitExceeded,
        InvalidCommitId,
        InvalidConflictDetailLevel,
        InvalidConflictResolution,
        InvalidConflictResolutionStrategy,
        InvalidEmail,
        InvalidFileMode,
        InvalidPath,
        InvalidPullRequestId,
        InvalidReplacementContent,
        InvalidReplacementType,
        InvalidRepositoryName,
        ManualMergeRequired,
        MaximumConflictResolutionEntriesExceeded,
        MaximumFileContentToLoadExceeded,
        MaximumItemsToCompareExceeded,
        MultipleConflictResolutionEntries,
        NameLengthExceeded,
        PathRequired,
        PullRequestAlreadyClosed,
        PullRequestApprovalRulesNotSatisfied,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        ReplacementContentRequired,
        ReplacementTypeRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        RepositoryNotAssociatedWithPullRequest,
        TipOfSourceReferenceIsDifferent,
        TipsDivergenceExceeded,
    },
} = .{};
pub const override_pull_request_approval_rules: struct {
    action_name: []const u8 = "OverridePullRequestApprovalRules",
    Request: type = struct {
        pull_request_id: []const u8,
        revision_id: []const u8,
        override_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .revision_id = "revisionId",
                .override_status = "overrideStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(override_pull_request_approval_rules) } {
            return .{ .service_metadata = service_metadata, .action = override_pull_request_approval_rules };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidOverrideStatus,
        InvalidPullRequestId,
        InvalidRevisionId,
        OverrideAlreadySet,
        OverrideStatusRequired,
        PullRequestAlreadyClosed,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        RevisionIdRequired,
        RevisionNotCurrent,
    },
} = .{};
pub const post_comment_for_compared_commit: struct {
    action_name: []const u8 = "PostCommentForComparedCommit",
    Request: type = struct {
        repository_name: []const u8,
        before_commit_id: ?[]const u8 = null,
        after_commit_id: []const u8,
        location: ?Location = null,
        content: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .before_commit_id = "beforeCommitId",
                .after_commit_id = "afterCommitId",
                .location = "location",
                .content = "content",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(post_comment_for_compared_commit) } {
            return .{ .service_metadata = service_metadata, .action = post_comment_for_compared_commit };
        }
    },
    Response: type = struct {
        repository_name: ?[]const u8 = null,
        before_commit_id: ?[]const u8 = null,
        after_commit_id: ?[]const u8 = null,
        before_blob_id: ?[]const u8 = null,
        after_blob_id: ?[]const u8 = null,
        location: ?Location = null,
        comment: ?Comment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .before_commit_id = "beforeCommitId",
                .after_commit_id = "afterCommitId",
                .before_blob_id = "beforeBlobId",
                .after_blob_id = "afterBlobId",
                .location = "location",
                .comment = "comment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BeforeCommitIdAndAfterCommitIdAreSame,
        ClientRequestTokenRequired,
        CommentContentRequired,
        CommentContentSizeLimitExceeded,
        CommitDoesNotExist,
        CommitIdRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        IdempotencyParameterMismatch,
        InvalidClientRequestToken,
        InvalidCommitId,
        InvalidFileLocation,
        InvalidFilePosition,
        InvalidPath,
        InvalidRelativeFileVersionEnum,
        InvalidRepositoryName,
        PathDoesNotExist,
        PathRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const post_comment_for_pull_request: struct {
    action_name: []const u8 = "PostCommentForPullRequest",
    Request: type = struct {
        pull_request_id: []const u8,
        repository_name: []const u8,
        before_commit_id: []const u8,
        after_commit_id: []const u8,
        location: ?Location = null,
        content: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .repository_name = "repositoryName",
                .before_commit_id = "beforeCommitId",
                .after_commit_id = "afterCommitId",
                .location = "location",
                .content = "content",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(post_comment_for_pull_request) } {
            return .{ .service_metadata = service_metadata, .action = post_comment_for_pull_request };
        }
    },
    Response: type = struct {
        repository_name: ?[]const u8 = null,
        pull_request_id: ?[]const u8 = null,
        before_commit_id: ?[]const u8 = null,
        after_commit_id: ?[]const u8 = null,
        before_blob_id: ?[]const u8 = null,
        after_blob_id: ?[]const u8 = null,
        location: ?Location = null,
        comment: ?Comment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .pull_request_id = "pullRequestId",
                .before_commit_id = "beforeCommitId",
                .after_commit_id = "afterCommitId",
                .before_blob_id = "beforeBlobId",
                .after_blob_id = "afterBlobId",
                .location = "location",
                .comment = "comment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BeforeCommitIdAndAfterCommitIdAreSame,
        ClientRequestTokenRequired,
        CommentContentRequired,
        CommentContentSizeLimitExceeded,
        CommitDoesNotExist,
        CommitIdRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        IdempotencyParameterMismatch,
        InvalidClientRequestToken,
        InvalidCommitId,
        InvalidFileLocation,
        InvalidFilePosition,
        InvalidPath,
        InvalidPullRequestId,
        InvalidRelativeFileVersionEnum,
        InvalidRepositoryName,
        PathDoesNotExist,
        PathRequired,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        RepositoryNotAssociatedWithPullRequest,
    },
} = .{};
pub const post_comment_reply: struct {
    action_name: []const u8 = "PostCommentReply",
    Request: type = struct {
        in_reply_to: []const u8,
        client_request_token: ?[]const u8 = null,
        content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .in_reply_to = "inReplyTo",
                .client_request_token = "clientRequestToken",
                .content = "content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(post_comment_reply) } {
            return .{ .service_metadata = service_metadata, .action = post_comment_reply };
        }
    },
    Response: type = struct {
        comment: ?Comment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment = "comment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientRequestTokenRequired,
        CommentContentRequired,
        CommentContentSizeLimitExceeded,
        CommentDoesNotExist,
        CommentIdRequired,
        IdempotencyParameterMismatch,
        InvalidClientRequestToken,
        InvalidCommentId,
    },
} = .{};
pub const put_comment_reaction: struct {
    action_name: []const u8 = "PutCommentReaction",
    Request: type = struct {
        comment_id: []const u8,
        reaction_value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment_id = "commentId",
                .reaction_value = "reactionValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_comment_reaction) } {
            return .{ .service_metadata = service_metadata, .action = put_comment_reaction };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CommentDeleted,
        CommentDoesNotExist,
        CommentIdRequired,
        InvalidCommentId,
        InvalidReactionValue,
        ReactionLimitExceeded,
        ReactionValueRequired,
    },
} = .{};
pub const put_file: struct {
    action_name: []const u8 = "PutFile",
    Request: type = struct {
        repository_name: []const u8,
        branch_name: []const u8,
        file_content: []const u8,
        file_path: []const u8,
        file_mode: ?[]const u8 = null,
        parent_commit_id: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,
        name: ?[]const u8 = null,
        email: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .branch_name = "branchName",
                .file_content = "fileContent",
                .file_path = "filePath",
                .file_mode = "fileMode",
                .parent_commit_id = "parentCommitId",
                .commit_message = "commitMessage",
                .name = "name",
                .email = "email",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_file) } {
            return .{ .service_metadata = service_metadata, .action = put_file };
        }
    },
    Response: type = struct {
        commit_id: []const u8,
        blob_id: []const u8,
        tree_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commit_id = "commitId",
                .blob_id = "blobId",
                .tree_id = "treeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BranchDoesNotExist,
        BranchNameIsTagName,
        BranchNameRequired,
        CommitMessageLengthExceeded,
        DirectoryNameConflictsWithFileName,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        FileContentRequired,
        FileContentSizeLimitExceeded,
        FileNameConflictsWithDirectoryName,
        FilePathConflictsWithSubmodulePath,
        FolderContentSizeLimitExceeded,
        InvalidBranchName,
        InvalidDeletionParameter,
        InvalidEmail,
        InvalidFileMode,
        InvalidParentCommitId,
        InvalidPath,
        InvalidRepositoryName,
        NameLengthExceeded,
        ParentCommitDoesNotExist,
        ParentCommitIdOutdated,
        ParentCommitIdRequired,
        PathRequired,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        SameFileContent,
    },
} = .{};
pub const put_repository_triggers: struct {
    action_name: []const u8 = "PutRepositoryTriggers",
    Request: type = struct {
        repository_name: []const u8,
        triggers: []RepositoryTrigger,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .triggers = "triggers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_repository_triggers) } {
            return .{ .service_metadata = service_metadata, .action = put_repository_triggers };
        }
    },
    Response: type = struct {
        configuration_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_id = "configurationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryName,
        InvalidRepositoryTriggerBranchName,
        InvalidRepositoryTriggerCustomData,
        InvalidRepositoryTriggerDestinationArn,
        InvalidRepositoryTriggerEvents,
        InvalidRepositoryTriggerName,
        InvalidRepositoryTriggerRegion,
        MaximumBranchesExceeded,
        MaximumRepositoryTriggersExceeded,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        RepositoryTriggerBranchNameListRequired,
        RepositoryTriggerDestinationArnRequired,
        RepositoryTriggerEventsListRequired,
        RepositoryTriggerNameRequired,
        RepositoryTriggersListRequired,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRepositoryName,
        InvalidResourceArn,
        InvalidSystemTagUsage,
        InvalidTagsMap,
        RepositoryDoesNotExist,
        ResourceArnRequired,
        TagPolicy,
        TagsMapRequired,
        TooManyTags,
    },
} = .{};
pub const test_repository_triggers: struct {
    action_name: []const u8 = "TestRepositoryTriggers",
    Request: type = struct {
        repository_name: []const u8,
        triggers: []RepositoryTrigger,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .triggers = "triggers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_repository_triggers) } {
            return .{ .service_metadata = service_metadata, .action = test_repository_triggers };
        }
    },
    Response: type = struct {
        successful_executions: ?[][]const u8 = null,
        failed_executions: ?[]struct {
            trigger: ?[]const u8 = null,
            failure_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trigger = "trigger",
                    .failure_message = "failureMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_executions = "successfulExecutions",
                .failed_executions = "failedExecutions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryName,
        InvalidRepositoryTriggerBranchName,
        InvalidRepositoryTriggerCustomData,
        InvalidRepositoryTriggerDestinationArn,
        InvalidRepositoryTriggerEvents,
        InvalidRepositoryTriggerName,
        InvalidRepositoryTriggerRegion,
        MaximumBranchesExceeded,
        MaximumRepositoryTriggersExceeded,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
        RepositoryTriggerBranchNameListRequired,
        RepositoryTriggerDestinationArnRequired,
        RepositoryTriggerEventsListRequired,
        RepositoryTriggerNameRequired,
        RepositoryTriggersListRequired,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRepositoryName,
        InvalidResourceArn,
        InvalidSystemTagUsage,
        InvalidTagKeysList,
        RepositoryDoesNotExist,
        ResourceArnRequired,
        TagKeysListRequired,
        TagPolicy,
        TooManyTags,
    },
} = .{};
pub const update_approval_rule_template_content: struct {
    action_name: []const u8 = "UpdateApprovalRuleTemplateContent",
    Request: type = struct {
        approval_rule_template_name: []const u8,
        new_rule_content: []const u8,
        existing_rule_content_sha256: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
                .new_rule_content = "newRuleContent",
                .existing_rule_content_sha256 = "existingRuleContentSha256",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_approval_rule_template_content) } {
            return .{ .service_metadata = service_metadata, .action = update_approval_rule_template_content };
        }
    },
    Response: type = struct {
        approval_rule_template: ApprovalRuleTemplate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template = "approvalRuleTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateContentRequired,
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameRequired,
        InvalidApprovalRuleTemplateContent,
        InvalidApprovalRuleTemplateName,
        InvalidRuleContentSha256,
    },
} = .{};
pub const update_approval_rule_template_description: struct {
    action_name: []const u8 = "UpdateApprovalRuleTemplateDescription",
    Request: type = struct {
        approval_rule_template_name: []const u8,
        approval_rule_template_description: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template_name = "approvalRuleTemplateName",
                .approval_rule_template_description = "approvalRuleTemplateDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_approval_rule_template_description) } {
            return .{ .service_metadata = service_metadata, .action = update_approval_rule_template_description };
        }
    },
    Response: type = struct {
        approval_rule_template: ApprovalRuleTemplate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template = "approvalRuleTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameRequired,
        InvalidApprovalRuleTemplateDescription,
        InvalidApprovalRuleTemplateName,
    },
} = .{};
pub const update_approval_rule_template_name: struct {
    action_name: []const u8 = "UpdateApprovalRuleTemplateName",
    Request: type = struct {
        old_approval_rule_template_name: []const u8,
        new_approval_rule_template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .old_approval_rule_template_name = "oldApprovalRuleTemplateName",
                .new_approval_rule_template_name = "newApprovalRuleTemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_approval_rule_template_name) } {
            return .{ .service_metadata = service_metadata, .action = update_approval_rule_template_name };
        }
    },
    Response: type = struct {
        approval_rule_template: ApprovalRuleTemplate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule_template = "approvalRuleTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleTemplateDoesNotExist,
        ApprovalRuleTemplateNameAlreadyExists,
        ApprovalRuleTemplateNameRequired,
        InvalidApprovalRuleTemplateName,
    },
} = .{};
pub const update_comment: struct {
    action_name: []const u8 = "UpdateComment",
    Request: type = struct {
        comment_id: []const u8,
        content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment_id = "commentId",
                .content = "content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_comment) } {
            return .{ .service_metadata = service_metadata, .action = update_comment };
        }
    },
    Response: type = struct {
        comment: ?Comment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment = "comment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CommentContentRequired,
        CommentContentSizeLimitExceeded,
        CommentDeleted,
        CommentDoesNotExist,
        CommentIdRequired,
        CommentNotCreatedByCaller,
        InvalidCommentId,
    },
} = .{};
pub const update_default_branch: struct {
    action_name: []const u8 = "UpdateDefaultBranch",
    Request: type = struct {
        repository_name: []const u8,
        default_branch_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .default_branch_name = "defaultBranchName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_default_branch) } {
            return .{ .service_metadata = service_metadata, .action = update_default_branch };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BranchDoesNotExist,
        BranchNameRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidBranchName,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const update_pull_request_approval_rule_content: struct {
    action_name: []const u8 = "UpdatePullRequestApprovalRuleContent",
    Request: type = struct {
        pull_request_id: []const u8,
        approval_rule_name: []const u8,
        existing_rule_content_sha256: ?[]const u8 = null,
        new_rule_content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .approval_rule_name = "approvalRuleName",
                .existing_rule_content_sha256 = "existingRuleContentSha256",
                .new_rule_content = "newRuleContent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pull_request_approval_rule_content) } {
            return .{ .service_metadata = service_metadata, .action = update_pull_request_approval_rule_content };
        }
    },
    Response: type = struct {
        approval_rule: ApprovalRule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approval_rule = "approvalRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApprovalRuleContentRequired,
        ApprovalRuleDoesNotExist,
        ApprovalRuleNameRequired,
        CannotModifyApprovalRuleFromTemplate,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalRuleContent,
        InvalidApprovalRuleName,
        InvalidPullRequestId,
        InvalidRuleContentSha256,
        PullRequestAlreadyClosed,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
    },
} = .{};
pub const update_pull_request_approval_state: struct {
    action_name: []const u8 = "UpdatePullRequestApprovalState",
    Request: type = struct {
        pull_request_id: []const u8,
        revision_id: []const u8,
        approval_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .revision_id = "revisionId",
                .approval_state = "approvalState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pull_request_approval_state) } {
            return .{ .service_metadata = service_metadata, .action = update_pull_request_approval_state };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ApprovalStateRequired,
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidApprovalState,
        InvalidPullRequestId,
        InvalidRevisionId,
        MaximumNumberOfApprovalsExceeded,
        PullRequestAlreadyClosed,
        PullRequestCannotBeApprovedByAuthor,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        RevisionIdRequired,
        RevisionNotCurrent,
    },
} = .{};
pub const update_pull_request_description: struct {
    action_name: []const u8 = "UpdatePullRequestDescription",
    Request: type = struct {
        pull_request_id: []const u8,
        description: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pull_request_description) } {
            return .{ .service_metadata = service_metadata, .action = update_pull_request_description };
        }
    },
    Response: type = struct {
        pull_request: PullRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request = "pullRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDescription,
        InvalidPullRequestId,
        PullRequestAlreadyClosed,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
    },
} = .{};
pub const update_pull_request_status: struct {
    action_name: []const u8 = "UpdatePullRequestStatus",
    Request: type = struct {
        pull_request_id: []const u8,
        pull_request_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .pull_request_status = "pullRequestStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pull_request_status) } {
            return .{ .service_metadata = service_metadata, .action = update_pull_request_status };
        }
    },
    Response: type = struct {
        pull_request: PullRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request = "pullRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidPullRequestId,
        InvalidPullRequestStatus,
        InvalidPullRequestStatusUpdate,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        PullRequestStatusRequired,
    },
} = .{};
pub const update_pull_request_title: struct {
    action_name: []const u8 = "UpdatePullRequestTitle",
    Request: type = struct {
        pull_request_id: []const u8,
        title: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request_id = "pullRequestId",
                .title = "title",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pull_request_title) } {
            return .{ .service_metadata = service_metadata, .action = update_pull_request_title };
        }
    },
    Response: type = struct {
        pull_request: PullRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pull_request = "pullRequest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPullRequestId,
        InvalidTitle,
        PullRequestAlreadyClosed,
        PullRequestDoesNotExist,
        PullRequestIdRequired,
        TitleRequired,
    },
} = .{};
pub const update_repository_description: struct {
    action_name: []const u8 = "UpdateRepositoryDescription",
    Request: type = struct {
        repository_name: []const u8,
        repository_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .repository_description = "repositoryDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_repository_description) } {
            return .{ .service_metadata = service_metadata, .action = update_repository_description };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyNotFound,
        EncryptionKeyUnavailable,
        InvalidRepositoryDescription,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const update_repository_encryption_key: struct {
    action_name: []const u8 = "UpdateRepositoryEncryptionKey",
    Request: type = struct {
        repository_name: []const u8,
        kms_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_repository_encryption_key) } {
            return .{ .service_metadata = service_metadata, .action = update_repository_encryption_key };
        }
    },
    Response: type = struct {
        repository_id: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        original_kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_id = "repositoryId",
                .kms_key_id = "kmsKeyId",
                .original_kms_key_id = "originalKmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EncryptionIntegrityChecksFailed,
        EncryptionKeyAccessDenied,
        EncryptionKeyDisabled,
        EncryptionKeyInvalidId,
        EncryptionKeyInvalidUsage,
        EncryptionKeyNotFound,
        EncryptionKeyRequired,
        EncryptionKeyUnavailable,
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameRequired,
    },
} = .{};
pub const update_repository_name: struct {
    action_name: []const u8 = "UpdateRepositoryName",
    Request: type = struct {
        old_name: []const u8,
        new_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .old_name = "oldName",
                .new_name = "newName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_repository_name) } {
            return .{ .service_metadata = service_metadata, .action = update_repository_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRepositoryName,
        RepositoryDoesNotExist,
        RepositoryNameExists,
        RepositoryNameRequired,
    },
} = .{};

pub const PullRequest = struct {
    pull_request_id: ?[]const u8 = null,
    title: ?[]const u8 = null,
    description: ?[]const u8 = null,
    last_activity_date: ?i64 = null,
    creation_date: ?i64 = null,
    pull_request_status: ?[]const u8 = null,
    author_arn: ?[]const u8 = null,
    pull_request_targets: ?[]PullRequestTarget = null,
    client_request_token: ?[]const u8 = null,
    revision_id: ?[]const u8 = null,
    approval_rules: ?[]ApprovalRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pull_request_id = "pullRequestId",
            .title = "title",
            .description = "description",
            .last_activity_date = "lastActivityDate",
            .creation_date = "creationDate",
            .pull_request_status = "pullRequestStatus",
            .author_arn = "authorArn",
            .pull_request_targets = "pullRequestTargets",
            .client_request_token = "clientRequestToken",
            .revision_id = "revisionId",
            .approval_rules = "approvalRules",
        };
        return @field(mappings, field_name);
    }
};

pub const ApprovalRule = struct {
    approval_rule_id: ?[]const u8 = null,
    approval_rule_name: ?[]const u8 = null,
    approval_rule_content: ?[]const u8 = null,
    rule_content_sha256: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    creation_date: ?i64 = null,
    last_modified_user: ?[]const u8 = null,
    origin_approval_rule_template: ?OriginApprovalRuleTemplate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .approval_rule_id = "approvalRuleId",
            .approval_rule_name = "approvalRuleName",
            .approval_rule_content = "approvalRuleContent",
            .rule_content_sha256 = "ruleContentSha256",
            .last_modified_date = "lastModifiedDate",
            .creation_date = "creationDate",
            .last_modified_user = "lastModifiedUser",
            .origin_approval_rule_template = "originApprovalRuleTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginApprovalRuleTemplate = struct {
    approval_rule_template_id: ?[]const u8 = null,
    approval_rule_template_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .approval_rule_template_id = "approvalRuleTemplateId",
            .approval_rule_template_name = "approvalRuleTemplateName",
        };
        return @field(mappings, field_name);
    }
};

pub const PullRequestTarget = struct {
    repository_name: ?[]const u8 = null,
    source_reference: ?[]const u8 = null,
    destination_reference: ?[]const u8 = null,
    destination_commit: ?[]const u8 = null,
    source_commit: ?[]const u8 = null,
    merge_base: ?[]const u8 = null,
    merge_metadata: ?MergeMetadata = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_name = "repositoryName",
            .source_reference = "sourceReference",
            .destination_reference = "destinationReference",
            .destination_commit = "destinationCommit",
            .source_commit = "sourceCommit",
            .merge_base = "mergeBase",
            .merge_metadata = "mergeMetadata",
        };
        return @field(mappings, field_name);
    }
};

pub const MergeMetadata = struct {
    is_merged: ?bool = null,
    merged_by: ?[]const u8 = null,
    merge_commit_id: ?[]const u8 = null,
    merge_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_merged = "isMerged",
            .merged_by = "mergedBy",
            .merge_commit_id = "mergeCommitId",
            .merge_option = "mergeOption",
        };
        return @field(mappings, field_name);
    }
};

pub const Comment = struct {
    comment_id: ?[]const u8 = null,
    content: ?[]const u8 = null,
    in_reply_to: ?[]const u8 = null,
    creation_date: ?i64 = null,
    last_modified_date: ?i64 = null,
    author_arn: ?[]const u8 = null,
    deleted: ?bool = null,
    client_request_token: ?[]const u8 = null,
    caller_reactions: ?[][]const u8 = null,
    reaction_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment_id = "commentId",
            .content = "content",
            .in_reply_to = "inReplyTo",
            .creation_date = "creationDate",
            .last_modified_date = "lastModifiedDate",
            .author_arn = "authorArn",
            .deleted = "deleted",
            .client_request_token = "clientRequestToken",
            .caller_reactions = "callerReactions",
            .reaction_counts = "reactionCounts",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "reaction_counts", field_name))
            return try serializeMap(self.reaction_counts, self.fieldNameFor("reaction_counts"), options, out_stream);
        return false;
    }
};

pub const ApprovalRuleTemplate = struct {
    approval_rule_template_id: ?[]const u8 = null,
    approval_rule_template_name: ?[]const u8 = null,
    approval_rule_template_description: ?[]const u8 = null,
    approval_rule_template_content: ?[]const u8 = null,
    rule_content_sha256: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    creation_date: ?i64 = null,
    last_modified_user: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .approval_rule_template_id = "approvalRuleTemplateId",
            .approval_rule_template_name = "approvalRuleTemplateName",
            .approval_rule_template_description = "approvalRuleTemplateDescription",
            .approval_rule_template_content = "approvalRuleTemplateContent",
            .rule_content_sha256 = "ruleContentSha256",
            .last_modified_date = "lastModifiedDate",
            .creation_date = "creationDate",
            .last_modified_user = "lastModifiedUser",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryTrigger = struct {
    name: []const u8,
    destination_arn: []const u8,
    custom_data: ?[]const u8 = null,
    branches: ?[][]const u8 = null,
    events: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .destination_arn = "destinationArn",
            .custom_data = "customData",
            .branches = "branches",
            .events = "events",
        };
        return @field(mappings, field_name);
    }
};

pub const Location = struct {
    file_path: ?[]const u8 = null,
    file_position: ?i64 = null,
    relative_file_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_path = "filePath",
            .file_position = "filePosition",
            .relative_file_version = "relativeFileVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ConflictResolution = struct {
    replace_contents: ?[]ReplaceContentEntry = null,
    delete_files: ?[]DeleteFileEntry = null,
    set_file_modes: ?[]SetFileModeEntry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replace_contents = "replaceContents",
            .delete_files = "deleteFiles",
            .set_file_modes = "setFileModes",
        };
        return @field(mappings, field_name);
    }
};

pub const SetFileModeEntry = struct {
    file_path: []const u8,
    file_mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_path = "filePath",
            .file_mode = "fileMode",
        };
        return @field(mappings, field_name);
    }
};

pub const DeleteFileEntry = struct {
    file_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_path = "filePath",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplaceContentEntry = struct {
    file_path: []const u8,
    replacement_type: []const u8,
    content: ?[]const u8 = null,
    file_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_path = "filePath",
            .replacement_type = "replacementType",
            .content = "content",
            .file_mode = "fileMode",
        };
        return @field(mappings, field_name);
    }
};

pub const Commit = struct {
    commit_id: ?[]const u8 = null,
    tree_id: ?[]const u8 = null,
    parents: ?[][]const u8 = null,
    message: ?[]const u8 = null,
    author: ?UserInfo = null,
    committer: ?UserInfo = null,
    additional_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .commit_id = "commitId",
            .tree_id = "treeId",
            .parents = "parents",
            .message = "message",
            .author = "author",
            .committer = "committer",
            .additional_data = "additionalData",
        };
        return @field(mappings, field_name);
    }
};

pub const UserInfo = struct {
    name: ?[]const u8 = null,
    email: ?[]const u8 = null,
    date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .email = "email",
            .date = "date",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryMetadata = struct {
    account_id: ?[]const u8 = null,
    repository_id: ?[]const u8 = null,
    repository_name: ?[]const u8 = null,
    repository_description: ?[]const u8 = null,
    default_branch: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    creation_date: ?i64 = null,
    clone_url_http: ?[]const u8 = null,
    clone_url_ssh: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .repository_id = "repositoryId",
            .repository_name = "repositoryName",
            .repository_description = "repositoryDescription",
            .default_branch = "defaultBranch",
            .last_modified_date = "lastModifiedDate",
            .creation_date = "creationDate",
            .clone_url_http = "cloneUrlHttp",
            .clone_url_ssh = "cloneUrlSsh",
            .arn = "Arn",
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ConflictMetadata = struct {
    file_path: ?[]const u8 = null,
    file_sizes: ?FileSizes = null,
    file_modes: ?FileModes = null,
    object_types: ?ObjectTypes = null,
    number_of_conflicts: ?i64 = null,
    is_binary_file: ?IsBinaryFile = null,
    content_conflict: ?bool = null,
    file_mode_conflict: ?bool = null,
    object_type_conflict: ?bool = null,
    merge_operations: ?MergeOperations = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_path = "filePath",
            .file_sizes = "fileSizes",
            .file_modes = "fileModes",
            .object_types = "objectTypes",
            .number_of_conflicts = "numberOfConflicts",
            .is_binary_file = "isBinaryFile",
            .content_conflict = "contentConflict",
            .file_mode_conflict = "fileModeConflict",
            .object_type_conflict = "objectTypeConflict",
            .merge_operations = "mergeOperations",
        };
        return @field(mappings, field_name);
    }
};

pub const MergeOperations = struct {
    source: ?[]const u8 = null,
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const IsBinaryFile = struct {
    source: ?bool = null,
    destination: ?bool = null,
    base: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .destination = "destination",
            .base = "base",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectTypes = struct {
    source: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    base: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .destination = "destination",
            .base = "base",
        };
        return @field(mappings, field_name);
    }
};

pub const FileModes = struct {
    source: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    base: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .destination = "destination",
            .base = "base",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSizes = struct {
    source: ?i64 = null,
    destination: ?i64 = null,
    base: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .destination = "destination",
            .base = "base",
        };
        return @field(mappings, field_name);
    }
};

pub const BlobMetadata = struct {
    blob_id: ?[]const u8 = null,
    path: ?[]const u8 = null,
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blob_id = "blobId",
            .path = "path",
            .mode = "mode",
        };
        return @field(mappings, field_name);
    }
};

pub const BranchInfo = struct {
    branch_name: ?[]const u8 = null,
    commit_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .branch_name = "branchName",
            .commit_id = "commitId",
        };
        return @field(mappings, field_name);
    }
};

pub const MergeHunk = struct {
    is_conflict: ?bool = null,
    source: ?MergeHunkDetail = null,
    destination: ?MergeHunkDetail = null,
    base: ?MergeHunkDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_conflict = "isConflict",
            .source = "source",
            .destination = "destination",
            .base = "base",
        };
        return @field(mappings, field_name);
    }
};

pub const MergeHunkDetail = struct {
    start_line: ?i64 = null,
    end_line: ?i64 = null,
    hunk_content: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_line = "startLine",
            .end_line = "endLine",
            .hunk_content = "hunkContent",
        };
        return @field(mappings, field_name);
    }
};

pub const FileMetadata = struct {
    absolute_path: ?[]const u8 = null,
    blob_id: ?[]const u8 = null,
    file_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .absolute_path = "absolutePath",
            .blob_id = "blobId",
            .file_mode = "fileMode",
        };
        return @field(mappings, field_name);
    }
};
