const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-09-19";
pub const sdk_id: []const u8 = "CodeGuru Reviewer";
pub const arn_namespace: ?[]const u8 = "codeguru-reviewer";
pub const endpoint_prefix: []const u8 = "codeguru-reviewer";
pub const sigv4_name: []const u8 = "codeguru-reviewer";
pub const name: []const u8 = "AWSGuruFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-09-19",
    sdk_id: []const u8 = "CodeGuru Reviewer",
    arn_namespace: ?[]const u8 = "codeguru-reviewer",
    endpoint_prefix: []const u8 = "codeguru-reviewer",
    sigv4_name: []const u8 = "codeguru-reviewer",
    name: []const u8 = "AWSGuruFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_repository: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateRepository",
    Request: type = struct {
        repository: struct {
            code_commit: ?struct {
                name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            bitbucket: ?ThirdPartySourceRepository = null,
            git_hub_enterprise_server: ?ThirdPartySourceRepository = null,
            s3_bucket: ?struct {
                name: []const u8,
                bucket_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .bucket_name = "BucketName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code_commit = "CodeCommit",
                    .bitbucket = "Bitbucket",
                    .git_hub_enterprise_server = "GitHubEnterpriseServer",
                    .s3_bucket = "S3Bucket",
                };
                return @field(mappings, field_name);
            }
        },
        client_request_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        kms_key_details: ?KMSKeyDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "Repository",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .kms_key_details = "KMSKeyDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_repository) } {
            return .{ .service_metadata = service_metadata, .action = associate_repository };
        }
    },
    Response: type = struct {
        repository_association: ?RepositoryAssociation = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_association = "RepositoryAssociation",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_code_review: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/codereviews",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCodeReview",
    Request: type = struct {
        name: []const u8,
        repository_association_arn: []const u8,
        type: struct {
            repository_analysis: struct {
                repository_head: ?RepositoryHeadSourceCodeType = null,
                source_code_type: ?SourceCodeType = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .repository_head = "RepositoryHead",
                        .source_code_type = "SourceCodeType",
                    };
                    return @field(mappings, field_name);
                }
            },
            analysis_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .repository_analysis = "RepositoryAnalysis",
                    .analysis_types = "AnalysisTypes",
                };
                return @field(mappings, field_name);
            }
        },
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .repository_association_arn = "RepositoryAssociationArn",
                .type = "Type",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_code_review) } {
            return .{ .service_metadata = service_metadata, .action = create_code_review };
        }
    },
    Response: type = struct {
        code_review: ?CodeReview = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_review = "CodeReview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_code_review: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/codereviews/{CodeReviewArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCodeReview",
    Request: type = struct {
        code_review_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_review_arn = "CodeReviewArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_code_review) } {
            return .{ .service_metadata = service_metadata, .action = describe_code_review };
        }
    },
    Response: type = struct {
        code_review: ?CodeReview = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_review = "CodeReview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_recommendation_feedback: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/feedback/{CodeReviewArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRecommendationFeedback",
    Request: type = struct {
        code_review_arn: []const u8,
        recommendation_id: []const u8,
        user_id: ?[]const u8 = null,

        pub const http_query = .{
            .recommendation_id = "RecommendationId",
            .user_id = "UserId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_review_arn = "CodeReviewArn",
                .recommendation_id = "RecommendationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recommendation_feedback) } {
            return .{ .service_metadata = service_metadata, .action = describe_recommendation_feedback };
        }
    },
    Response: type = struct {
        recommendation_feedback: ?struct {
            code_review_arn: ?[]const u8 = null,
            recommendation_id: ?[]const u8 = null,
            reactions: ?[][]const u8 = null,
            user_id: ?[]const u8 = null,
            created_time_stamp: ?i64 = null,
            last_updated_time_stamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code_review_arn = "CodeReviewArn",
                    .recommendation_id = "RecommendationId",
                    .reactions = "Reactions",
                    .user_id = "UserId",
                    .created_time_stamp = "CreatedTimeStamp",
                    .last_updated_time_stamp = "LastUpdatedTimeStamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_feedback = "RecommendationFeedback",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_repository_association: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/associations/{AssociationArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRepositoryAssociation",
    Request: type = struct {
        association_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_arn = "AssociationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_repository_association) } {
            return .{ .service_metadata = service_metadata, .action = describe_repository_association };
        }
    },
    Response: type = struct {
        repository_association: ?RepositoryAssociation = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_association = "RepositoryAssociation",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_repository: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/associations/{AssociationArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateRepository",
    Request: type = struct {
        association_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_arn = "AssociationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_repository) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_repository };
        }
    },
    Response: type = struct {
        repository_association: ?RepositoryAssociation = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_association = "RepositoryAssociation",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_code_reviews: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/codereviews",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCodeReviews",
    Request: type = struct {
        provider_types: ?[][]const u8 = null,
        states: ?[][]const u8 = null,
        repository_names: ?[][]const u8 = null,
        type: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .provider_types = "ProviderTypes",
            .states = "States",
            .repository_names = "RepositoryNames",
            .type = "Type",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_types = "ProviderTypes",
                .states = "States",
                .repository_names = "RepositoryNames",
                .type = "Type",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_code_reviews) } {
            return .{ .service_metadata = service_metadata, .action = list_code_reviews };
        }
    },
    Response: type = struct {
        code_review_summaries: ?[]struct {
            name: ?[]const u8 = null,
            code_review_arn: ?[]const u8 = null,
            repository_name: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            provider_type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            created_time_stamp: ?i64 = null,
            last_updated_time_stamp: ?i64 = null,
            type: ?[]const u8 = null,
            pull_request_id: ?[]const u8 = null,
            metrics_summary: ?struct {
                metered_lines_of_code_count: ?i64 = null,
                suppressed_lines_of_code_count: ?i64 = null,
                findings_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metered_lines_of_code_count = "MeteredLinesOfCodeCount",
                        .suppressed_lines_of_code_count = "SuppressedLinesOfCodeCount",
                        .findings_count = "FindingsCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            source_code_type: ?SourceCodeType = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .code_review_arn = "CodeReviewArn",
                    .repository_name = "RepositoryName",
                    .owner = "Owner",
                    .provider_type = "ProviderType",
                    .state = "State",
                    .created_time_stamp = "CreatedTimeStamp",
                    .last_updated_time_stamp = "LastUpdatedTimeStamp",
                    .type = "Type",
                    .pull_request_id = "PullRequestId",
                    .metrics_summary = "MetricsSummary",
                    .source_code_type = "SourceCodeType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_review_summaries = "CodeReviewSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommendation_feedback: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/feedback/{CodeReviewArn}/RecommendationFeedback",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendationFeedback",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        code_review_arn: []const u8,
        user_ids: ?[][]const u8 = null,
        recommendation_ids: ?[][]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .user_ids = "UserIds",
            .recommendation_ids = "RecommendationIds",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .code_review_arn = "CodeReviewArn",
                .user_ids = "UserIds",
                .recommendation_ids = "RecommendationIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendation_feedback) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendation_feedback };
        }
    },
    Response: type = struct {
        recommendation_feedback_summaries: ?[]struct {
            recommendation_id: ?[]const u8 = null,
            reactions: ?[][]const u8 = null,
            user_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_id = "RecommendationId",
                    .reactions = "Reactions",
                    .user_id = "UserId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_feedback_summaries = "RecommendationFeedbackSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommendations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/codereviews/{CodeReviewArn}/Recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        code_review_arn: []const u8,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .code_review_arn = "CodeReviewArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendations };
        }
    },
    Response: type = struct {
        recommendation_summaries: ?[]struct {
            file_path: ?[]const u8 = null,
            recommendation_id: ?[]const u8 = null,
            start_line: ?i64 = null,
            end_line: ?i64 = null,
            description: ?[]const u8 = null,
            recommendation_category: ?[]const u8 = null,
            rule_metadata: ?struct {
                rule_id: ?[]const u8 = null,
                rule_name: ?[]const u8 = null,
                short_description: ?[]const u8 = null,
                long_description: ?[]const u8 = null,
                rule_tags: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rule_id = "RuleId",
                        .rule_name = "RuleName",
                        .short_description = "ShortDescription",
                        .long_description = "LongDescription",
                        .rule_tags = "RuleTags",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            severity: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_path = "FilePath",
                    .recommendation_id = "RecommendationId",
                    .start_line = "StartLine",
                    .end_line = "EndLine",
                    .description = "Description",
                    .recommendation_category = "RecommendationCategory",
                    .rule_metadata = "RuleMetadata",
                    .severity = "Severity",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_summaries = "RecommendationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_repository_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRepositoryAssociations",
    Request: type = struct {
        provider_types: ?[][]const u8 = null,
        states: ?[][]const u8 = null,
        names: ?[][]const u8 = null,
        owners: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .provider_types = "ProviderType",
            .states = "State",
            .names = "Name",
            .owners = "Owner",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_types = "ProviderTypes",
                .states = "States",
                .names = "Names",
                .owners = "Owners",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_repository_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_repository_associations };
        }
    },
    Response: type = struct {
        repository_association_summaries: ?[]struct {
            association_arn: ?[]const u8 = null,
            connection_arn: ?[]const u8 = null,
            last_updated_time_stamp: ?i64 = null,
            association_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            provider_type: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_arn = "AssociationArn",
                    .connection_arn = "ConnectionArn",
                    .last_updated_time_stamp = "LastUpdatedTimeStamp",
                    .association_id = "AssociationId",
                    .name = "Name",
                    .owner = "Owner",
                    .provider_type = "ProviderType",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_association_summaries = "RepositoryAssociationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_recommendation_feedback: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "PutRecommendationFeedback",
    Request: type = struct {
        code_review_arn: []const u8,
        recommendation_id: []const u8,
        reactions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_review_arn = "CodeReviewArn",
                .recommendation_id = "RecommendationId",
                .reactions = "Reactions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_recommendation_feedback) } {
            return .{ .service_metadata = service_metadata, .action = put_recommendation_feedback };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const SourceCodeType = struct {
    commit_diff: ?CommitDiffSourceCodeType = null,
    repository_head: ?RepositoryHeadSourceCodeType = null,
    branch_diff: ?BranchDiffSourceCodeType = null,
    s3_bucket_repository: ?S3BucketRepository = null,
    request_metadata: ?RequestMetadata = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .commit_diff = "CommitDiff",
            .repository_head = "RepositoryHead",
            .branch_diff = "BranchDiff",
            .s3_bucket_repository = "S3BucketRepository",
            .request_metadata = "RequestMetadata",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestMetadata = struct {
    request_id: ?[]const u8 = null,
    requester: ?[]const u8 = null,
    event_info: ?EventInfo = null,
    vendor_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .request_id = "RequestId",
            .requester = "Requester",
            .event_info = "EventInfo",
            .vendor_name = "VendorName",
        };
        return @field(mappings, field_name);
    }
};

pub const EventInfo = struct {
    name: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketRepository = struct {
    name: []const u8,
    details: ?S3RepositoryDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .details = "Details",
        };
        return @field(mappings, field_name);
    }
};

pub const S3RepositoryDetails = struct {
    bucket_name: ?[]const u8 = null,
    code_artifacts: ?CodeArtifacts = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .code_artifacts = "CodeArtifacts",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeArtifacts = struct {
    source_code_artifacts_object_key: []const u8,
    build_artifacts_object_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_code_artifacts_object_key = "SourceCodeArtifactsObjectKey",
            .build_artifacts_object_key = "BuildArtifactsObjectKey",
        };
        return @field(mappings, field_name);
    }
};

pub const BranchDiffSourceCodeType = struct {
    source_branch_name: []const u8,
    destination_branch_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_branch_name = "SourceBranchName",
            .destination_branch_name = "DestinationBranchName",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryHeadSourceCodeType = struct {
    branch_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .branch_name = "BranchName",
        };
        return @field(mappings, field_name);
    }
};

pub const CommitDiffSourceCodeType = struct {
    source_commit: ?[]const u8 = null,
    destination_commit: ?[]const u8 = null,
    merge_base_commit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_commit = "SourceCommit",
            .destination_commit = "DestinationCommit",
            .merge_base_commit = "MergeBaseCommit",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryAssociation = struct {
    association_id: ?[]const u8 = null,
    association_arn: ?[]const u8 = null,
    connection_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    provider_type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    state_reason: ?[]const u8 = null,
    last_updated_time_stamp: ?i64 = null,
    created_time_stamp: ?i64 = null,
    kms_key_details: ?KMSKeyDetails = null,
    s3_repository_details: ?S3RepositoryDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "AssociationId",
            .association_arn = "AssociationArn",
            .connection_arn = "ConnectionArn",
            .name = "Name",
            .owner = "Owner",
            .provider_type = "ProviderType",
            .state = "State",
            .state_reason = "StateReason",
            .last_updated_time_stamp = "LastUpdatedTimeStamp",
            .created_time_stamp = "CreatedTimeStamp",
            .kms_key_details = "KMSKeyDetails",
            .s3_repository_details = "S3RepositoryDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const KMSKeyDetails = struct {
    kms_key_id: ?[]const u8 = null,
    encryption_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "KMSKeyId",
            .encryption_option = "EncryptionOption",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeReview = struct {
    name: ?[]const u8 = null,
    code_review_arn: ?[]const u8 = null,
    repository_name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    provider_type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    state_reason: ?[]const u8 = null,
    created_time_stamp: ?i64 = null,
    last_updated_time_stamp: ?i64 = null,
    type: ?[]const u8 = null,
    pull_request_id: ?[]const u8 = null,
    source_code_type: ?SourceCodeType = null,
    association_arn: ?[]const u8 = null,
    metrics: ?Metrics = null,
    analysis_types: ?[][]const u8 = null,
    config_file_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .code_review_arn = "CodeReviewArn",
            .repository_name = "RepositoryName",
            .owner = "Owner",
            .provider_type = "ProviderType",
            .state = "State",
            .state_reason = "StateReason",
            .created_time_stamp = "CreatedTimeStamp",
            .last_updated_time_stamp = "LastUpdatedTimeStamp",
            .type = "Type",
            .pull_request_id = "PullRequestId",
            .source_code_type = "SourceCodeType",
            .association_arn = "AssociationArn",
            .metrics = "Metrics",
            .analysis_types = "AnalysisTypes",
            .config_file_state = "ConfigFileState",
        };
        return @field(mappings, field_name);
    }
};

pub const Metrics = struct {
    metered_lines_of_code_count: ?i64 = null,
    suppressed_lines_of_code_count: ?i64 = null,
    findings_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metered_lines_of_code_count = "MeteredLinesOfCodeCount",
            .suppressed_lines_of_code_count = "SuppressedLinesOfCodeCount",
            .findings_count = "FindingsCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ThirdPartySourceRepository = struct {
    name: []const u8,
    connection_arn: []const u8,
    owner: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .connection_arn = "ConnectionArn",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};
