const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "CodeGuru Security";
pub const arn_namespace: ?[]const u8 = "codeguru-security";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "codeguru-security";
pub const name: []const u8 = "AwsCodeGuruSecurity";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "CodeGuru Security",
    arn_namespace: ?[]const u8 = "codeguru-security",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "codeguru-security",
    name: []const u8 = "AwsCodeGuruSecurity",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/batchGetFindings",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetFindings",
    Request: type = struct {
        finding_identifiers: []struct {
            scan_name: []const u8,
            finding_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_name = "scanName",
                    .finding_id = "findingId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_identifiers = "findingIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_findings) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_findings };
        }
    },
    Response: type = struct {
        findings: []Finding,
        failed_findings: []struct {
            scan_name: []const u8,
            finding_id: []const u8,
            error_code: []const u8,
            message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_name = "scanName",
                    .finding_id = "findingId",
                    .error_code = "errorCode",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .failed_findings = "failedFindings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_scan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/scans",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateScan",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        resource_id: ResourceId,
        scan_name: []const u8,
        scan_type: ?[]const u8 = null,
        analysis_type: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .resource_id = "resourceId",
                .scan_name = "scanName",
                .scan_type = "scanType",
                .analysis_type = "analysisType",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_scan) } {
            return .{ .service_metadata = service_metadata, .action = create_scan };
        }
    },
    Response: type = struct {
        scan_name: []const u8,
        run_id: []const u8,
        resource_id: ResourceId,
        scan_state: []const u8,
        scan_name_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_name = "scanName",
                .run_id = "runId",
                .resource_id = "resourceId",
                .scan_state = "scanState",
                .scan_name_arn = "scanNameArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_upload_url: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/uploadUrl",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUploadUrl",
    Request: type = struct {
        scan_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_name = "scanName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_upload_url) } {
            return .{ .service_metadata = service_metadata, .action = create_upload_url };
        }
    },
    Response: type = struct {
        s3_url: []const u8,
        request_headers: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        code_artifact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_url = "s3Url",
                .request_headers = "requestHeaders",
                .code_artifact_id = "codeArtifactId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_headers", field_name))
                return try serializeMap(self.request_headers, self.fieldNameFor("request_headers"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_account_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accountConfiguration/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccountConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_account_configuration };
        }
    },
    Response: type = struct {
        encryption_config: EncryptionConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_config = "encryptionConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_findings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findings/{scanName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindings",
    Request: type = struct {
        scan_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .status = "status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_name = "scanName",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings) } {
            return .{ .service_metadata = service_metadata, .action = get_findings };
        }
    },
    Response: type = struct {
        findings: ?[]Finding = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_metrics_summary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/metrics/summary",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMetricsSummary",
    Request: type = struct {
        date: i64,

        pub const http_query = .{
            .date = "date",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .date = "date",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_metrics_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_metrics_summary };
        }
    },
    Response: type = struct {
        metrics_summary: ?struct {
            date: ?i64 = null,
            open_findings: ?FindingMetricsValuePerSeverity = null,
            categories_with_most_findings: ?[]struct {
                category_name: ?[]const u8 = null,
                finding_number: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .category_name = "categoryName",
                        .finding_number = "findingNumber",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            scans_with_most_open_findings: ?[]ScanNameWithFindingNum = null,
            scans_with_most_open_critical_findings: ?[]ScanNameWithFindingNum = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .date = "date",
                    .open_findings = "openFindings",
                    .categories_with_most_findings = "categoriesWithMostFindings",
                    .scans_with_most_open_findings = "scansWithMostOpenFindings",
                    .scans_with_most_open_critical_findings = "scansWithMostOpenCriticalFindings",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metrics_summary = "metricsSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_scan: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/scans/{scanName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetScan",
    Request: type = struct {
        scan_name: []const u8,
        run_id: ?[]const u8 = null,

        pub const http_query = .{
            .run_id = "runId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_name = "scanName",
                .run_id = "runId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_scan) } {
            return .{ .service_metadata = service_metadata, .action = get_scan };
        }
    },
    Response: type = struct {
        scan_name: []const u8,
        run_id: []const u8,
        scan_state: []const u8,
        created_at: i64,
        analysis_type: []const u8,
        updated_at: ?i64 = null,
        number_of_revisions: ?i64 = null,
        scan_name_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_name = "scanName",
                .run_id = "runId",
                .scan_state = "scanState",
                .created_at = "createdAt",
                .analysis_type = "analysisType",
                .updated_at = "updatedAt",
                .number_of_revisions = "numberOfRevisions",
                .scan_name_arn = "scanNameArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_findings_metrics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/metrics/findings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindingsMetrics",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        start_date: i64,
        end_date: i64,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .start_date = "startDate",
            .end_date = "endDate",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .start_date = "startDate",
                .end_date = "endDate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_findings_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_findings_metrics };
        }
    },
    Response: type = struct {
        findings_metrics: ?[]struct {
            date: ?i64 = null,
            new_findings: ?FindingMetricsValuePerSeverity = null,
            closed_findings: ?FindingMetricsValuePerSeverity = null,
            open_findings: ?FindingMetricsValuePerSeverity = null,
            mean_time_to_close: ?FindingMetricsValuePerSeverity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .date = "date",
                    .new_findings = "newFindings",
                    .closed_findings = "closedFindings",
                    .open_findings = "openFindings",
                    .mean_time_to_close = "meanTimeToClose",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings_metrics = "findingsMetrics",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_scans: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/scans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListScans",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_scans) } {
            return .{ .service_metadata = service_metadata, .action = list_scans };
        }
    },
    Response: type = struct {
        summaries: ?[]struct {
            scan_state: []const u8,
            created_at: i64,
            updated_at: ?i64 = null,
            scan_name: []const u8,
            run_id: []const u8,
            scan_name_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_state = "scanState",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .scan_name = "scanName",
                    .run_id = "runId",
                    .scan_name_arn = "scanNameArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_account_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/updateAccountConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccountConfiguration",
    Request: type = struct {
        encryption_config: EncryptionConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_config = "encryptionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_account_configuration };
        }
    },
    Response: type = struct {
        encryption_config: EncryptionConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_config = "encryptionConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const EncryptionConfig = struct {
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FindingMetricsValuePerSeverity = struct {
    info: ?f64 = null,
    low: ?f64 = null,
    medium: ?f64 = null,
    high: ?f64 = null,
    critical: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .info = "info",
            .low = "low",
            .medium = "medium",
            .high = "high",
            .critical = "critical",
        };
        return @field(mappings, field_name);
    }
};

pub const ScanNameWithFindingNum = struct {
    scan_name: ?[]const u8 = null,
    finding_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scan_name = "scanName",
            .finding_number = "findingNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const Finding = struct {
    created_at: ?i64 = null,
    description: ?[]const u8 = null,
    generator_id: ?[]const u8 = null,
    id: ?[]const u8 = null,
    updated_at: ?i64 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    resource: ?Resource = null,
    vulnerability: ?Vulnerability = null,
    severity: ?[]const u8 = null,
    remediation: ?Remediation = null,
    title: ?[]const u8 = null,
    detector_tags: ?[][]const u8 = null,
    detector_id: ?[]const u8 = null,
    detector_name: ?[]const u8 = null,
    rule_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .created_at = "createdAt",
            .description = "description",
            .generator_id = "generatorId",
            .id = "id",
            .updated_at = "updatedAt",
            .type = "type",
            .status = "status",
            .resource = "resource",
            .vulnerability = "vulnerability",
            .severity = "severity",
            .remediation = "remediation",
            .title = "title",
            .detector_tags = "detectorTags",
            .detector_id = "detectorId",
            .detector_name = "detectorName",
            .rule_id = "ruleId",
        };
        return @field(mappings, field_name);
    }
};

pub const Remediation = struct {
    recommendation: ?Recommendation = null,
    suggested_fixes: ?[]SuggestedFix = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recommendation = "recommendation",
            .suggested_fixes = "suggestedFixes",
        };
        return @field(mappings, field_name);
    }
};

pub const SuggestedFix = struct {
    description: ?[]const u8 = null,
    code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .code = "code",
        };
        return @field(mappings, field_name);
    }
};

pub const Recommendation = struct {
    text: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "text",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const Vulnerability = struct {
    reference_urls: ?[][]const u8 = null,
    related_vulnerabilities: ?[][]const u8 = null,
    id: ?[]const u8 = null,
    file_path: ?FilePath = null,
    item_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reference_urls = "referenceUrls",
            .related_vulnerabilities = "relatedVulnerabilities",
            .id = "id",
            .file_path = "filePath",
            .item_count = "itemCount",
        };
        return @field(mappings, field_name);
    }
};

pub const FilePath = struct {
    name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    start_line: ?i64 = null,
    end_line: ?i64 = null,
    code_snippet: ?[]CodeLine = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .path = "path",
            .start_line = "startLine",
            .end_line = "endLine",
            .code_snippet = "codeSnippet",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeLine = struct {
    number: ?i64 = null,
    content: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number = "number",
            .content = "content",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    id: ?[]const u8 = null,
    sub_resource_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .sub_resource_id = "subResourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceId = union {
    code_artifact_id: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code_artifact_id = "codeArtifactId",
        };
        return @field(mappings, field_name);
    }
};
