const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-07-09";
pub const sdk_id: []const u8 = "CodePipeline";
pub const arn_namespace: ?[]const u8 = "codepipeline";
pub const endpoint_prefix: []const u8 = "codepipeline";
pub const sigv4_name: []const u8 = "codepipeline";
pub const name: []const u8 = "CodePipeline_20150709";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-07-09",
    sdk_id: []const u8 = "CodePipeline",
    arn_namespace: ?[]const u8 = "codepipeline",
    endpoint_prefix: []const u8 = "codepipeline",
    sigv4_name: []const u8 = "codepipeline",
    name: []const u8 = "CodePipeline_20150709",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const acknowledge_job: struct {
    action_name: []const u8 = "AcknowledgeJob",
    Request: type = struct {
        job_id: []const u8,
        nonce: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .nonce = "nonce",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(acknowledge_job) } {
            return .{ .service_metadata = service_metadata, .action = acknowledge_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNonce,
        JobNotFound,
        Validation,
    },
} = .{};
pub const acknowledge_third_party_job: struct {
    action_name: []const u8 = "AcknowledgeThirdPartyJob",
    Request: type = struct {
        job_id: []const u8,
        nonce: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .nonce = "nonce",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(acknowledge_third_party_job) } {
            return .{ .service_metadata = service_metadata, .action = acknowledge_third_party_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidClientToken,
        InvalidNonce,
        JobNotFound,
        Validation,
    },
} = .{};
pub const create_custom_action_type: struct {
    action_name: []const u8 = "CreateCustomActionType",
    Request: type = struct {
        category: []const u8,
        provider: []const u8,
        version: []const u8,
        settings: ?ActionTypeSettings = null,
        configuration_properties: ?[]ActionConfigurationProperty = null,
        input_artifact_details: ArtifactDetails,
        output_artifact_details: ArtifactDetails,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "category",
                .provider = "provider",
                .version = "version",
                .settings = "settings",
                .configuration_properties = "configurationProperties",
                .input_artifact_details = "inputArtifactDetails",
                .output_artifact_details = "outputArtifactDetails",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_action_type) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_action_type };
        }
    },
    Response: type = struct {
        action_type: ActionType,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "actionType",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidTags,
        LimitExceeded,
        TooManyTags,
        Validation,
    },
} = .{};
pub const create_pipeline: struct {
    action_name: []const u8 = "CreatePipeline",
    Request: type = struct {
        pipeline: PipelineDeclaration,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "pipeline",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?PipelineDeclaration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "pipeline",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidActionDeclaration,
        InvalidBlockerDeclaration,
        InvalidStageDeclaration,
        InvalidStructure,
        InvalidTags,
        LimitExceeded,
        PipelineNameInUse,
        TooManyTags,
        Validation,
    },
} = .{};
pub const delete_custom_action_type: struct {
    action_name: []const u8 = "DeleteCustomActionType",
    Request: type = struct {
        category: []const u8,
        provider: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "category",
                .provider = "provider",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_action_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_action_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Validation,
    },
} = .{};
pub const delete_pipeline: struct {
    action_name: []const u8 = "DeletePipeline",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_pipeline };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        Validation,
    },
} = .{};
pub const delete_webhook: struct {
    action_name: []const u8 = "DeleteWebhook",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_webhook) } {
            return .{ .service_metadata = service_metadata, .action = delete_webhook };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Validation,
    },
} = .{};
pub const deregister_webhook_with_third_party: struct {
    action_name: []const u8 = "DeregisterWebhookWithThirdParty",
    Request: type = struct {
        webhook_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook_name = "webhookName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_webhook_with_third_party) } {
            return .{ .service_metadata = service_metadata, .action = deregister_webhook_with_third_party };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
        WebhookNotFound,
    },
} = .{};
pub const disable_stage_transition: struct {
    action_name: []const u8 = "DisableStageTransition",
    Request: type = struct {
        pipeline_name: []const u8,
        stage_name: []const u8,
        transition_type: []const u8,
        reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .stage_name = "stageName",
                .transition_type = "transitionType",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_stage_transition) } {
            return .{ .service_metadata = service_metadata, .action = disable_stage_transition };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        PipelineNotFound,
        StageNotFound,
        Validation,
    },
} = .{};
pub const enable_stage_transition: struct {
    action_name: []const u8 = "EnableStageTransition",
    Request: type = struct {
        pipeline_name: []const u8,
        stage_name: []const u8,
        transition_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .stage_name = "stageName",
                .transition_type = "transitionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_stage_transition) } {
            return .{ .service_metadata = service_metadata, .action = enable_stage_transition };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        PipelineNotFound,
        StageNotFound,
        Validation,
    },
} = .{};
pub const get_action_type: struct {
    action_name: []const u8 = "GetActionType",
    Request: type = struct {
        category: []const u8,
        owner: []const u8,
        provider: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "category",
                .owner = "owner",
                .provider = "provider",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_action_type) } {
            return .{ .service_metadata = service_metadata, .action = get_action_type };
        }
    },
    Response: type = struct {
        action_type: ?ActionTypeDeclaration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "actionType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActionTypeNotFound,
        Validation,
    },
} = .{};
pub const get_job_details: struct {
    action_name: []const u8 = "GetJobDetails",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_details) } {
            return .{ .service_metadata = service_metadata, .action = get_job_details };
        }
    },
    Response: type = struct {
        job_details: ?struct {
            id: ?[]const u8 = null,
            data: ?JobData = null,
            account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .data = "data",
                    .account_id = "accountId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_details = "jobDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        JobNotFound,
        Validation,
    },
} = .{};
pub const get_pipeline: struct {
    action_name: []const u8 = "GetPipeline",
    Request: type = struct {
        name: []const u8,
        version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = get_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?PipelineDeclaration = null,
        metadata: ?struct {
            pipeline_arn: ?[]const u8 = null,
            created: ?i64 = null,
            updated: ?i64 = null,
            polling_disabled_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_arn = "pipelineArn",
                    .created = "created",
                    .updated = "updated",
                    .polling_disabled_at = "pollingDisabledAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "pipeline",
                .metadata = "metadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        PipelineNotFound,
        PipelineVersionNotFound,
        Validation,
    },
} = .{};
pub const get_pipeline_execution: struct {
    action_name: []const u8 = "GetPipelineExecution",
    Request: type = struct {
        pipeline_name: []const u8,
        pipeline_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .pipeline_execution_id = "pipelineExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_pipeline_execution };
        }
    },
    Response: type = struct {
        pipeline_execution: ?struct {
            pipeline_name: ?[]const u8 = null,
            pipeline_version: ?i64 = null,
            pipeline_execution_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_summary: ?[]const u8 = null,
            artifact_revisions: ?[]struct {
                name: ?[]const u8 = null,
                revision_id: ?[]const u8 = null,
                revision_change_identifier: ?[]const u8 = null,
                revision_summary: ?[]const u8 = null,
                created: ?i64 = null,
                revision_url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .revision_id = "revisionId",
                        .revision_change_identifier = "revisionChangeIdentifier",
                        .revision_summary = "revisionSummary",
                        .created = "created",
                        .revision_url = "revisionUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            variables: ?[]struct {
                name: ?[]const u8 = null,
                resolved_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .resolved_value = "resolvedValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            trigger: ?ExecutionTrigger = null,
            execution_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_name = "pipelineName",
                    .pipeline_version = "pipelineVersion",
                    .pipeline_execution_id = "pipelineExecutionId",
                    .status = "status",
                    .status_summary = "statusSummary",
                    .artifact_revisions = "artifactRevisions",
                    .variables = "variables",
                    .trigger = "trigger",
                    .execution_mode = "executionMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution = "pipelineExecution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        PipelineExecutionNotFound,
        PipelineNotFound,
        Validation,
    },
} = .{};
pub const get_pipeline_state: struct {
    action_name: []const u8 = "GetPipelineState",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pipeline_state) } {
            return .{ .service_metadata = service_metadata, .action = get_pipeline_state };
        }
    },
    Response: type = struct {
        pipeline_name: ?[]const u8 = null,
        pipeline_version: ?i64 = null,
        stage_states: ?[]struct {
            stage_name: ?[]const u8 = null,
            inbound_execution: ?StageExecution = null,
            inbound_executions: ?[]StageExecution = null,
            inbound_transition_state: ?struct {
                enabled: ?bool = null,
                last_changed_by: ?[]const u8 = null,
                last_changed_at: ?i64 = null,
                disabled_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enabled = "enabled",
                        .last_changed_by = "lastChangedBy",
                        .last_changed_at = "lastChangedAt",
                        .disabled_reason = "disabledReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            action_states: ?[]struct {
                action_name: ?[]const u8 = null,
                current_revision: ?ActionRevision = null,
                latest_execution: ?struct {
                    action_execution_id: ?[]const u8 = null,
                    status: ?[]const u8 = null,
                    summary: ?[]const u8 = null,
                    last_status_change: ?i64 = null,
                    token: ?[]const u8 = null,
                    last_updated_by: ?[]const u8 = null,
                    external_execution_id: ?[]const u8 = null,
                    external_execution_url: ?[]const u8 = null,
                    percent_complete: ?i64 = null,
                    error_details: ?ErrorDetails = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .action_execution_id = "actionExecutionId",
                            .status = "status",
                            .summary = "summary",
                            .last_status_change = "lastStatusChange",
                            .token = "token",
                            .last_updated_by = "lastUpdatedBy",
                            .external_execution_id = "externalExecutionId",
                            .external_execution_url = "externalExecutionUrl",
                            .percent_complete = "percentComplete",
                            .error_details = "errorDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                entity_url: ?[]const u8 = null,
                revision_url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action_name = "actionName",
                        .current_revision = "currentRevision",
                        .latest_execution = "latestExecution",
                        .entity_url = "entityUrl",
                        .revision_url = "revisionUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            latest_execution: ?StageExecution = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stage_name = "stageName",
                    .inbound_execution = "inboundExecution",
                    .inbound_executions = "inboundExecutions",
                    .inbound_transition_state = "inboundTransitionState",
                    .action_states = "actionStates",
                    .latest_execution = "latestExecution",
                };
                return @field(mappings, field_name);
            }
        } = null,
        created: ?i64 = null,
        updated: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .pipeline_version = "pipelineVersion",
                .stage_states = "stageStates",
                .created = "created",
                .updated = "updated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        PipelineNotFound,
        Validation,
    },
} = .{};
pub const get_third_party_job_details: struct {
    action_name: []const u8 = "GetThirdPartyJobDetails",
    Request: type = struct {
        job_id: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_third_party_job_details) } {
            return .{ .service_metadata = service_metadata, .action = get_third_party_job_details };
        }
    },
    Response: type = struct {
        job_details: ?struct {
            id: ?[]const u8 = null,
            data: ?struct {
                action_type_id: ?ActionTypeId = null,
                action_configuration: ?ActionConfiguration = null,
                pipeline_context: ?PipelineContext = null,
                input_artifacts: ?[]Artifact = null,
                output_artifacts: ?[]Artifact = null,
                artifact_credentials: ?AWSSessionCredentials = null,
                continuation_token: ?[]const u8 = null,
                encryption_key: ?EncryptionKey = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action_type_id = "actionTypeId",
                        .action_configuration = "actionConfiguration",
                        .pipeline_context = "pipelineContext",
                        .input_artifacts = "inputArtifacts",
                        .output_artifacts = "outputArtifacts",
                        .artifact_credentials = "artifactCredentials",
                        .continuation_token = "continuationToken",
                        .encryption_key = "encryptionKey",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            nonce: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .data = "data",
                    .nonce = "nonce",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_details = "jobDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidClientToken,
        InvalidJob,
        JobNotFound,
        Validation,
    },
} = .{};
pub const list_action_executions: struct {
    action_name: []const u8 = "ListActionExecutions",
    Request: type = struct {
        pipeline_name: []const u8,
        filter: ?struct {
            pipeline_execution_id: ?[]const u8 = null,
            latest_in_pipeline_execution: ?struct {
                pipeline_execution_id: []const u8,
                start_time_range: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pipeline_execution_id = "pipelineExecutionId",
                        .start_time_range = "startTimeRange",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_execution_id = "pipelineExecutionId",
                    .latest_in_pipeline_execution = "latestInPipelineExecution",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .filter = "filter",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_action_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_action_executions };
        }
    },
    Response: type = struct {
        action_execution_details: ?[]struct {
            pipeline_execution_id: ?[]const u8 = null,
            action_execution_id: ?[]const u8 = null,
            pipeline_version: ?i64 = null,
            stage_name: ?[]const u8 = null,
            action_name: ?[]const u8 = null,
            start_time: ?i64 = null,
            last_update_time: ?i64 = null,
            updated_by: ?[]const u8 = null,
            status: ?[]const u8 = null,
            input: ?struct {
                action_type_id: ?ActionTypeId = null,
                configuration: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                resolved_configuration: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                role_arn: ?[]const u8 = null,
                region: ?[]const u8 = null,
                input_artifacts: ?[]ArtifactDetail = null,
                namespace: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action_type_id = "actionTypeId",
                        .configuration = "configuration",
                        .resolved_configuration = "resolvedConfiguration",
                        .role_arn = "roleArn",
                        .region = "region",
                        .input_artifacts = "inputArtifacts",
                        .namespace = "namespace",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "configuration", field_name))
                        return try serializeMap(self.configuration, self.fieldNameFor("configuration"), options, out_stream);
                    if (std.mem.eql(u8, "resolved_configuration", field_name))
                        return try serializeMap(self.resolved_configuration, self.fieldNameFor("resolved_configuration"), options, out_stream);
                    return false;
                }
            } = null,
            output: ?struct {
                output_artifacts: ?[]ArtifactDetail = null,
                execution_result: ?struct {
                    external_execution_id: ?[]const u8 = null,
                    external_execution_summary: ?[]const u8 = null,
                    external_execution_url: ?[]const u8 = null,
                    error_details: ?ErrorDetails = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .external_execution_id = "externalExecutionId",
                            .external_execution_summary = "externalExecutionSummary",
                            .external_execution_url = "externalExecutionUrl",
                            .error_details = "errorDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                output_variables: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .output_artifacts = "outputArtifacts",
                        .execution_result = "executionResult",
                        .output_variables = "outputVariables",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "output_variables", field_name))
                        return try serializeMap(self.output_variables, self.fieldNameFor("output_variables"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_execution_id = "pipelineExecutionId",
                    .action_execution_id = "actionExecutionId",
                    .pipeline_version = "pipelineVersion",
                    .stage_name = "stageName",
                    .action_name = "actionName",
                    .start_time = "startTime",
                    .last_update_time = "lastUpdateTime",
                    .updated_by = "updatedBy",
                    .status = "status",
                    .input = "input",
                    .output = "output",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_execution_details = "actionExecutionDetails",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        PipelineExecutionNotFound,
        PipelineNotFound,
        Validation,
    },
} = .{};
pub const list_action_types: struct {
    action_name: []const u8 = "ListActionTypes",
    Request: type = struct {
        action_owner_filter: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        region_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_owner_filter = "actionOwnerFilter",
                .next_token = "nextToken",
                .region_filter = "regionFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_action_types) } {
            return .{ .service_metadata = service_metadata, .action = list_action_types };
        }
    },
    Response: type = struct {
        action_types: []ActionType,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_types = "actionTypes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const list_pipeline_executions: struct {
    action_name: []const u8 = "ListPipelineExecutions",
    Request: type = struct {
        pipeline_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipeline_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_pipeline_executions };
        }
    },
    Response: type = struct {
        pipeline_execution_summaries: ?[]struct {
            pipeline_execution_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            start_time: ?i64 = null,
            last_update_time: ?i64 = null,
            source_revisions: ?[]struct {
                action_name: []const u8,
                revision_id: ?[]const u8 = null,
                revision_summary: ?[]const u8 = null,
                revision_url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action_name = "actionName",
                        .revision_id = "revisionId",
                        .revision_summary = "revisionSummary",
                        .revision_url = "revisionUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            trigger: ?ExecutionTrigger = null,
            stop_trigger: ?struct {
                reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .reason = "reason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            execution_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_execution_id = "pipelineExecutionId",
                    .status = "status",
                    .start_time = "startTime",
                    .last_update_time = "lastUpdateTime",
                    .source_revisions = "sourceRevisions",
                    .trigger = "trigger",
                    .stop_trigger = "stopTrigger",
                    .execution_mode = "executionMode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_summaries = "pipelineExecutionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        PipelineNotFound,
        Validation,
    },
} = .{};
pub const list_pipelines: struct {
    action_name: []const u8 = "ListPipelines",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_pipelines };
        }
    },
    Response: type = struct {
        pipelines: ?[]struct {
            name: ?[]const u8 = null,
            version: ?i64 = null,
            pipeline_type: ?[]const u8 = null,
            execution_mode: ?[]const u8 = null,
            created: ?i64 = null,
            updated: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .version = "version",
                    .pipeline_type = "pipelineType",
                    .execution_mode = "executionMode",
                    .created = "created",
                    .updated = "updated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipelines = "pipelines",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidNextToken,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_webhooks: struct {
    action_name: []const u8 = "ListWebhooks",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_webhooks) } {
            return .{ .service_metadata = service_metadata, .action = list_webhooks };
        }
    },
    Response: type = struct {
        webhooks: ?[]ListWebhookItem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhooks = "webhooks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const poll_for_jobs: struct {
    action_name: []const u8 = "PollForJobs",
    Request: type = struct {
        action_type_id: ActionTypeId,
        max_batch_size: ?i64 = null,
        query_param: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type_id = "actionTypeId",
                .max_batch_size = "maxBatchSize",
                .query_param = "queryParam",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "query_param", field_name))
                return try serializeMap(self.query_param, self.fieldNameFor("query_param"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(poll_for_jobs) } {
            return .{ .service_metadata = service_metadata, .action = poll_for_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            id: ?[]const u8 = null,
            data: ?JobData = null,
            nonce: ?[]const u8 = null,
            account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .data = "data",
                    .nonce = "nonce",
                    .account_id = "accountId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActionTypeNotFound,
        Validation,
    },
} = .{};
pub const poll_for_third_party_jobs: struct {
    action_name: []const u8 = "PollForThirdPartyJobs",
    Request: type = struct {
        action_type_id: ActionTypeId,
        max_batch_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type_id = "actionTypeId",
                .max_batch_size = "maxBatchSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(poll_for_third_party_jobs) } {
            return .{ .service_metadata = service_metadata, .action = poll_for_third_party_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            client_id: ?[]const u8 = null,
            job_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_id = "clientId",
                    .job_id = "jobId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActionTypeNotFound,
        Validation,
    },
} = .{};
pub const put_action_revision: struct {
    action_name: []const u8 = "PutActionRevision",
    Request: type = struct {
        pipeline_name: []const u8,
        stage_name: []const u8,
        action_name: []const u8,
        action_revision: ActionRevision,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .stage_name = "stageName",
                .action_name = "actionName",
                .action_revision = "actionRevision",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_action_revision) } {
            return .{ .service_metadata = service_metadata, .action = put_action_revision };
        }
    },
    Response: type = struct {
        new_revision: ?bool = null,
        pipeline_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .new_revision = "newRevision",
                .pipeline_execution_id = "pipelineExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActionNotFound,
        PipelineNotFound,
        StageNotFound,
        Validation,
    },
} = .{};
pub const put_approval_result: struct {
    action_name: []const u8 = "PutApprovalResult",
    Request: type = struct {
        pipeline_name: []const u8,
        stage_name: []const u8,
        action_name: []const u8,
        result: struct {
            summary: []const u8,
            status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .summary = "summary",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        },
        token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .stage_name = "stageName",
                .action_name = "actionName",
                .result = "result",
                .token = "token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_approval_result) } {
            return .{ .service_metadata = service_metadata, .action = put_approval_result };
        }
    },
    Response: type = struct {
        approved_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approved_at = "approvedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActionNotFound,
        ApprovalAlreadyCompleted,
        InvalidApprovalToken,
        PipelineNotFound,
        StageNotFound,
        Validation,
    },
} = .{};
pub const put_job_failure_result: struct {
    action_name: []const u8 = "PutJobFailureResult",
    Request: type = struct {
        job_id: []const u8,
        failure_details: FailureDetails,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .failure_details = "failureDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_job_failure_result) } {
            return .{ .service_metadata = service_metadata, .action = put_job_failure_result };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidJobState,
        JobNotFound,
        Validation,
    },
} = .{};
pub const put_job_success_result: struct {
    action_name: []const u8 = "PutJobSuccessResult",
    Request: type = struct {
        job_id: []const u8,
        current_revision: ?CurrentRevision = null,
        continuation_token: ?[]const u8 = null,
        execution_details: ?ExecutionDetails = null,
        output_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .current_revision = "currentRevision",
                .continuation_token = "continuationToken",
                .execution_details = "executionDetails",
                .output_variables = "outputVariables",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "output_variables", field_name))
                return try serializeMap(self.output_variables, self.fieldNameFor("output_variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_job_success_result) } {
            return .{ .service_metadata = service_metadata, .action = put_job_success_result };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidJobState,
        JobNotFound,
        OutputVariablesSizeExceeded,
        Validation,
    },
} = .{};
pub const put_third_party_job_failure_result: struct {
    action_name: []const u8 = "PutThirdPartyJobFailureResult",
    Request: type = struct {
        job_id: []const u8,
        client_token: []const u8,
        failure_details: FailureDetails,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .client_token = "clientToken",
                .failure_details = "failureDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_third_party_job_failure_result) } {
            return .{ .service_metadata = service_metadata, .action = put_third_party_job_failure_result };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidClientToken,
        InvalidJobState,
        JobNotFound,
        Validation,
    },
} = .{};
pub const put_third_party_job_success_result: struct {
    action_name: []const u8 = "PutThirdPartyJobSuccessResult",
    Request: type = struct {
        job_id: []const u8,
        client_token: []const u8,
        current_revision: ?CurrentRevision = null,
        continuation_token: ?[]const u8 = null,
        execution_details: ?ExecutionDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .client_token = "clientToken",
                .current_revision = "currentRevision",
                .continuation_token = "continuationToken",
                .execution_details = "executionDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_third_party_job_success_result) } {
            return .{ .service_metadata = service_metadata, .action = put_third_party_job_success_result };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidClientToken,
        InvalidJobState,
        JobNotFound,
        Validation,
    },
} = .{};
pub const put_webhook: struct {
    action_name: []const u8 = "PutWebhook",
    Request: type = struct {
        webhook: WebhookDefinition,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook = "webhook",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_webhook) } {
            return .{ .service_metadata = service_metadata, .action = put_webhook };
        }
    },
    Response: type = struct {
        webhook: ?ListWebhookItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook = "webhook",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidTags,
        InvalidWebhookAuthenticationParameters,
        InvalidWebhookFilterPattern,
        LimitExceeded,
        PipelineNotFound,
        TooManyTags,
        Validation,
    },
} = .{};
pub const register_webhook_with_third_party: struct {
    action_name: []const u8 = "RegisterWebhookWithThirdParty",
    Request: type = struct {
        webhook_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .webhook_name = "webhookName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_webhook_with_third_party) } {
            return .{ .service_metadata = service_metadata, .action = register_webhook_with_third_party };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
        WebhookNotFound,
    },
} = .{};
pub const retry_stage_execution: struct {
    action_name: []const u8 = "RetryStageExecution",
    Request: type = struct {
        pipeline_name: []const u8,
        stage_name: []const u8,
        pipeline_execution_id: []const u8,
        retry_mode: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .stage_name = "stageName",
                .pipeline_execution_id = "pipelineExecutionId",
                .retry_mode = "retryMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(retry_stage_execution) } {
            return .{ .service_metadata = service_metadata, .action = retry_stage_execution };
        }
    },
    Response: type = struct {
        pipeline_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_id = "pipelineExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        NotLatestPipelineExecution,
        PipelineNotFound,
        StageNotFound,
        StageNotRetryable,
        Validation,
    },
} = .{};
pub const start_pipeline_execution: struct {
    action_name: []const u8 = "StartPipelineExecution",
    Request: type = struct {
        name: []const u8,
        variables: ?[]struct {
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_request_token: ?[]const u8 = null,
        source_revisions: ?[]struct {
            action_name: []const u8,
            revision_type: []const u8,
            revision_value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_name = "actionName",
                    .revision_type = "revisionType",
                    .revision_value = "revisionValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .variables = "variables",
                .client_request_token = "clientRequestToken",
                .source_revisions = "sourceRevisions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_pipeline_execution };
        }
    },
    Response: type = struct {
        pipeline_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_id = "pipelineExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentPipelineExecutionsLimitExceeded,
        Conflict,
        PipelineNotFound,
        Validation,
    },
} = .{};
pub const stop_pipeline_execution: struct {
    action_name: []const u8 = "StopPipelineExecution",
    Request: type = struct {
        pipeline_name: []const u8,
        pipeline_execution_id: []const u8,
        abandon: ?bool = null,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .pipeline_execution_id = "pipelineExecutionId",
                .abandon = "abandon",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = stop_pipeline_execution };
        }
    },
    Response: type = struct {
        pipeline_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_id = "pipelineExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        DuplicatedStopRequest,
        PipelineExecutionNotStoppable,
        PipelineNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidArn,
        InvalidTags,
        ResourceNotFound,
        TooManyTags,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidArn,
        InvalidTags,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_action_type: struct {
    action_name: []const u8 = "UpdateActionType",
    Request: type = struct {
        action_type: ActionTypeDeclaration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "actionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_action_type) } {
            return .{ .service_metadata = service_metadata, .action = update_action_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ActionTypeNotFound,
        RequestFailed,
        Validation,
    },
} = .{};
pub const update_pipeline: struct {
    action_name: []const u8 = "UpdatePipeline",
    Request: type = struct {
        pipeline: PipelineDeclaration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "pipeline",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = update_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?PipelineDeclaration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidActionDeclaration,
        InvalidBlockerDeclaration,
        InvalidStageDeclaration,
        InvalidStructure,
        LimitExceeded,
        Validation,
    },
} = .{};

pub const PipelineDeclaration = struct {
    name: []const u8,
    role_arn: []const u8,
    artifact_store: ?ArtifactStore = null,
    artifact_stores: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ArtifactStore = null,
    } = null,
    stages: []StageDeclaration,
    version: ?i64 = null,
    execution_mode: ?[]const u8 = null,
    pipeline_type: ?[]const u8 = null,
    variables: ?[]PipelineVariableDeclaration = null,
    triggers: ?[]PipelineTriggerDeclaration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .role_arn = "roleArn",
            .artifact_store = "artifactStore",
            .artifact_stores = "artifactStores",
            .stages = "stages",
            .version = "version",
            .execution_mode = "executionMode",
            .pipeline_type = "pipelineType",
            .variables = "variables",
            .triggers = "triggers",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "artifact_stores", field_name))
            return try serializeMap(self.artifact_stores, self.fieldNameFor("artifact_stores"), options, out_stream);
        return false;
    }
};

pub const PipelineTriggerDeclaration = struct {
    provider_type: []const u8,
    git_configuration: GitConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provider_type = "providerType",
            .git_configuration = "gitConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const GitConfiguration = struct {
    source_action_name: []const u8,
    push: ?[]GitPushFilter = null,
    pull_request: ?[]GitPullRequestFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_action_name = "sourceActionName",
            .push = "push",
            .pull_request = "pullRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const GitPullRequestFilter = struct {
    events: ?[][]const u8 = null,
    branches: ?GitBranchFilterCriteria = null,
    file_paths: ?GitFilePathFilterCriteria = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .events = "events",
            .branches = "branches",
            .file_paths = "filePaths",
        };
        return @field(mappings, field_name);
    }
};

pub const GitFilePathFilterCriteria = struct {
    includes: ?[][]const u8 = null,
    excludes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .includes = "includes",
            .excludes = "excludes",
        };
        return @field(mappings, field_name);
    }
};

pub const GitBranchFilterCriteria = struct {
    includes: ?[][]const u8 = null,
    excludes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .includes = "includes",
            .excludes = "excludes",
        };
        return @field(mappings, field_name);
    }
};

pub const GitPushFilter = struct {
    tags: ?GitTagFilterCriteria = null,
    branches: ?GitBranchFilterCriteria = null,
    file_paths: ?GitFilePathFilterCriteria = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tags = "tags",
            .branches = "branches",
            .file_paths = "filePaths",
        };
        return @field(mappings, field_name);
    }
};

pub const GitTagFilterCriteria = struct {
    includes: ?[][]const u8 = null,
    excludes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .includes = "includes",
            .excludes = "excludes",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelineVariableDeclaration = struct {
    name: []const u8,
    default_value: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .default_value = "defaultValue",
            .description = "description",
        };
        return @field(mappings, field_name);
    }
};

pub const StageDeclaration = struct {
    name: []const u8,
    blockers: ?[]BlockerDeclaration = null,
    actions: []ActionDeclaration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .blockers = "blockers",
            .actions = "actions",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionDeclaration = struct {
    name: []const u8,
    action_type_id: ActionTypeId,
    run_order: ?i64 = null,
    configuration: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    output_artifacts: ?[]OutputArtifact = null,
    input_artifacts: ?[]InputArtifact = null,
    role_arn: ?[]const u8 = null,
    region: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    timeout_in_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .action_type_id = "actionTypeId",
            .run_order = "runOrder",
            .configuration = "configuration",
            .output_artifacts = "outputArtifacts",
            .input_artifacts = "inputArtifacts",
            .role_arn = "roleArn",
            .region = "region",
            .namespace = "namespace",
            .timeout_in_minutes = "timeoutInMinutes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "configuration", field_name))
            return try serializeMap(self.configuration, self.fieldNameFor("configuration"), options, out_stream);
        return false;
    }
};

pub const InputArtifact = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputArtifact = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypeId = struct {
    category: []const u8,
    owner: []const u8,
    provider: []const u8,
    version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "category",
            .owner = "owner",
            .provider = "provider",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const BlockerDeclaration = struct {
    name: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactStore = struct {
    type: []const u8,
    location: []const u8,
    encryption_key: ?EncryptionKey = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .location = "location",
            .encryption_key = "encryptionKey",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionKey = struct {
    id: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypeDeclaration = struct {
    description: ?[]const u8 = null,
    executor: ActionTypeExecutor,
    id: ActionTypeIdentifier,
    input_artifact_details: ActionTypeArtifactDetails,
    output_artifact_details: ActionTypeArtifactDetails,
    permissions: ?ActionTypePermissions = null,
    properties: ?[]ActionTypeProperty = null,
    urls: ?ActionTypeUrls = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .executor = "executor",
            .id = "id",
            .input_artifact_details = "inputArtifactDetails",
            .output_artifact_details = "outputArtifactDetails",
            .permissions = "permissions",
            .properties = "properties",
            .urls = "urls",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypeUrls = struct {
    configuration_url: ?[]const u8 = null,
    entity_url_template: ?[]const u8 = null,
    execution_url_template: ?[]const u8 = null,
    revision_url_template: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration_url = "configurationUrl",
            .entity_url_template = "entityUrlTemplate",
            .execution_url_template = "executionUrlTemplate",
            .revision_url_template = "revisionUrlTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypeProperty = struct {
    name: []const u8,
    optional: bool,
    key: bool,
    no_echo: bool,
    queryable: ?bool = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .optional = "optional",
            .key = "key",
            .no_echo = "noEcho",
            .queryable = "queryable",
            .description = "description",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypePermissions = struct {
    allowed_accounts: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_accounts = "allowedAccounts",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypeArtifactDetails = struct {
    minimum_count: i64,
    maximum_count: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_count = "minimumCount",
            .maximum_count = "maximumCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypeIdentifier = struct {
    category: []const u8,
    owner: []const u8,
    provider: []const u8,
    version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "category",
            .owner = "owner",
            .provider = "provider",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypeExecutor = struct {
    configuration: ExecutorConfiguration,
    type: []const u8,
    policy_statements_template: ?[]const u8 = null,
    job_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .type = "type",
            .policy_statements_template = "policyStatementsTemplate",
            .job_timeout = "jobTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutorConfiguration = struct {
    lambda_executor_configuration: ?LambdaExecutorConfiguration = null,
    job_worker_executor_configuration: ?JobWorkerExecutorConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_executor_configuration = "lambdaExecutorConfiguration",
            .job_worker_executor_configuration = "jobWorkerExecutorConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const JobWorkerExecutorConfiguration = struct {
    polling_accounts: ?[][]const u8 = null,
    polling_service_principals: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .polling_accounts = "pollingAccounts",
            .polling_service_principals = "pollingServicePrincipals",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaExecutorConfiguration = struct {
    lambda_function_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_function_arn = "lambdaFunctionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ListWebhookItem = struct {
    definition: WebhookDefinition,
    url: []const u8,
    error_message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    last_triggered: ?i64 = null,
    arn: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .definition = "definition",
            .url = "url",
            .error_message = "errorMessage",
            .error_code = "errorCode",
            .last_triggered = "lastTriggered",
            .arn = "arn",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }
};

pub const WebhookDefinition = struct {
    name: []const u8,
    target_pipeline: []const u8,
    target_action: []const u8,
    filters: []WebhookFilterRule,
    authentication: []const u8,
    authentication_configuration: WebhookAuthConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .target_pipeline = "targetPipeline",
            .target_action = "targetAction",
            .filters = "filters",
            .authentication = "authentication",
            .authentication_configuration = "authenticationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const WebhookAuthConfiguration = struct {
    allowed_ip_range: ?[]const u8 = null,
    secret_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_ip_range = "AllowedIPRange",
            .secret_token = "SecretToken",
        };
        return @field(mappings, field_name);
    }
};

pub const WebhookFilterRule = struct {
    json_path: []const u8,
    match_equals: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .json_path = "jsonPath",
            .match_equals = "matchEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionDetails = struct {
    summary: ?[]const u8 = null,
    external_execution_id: ?[]const u8 = null,
    percent_complete: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .summary = "summary",
            .external_execution_id = "externalExecutionId",
            .percent_complete = "percentComplete",
        };
        return @field(mappings, field_name);
    }
};

pub const CurrentRevision = struct {
    revision: []const u8,
    change_identifier: []const u8,
    created: ?i64 = null,
    revision_summary: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .revision = "revision",
            .change_identifier = "changeIdentifier",
            .created = "created",
            .revision_summary = "revisionSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const FailureDetails = struct {
    type: []const u8,
    message: []const u8,
    external_execution_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .message = "message",
            .external_execution_id = "externalExecutionId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionRevision = struct {
    revision_id: []const u8,
    revision_change_id: []const u8,
    created: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .revision_id = "revisionId",
            .revision_change_id = "revisionChangeId",
            .created = "created",
        };
        return @field(mappings, field_name);
    }
};

pub const JobData = struct {
    action_type_id: ?ActionTypeId = null,
    action_configuration: ?ActionConfiguration = null,
    pipeline_context: ?PipelineContext = null,
    input_artifacts: ?[]Artifact = null,
    output_artifacts: ?[]Artifact = null,
    artifact_credentials: ?AWSSessionCredentials = null,
    continuation_token: ?[]const u8 = null,
    encryption_key: ?EncryptionKey = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_type_id = "actionTypeId",
            .action_configuration = "actionConfiguration",
            .pipeline_context = "pipelineContext",
            .input_artifacts = "inputArtifacts",
            .output_artifacts = "outputArtifacts",
            .artifact_credentials = "artifactCredentials",
            .continuation_token = "continuationToken",
            .encryption_key = "encryptionKey",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSSessionCredentials = struct {
    access_key_id: []const u8,
    secret_access_key: []const u8,
    session_token: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_key_id = "accessKeyId",
            .secret_access_key = "secretAccessKey",
            .session_token = "sessionToken",
        };
        return @field(mappings, field_name);
    }
};

pub const Artifact = struct {
    name: ?[]const u8 = null,
    revision: ?[]const u8 = null,
    location: ?ArtifactLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .revision = "revision",
            .location = "location",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactLocation = struct {
    type: ?[]const u8 = null,
    s3_location: ?S3ArtifactLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .s3_location = "s3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ArtifactLocation = struct {
    bucket_name: []const u8,
    object_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .object_key = "objectKey",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelineContext = struct {
    pipeline_name: ?[]const u8 = null,
    stage: ?StageContext = null,
    action: ?ActionContext = null,
    pipeline_arn: ?[]const u8 = null,
    pipeline_execution_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pipeline_name = "pipelineName",
            .stage = "stage",
            .action = "action",
            .pipeline_arn = "pipelineArn",
            .pipeline_execution_id = "pipelineExecutionId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionContext = struct {
    name: ?[]const u8 = null,
    action_execution_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .action_execution_id = "actionExecutionId",
        };
        return @field(mappings, field_name);
    }
};

pub const StageContext = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionConfiguration = struct {
    configuration: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "configuration", field_name))
            return try serializeMap(self.configuration, self.fieldNameFor("configuration"), options, out_stream);
        return false;
    }
};

pub const ExecutionTrigger = struct {
    trigger_type: ?[]const u8 = null,
    trigger_detail: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trigger_type = "triggerType",
            .trigger_detail = "triggerDetail",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionType = struct {
    id: ActionTypeId,
    settings: ?ActionTypeSettings = null,
    action_configuration_properties: ?[]ActionConfigurationProperty = null,
    input_artifact_details: ArtifactDetails,
    output_artifact_details: ArtifactDetails,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .settings = "settings",
            .action_configuration_properties = "actionConfigurationProperties",
            .input_artifact_details = "inputArtifactDetails",
            .output_artifact_details = "outputArtifactDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactDetails = struct {
    minimum_count: i64,
    maximum_count: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_count = "minimumCount",
            .maximum_count = "maximumCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionConfigurationProperty = struct {
    name: []const u8,
    required: bool,
    key: bool,
    secret: bool,
    queryable: ?bool = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .required = "required",
            .key = "key",
            .secret = "secret",
            .queryable = "queryable",
            .description = "description",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTypeSettings = struct {
    third_party_configuration_url: ?[]const u8 = null,
    entity_url_template: ?[]const u8 = null,
    execution_url_template: ?[]const u8 = null,
    revision_url_template: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .third_party_configuration_url = "thirdPartyConfigurationUrl",
            .entity_url_template = "entityUrlTemplate",
            .execution_url_template = "executionUrlTemplate",
            .revision_url_template = "revisionUrlTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetails = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactDetail = struct {
    name: ?[]const u8 = null,
    s3location: ?S3Location = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .s3location = "s3location",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key = "key",
        };
        return @field(mappings, field_name);
    }
};

pub const StageExecution = struct {
    pipeline_execution_id: []const u8,
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pipeline_execution_id = "pipelineExecutionId",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};
