const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-04-19";
pub const sdk_id: []const u8 = "CodeStar";
pub const arn_namespace: ?[]const u8 = "codestar";
pub const endpoint_prefix: []const u8 = "codestar";
pub const sigv4_name: []const u8 = "codestar";
pub const name: []const u8 = "CodeStar_20170419";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-04-19",
    sdk_id: []const u8 = "CodeStar",
    arn_namespace: ?[]const u8 = "codestar",
    endpoint_prefix: []const u8 = "codestar",
    sigv4_name: []const u8 = "codestar",
    name: []const u8 = "CodeStar_20170419",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_team_member: struct {
    action_name: []const u8 = "AssociateTeamMember",
    Request: type = struct {
        project_id: []const u8,
        client_request_token: ?[]const u8 = null,
        user_arn: []const u8,
        project_role: []const u8,
        remote_access_allowed: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .client_request_token = "clientRequestToken",
                .user_arn = "userArn",
                .project_role = "projectRole",
                .remote_access_allowed = "remoteAccessAllowed",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_team_member) } {
            return .{ .service_metadata = service_metadata, .action = associate_team_member };
        }
    },
    Response: type = struct {
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidServiceRole,
        LimitExceeded,
        ProjectConfiguration,
        ProjectNotFound,
        TeamMemberAlreadyAssociated,
        Validation,
    },
} = .{};
pub const create_project: struct {
    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        name: []const u8,
        id: []const u8,
        description: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        source_code: ?[]struct {
            source: struct {
                s3: S3Location,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3 = "s3",
                    };
                    return @field(mappings, field_name);
                }
            },
            destination: struct {
                code_commit: ?struct {
                    name: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                git_hub: ?struct {
                    name: []const u8,
                    description: ?[]const u8 = null,
                    type: []const u8,
                    owner: []const u8,
                    private_repository: bool,
                    issues_enabled: bool,
                    token: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .description = "description",
                            .type = "type",
                            .owner = "owner",
                            .private_repository = "privateRepository",
                            .issues_enabled = "issuesEnabled",
                            .token = "token",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code_commit = "codeCommit",
                        .git_hub = "gitHub",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source = "source",
                    .destination = "destination",
                };
                return @field(mappings, field_name);
            }
        } = null,
        toolchain: ?struct {
            source: struct {
                s3: S3Location,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3 = "s3",
                    };
                    return @field(mappings, field_name);
                }
            },
            role_arn: ?[]const u8 = null,
            stack_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source = "source",
                    .role_arn = "roleArn",
                    .stack_parameters = "stackParameters",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "stack_parameters", field_name))
                    return try serializeMap(self.stack_parameters, self.fieldNameFor("stack_parameters"), options, out_stream);
                return false;
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .id = "id",
                .description = "description",
                .client_request_token = "clientRequestToken",
                .source_code = "sourceCode",
                .toolchain = "toolchain",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        client_request_token: ?[]const u8 = null,
        project_template_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .client_request_token = "clientRequestToken",
                .project_template_id = "projectTemplateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidServiceRole,
        LimitExceeded,
        ProjectAlreadyExists,
        ProjectConfiguration,
        ProjectCreationFailed,
        Validation,
    },
} = .{};
pub const create_user_profile: struct {
    action_name: []const u8 = "CreateUserProfile",
    Request: type = struct {
        user_arn: []const u8,
        display_name: []const u8,
        email_address: []const u8,
        ssh_public_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
                .display_name = "displayName",
                .email_address = "emailAddress",
                .ssh_public_key = "sshPublicKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_user_profile };
        }
    },
    Response: type = struct {
        user_arn: []const u8,
        display_name: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        ssh_public_key: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
                .display_name = "displayName",
                .email_address = "emailAddress",
                .ssh_public_key = "sshPublicKey",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        UserProfileAlreadyExists,
        Validation,
    },
} = .{};
pub const delete_project: struct {
    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        id: []const u8,
        client_request_token: ?[]const u8 = null,
        delete_stack: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .client_request_token = "clientRequestToken",
                .delete_stack = "deleteStack",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {
        stack_id: ?[]const u8 = null,
        project_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_id = "stackId",
                .project_arn = "projectArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidServiceRole,
        Validation,
    },
} = .{};
pub const delete_user_profile: struct {
    action_name: []const u8 = "DeleteUserProfile",
    Request: type = struct {
        user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_profile };
        }
    },
    Response: type = struct {
        user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const describe_project: struct {
    action_name: []const u8 = "DescribeProject",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project) } {
            return .{ .service_metadata = service_metadata, .action = describe_project };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        created_time_stamp: ?i64 = null,
        stack_id: ?[]const u8 = null,
        project_template_id: ?[]const u8 = null,
        status: ?struct {
            state: []const u8,
            reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .state = "state",
                    .reason = "reason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .id = "id",
                .arn = "arn",
                .description = "description",
                .client_request_token = "clientRequestToken",
                .created_time_stamp = "createdTimeStamp",
                .stack_id = "stackId",
                .project_template_id = "projectTemplateId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidServiceRole,
        ProjectConfiguration,
        ProjectNotFound,
        Validation,
    },
} = .{};
pub const describe_user_profile: struct {
    action_name: []const u8 = "DescribeUserProfile",
    Request: type = struct {
        user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_profile };
        }
    },
    Response: type = struct {
        user_arn: []const u8,
        display_name: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        ssh_public_key: ?[]const u8 = null,
        created_timestamp: i64,
        last_modified_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
                .display_name = "displayName",
                .email_address = "emailAddress",
                .ssh_public_key = "sshPublicKey",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        UserProfileNotFound,
        Validation,
    },
} = .{};
pub const disassociate_team_member: struct {
    action_name: []const u8 = "DisassociateTeamMember",
    Request: type = struct {
        project_id: []const u8,
        user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .user_arn = "userArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_team_member) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_team_member };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidServiceRole,
        ProjectNotFound,
        Validation,
    },
} = .{};
pub const list_projects: struct {
    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        projects: []struct {
            project_id: ?[]const u8 = null,
            project_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_id = "projectId",
                    .project_arn = "projectArn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .projects = "projects",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const list_resources: struct {
    action_name: []const u8 = "ListResources",
    Request: type = struct {
        project_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_resources };
        }
    },
    Response: type = struct {
        resources: ?[]struct {
            id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "resources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ProjectNotFound,
        Validation,
    },
} = .{};
pub const list_tags_for_project: struct {
    action_name: []const u8 = "ListTagsForProject",
    Request: type = struct {
        id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_project) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_project };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ProjectNotFound,
        Validation,
    },
} = .{};
pub const list_team_members: struct {
    action_name: []const u8 = "ListTeamMembers",
    Request: type = struct {
        project_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_team_members) } {
            return .{ .service_metadata = service_metadata, .action = list_team_members };
        }
    },
    Response: type = struct {
        team_members: []struct {
            user_arn: []const u8,
            project_role: []const u8,
            remote_access_allowed: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_arn = "userArn",
                    .project_role = "projectRole",
                    .remote_access_allowed = "remoteAccessAllowed",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .team_members = "teamMembers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ProjectNotFound,
        Validation,
    },
} = .{};
pub const list_user_profiles: struct {
    action_name: []const u8 = "ListUserProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_user_profiles };
        }
    },
    Response: type = struct {
        user_profiles: []struct {
            user_arn: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            email_address: ?[]const u8 = null,
            ssh_public_key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_arn = "userArn",
                    .display_name = "displayName",
                    .email_address = "emailAddress",
                    .ssh_public_key = "sshPublicKey",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_profiles = "userProfiles",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const tag_project: struct {
    action_name: []const u8 = "TagProject",
    Request: type = struct {
        id: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_project) } {
            return .{ .service_metadata = service_metadata, .action = tag_project };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        LimitExceeded,
        ProjectNotFound,
        Validation,
    },
} = .{};
pub const untag_project: struct {
    action_name: []const u8 = "UntagProject",
    Request: type = struct {
        id: []const u8,
        tags: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_project) } {
            return .{ .service_metadata = service_metadata, .action = untag_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        LimitExceeded,
        ProjectNotFound,
        Validation,
    },
} = .{};
pub const update_project: struct {
    action_name: []const u8 = "UpdateProject",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_project) } {
            return .{ .service_metadata = service_metadata, .action = update_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ProjectNotFound,
        Validation,
    },
} = .{};
pub const update_team_member: struct {
    action_name: []const u8 = "UpdateTeamMember",
    Request: type = struct {
        project_id: []const u8,
        user_arn: []const u8,
        project_role: ?[]const u8 = null,
        remote_access_allowed: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .user_arn = "userArn",
                .project_role = "projectRole",
                .remote_access_allowed = "remoteAccessAllowed",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_team_member) } {
            return .{ .service_metadata = service_metadata, .action = update_team_member };
        }
    },
    Response: type = struct {
        user_arn: ?[]const u8 = null,
        project_role: ?[]const u8 = null,
        remote_access_allowed: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
                .project_role = "projectRole",
                .remote_access_allowed = "remoteAccessAllowed",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidServiceRole,
        LimitExceeded,
        ProjectConfiguration,
        ProjectNotFound,
        TeamMemberNotFound,
        Validation,
    },
} = .{};
pub const update_user_profile: struct {
    action_name: []const u8 = "UpdateUserProfile",
    Request: type = struct {
        user_arn: []const u8,
        display_name: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        ssh_public_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
                .display_name = "displayName",
                .email_address = "emailAddress",
                .ssh_public_key = "sshPublicKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_user_profile };
        }
    },
    Response: type = struct {
        user_arn: []const u8,
        display_name: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        ssh_public_key: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
                .display_name = "displayName",
                .email_address = "emailAddress",
                .ssh_public_key = "sshPublicKey",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        UserProfileNotFound,
        Validation,
    },
} = .{};

pub const S3Location = struct {
    bucket_name: ?[]const u8 = null,
    bucket_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .bucket_key = "bucketKey",
        };
        return @field(mappings, field_name);
    }
};
