const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-01";
pub const sdk_id: []const u8 = "CodeStar connections";
pub const arn_namespace: ?[]const u8 = "codestar-connections";
pub const endpoint_prefix: []const u8 = "codestar-connections";
pub const sigv4_name: []const u8 = "codestar-connections";
pub const name: []const u8 = "CodeStar_connections_20191201";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-01",
    sdk_id: []const u8 = "CodeStar connections",
    arn_namespace: ?[]const u8 = "codestar-connections",
    endpoint_prefix: []const u8 = "codestar-connections",
    sigv4_name: []const u8 = "codestar-connections",
    name: []const u8 = "CodeStar_connections_20191201",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_connection: struct {
    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        provider_type: ?[]const u8 = null,
        connection_name: []const u8,
        tags: ?[]Tag = null,
        host_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_type = "ProviderType",
                .connection_name = "ConnectionName",
                .tags = "Tags",
                .host_arn = "HostArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {
        connection_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const create_host: struct {
    action_name: []const u8 = "CreateHost",
    Request: type = struct {
        name: []const u8,
        provider_type: []const u8,
        provider_endpoint: []const u8,
        vpc_configuration: ?VpcConfiguration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .provider_type = "ProviderType",
                .provider_endpoint = "ProviderEndpoint",
                .vpc_configuration = "VpcConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_host) } {
            return .{ .service_metadata = service_metadata, .action = create_host };
        }
    },
    Response: type = struct {
        host_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_arn = "HostArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const create_repository_link: struct {
    action_name: []const u8 = "CreateRepositoryLink",
    Request: type = struct {
        connection_arn: []const u8,
        owner_id: []const u8,
        repository_name: []const u8,
        encryption_key_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .owner_id = "OwnerId",
                .repository_name = "RepositoryName",
                .encryption_key_arn = "EncryptionKeyArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_repository_link) } {
            return .{ .service_metadata = service_metadata, .action = create_repository_link };
        }
    },
    Response: type = struct {
        repository_link_info: RepositoryLinkInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_link_info = "RepositoryLinkInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        InternalServer,
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_sync_configuration: struct {
    action_name: []const u8 = "CreateSyncConfiguration",
    Request: type = struct {
        branch: []const u8,
        config_file: []const u8,
        repository_link_id: []const u8,
        resource_name: []const u8,
        role_arn: []const u8,
        sync_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch = "Branch",
                .config_file = "ConfigFile",
                .repository_link_id = "RepositoryLinkId",
                .resource_name = "ResourceName",
                .role_arn = "RoleArn",
                .sync_type = "SyncType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sync_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_sync_configuration };
        }
    },
    Response: type = struct {
        sync_configuration: SyncConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_configuration = "SyncConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        InternalServer,
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        connection_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_host: struct {
    action_name: []const u8 = "DeleteHost",
    Request: type = struct {
        host_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_arn = "HostArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_host) } {
            return .{ .service_metadata = service_metadata, .action = delete_host };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const delete_repository_link: struct {
    action_name: []const u8 = "DeleteRepositoryLink",
    Request: type = struct {
        repository_link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_link_id = "RepositoryLinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_repository_link) } {
            return .{ .service_metadata = service_metadata, .action = delete_repository_link };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        SyncConfigurationStillExists,
        Throttling,
        UnsupportedProviderType,
    },
} = .{};
pub const delete_sync_configuration: struct {
    action_name: []const u8 = "DeleteSyncConfiguration",
    Request: type = struct {
        sync_type: []const u8,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_type = "SyncType",
                .resource_name = "ResourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sync_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_sync_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        InternalServer,
        InvalidInput,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const get_connection: struct {
    action_name: []const u8 = "GetConnection",
    Request: type = struct {
        connection_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connection) } {
            return .{ .service_metadata = service_metadata, .action = get_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const get_host: struct {
    action_name: []const u8 = "GetHost",
    Request: type = struct {
        host_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_arn = "HostArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_host) } {
            return .{ .service_metadata = service_metadata, .action = get_host };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        provider_type: ?[]const u8 = null,
        provider_endpoint: ?[]const u8 = null,
        vpc_configuration: ?VpcConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .status = "Status",
                .provider_type = "ProviderType",
                .provider_endpoint = "ProviderEndpoint",
                .vpc_configuration = "VpcConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const get_repository_link: struct {
    action_name: []const u8 = "GetRepositoryLink",
    Request: type = struct {
        repository_link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_link_id = "RepositoryLinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_link) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_link };
        }
    },
    Response: type = struct {
        repository_link_info: RepositoryLinkInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_link_info = "RepositoryLinkInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_repository_sync_status: struct {
    action_name: []const u8 = "GetRepositorySyncStatus",
    Request: type = struct {
        branch: []const u8,
        repository_link_id: []const u8,
        sync_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch = "Branch",
                .repository_link_id = "RepositoryLinkId",
                .sync_type = "SyncType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_sync_status) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_sync_status };
        }
    },
    Response: type = struct {
        latest_sync: struct {
            started_at: i64,
            status: []const u8,
            events: []struct {
                event: []const u8,
                external_id: ?[]const u8 = null,
                time: i64,
                type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event = "Event",
                        .external_id = "ExternalId",
                        .time = "Time",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .started_at = "StartedAt",
                    .status = "Status",
                    .events = "Events",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .latest_sync = "LatestSync",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_resource_sync_status: struct {
    action_name: []const u8 = "GetResourceSyncStatus",
    Request: type = struct {
        resource_name: []const u8,
        sync_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .sync_type = "SyncType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_sync_status) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_sync_status };
        }
    },
    Response: type = struct {
        desired_state: ?Revision = null,
        latest_successful_sync: ?ResourceSyncAttempt = null,
        latest_sync: ResourceSyncAttempt,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .desired_state = "DesiredState",
                .latest_successful_sync = "LatestSuccessfulSync",
                .latest_sync = "LatestSync",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_sync_blocker_summary: struct {
    action_name: []const u8 = "GetSyncBlockerSummary",
    Request: type = struct {
        sync_type: []const u8,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_type = "SyncType",
                .resource_name = "ResourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sync_blocker_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_sync_blocker_summary };
        }
    },
    Response: type = struct {
        sync_blocker_summary: struct {
            resource_name: []const u8,
            parent_resource_name: ?[]const u8 = null,
            latest_blockers: ?[]SyncBlocker = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_name = "ResourceName",
                    .parent_resource_name = "ParentResourceName",
                    .latest_blockers = "LatestBlockers",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_blocker_summary = "SyncBlockerSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_sync_configuration: struct {
    action_name: []const u8 = "GetSyncConfiguration",
    Request: type = struct {
        sync_type: []const u8,
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_type = "SyncType",
                .resource_name = "ResourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sync_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_sync_configuration };
        }
    },
    Response: type = struct {
        sync_configuration: SyncConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_configuration = "SyncConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_connections: struct {
    action_name: []const u8 = "ListConnections",
    Request: type = struct {
        provider_type_filter: ?[]const u8 = null,
        host_arn_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_type_filter = "ProviderTypeFilter",
                .host_arn_filter = "HostArnFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connections) } {
            return .{ .service_metadata = service_metadata, .action = list_connections };
        }
    },
    Response: type = struct {
        connections: ?[]Connection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "Connections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_hosts: struct {
    action_name: []const u8 = "ListHosts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hosts) } {
            return .{ .service_metadata = service_metadata, .action = list_hosts };
        }
    },
    Response: type = struct {
        hosts: ?[]struct {
            name: ?[]const u8 = null,
            host_arn: ?[]const u8 = null,
            provider_type: ?[]const u8 = null,
            provider_endpoint: ?[]const u8 = null,
            vpc_configuration: ?VpcConfiguration = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .host_arn = "HostArn",
                    .provider_type = "ProviderType",
                    .provider_endpoint = "ProviderEndpoint",
                    .vpc_configuration = "VpcConfiguration",
                    .status = "Status",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosts = "Hosts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_repository_links: struct {
    action_name: []const u8 = "ListRepositoryLinks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_repository_links) } {
            return .{ .service_metadata = service_metadata, .action = list_repository_links };
        }
    },
    Response: type = struct {
        repository_links: []RepositoryLinkInfo,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_links = "RepositoryLinks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_repository_sync_definitions: struct {
    action_name: []const u8 = "ListRepositorySyncDefinitions",
    Request: type = struct {
        repository_link_id: []const u8,
        sync_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_link_id = "RepositoryLinkId",
                .sync_type = "SyncType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_repository_sync_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_repository_sync_definitions };
        }
    },
    Response: type = struct {
        repository_sync_definitions: []struct {
            branch: []const u8,
            directory: []const u8,
            parent: []const u8,
            target: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .branch = "Branch",
                    .directory = "Directory",
                    .parent = "Parent",
                    .target = "Target",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_sync_definitions = "RepositorySyncDefinitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_sync_configurations: struct {
    action_name: []const u8 = "ListSyncConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        repository_link_id: []const u8,
        sync_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .repository_link_id = "RepositoryLinkId",
                .sync_type = "SyncType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sync_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_sync_configurations };
        }
    },
    Response: type = struct {
        sync_configurations: []SyncConfiguration,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_configurations = "SyncConfigurations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_host: struct {
    action_name: []const u8 = "UpdateHost",
    Request: type = struct {
        host_arn: []const u8,
        provider_endpoint: ?[]const u8 = null,
        vpc_configuration: ?VpcConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_arn = "HostArn",
                .provider_endpoint = "ProviderEndpoint",
                .vpc_configuration = "VpcConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_host) } {
            return .{ .service_metadata = service_metadata, .action = update_host };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        ResourceUnavailable,
        UnsupportedOperation,
    },
} = .{};
pub const update_repository_link: struct {
    action_name: []const u8 = "UpdateRepositoryLink",
    Request: type = struct {
        connection_arn: ?[]const u8 = null,
        encryption_key_arn: ?[]const u8 = null,
        repository_link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .encryption_key_arn = "EncryptionKeyArn",
                .repository_link_id = "RepositoryLinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_repository_link) } {
            return .{ .service_metadata = service_metadata, .action = update_repository_link };
        }
    },
    Response: type = struct {
        repository_link_info: RepositoryLinkInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_link_info = "RepositoryLinkInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConditionalCheckFailed,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
        UpdateOutOfSync,
    },
} = .{};
pub const update_sync_blocker: struct {
    action_name: []const u8 = "UpdateSyncBlocker",
    Request: type = struct {
        id: []const u8,
        sync_type: []const u8,
        resource_name: []const u8,
        resolved_reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .sync_type = "SyncType",
                .resource_name = "ResourceName",
                .resolved_reason = "ResolvedReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sync_blocker) } {
            return .{ .service_metadata = service_metadata, .action = update_sync_blocker };
        }
    },
    Response: type = struct {
        resource_name: []const u8,
        parent_resource_name: ?[]const u8 = null,
        sync_blocker: SyncBlocker,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .parent_resource_name = "ParentResourceName",
                .sync_blocker = "SyncBlocker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        RetryLatestCommitFailed,
        SyncBlockerDoesNotExist,
        Throttling,
    },
} = .{};
pub const update_sync_configuration: struct {
    action_name: []const u8 = "UpdateSyncConfiguration",
    Request: type = struct {
        branch: ?[]const u8 = null,
        config_file: ?[]const u8 = null,
        repository_link_id: ?[]const u8 = null,
        resource_name: []const u8,
        role_arn: ?[]const u8 = null,
        sync_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch = "Branch",
                .config_file = "ConfigFile",
                .repository_link_id = "RepositoryLinkId",
                .resource_name = "ResourceName",
                .role_arn = "RoleArn",
                .sync_type = "SyncType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sync_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_sync_configuration };
        }
    },
    Response: type = struct {
        sync_configuration: SyncConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_configuration = "SyncConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        InternalServer,
        InvalidInput,
        ResourceNotFound,
        Throttling,
        UpdateOutOfSync,
    },
} = .{};

pub const SyncConfiguration = struct {
    branch: []const u8,
    config_file: ?[]const u8 = null,
    owner_id: []const u8,
    provider_type: []const u8,
    repository_link_id: []const u8,
    repository_name: []const u8,
    resource_name: []const u8,
    role_arn: []const u8,
    sync_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .branch = "Branch",
            .config_file = "ConfigFile",
            .owner_id = "OwnerId",
            .provider_type = "ProviderType",
            .repository_link_id = "RepositoryLinkId",
            .repository_name = "RepositoryName",
            .resource_name = "ResourceName",
            .role_arn = "RoleArn",
            .sync_type = "SyncType",
        };
        return @field(mappings, field_name);
    }
};

pub const SyncBlocker = struct {
    id: []const u8,
    type: []const u8,
    status: []const u8,
    created_reason: []const u8,
    created_at: i64,
    contexts: ?[]SyncBlockerContext = null,
    resolved_reason: ?[]const u8 = null,
    resolved_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .type = "Type",
            .status = "Status",
            .created_reason = "CreatedReason",
            .created_at = "CreatedAt",
            .contexts = "Contexts",
            .resolved_reason = "ResolvedReason",
            .resolved_at = "ResolvedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const SyncBlockerContext = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryLinkInfo = struct {
    connection_arn: []const u8,
    encryption_key_arn: ?[]const u8 = null,
    owner_id: []const u8,
    provider_type: []const u8,
    repository_link_arn: []const u8,
    repository_link_id: []const u8,
    repository_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_arn = "ConnectionArn",
            .encryption_key_arn = "EncryptionKeyArn",
            .owner_id = "OwnerId",
            .provider_type = "ProviderType",
            .repository_link_arn = "RepositoryLinkArn",
            .repository_link_id = "RepositoryLinkId",
            .repository_name = "RepositoryName",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfiguration = struct {
    vpc_id: []const u8,
    subnet_ids: [][]const u8,
    security_group_ids: [][]const u8,
    tls_certificate: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
            .tls_certificate = "TlsCertificate",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Connection = struct {
    connection_name: ?[]const u8 = null,
    connection_arn: ?[]const u8 = null,
    provider_type: ?[]const u8 = null,
    owner_account_id: ?[]const u8 = null,
    connection_status: ?[]const u8 = null,
    host_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_name = "ConnectionName",
            .connection_arn = "ConnectionArn",
            .provider_type = "ProviderType",
            .owner_account_id = "OwnerAccountId",
            .connection_status = "ConnectionStatus",
            .host_arn = "HostArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceSyncAttempt = struct {
    events: []ResourceSyncEvent,
    initial_revision: Revision,
    started_at: i64,
    status: []const u8,
    target_revision: Revision,
    target: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .events = "Events",
            .initial_revision = "InitialRevision",
            .started_at = "StartedAt",
            .status = "Status",
            .target_revision = "TargetRevision",
            .target = "Target",
        };
        return @field(mappings, field_name);
    }
};

pub const Revision = struct {
    branch: []const u8,
    directory: []const u8,
    owner_id: []const u8,
    repository_name: []const u8,
    provider_type: []const u8,
    sha: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .branch = "Branch",
            .directory = "Directory",
            .owner_id = "OwnerId",
            .repository_name = "RepositoryName",
            .provider_type = "ProviderType",
            .sha = "Sha",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceSyncEvent = struct {
    event: []const u8,
    external_id: ?[]const u8 = null,
    time: i64,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event = "Event",
            .external_id = "ExternalId",
            .time = "Time",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};
