const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-09-22";
pub const sdk_id: []const u8 = "codeartifact";
pub const arn_namespace: ?[]const u8 = "codeartifact";
pub const endpoint_prefix: []const u8 = "codeartifact";
pub const sigv4_name: []const u8 = "codeartifact";
pub const name: []const u8 = "CodeArtifactControlPlaneService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-09-22",
    sdk_id: []const u8 = "codeartifact",
    arn_namespace: ?[]const u8 = "codeartifact",
    endpoint_prefix: []const u8 = "codeartifact",
    sigv4_name: []const u8 = "codeartifact",
    name: []const u8 = "CodeArtifactControlPlaneService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_external_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/repository/external-connection",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateExternalConnection",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        external_connection: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .external_connection = "external-connection",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .external_connection = "externalConnection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_external_connection) } {
            return .{ .service_metadata = service_metadata, .action = associate_external_connection };
        }
    },
    Response: type = struct {
        repository: ?RepositoryDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const copy_package_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package/versions/copy",
        .success_code = 200,
    };

    action_name: []const u8 = "CopyPackageVersions",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        source_repository: []const u8,
        destination_repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        versions: ?[][]const u8 = null,
        version_revisions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        allow_overwrite: ?bool = null,
        include_from_upstream: ?bool = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .source_repository = "source-repository",
            .destination_repository = "destination-repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .source_repository = "sourceRepository",
                .destination_repository = "destinationRepository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .versions = "versions",
                .version_revisions = "versionRevisions",
                .allow_overwrite = "allowOverwrite",
                .include_from_upstream = "includeFromUpstream",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "version_revisions", field_name))
                return try serializeMap(self.version_revisions, self.fieldNameFor("version_revisions"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_package_versions) } {
            return .{ .service_metadata = service_metadata, .action = copy_package_versions };
        }
    },
    Response: type = struct {
        successful_versions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?SuccessfulPackageVersionInfo = null,
        } = null,
        failed_versions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PackageVersionError = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_versions = "successfulVersions",
                .failed_versions = "failedVersions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "successful_versions", field_name))
                return try serializeMap(self.successful_versions, self.fieldNameFor("successful_versions"), options, out_stream);
            if (std.mem.eql(u8, "failed_versions", field_name))
                return try serializeMap(self.failed_versions, self.fieldNameFor("failed_versions"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/domain",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDomain",
    Request: type = struct {
        domain: []const u8,
        encryption_key: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub const http_query = .{
            .domain = "domain",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .encryption_key = "encryptionKey",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_domain };
        }
    },
    Response: type = struct {
        domain: ?DomainDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_repository: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/repository",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRepository",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        description: ?[]const u8 = null,
        upstreams: ?[]UpstreamRepository = null,
        tags: ?[]Tag = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .description = "description",
                .upstreams = "upstreams",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_repository) } {
            return .{ .service_metadata = service_metadata, .action = create_repository };
        }
    },
    Response: type = struct {
        repository: ?RepositoryDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_domain: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/domain",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDomain",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain };
        }
    },
    Response: type = struct {
        domain: ?DomainDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_domain_permissions_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/domain/permissions/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDomainPermissionsPolicy",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        policy_revision: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .policy_revision = "policy-revision",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .policy_revision = "policyRevision",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain_permissions_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain_permissions_policy };
        }
    },
    Response: type = struct {
        policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_package: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/package",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePackage",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_package) } {
            return .{ .service_metadata = service_metadata, .action = delete_package };
        }
    },
    Response: type = struct {
        deleted_package: ?PackageSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted_package = "deletedPackage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_package_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package/versions/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePackageVersions",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        versions: [][]const u8,
        expected_status: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .versions = "versions",
                .expected_status = "expectedStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_package_versions) } {
            return .{ .service_metadata = service_metadata, .action = delete_package_versions };
        }
    },
    Response: type = struct {
        successful_versions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?SuccessfulPackageVersionInfo = null,
        } = null,
        failed_versions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PackageVersionError = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_versions = "successfulVersions",
                .failed_versions = "failedVersions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "successful_versions", field_name))
                return try serializeMap(self.successful_versions, self.fieldNameFor("successful_versions"), options, out_stream);
            if (std.mem.eql(u8, "failed_versions", field_name))
                return try serializeMap(self.failed_versions, self.fieldNameFor("failed_versions"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_repository: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/repository",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRepository",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_repository) } {
            return .{ .service_metadata = service_metadata, .action = delete_repository };
        }
    },
    Response: type = struct {
        repository: ?RepositoryDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_repository_permissions_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/repository/permissions/policies",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRepositoryPermissionsPolicy",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        policy_revision: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .policy_revision = "policy-revision",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .policy_revision = "policyRevision",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_repository_permissions_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_repository_permissions_policy };
        }
    },
    Response: type = struct {
        policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/domain",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomain",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain };
        }
    },
    Response: type = struct {
        domain: ?DomainDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_package: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/package",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackage",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_package) } {
            return .{ .service_metadata = service_metadata, .action = describe_package };
        }
    },
    Response: type = struct {
        package: struct {
            format: ?[]const u8 = null,
            namespace: ?[]const u8 = null,
            name: ?[]const u8 = null,
            origin_configuration: ?PackageOriginConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .format = "format",
                    .namespace = "namespace",
                    .name = "name",
                    .origin_configuration = "originConfiguration",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package = "package",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_package_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/package/version",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackageVersion",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        package_version: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
            .package_version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .package_version = "packageVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_package_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_package_version };
        }
    },
    Response: type = struct {
        package_version: struct {
            format: ?[]const u8 = null,
            namespace: ?[]const u8 = null,
            package_name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            summary: ?[]const u8 = null,
            home_page: ?[]const u8 = null,
            source_code_repository: ?[]const u8 = null,
            published_time: ?i64 = null,
            licenses: ?[]struct {
                name: ?[]const u8 = null,
                url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .url = "url",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            revision: ?[]const u8 = null,
            status: ?[]const u8 = null,
            origin: ?PackageVersionOrigin = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .format = "format",
                    .namespace = "namespace",
                    .package_name = "packageName",
                    .display_name = "displayName",
                    .version = "version",
                    .summary = "summary",
                    .home_page = "homePage",
                    .source_code_repository = "sourceCodeRepository",
                    .published_time = "publishedTime",
                    .licenses = "licenses",
                    .revision = "revision",
                    .status = "status",
                    .origin = "origin",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_version = "packageVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_repository: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/repository",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRepository",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_repository) } {
            return .{ .service_metadata = service_metadata, .action = describe_repository };
        }
    },
    Response: type = struct {
        repository: ?RepositoryDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_external_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/repository/external-connection",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateExternalConnection",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        external_connection: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .external_connection = "external-connection",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .external_connection = "externalConnection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_external_connection) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_external_connection };
        }
    },
    Response: type = struct {
        repository: ?RepositoryDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const dispose_package_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package/versions/dispose",
        .success_code = 200,
    };

    action_name: []const u8 = "DisposePackageVersions",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        versions: [][]const u8,
        version_revisions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        expected_status: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .versions = "versions",
                .version_revisions = "versionRevisions",
                .expected_status = "expectedStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "version_revisions", field_name))
                return try serializeMap(self.version_revisions, self.fieldNameFor("version_revisions"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(dispose_package_versions) } {
            return .{ .service_metadata = service_metadata, .action = dispose_package_versions };
        }
    },
    Response: type = struct {
        successful_versions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?SuccessfulPackageVersionInfo = null,
        } = null,
        failed_versions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PackageVersionError = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_versions = "successfulVersions",
                .failed_versions = "failedVersions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "successful_versions", field_name))
                return try serializeMap(self.successful_versions, self.fieldNameFor("successful_versions"), options, out_stream);
            if (std.mem.eql(u8, "failed_versions", field_name))
                return try serializeMap(self.failed_versions, self.fieldNameFor("failed_versions"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_authorization_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/authorization-token",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAuthorizationToken",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        duration_seconds: ?i64 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .duration_seconds = "duration",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .duration_seconds = "durationSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_authorization_token) } {
            return .{ .service_metadata = service_metadata, .action = get_authorization_token };
        }
    },
    Response: type = struct {
        authorization_token: ?[]const u8 = null,
        expiration: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization_token = "authorizationToken",
                .expiration = "expiration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_domain_permissions_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/domain/permissions/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainPermissionsPolicy",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_permissions_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_permissions_policy };
        }
    },
    Response: type = struct {
        policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_package_version_asset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/package/version/asset",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPackageVersionAsset",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        package_version: []const u8,
        asset: []const u8,
        package_version_revision: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
            .package_version = "version",
            .asset = "asset",
            .package_version_revision = "revision",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .package_version = "packageVersion",
                .asset = "asset",
                .package_version_revision = "packageVersionRevision",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_package_version_asset) } {
            return .{ .service_metadata = service_metadata, .action = get_package_version_asset };
        }
    },
    Response: type = struct {
        asset: ?[]const u8 = null,
        asset_name: ?[]const u8 = null,
        package_version: ?[]const u8 = null,
        package_version_revision: ?[]const u8 = null,
        pub const http_header = .{
            .asset_name = "X-AssetName",
            .package_version = "X-PackageVersion",
            .package_version_revision = "X-PackageVersionRevision",
        };

        pub const http_payload: []const u8 = "asset";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset = "asset",
                .asset_name = "assetName",
                .package_version = "packageVersion",
                .package_version_revision = "packageVersionRevision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_package_version_readme: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/package/version/readme",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPackageVersionReadme",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        package_version: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
            .package_version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .package_version = "packageVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_package_version_readme) } {
            return .{ .service_metadata = service_metadata, .action = get_package_version_readme };
        }
    },
    Response: type = struct {
        format: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        package: ?[]const u8 = null,
        version: ?[]const u8 = null,
        version_revision: ?[]const u8 = null,
        readme: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .version = "version",
                .version_revision = "versionRevision",
                .readme = "readme",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_repository_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/repository/endpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRepositoryEndpoint",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_endpoint };
        }
    },
    Response: type = struct {
        repository_endpoint: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_endpoint = "repositoryEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_repository_permissions_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/repository/permissions/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRepositoryPermissionsPolicy",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_permissions_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_permissions_policy };
        }
    },
    Response: type = struct {
        policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_domains: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/domains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomains",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domains) } {
            return .{ .service_metadata = service_metadata, .action = list_domains };
        }
    },
    Response: type = struct {
        domains: ?[]struct {
            name: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_time: ?i64 = null,
            encryption_key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .owner = "owner",
                    .arn = "arn",
                    .status = "status",
                    .created_time = "createdTime",
                    .encryption_key = "encryptionKey",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domains = "domains",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_packages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/packages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackages",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        package_prefix: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        publish: ?[]const u8 = null,
        upstream: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package_prefix = "package-prefix",
            .max_results = "max-results",
            .next_token = "next-token",
            .publish = "publish",
            .upstream = "upstream",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package_prefix = "packagePrefix",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .publish = "publish",
                .upstream = "upstream",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_packages };
        }
    },
    Response: type = struct {
        packages: ?[]PackageSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .packages = "packages",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_package_version_assets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package/version/assets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackageVersionAssets",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        package_version: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
            .package_version = "version",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .package_version = "packageVersion",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_package_version_assets) } {
            return .{ .service_metadata = service_metadata, .action = list_package_version_assets };
        }
    },
    Response: type = struct {
        format: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        package: ?[]const u8 = null,
        version: ?[]const u8 = null,
        version_revision: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        assets: ?[]AssetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .version = "version",
                .version_revision = "versionRevision",
                .next_token = "nextToken",
                .assets = "assets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_package_version_dependencies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package/version/dependencies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackageVersionDependencies",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        package_version: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
            .package_version = "version",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .package_version = "packageVersion",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_package_version_dependencies) } {
            return .{ .service_metadata = service_metadata, .action = list_package_version_dependencies };
        }
    },
    Response: type = struct {
        format: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        package: ?[]const u8 = null,
        version: ?[]const u8 = null,
        version_revision: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        dependencies: ?[]struct {
            namespace: ?[]const u8 = null,
            package: ?[]const u8 = null,
            dependency_type: ?[]const u8 = null,
            version_requirement: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .namespace = "namespace",
                    .package = "package",
                    .dependency_type = "dependencyType",
                    .version_requirement = "versionRequirement",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .version = "version",
                .version_revision = "versionRevision",
                .next_token = "nextToken",
                .dependencies = "dependencies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_package_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackageVersions",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        status: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        origin_type: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
            .status = "status",
            .sort_by = "sortBy",
            .max_results = "max-results",
            .next_token = "next-token",
            .origin_type = "originType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .status = "status",
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .origin_type = "originType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_package_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_package_versions };
        }
    },
    Response: type = struct {
        default_display_version: ?[]const u8 = null,
        format: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        package: ?[]const u8 = null,
        versions: ?[]struct {
            version: []const u8,
            revision: ?[]const u8 = null,
            status: []const u8,
            origin: ?PackageVersionOrigin = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "version",
                    .revision = "revision",
                    .status = "status",
                    .origin = "origin",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .default_display_version = "defaultDisplayVersion",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .versions = "versions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_repositories: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/repositories",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRepositories",
    Request: type = struct {
        repository_prefix: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .repository_prefix = "repository-prefix",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_prefix = "repositoryPrefix",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_repositories) } {
            return .{ .service_metadata = service_metadata, .action = list_repositories };
        }
    },
    Response: type = struct {
        repositories: ?[]RepositorySummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repositories = "repositories",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_repositories_in_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/domain/repositories",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRepositoriesInDomain",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        administrator_account: ?[]const u8 = null,
        repository_prefix: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .administrator_account = "administrator-account",
            .repository_prefix = "repository-prefix",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .administrator_account = "administratorAccount",
                .repository_prefix = "repositoryPrefix",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_repositories_in_domain) } {
            return .{ .service_metadata = service_metadata, .action = list_repositories_in_domain };
        }
    },
    Response: type = struct {
        repositories: ?[]RepositorySummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repositories = "repositories",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const publish_package_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package/version/publish",
        .success_code = 200,
    };

    action_name: []const u8 = "PublishPackageVersion",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        package_version: []const u8,
        asset_content: []const u8,
        asset_name: []const u8,
        asset_sha256: []const u8,
        unfinished: ?bool = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
            .package_version = "version",
            .asset_name = "asset",
            .unfinished = "unfinished",
        };

        pub const http_header = .{
            .asset_sha256 = "x-amz-content-sha256",
        };

        pub const http_payload: []const u8 = "asset_content";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .package_version = "packageVersion",
                .asset_content = "assetContent",
                .asset_name = "assetName",
                .asset_sha256 = "assetSHA256",
                .unfinished = "unfinished",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_package_version) } {
            return .{ .service_metadata = service_metadata, .action = publish_package_version };
        }
    },
    Response: type = struct {
        format: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        package: ?[]const u8 = null,
        version: ?[]const u8 = null,
        version_revision: ?[]const u8 = null,
        status: ?[]const u8 = null,
        asset: ?AssetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .version = "version",
                .version_revision = "versionRevision",
                .status = "status",
                .asset = "asset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const put_domain_permissions_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/domain/permissions/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDomainPermissionsPolicy",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        policy_revision: ?[]const u8 = null,
        policy_document: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .policy_revision = "policyRevision",
                .policy_document = "policyDocument",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_domain_permissions_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_domain_permissions_policy };
        }
    },
    Response: type = struct {
        policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const put_package_origin_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package",
        .success_code = 200,
    };

    action_name: []const u8 = "PutPackageOriginConfiguration",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        restrictions: PackageOriginRestrictions,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .restrictions = "restrictions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_package_origin_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_package_origin_configuration };
        }
    },
    Response: type = struct {
        origin_configuration: ?PackageOriginConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origin_configuration = "originConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_repository_permissions_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/repository/permissions/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutRepositoryPermissionsPolicy",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        policy_revision: ?[]const u8 = null,
        policy_document: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .policy_revision = "policyRevision",
                .policy_document = "policyDocument",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_repository_permissions_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_repository_permissions_policy };
        }
    },
    Response: type = struct {
        policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tag",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/untag",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_package_versions_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/package/versions/update_status",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePackageVersionsStatus",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        format: []const u8,
        namespace: ?[]const u8 = null,
        package: []const u8,
        versions: [][]const u8,
        version_revisions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        expected_status: ?[]const u8 = null,
        target_status: []const u8,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
            .format = "format",
            .namespace = "namespace",
            .package = "package",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .format = "format",
                .namespace = "namespace",
                .package = "package",
                .versions = "versions",
                .version_revisions = "versionRevisions",
                .expected_status = "expectedStatus",
                .target_status = "targetStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "version_revisions", field_name))
                return try serializeMap(self.version_revisions, self.fieldNameFor("version_revisions"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_package_versions_status) } {
            return .{ .service_metadata = service_metadata, .action = update_package_versions_status };
        }
    },
    Response: type = struct {
        successful_versions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?SuccessfulPackageVersionInfo = null,
        } = null,
        failed_versions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PackageVersionError = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_versions = "successfulVersions",
                .failed_versions = "failedVersions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "successful_versions", field_name))
                return try serializeMap(self.successful_versions, self.fieldNameFor("successful_versions"), options, out_stream);
            if (std.mem.eql(u8, "failed_versions", field_name))
                return try serializeMap(self.failed_versions, self.fieldNameFor("failed_versions"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_repository: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/repository",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRepository",
    Request: type = struct {
        domain: []const u8,
        domain_owner: ?[]const u8 = null,
        repository: []const u8,
        description: ?[]const u8 = null,
        upstreams: ?[]UpstreamRepository = null,

        pub const http_query = .{
            .domain = "domain",
            .domain_owner = "domain-owner",
            .repository = "repository",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .domain_owner = "domainOwner",
                .repository = "repository",
                .description = "description",
                .upstreams = "upstreams",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_repository) } {
            return .{ .service_metadata = service_metadata, .action = update_repository };
        }
    },
    Response: type = struct {
        repository: ?RepositoryDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const RepositoryDescription = struct {
    name: ?[]const u8 = null,
    administrator_account: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    domain_owner: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    upstreams: ?[]UpstreamRepositoryInfo = null,
    external_connections: ?[]RepositoryExternalConnectionInfo = null,
    created_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .administrator_account = "administratorAccount",
            .domain_name = "domainName",
            .domain_owner = "domainOwner",
            .arn = "arn",
            .description = "description",
            .upstreams = "upstreams",
            .external_connections = "externalConnections",
            .created_time = "createdTime",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryExternalConnectionInfo = struct {
    external_connection_name: ?[]const u8 = null,
    package_format: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_connection_name = "externalConnectionName",
            .package_format = "packageFormat",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const UpstreamRepositoryInfo = struct {
    repository_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_name = "repositoryName",
        };
        return @field(mappings, field_name);
    }
};

pub const UpstreamRepository = struct {
    repository_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_name = "repositoryName",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageVersionError = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const SuccessfulPackageVersionInfo = struct {
    revision: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .revision = "revision",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePolicy = struct {
    resource_arn: ?[]const u8 = null,
    revision: ?[]const u8 = null,
    document: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "resourceArn",
            .revision = "revision",
            .document = "document",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageOriginConfiguration = struct {
    restrictions: ?PackageOriginRestrictions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .restrictions = "restrictions",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageOriginRestrictions = struct {
    publish: []const u8,
    upstream: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .publish = "publish",
            .upstream = "upstream",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetSummary = struct {
    name: []const u8,
    size: ?i64 = null,
    hashes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .size = "size",
            .hashes = "hashes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "hashes", field_name))
            return try serializeMap(self.hashes, self.fieldNameFor("hashes"), options, out_stream);
        return false;
    }
};

pub const RepositorySummary = struct {
    name: ?[]const u8 = null,
    administrator_account: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    domain_owner: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .administrator_account = "administratorAccount",
            .domain_name = "domainName",
            .domain_owner = "domainOwner",
            .arn = "arn",
            .description = "description",
            .created_time = "createdTime",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageVersionOrigin = struct {
    domain_entry_point: ?DomainEntryPoint = null,
    origin_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_entry_point = "domainEntryPoint",
            .origin_type = "originType",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainEntryPoint = struct {
    repository_name: ?[]const u8 = null,
    external_connection_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_name = "repositoryName",
            .external_connection_name = "externalConnectionName",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageSummary = struct {
    format: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    package: ?[]const u8 = null,
    origin_configuration: ?PackageOriginConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "format",
            .namespace = "namespace",
            .package = "package",
            .origin_configuration = "originConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainDescription = struct {
    name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_time: ?i64 = null,
    encryption_key: ?[]const u8 = null,
    repository_count: ?i64 = null,
    asset_size_bytes: ?i64 = null,
    s3_bucket_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .owner = "owner",
            .arn = "arn",
            .status = "status",
            .created_time = "createdTime",
            .encryption_key = "encryptionKey",
            .repository_count = "repositoryCount",
            .asset_size_bytes = "assetSizeBytes",
            .s3_bucket_arn = "s3BucketArn",
        };
        return @field(mappings, field_name);
    }
};
