const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-10-15";
pub const sdk_id: []const u8 = "codestar notifications";
pub const arn_namespace: ?[]const u8 = "codestar-notifications";
pub const endpoint_prefix: []const u8 = "codestar-notifications";
pub const sigv4_name: []const u8 = "codestar-notifications";
pub const name: []const u8 = "CodeStarNotifications_20191015";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-10-15",
    sdk_id: []const u8 = "codestar notifications",
    arn_namespace: ?[]const u8 = "codestar-notifications",
    endpoint_prefix: []const u8 = "codestar-notifications",
    sigv4_name: []const u8 = "codestar-notifications",
    name: []const u8 = "CodeStarNotifications_20191015",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_notification_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createNotificationRule",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNotificationRule",
    Request: type = struct {
        name: []const u8,
        event_type_ids: [][]const u8,
        resource: []const u8,
        targets: []Target,
        detail_type: []const u8,
        client_request_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .event_type_ids = "EventTypeIds",
                .resource = "Resource",
                .targets = "Targets",
                .detail_type = "DetailType",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_notification_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_notification_rule };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        Configuration,
        LimitExceeded,
        ResourceAlreadyExists,
        Validation,
    },
} = .{};
pub const delete_notification_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteNotificationRule",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteNotificationRule",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_notification_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_notification_rule };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const delete_target: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteTarget",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTarget",
    Request: type = struct {
        target_address: []const u8,
        force_unsubscribe_all: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_address = "TargetAddress",
                .force_unsubscribe_all = "ForceUnsubscribeAll",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_target) } {
            return .{ .service_metadata = service_metadata, .action = delete_target };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const describe_notification_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeNotificationRule",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeNotificationRule",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_notification_rule) } {
            return .{ .service_metadata = service_metadata, .action = describe_notification_rule };
        }
    },
    Response: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        event_types: ?[]EventTypeSummary = null,
        resource: ?[]const u8 = null,
        targets: ?[]TargetSummary = null,
        detail_type: ?[]const u8 = null,
        created_by: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .event_types = "EventTypes",
                .resource = "Resource",
                .targets = "Targets",
                .detail_type = "DetailType",
                .created_by = "CreatedBy",
                .status = "Status",
                .created_timestamp = "CreatedTimestamp",
                .last_modified_timestamp = "LastModifiedTimestamp",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_event_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listEventTypes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEventTypes",
    Request: type = struct {
        filters: ?[]struct {
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_types) } {
            return .{ .service_metadata = service_metadata, .action = list_event_types };
        }
    },
    Response: type = struct {
        event_types: ?[]EventTypeSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_types = "EventTypes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const list_notification_rules: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listNotificationRules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNotificationRules",
    Request: type = struct {
        filters: ?[]struct {
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notification_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_notification_rules };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        notification_rules: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .notification_rules = "NotificationRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listTagsForResource",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_targets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listTargets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTargets",
    Request: type = struct {
        filters: ?[]struct {
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_targets) } {
            return .{ .service_metadata = service_metadata, .action = list_targets };
        }
    },
    Response: type = struct {
        targets: ?[]TargetSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .targets = "Targets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const subscribe: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/subscribe",
        .success_code = 200,
    };

    action_name: []const u8 = "Subscribe",
    Request: type = struct {
        arn: []const u8,
        target: Target,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .target = "Target",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(subscribe) } {
            return .{ .service_metadata = service_metadata, .action = subscribe };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Configuration,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const unsubscribe: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/unsubscribe",
        .success_code = 200,
    };

    action_name: []const u8 = "Unsubscribe",
    Request: type = struct {
        arn: []const u8,
        target_address: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .target_address = "TargetAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unsubscribe) } {
            return .{ .service_metadata = service_metadata, .action = unsubscribe };
        }
    },
    Response: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/untagResource/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_notification_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateNotificationRule",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateNotificationRule",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        event_type_ids: ?[][]const u8 = null,
        targets: ?[]Target = null,
        detail_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .status = "Status",
                .event_type_ids = "EventTypeIds",
                .targets = "Targets",
                .detail_type = "DetailType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_notification_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_notification_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Configuration,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const Target = struct {
    target_type: ?[]const u8 = null,
    target_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_type = "TargetType",
            .target_address = "TargetAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetSummary = struct {
    target_address: ?[]const u8 = null,
    target_type: ?[]const u8 = null,
    target_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_address = "TargetAddress",
            .target_type = "TargetType",
            .target_status = "TargetStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const EventTypeSummary = struct {
    event_type_id: ?[]const u8 = null,
    service_name: ?[]const u8 = null,
    event_type_name: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_type_id = "EventTypeId",
            .service_name = "ServiceName",
            .event_type_name = "EventTypeName",
            .resource_type = "ResourceType",
        };
        return @field(mappings, field_name);
    }
};
