const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-06-30";
pub const sdk_id: []const u8 = "Cognito Identity";
pub const arn_namespace: ?[]const u8 = "cognito-identity";
pub const endpoint_prefix: []const u8 = "cognito-identity";
pub const sigv4_name: []const u8 = "cognito-identity";
pub const name: []const u8 = "AWSCognitoIdentityService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2014-06-30",
    sdk_id: []const u8 = "Cognito Identity",
    arn_namespace: ?[]const u8 = "cognito-identity",
    endpoint_prefix: []const u8 = "cognito-identity",
    sigv4_name: []const u8 = "cognito-identity",
    name: []const u8 = "AWSCognitoIdentityService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_identity_pool: struct {
    action_name: []const u8 = "CreateIdentityPool",
    Request: type = struct {
        identity_pool_name: []const u8,
        allow_unauthenticated_identities: bool,
        allow_classic_flow: ?bool = null,
        supported_login_providers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        developer_provider_name: ?[]const u8 = null,
        open_id_connect_provider_ar_ns: ?[][]const u8 = null,
        cognito_identity_providers: ?[]CognitoIdentityProvider = null,
        saml_provider_ar_ns: ?[][]const u8 = null,
        identity_pool_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_name = "IdentityPoolName",
                .allow_unauthenticated_identities = "AllowUnauthenticatedIdentities",
                .allow_classic_flow = "AllowClassicFlow",
                .supported_login_providers = "SupportedLoginProviders",
                .developer_provider_name = "DeveloperProviderName",
                .open_id_connect_provider_ar_ns = "OpenIdConnectProviderARNs",
                .cognito_identity_providers = "CognitoIdentityProviders",
                .saml_provider_ar_ns = "SamlProviderARNs",
                .identity_pool_tags = "IdentityPoolTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "supported_login_providers", field_name))
                return try serializeMap(self.supported_login_providers, self.fieldNameFor("supported_login_providers"), options, out_stream);
            if (std.mem.eql(u8, "identity_pool_tags", field_name))
                return try serializeMap(self.identity_pool_tags, self.fieldNameFor("identity_pool_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_identity_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_identity_pool };
        }
    },
    Response: type = struct {
        identity_pool_id: []const u8,
        identity_pool_name: []const u8,
        allow_unauthenticated_identities: bool,
        allow_classic_flow: ?bool = null,
        supported_login_providers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        developer_provider_name: ?[]const u8 = null,
        open_id_connect_provider_ar_ns: ?[][]const u8 = null,
        cognito_identity_providers: ?[]CognitoIdentityProvider = null,
        saml_provider_ar_ns: ?[][]const u8 = null,
        identity_pool_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_pool_name = "IdentityPoolName",
                .allow_unauthenticated_identities = "AllowUnauthenticatedIdentities",
                .allow_classic_flow = "AllowClassicFlow",
                .supported_login_providers = "SupportedLoginProviders",
                .developer_provider_name = "DeveloperProviderName",
                .open_id_connect_provider_ar_ns = "OpenIdConnectProviderARNs",
                .cognito_identity_providers = "CognitoIdentityProviders",
                .saml_provider_ar_ns = "SamlProviderARNs",
                .identity_pool_tags = "IdentityPoolTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "supported_login_providers", field_name))
                return try serializeMap(self.supported_login_providers, self.fieldNameFor("supported_login_providers"), options, out_stream);
            if (std.mem.eql(u8, "identity_pool_tags", field_name))
                return try serializeMap(self.identity_pool_tags, self.fieldNameFor("identity_pool_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceConflict,
        TooManyRequests,
    },
} = .{};
pub const delete_identities: struct {
    action_name: []const u8 = "DeleteIdentities",
    Request: type = struct {
        identity_ids_to_delete: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_ids_to_delete = "IdentityIdsToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_identities) } {
            return .{ .service_metadata = service_metadata, .action = delete_identities };
        }
    },
    Response: type = struct {
        unprocessed_identity_ids: ?[]struct {
            identity_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identity_id = "IdentityId",
                    .error_code = "ErrorCode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_identity_ids = "UnprocessedIdentityIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        TooManyRequests,
    },
} = .{};
pub const delete_identity_pool: struct {
    action_name: []const u8 = "DeleteIdentityPool",
    Request: type = struct {
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_identity_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_identity_pool };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_identity: struct {
    action_name: []const u8 = "DescribeIdentity",
    Request: type = struct {
        identity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_identity) } {
            return .{ .service_metadata = service_metadata, .action = describe_identity };
        }
    },
    Response: type = struct {
        identity_id: ?[]const u8 = null,
        logins: ?[][]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .logins = "Logins",
                .creation_date = "CreationDate",
                .last_modified_date = "LastModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_identity_pool: struct {
    action_name: []const u8 = "DescribeIdentityPool",
    Request: type = struct {
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_identity_pool) } {
            return .{ .service_metadata = service_metadata, .action = describe_identity_pool };
        }
    },
    Response: type = struct {
        identity_pool_id: []const u8,
        identity_pool_name: []const u8,
        allow_unauthenticated_identities: bool,
        allow_classic_flow: ?bool = null,
        supported_login_providers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        developer_provider_name: ?[]const u8 = null,
        open_id_connect_provider_ar_ns: ?[][]const u8 = null,
        cognito_identity_providers: ?[]CognitoIdentityProvider = null,
        saml_provider_ar_ns: ?[][]const u8 = null,
        identity_pool_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_pool_name = "IdentityPoolName",
                .allow_unauthenticated_identities = "AllowUnauthenticatedIdentities",
                .allow_classic_flow = "AllowClassicFlow",
                .supported_login_providers = "SupportedLoginProviders",
                .developer_provider_name = "DeveloperProviderName",
                .open_id_connect_provider_ar_ns = "OpenIdConnectProviderARNs",
                .cognito_identity_providers = "CognitoIdentityProviders",
                .saml_provider_ar_ns = "SamlProviderARNs",
                .identity_pool_tags = "IdentityPoolTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "supported_login_providers", field_name))
                return try serializeMap(self.supported_login_providers, self.fieldNameFor("supported_login_providers"), options, out_stream);
            if (std.mem.eql(u8, "identity_pool_tags", field_name))
                return try serializeMap(self.identity_pool_tags, self.fieldNameFor("identity_pool_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_credentials_for_identity: struct {
    action_name: []const u8 = "GetCredentialsForIdentity",
    Request: type = struct {
        identity_id: []const u8,
        logins: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        custom_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .logins = "Logins",
                .custom_role_arn = "CustomRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "logins", field_name))
                return try serializeMap(self.logins, self.fieldNameFor("logins"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_credentials_for_identity) } {
            return .{ .service_metadata = service_metadata, .action = get_credentials_for_identity };
        }
    },
    Response: type = struct {
        identity_id: ?[]const u8 = null,
        credentials: ?struct {
            access_key_id: ?[]const u8 = null,
            secret_key: ?[]const u8 = null,
            session_token: ?[]const u8 = null,
            expiration: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_key_id = "AccessKeyId",
                    .secret_key = "SecretKey",
                    .session_token = "SessionToken",
                    .expiration = "Expiration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExternalService,
        InternalError,
        InvalidIdentityPoolConfiguration,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_id: struct {
    action_name: []const u8 = "GetId",
    Request: type = struct {
        account_id: ?[]const u8 = null,
        identity_pool_id: []const u8,
        logins: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .identity_pool_id = "IdentityPoolId",
                .logins = "Logins",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "logins", field_name))
                return try serializeMap(self.logins, self.fieldNameFor("logins"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_id) } {
            return .{ .service_metadata = service_metadata, .action = get_id };
        }
    },
    Response: type = struct {
        identity_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExternalService,
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_identity_pool_roles: struct {
    action_name: []const u8 = "GetIdentityPoolRoles",
    Request: type = struct {
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_pool_roles) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_pool_roles };
        }
    },
    Response: type = struct {
        identity_pool_id: ?[]const u8 = null,
        roles: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        role_mappings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RoleMapping = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .roles = "Roles",
                .role_mappings = "RoleMappings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "roles", field_name))
                return try serializeMap(self.roles, self.fieldNameFor("roles"), options, out_stream);
            if (std.mem.eql(u8, "role_mappings", field_name))
                return try serializeMap(self.role_mappings, self.fieldNameFor("role_mappings"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_open_id_token: struct {
    action_name: []const u8 = "GetOpenIdToken",
    Request: type = struct {
        identity_id: []const u8,
        logins: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .logins = "Logins",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "logins", field_name))
                return try serializeMap(self.logins, self.fieldNameFor("logins"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_open_id_token) } {
            return .{ .service_metadata = service_metadata, .action = get_open_id_token };
        }
    },
    Response: type = struct {
        identity_id: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExternalService,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_open_id_token_for_developer_identity: struct {
    action_name: []const u8 = "GetOpenIdTokenForDeveloperIdentity",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: ?[]const u8 = null,
        logins: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        principal_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        token_duration: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .logins = "Logins",
                .principal_tags = "PrincipalTags",
                .token_duration = "TokenDuration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "logins", field_name))
                return try serializeMap(self.logins, self.fieldNameFor("logins"), options, out_stream);
            if (std.mem.eql(u8, "principal_tags", field_name))
                return try serializeMap(self.principal_tags, self.fieldNameFor("principal_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_open_id_token_for_developer_identity) } {
            return .{ .service_metadata = service_metadata, .action = get_open_id_token_for_developer_identity };
        }
    },
    Response: type = struct {
        identity_id: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DeveloperUserAlreadyRegistered,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_principal_tag_attribute_map: struct {
    action_name: []const u8 = "GetPrincipalTagAttributeMap",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_provider_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_provider_name = "IdentityProviderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_principal_tag_attribute_map) } {
            return .{ .service_metadata = service_metadata, .action = get_principal_tag_attribute_map };
        }
    },
    Response: type = struct {
        identity_pool_id: ?[]const u8 = null,
        identity_provider_name: ?[]const u8 = null,
        use_defaults: ?bool = null,
        principal_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_provider_name = "IdentityProviderName",
                .use_defaults = "UseDefaults",
                .principal_tags = "PrincipalTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "principal_tags", field_name))
                return try serializeMap(self.principal_tags, self.fieldNameFor("principal_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_identities: struct {
    action_name: []const u8 = "ListIdentities",
    Request: type = struct {
        identity_pool_id: []const u8,
        max_results: i64,
        next_token: ?[]const u8 = null,
        hide_disabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .hide_disabled = "HideDisabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identities) } {
            return .{ .service_metadata = service_metadata, .action = list_identities };
        }
    },
    Response: type = struct {
        identity_pool_id: ?[]const u8 = null,
        identities: ?[]IdentityDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identities = "Identities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_identity_pools: struct {
    action_name: []const u8 = "ListIdentityPools",
    Request: type = struct {
        max_results: i64,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identity_pools) } {
            return .{ .service_metadata = service_metadata, .action = list_identity_pools };
        }
    },
    Response: type = struct {
        identity_pools: ?[]struct {
            identity_pool_id: ?[]const u8 = null,
            identity_pool_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identity_pool_id = "IdentityPoolId",
                    .identity_pool_name = "IdentityPoolName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pools = "IdentityPools",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const lookup_developer_identity: struct {
    action_name: []const u8 = "LookupDeveloperIdentity",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: ?[]const u8 = null,
        developer_user_identifier: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .developer_user_identifier = "DeveloperUserIdentifier",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(lookup_developer_identity) } {
            return .{ .service_metadata = service_metadata, .action = lookup_developer_identity };
        }
    },
    Response: type = struct {
        identity_id: ?[]const u8 = null,
        developer_user_identifier_list: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .developer_user_identifier_list = "DeveloperUserIdentifierList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const merge_developer_identities: struct {
    action_name: []const u8 = "MergeDeveloperIdentities",
    Request: type = struct {
        source_user_identifier: []const u8,
        destination_user_identifier: []const u8,
        developer_provider_name: []const u8,
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_user_identifier = "SourceUserIdentifier",
                .destination_user_identifier = "DestinationUserIdentifier",
                .developer_provider_name = "DeveloperProviderName",
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_developer_identities) } {
            return .{ .service_metadata = service_metadata, .action = merge_developer_identities };
        }
    },
    Response: type = struct {
        identity_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const set_identity_pool_roles: struct {
    action_name: []const u8 = "SetIdentityPoolRoles",
    Request: type = struct {
        identity_pool_id: []const u8,
        roles: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        role_mappings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RoleMapping = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .roles = "Roles",
                .role_mappings = "RoleMappings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "roles", field_name))
                return try serializeMap(self.roles, self.fieldNameFor("roles"), options, out_stream);
            if (std.mem.eql(u8, "role_mappings", field_name))
                return try serializeMap(self.role_mappings, self.fieldNameFor("role_mappings"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_identity_pool_roles) } {
            return .{ .service_metadata = service_metadata, .action = set_identity_pool_roles };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const set_principal_tag_attribute_map: struct {
    action_name: []const u8 = "SetPrincipalTagAttributeMap",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_provider_name: []const u8,
        use_defaults: ?bool = null,
        principal_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_provider_name = "IdentityProviderName",
                .use_defaults = "UseDefaults",
                .principal_tags = "PrincipalTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "principal_tags", field_name))
                return try serializeMap(self.principal_tags, self.fieldNameFor("principal_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_principal_tag_attribute_map) } {
            return .{ .service_metadata = service_metadata, .action = set_principal_tag_attribute_map };
        }
    },
    Response: type = struct {
        identity_pool_id: ?[]const u8 = null,
        identity_provider_name: ?[]const u8 = null,
        use_defaults: ?bool = null,
        principal_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_provider_name = "IdentityProviderName",
                .use_defaults = "UseDefaults",
                .principal_tags = "PrincipalTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "principal_tags", field_name))
                return try serializeMap(self.principal_tags, self.fieldNameFor("principal_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const unlink_developer_identity: struct {
    action_name: []const u8 = "UnlinkDeveloperIdentity",
    Request: type = struct {
        identity_id: []const u8,
        identity_pool_id: []const u8,
        developer_provider_name: []const u8,
        developer_user_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .identity_pool_id = "IdentityPoolId",
                .developer_provider_name = "DeveloperProviderName",
                .developer_user_identifier = "DeveloperUserIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unlink_developer_identity) } {
            return .{ .service_metadata = service_metadata, .action = unlink_developer_identity };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const unlink_identity: struct {
    action_name: []const u8 = "UnlinkIdentity",
    Request: type = struct {
        identity_id: []const u8,
        logins: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        logins_to_remove: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_id = "IdentityId",
                .logins = "Logins",
                .logins_to_remove = "LoginsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "logins", field_name))
                return try serializeMap(self.logins, self.fieldNameFor("logins"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unlink_identity) } {
            return .{ .service_metadata = service_metadata, .action = unlink_identity };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ExternalService,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const update_identity_pool: struct {
    action_name: []const u8 = "UpdateIdentityPool",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_pool_name: []const u8,
        allow_unauthenticated_identities: bool,
        allow_classic_flow: ?bool = null,
        supported_login_providers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        developer_provider_name: ?[]const u8 = null,
        open_id_connect_provider_ar_ns: ?[][]const u8 = null,
        cognito_identity_providers: ?[]CognitoIdentityProvider = null,
        saml_provider_ar_ns: ?[][]const u8 = null,
        identity_pool_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_pool_name = "IdentityPoolName",
                .allow_unauthenticated_identities = "AllowUnauthenticatedIdentities",
                .allow_classic_flow = "AllowClassicFlow",
                .supported_login_providers = "SupportedLoginProviders",
                .developer_provider_name = "DeveloperProviderName",
                .open_id_connect_provider_ar_ns = "OpenIdConnectProviderARNs",
                .cognito_identity_providers = "CognitoIdentityProviders",
                .saml_provider_ar_ns = "SamlProviderARNs",
                .identity_pool_tags = "IdentityPoolTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "supported_login_providers", field_name))
                return try serializeMap(self.supported_login_providers, self.fieldNameFor("supported_login_providers"), options, out_stream);
            if (std.mem.eql(u8, "identity_pool_tags", field_name))
                return try serializeMap(self.identity_pool_tags, self.fieldNameFor("identity_pool_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_identity_pool) } {
            return .{ .service_metadata = service_metadata, .action = update_identity_pool };
        }
    },
    Response: type = struct {
        identity_pool_id: []const u8,
        identity_pool_name: []const u8,
        allow_unauthenticated_identities: bool,
        allow_classic_flow: ?bool = null,
        supported_login_providers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        developer_provider_name: ?[]const u8 = null,
        open_id_connect_provider_ar_ns: ?[][]const u8 = null,
        cognito_identity_providers: ?[]CognitoIdentityProvider = null,
        saml_provider_ar_ns: ?[][]const u8 = null,
        identity_pool_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_pool_name = "IdentityPoolName",
                .allow_unauthenticated_identities = "AllowUnauthenticatedIdentities",
                .allow_classic_flow = "AllowClassicFlow",
                .supported_login_providers = "SupportedLoginProviders",
                .developer_provider_name = "DeveloperProviderName",
                .open_id_connect_provider_ar_ns = "OpenIdConnectProviderARNs",
                .cognito_identity_providers = "CognitoIdentityProviders",
                .saml_provider_ar_ns = "SamlProviderARNs",
                .identity_pool_tags = "IdentityPoolTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "supported_login_providers", field_name))
                return try serializeMap(self.supported_login_providers, self.fieldNameFor("supported_login_providers"), options, out_stream);
            if (std.mem.eql(u8, "identity_pool_tags", field_name))
                return try serializeMap(self.identity_pool_tags, self.fieldNameFor("identity_pool_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};

pub const CognitoIdentityProvider = struct {
    provider_name: ?[]const u8 = null,
    client_id: ?[]const u8 = null,
    server_side_token_check: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provider_name = "ProviderName",
            .client_id = "ClientId",
            .server_side_token_check = "ServerSideTokenCheck",
        };
        return @field(mappings, field_name);
    }
};

pub const RoleMapping = struct {
    type: []const u8,
    ambiguous_role_resolution: ?[]const u8 = null,
    rules_configuration: ?RulesConfigurationType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .ambiguous_role_resolution = "AmbiguousRoleResolution",
            .rules_configuration = "RulesConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const RulesConfigurationType = struct {
    rules: []MappingRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const MappingRule = struct {
    claim: []const u8,
    match_type: []const u8,
    value: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .claim = "Claim",
            .match_type = "MatchType",
            .value = "Value",
            .role_arn = "RoleARN",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityDescription = struct {
    identity_id: ?[]const u8 = null,
    logins: ?[][]const u8 = null,
    creation_date: ?i64 = null,
    last_modified_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_id = "IdentityId",
            .logins = "Logins",
            .creation_date = "CreationDate",
            .last_modified_date = "LastModifiedDate",
        };
        return @field(mappings, field_name);
    }
};
