const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-04-18";
pub const sdk_id: []const u8 = "Cognito Identity Provider";
pub const arn_namespace: ?[]const u8 = "cognito-idp";
pub const endpoint_prefix: []const u8 = "cognito-idp";
pub const sigv4_name: []const u8 = "cognito-idp";
pub const name: []const u8 = "AWSCognitoIdentityProviderService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-04-18",
    sdk_id: []const u8 = "Cognito Identity Provider",
    arn_namespace: ?[]const u8 = "cognito-idp",
    endpoint_prefix: []const u8 = "cognito-idp",
    sigv4_name: []const u8 = "cognito-idp",
    name: []const u8 = "AWSCognitoIdentityProviderService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_custom_attributes: struct {
    action_name: []const u8 = "AddCustomAttributes",
    Request: type = struct {
        user_pool_id: []const u8,
        custom_attributes: []SchemaAttributeType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .custom_attributes = "CustomAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_custom_attributes) } {
            return .{ .service_metadata = service_metadata, .action = add_custom_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserImportInProgress,
    },
} = .{};
pub const admin_add_user_to_group: struct {
    action_name: []const u8 = "AdminAddUserToGroup",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .group_name = "GroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_add_user_to_group) } {
            return .{ .service_metadata = service_metadata, .action = admin_add_user_to_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_confirm_sign_up: struct {
    action_name: []const u8 = "AdminConfirmSignUp",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_confirm_sign_up) } {
            return .{ .service_metadata = service_metadata, .action = admin_confirm_sign_up };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyFailedAttempts,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotFound,
    },
} = .{};
pub const admin_create_user: struct {
    action_name: []const u8 = "AdminCreateUser",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        user_attributes: ?[]AttributeType = null,
        validation_data: ?[]AttributeType = null,
        temporary_password: ?[]const u8 = null,
        force_alias_creation: ?bool = null,
        message_action: ?[]const u8 = null,
        desired_delivery_mediums: ?[][]const u8 = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .user_attributes = "UserAttributes",
                .validation_data = "ValidationData",
                .temporary_password = "TemporaryPassword",
                .force_alias_creation = "ForceAliasCreation",
                .message_action = "MessageAction",
                .desired_delivery_mediums = "DesiredDeliveryMediums",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_create_user) } {
            return .{ .service_metadata = service_metadata, .action = admin_create_user };
        }
    },
    Response: type = struct {
        user: ?UserType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeDeliveryFailure,
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidPassword,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        NotAuthorized,
        PreconditionNotMet,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UnsupportedUserState,
        UserLambdaValidation,
        UsernameExists,
        UserNotFound,
    },
} = .{};
pub const admin_delete_user: struct {
    action_name: []const u8 = "AdminDeleteUser",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_delete_user) } {
            return .{ .service_metadata = service_metadata, .action = admin_delete_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_delete_user_attributes: struct {
    action_name: []const u8 = "AdminDeleteUserAttributes",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        user_attribute_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .user_attribute_names = "UserAttributeNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_delete_user_attributes) } {
            return .{ .service_metadata = service_metadata, .action = admin_delete_user_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_disable_provider_for_user: struct {
    action_name: []const u8 = "AdminDisableProviderForUser",
    Request: type = struct {
        user_pool_id: []const u8,
        user: ProviderUserIdentifierType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .user = "User",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_disable_provider_for_user) } {
            return .{ .service_metadata = service_metadata, .action = admin_disable_provider_for_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AliasExists,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_disable_user: struct {
    action_name: []const u8 = "AdminDisableUser",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_disable_user) } {
            return .{ .service_metadata = service_metadata, .action = admin_disable_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_enable_user: struct {
    action_name: []const u8 = "AdminEnableUser",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_enable_user) } {
            return .{ .service_metadata = service_metadata, .action = admin_enable_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_forget_device: struct {
    action_name: []const u8 = "AdminForgetDevice",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        device_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .device_key = "DeviceKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_forget_device) } {
            return .{ .service_metadata = service_metadata, .action = admin_forget_device };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_get_device: struct {
    action_name: []const u8 = "AdminGetDevice",
    Request: type = struct {
        device_key: []const u8,
        user_pool_id: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_key = "DeviceKey",
                .user_pool_id = "UserPoolId",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_get_device) } {
            return .{ .service_metadata = service_metadata, .action = admin_get_device };
        }
    },
    Response: type = struct {
        device: DeviceType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const admin_get_user: struct {
    action_name: []const u8 = "AdminGetUser",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_get_user) } {
            return .{ .service_metadata = service_metadata, .action = admin_get_user };
        }
    },
    Response: type = struct {
        username: []const u8,
        user_attributes: ?[]AttributeType = null,
        user_create_date: ?i64 = null,
        user_last_modified_date: ?i64 = null,
        enabled: ?bool = null,
        user_status: ?[]const u8 = null,
        mfa_options: ?[]MFAOptionType = null,
        preferred_mfa_setting: ?[]const u8 = null,
        user_mfa_setting_list: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .user_attributes = "UserAttributes",
                .user_create_date = "UserCreateDate",
                .user_last_modified_date = "UserLastModifiedDate",
                .enabled = "Enabled",
                .user_status = "UserStatus",
                .mfa_options = "MFAOptions",
                .preferred_mfa_setting = "PreferredMfaSetting",
                .user_mfa_setting_list = "UserMFASettingList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_initiate_auth: struct {
    action_name: []const u8 = "AdminInitiateAuth",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: []const u8,
        auth_flow: []const u8,
        auth_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        analytics_metadata: ?AnalyticsMetadataType = null,
        context_data: ?ContextDataType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
                .auth_flow = "AuthFlow",
                .auth_parameters = "AuthParameters",
                .client_metadata = "ClientMetadata",
                .analytics_metadata = "AnalyticsMetadata",
                .context_data = "ContextData",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "auth_parameters", field_name))
                return try serializeMap(self.auth_parameters, self.fieldNameFor("auth_parameters"), options, out_stream);
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_initiate_auth) } {
            return .{ .service_metadata = service_metadata, .action = admin_initiate_auth };
        }
    },
    Response: type = struct {
        challenge_name: ?[]const u8 = null,
        session: ?[]const u8 = null,
        challenge_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        authentication_result: ?AuthenticationResultType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .challenge_name = "ChallengeName",
                .session = "Session",
                .challenge_parameters = "ChallengeParameters",
                .authentication_result = "AuthenticationResult",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "challenge_parameters", field_name))
                return try serializeMap(self.challenge_parameters, self.fieldNameFor("challenge_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        InvalidUserPoolConfiguration,
        MFAMethodNotFound,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const admin_link_provider_for_user: struct {
    action_name: []const u8 = "AdminLinkProviderForUser",
    Request: type = struct {
        user_pool_id: []const u8,
        destination_user: ProviderUserIdentifierType,
        source_user: ProviderUserIdentifierType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .destination_user = "DestinationUser",
                .source_user = "SourceUser",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_link_provider_for_user) } {
            return .{ .service_metadata = service_metadata, .action = admin_link_provider_for_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AliasExists,
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_list_devices: struct {
    action_name: []const u8 = "AdminListDevices",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        limit: ?i64 = null,
        pagination_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .limit = "Limit",
                .pagination_token = "PaginationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_list_devices) } {
            return .{ .service_metadata = service_metadata, .action = admin_list_devices };
        }
    },
    Response: type = struct {
        devices: ?[]DeviceType = null,
        pagination_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "Devices",
                .pagination_token = "PaginationToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const admin_list_groups_for_user: struct {
    action_name: []const u8 = "AdminListGroupsForUser",
    Request: type = struct {
        username: []const u8,
        user_pool_id: []const u8,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .user_pool_id = "UserPoolId",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_list_groups_for_user) } {
            return .{ .service_metadata = service_metadata, .action = admin_list_groups_for_user };
        }
    },
    Response: type = struct {
        groups: ?[]GroupType = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_list_user_auth_events: struct {
    action_name: []const u8 = "AdminListUserAuthEvents",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_list_user_auth_events) } {
            return .{ .service_metadata = service_metadata, .action = admin_list_user_auth_events };
        }
    },
    Response: type = struct {
        auth_events: ?[]struct {
            event_id: ?[]const u8 = null,
            event_type: ?[]const u8 = null,
            creation_date: ?i64 = null,
            event_response: ?[]const u8 = null,
            event_risk: ?struct {
                risk_decision: ?[]const u8 = null,
                risk_level: ?[]const u8 = null,
                compromised_credentials_detected: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .risk_decision = "RiskDecision",
                        .risk_level = "RiskLevel",
                        .compromised_credentials_detected = "CompromisedCredentialsDetected",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            challenge_responses: ?[]struct {
                challenge_name: ?[]const u8 = null,
                challenge_response: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .challenge_name = "ChallengeName",
                        .challenge_response = "ChallengeResponse",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            event_context_data: ?struct {
                ip_address: ?[]const u8 = null,
                device_name: ?[]const u8 = null,
                timezone: ?[]const u8 = null,
                city: ?[]const u8 = null,
                country: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ip_address = "IpAddress",
                        .device_name = "DeviceName",
                        .timezone = "Timezone",
                        .city = "City",
                        .country = "Country",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            event_feedback: ?struct {
                feedback_value: []const u8,
                provider: []const u8,
                feedback_date: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .feedback_value = "FeedbackValue",
                        .provider = "Provider",
                        .feedback_date = "FeedbackDate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_id = "EventId",
                    .event_type = "EventType",
                    .creation_date = "CreationDate",
                    .event_response = "EventResponse",
                    .event_risk = "EventRisk",
                    .challenge_responses = "ChallengeResponses",
                    .event_context_data = "EventContextData",
                    .event_feedback = "EventFeedback",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auth_events = "AuthEvents",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
        UserPoolAddOnNotEnabled,
    },
} = .{};
pub const admin_remove_user_from_group: struct {
    action_name: []const u8 = "AdminRemoveUserFromGroup",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .group_name = "GroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_remove_user_from_group) } {
            return .{ .service_metadata = service_metadata, .action = admin_remove_user_from_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_reset_user_password: struct {
    action_name: []const u8 = "AdminResetUserPassword",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_reset_user_password) } {
            return .{ .service_metadata = service_metadata, .action = admin_reset_user_password };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotFound,
    },
} = .{};
pub const admin_respond_to_auth_challenge: struct {
    action_name: []const u8 = "AdminRespondToAuthChallenge",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: []const u8,
        challenge_name: []const u8,
        challenge_responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        session: ?[]const u8 = null,
        analytics_metadata: ?AnalyticsMetadataType = null,
        context_data: ?ContextDataType = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
                .challenge_name = "ChallengeName",
                .challenge_responses = "ChallengeResponses",
                .session = "Session",
                .analytics_metadata = "AnalyticsMetadata",
                .context_data = "ContextData",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "challenge_responses", field_name))
                return try serializeMap(self.challenge_responses, self.fieldNameFor("challenge_responses"), options, out_stream);
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_respond_to_auth_challenge) } {
            return .{ .service_metadata = service_metadata, .action = admin_respond_to_auth_challenge };
        }
    },
    Response: type = struct {
        challenge_name: ?[]const u8 = null,
        session: ?[]const u8 = null,
        challenge_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        authentication_result: ?AuthenticationResultType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .challenge_name = "ChallengeName",
                .session = "Session",
                .challenge_parameters = "ChallengeParameters",
                .authentication_result = "AuthenticationResult",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "challenge_parameters", field_name))
                return try serializeMap(self.challenge_parameters, self.fieldNameFor("challenge_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AliasExists,
        CodeMismatch,
        ExpiredCode,
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidPassword,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        InvalidUserPoolConfiguration,
        MFAMethodNotFound,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        SoftwareTokenMFANotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const admin_set_user_mfa_preference: struct {
    action_name: []const u8 = "AdminSetUserMFAPreference",
    Request: type = struct {
        sms_mfa_settings: ?SMSMfaSettingsType = null,
        software_token_mfa_settings: ?SoftwareTokenMfaSettingsType = null,
        username: []const u8,
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_mfa_settings = "SMSMfaSettings",
                .software_token_mfa_settings = "SoftwareTokenMfaSettings",
                .username = "Username",
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_set_user_mfa_preference) } {
            return .{ .service_metadata = service_metadata, .action = admin_set_user_mfa_preference };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const admin_set_user_password: struct {
    action_name: []const u8 = "AdminSetUserPassword",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        password: []const u8,
        permanent: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .password = "Password",
                .permanent = "Permanent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_set_user_password) } {
            return .{ .service_metadata = service_metadata, .action = admin_set_user_password };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        InvalidPassword,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_set_user_settings: struct {
    action_name: []const u8 = "AdminSetUserSettings",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        mfa_options: []MFAOptionType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .mfa_options = "MFAOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_set_user_settings) } {
            return .{ .service_metadata = service_metadata, .action = admin_set_user_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        UserNotFound,
    },
} = .{};
pub const admin_update_auth_event_feedback: struct {
    action_name: []const u8 = "AdminUpdateAuthEventFeedback",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        event_id: []const u8,
        feedback_value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .event_id = "EventId",
                .feedback_value = "FeedbackValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_update_auth_event_feedback) } {
            return .{ .service_metadata = service_metadata, .action = admin_update_auth_event_feedback };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
        UserPoolAddOnNotEnabled,
    },
} = .{};
pub const admin_update_device_status: struct {
    action_name: []const u8 = "AdminUpdateDeviceStatus",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        device_key: []const u8,
        device_remembered_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .device_key = "DeviceKey",
                .device_remembered_status = "DeviceRememberedStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_update_device_status) } {
            return .{ .service_metadata = service_metadata, .action = admin_update_device_status };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const admin_update_user_attributes: struct {
    action_name: []const u8 = "AdminUpdateUserAttributes",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        user_attributes: []AttributeType,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .user_attributes = "UserAttributes",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_update_user_attributes) } {
            return .{ .service_metadata = service_metadata, .action = admin_update_user_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AliasExists,
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotFound,
    },
} = .{};
pub const admin_user_global_sign_out: struct {
    action_name: []const u8 = "AdminUserGlobalSignOut",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(admin_user_global_sign_out) } {
            return .{ .service_metadata = service_metadata, .action = admin_user_global_sign_out };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
    },
} = .{};
pub const associate_software_token: struct {
    action_name: []const u8 = "AssociateSoftwareToken",
    Request: type = struct {
        access_token: ?[]const u8 = null,
        session: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .session = "Session",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_software_token) } {
            return .{ .service_metadata = service_metadata, .action = associate_software_token };
        }
    },
    Response: type = struct {
        secret_code: ?[]const u8 = null,
        session: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_code = "SecretCode",
                .session = "Session",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        Forbidden,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        SoftwareTokenMFANotFound,
    },
} = .{};
pub const change_password: struct {
    action_name: []const u8 = "ChangePassword",
    Request: type = struct {
        previous_password: []const u8,
        proposed_password: []const u8,
        access_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .previous_password = "PreviousPassword",
                .proposed_password = "ProposedPassword",
                .access_token = "AccessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(change_password) } {
            return .{ .service_metadata = service_metadata, .action = change_password };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        InvalidPassword,
        LimitExceeded,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const confirm_device: struct {
    action_name: []const u8 = "ConfirmDevice",
    Request: type = struct {
        access_token: []const u8,
        device_key: []const u8,
        device_secret_verifier_config: ?struct {
            password_verifier: ?[]const u8 = null,
            salt: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .password_verifier = "PasswordVerifier",
                    .salt = "Salt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        device_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .device_key = "DeviceKey",
                .device_secret_verifier_config = "DeviceSecretVerifierConfig",
                .device_name = "DeviceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_device) } {
            return .{ .service_metadata = service_metadata, .action = confirm_device };
        }
    },
    Response: type = struct {
        user_confirmation_necessary: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_confirmation_necessary = "UserConfirmationNecessary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidPassword,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UsernameExists,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const confirm_forgot_password: struct {
    action_name: []const u8 = "ConfirmForgotPassword",
    Request: type = struct {
        client_id: []const u8,
        secret_hash: ?[]const u8 = null,
        username: []const u8,
        confirmation_code: []const u8,
        password: []const u8,
        analytics_metadata: ?AnalyticsMetadataType = null,
        user_context_data: ?UserContextDataType = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "ClientId",
                .secret_hash = "SecretHash",
                .username = "Username",
                .confirmation_code = "ConfirmationCode",
                .password = "Password",
                .analytics_metadata = "AnalyticsMetadata",
                .user_context_data = "UserContextData",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_forgot_password) } {
            return .{ .service_metadata = service_metadata, .action = confirm_forgot_password };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeMismatch,
        ExpiredCode,
        Forbidden,
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidPassword,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyFailedAttempts,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const confirm_sign_up: struct {
    action_name: []const u8 = "ConfirmSignUp",
    Request: type = struct {
        client_id: []const u8,
        secret_hash: ?[]const u8 = null,
        username: []const u8,
        confirmation_code: []const u8,
        force_alias_creation: ?bool = null,
        analytics_metadata: ?AnalyticsMetadataType = null,
        user_context_data: ?UserContextDataType = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "ClientId",
                .secret_hash = "SecretHash",
                .username = "Username",
                .confirmation_code = "ConfirmationCode",
                .force_alias_creation = "ForceAliasCreation",
                .analytics_metadata = "AnalyticsMetadata",
                .user_context_data = "UserContextData",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_sign_up) } {
            return .{ .service_metadata = service_metadata, .action = confirm_sign_up };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AliasExists,
        CodeMismatch,
        ExpiredCode,
        Forbidden,
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyFailedAttempts,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotFound,
    },
} = .{};
pub const create_group: struct {
    action_name: []const u8 = "CreateGroup",
    Request: type = struct {
        group_name: []const u8,
        user_pool_id: []const u8,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        precedence: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .user_pool_id = "UserPoolId",
                .description = "Description",
                .role_arn = "RoleArn",
                .precedence = "Precedence",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group) } {
            return .{ .service_metadata = service_metadata, .action = create_group };
        }
    },
    Response: type = struct {
        group: ?GroupType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GroupExists,
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const create_identity_provider: struct {
    action_name: []const u8 = "CreateIdentityProvider",
    Request: type = struct {
        user_pool_id: []const u8,
        provider_name: []const u8,
        provider_type: []const u8,
        provider_details: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        attribute_mapping: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        idp_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .provider_name = "ProviderName",
                .provider_type = "ProviderType",
                .provider_details = "ProviderDetails",
                .attribute_mapping = "AttributeMapping",
                .idp_identifiers = "IdpIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "provider_details", field_name))
                return try serializeMap(self.provider_details, self.fieldNameFor("provider_details"), options, out_stream);
            if (std.mem.eql(u8, "attribute_mapping", field_name))
                return try serializeMap(self.attribute_mapping, self.fieldNameFor("attribute_mapping"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_identity_provider) } {
            return .{ .service_metadata = service_metadata, .action = create_identity_provider };
        }
    },
    Response: type = struct {
        identity_provider: IdentityProviderType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider = "IdentityProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateProvider,
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const create_resource_server: struct {
    action_name: []const u8 = "CreateResourceServer",
    Request: type = struct {
        user_pool_id: []const u8,
        identifier: []const u8,
        name: []const u8,
        scopes: ?[]ResourceServerScopeType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .identifier = "Identifier",
                .name = "Name",
                .scopes = "Scopes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_server) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_server };
        }
    },
    Response: type = struct {
        resource_server: ResourceServerType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_server = "ResourceServer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const create_user_import_job: struct {
    action_name: []const u8 = "CreateUserImportJob",
    Request: type = struct {
        job_name: []const u8,
        user_pool_id: []const u8,
        cloud_watch_logs_role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .user_pool_id = "UserPoolId",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_import_job) } {
            return .{ .service_metadata = service_metadata, .action = create_user_import_job };
        }
    },
    Response: type = struct {
        user_import_job: ?UserImportJobType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_import_job = "UserImportJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        PreconditionNotMet,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const create_user_pool: struct {
    action_name: []const u8 = "CreateUserPool",
    Request: type = struct {
        pool_name: []const u8,
        policies: ?UserPoolPolicyType = null,
        deletion_protection: ?[]const u8 = null,
        lambda_config: ?LambdaConfigType = null,
        auto_verified_attributes: ?[][]const u8 = null,
        alias_attributes: ?[][]const u8 = null,
        username_attributes: ?[][]const u8 = null,
        sms_verification_message: ?[]const u8 = null,
        email_verification_message: ?[]const u8 = null,
        email_verification_subject: ?[]const u8 = null,
        verification_message_template: ?VerificationMessageTemplateType = null,
        sms_authentication_message: ?[]const u8 = null,
        mfa_configuration: ?[]const u8 = null,
        user_attribute_update_settings: ?UserAttributeUpdateSettingsType = null,
        device_configuration: ?DeviceConfigurationType = null,
        email_configuration: ?EmailConfigurationType = null,
        sms_configuration: ?SmsConfigurationType = null,
        user_pool_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        admin_create_user_config: ?AdminCreateUserConfigType = null,
        schema: ?[]SchemaAttributeType = null,
        user_pool_add_ons: ?UserPoolAddOnsType = null,
        username_configuration: ?UsernameConfigurationType = null,
        account_recovery_setting: ?AccountRecoverySettingType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
                .policies = "Policies",
                .deletion_protection = "DeletionProtection",
                .lambda_config = "LambdaConfig",
                .auto_verified_attributes = "AutoVerifiedAttributes",
                .alias_attributes = "AliasAttributes",
                .username_attributes = "UsernameAttributes",
                .sms_verification_message = "SmsVerificationMessage",
                .email_verification_message = "EmailVerificationMessage",
                .email_verification_subject = "EmailVerificationSubject",
                .verification_message_template = "VerificationMessageTemplate",
                .sms_authentication_message = "SmsAuthenticationMessage",
                .mfa_configuration = "MfaConfiguration",
                .user_attribute_update_settings = "UserAttributeUpdateSettings",
                .device_configuration = "DeviceConfiguration",
                .email_configuration = "EmailConfiguration",
                .sms_configuration = "SmsConfiguration",
                .user_pool_tags = "UserPoolTags",
                .admin_create_user_config = "AdminCreateUserConfig",
                .schema = "Schema",
                .user_pool_add_ons = "UserPoolAddOns",
                .username_configuration = "UsernameConfiguration",
                .account_recovery_setting = "AccountRecoverySetting",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "user_pool_tags", field_name))
                return try serializeMap(self.user_pool_tags, self.fieldNameFor("user_pool_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_user_pool };
        }
    },
    Response: type = struct {
        user_pool: ?UserPoolType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool = "UserPool",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        LimitExceeded,
        NotAuthorized,
        TooManyRequests,
        UserPoolTagging,
    },
} = .{};
pub const create_user_pool_client: struct {
    action_name: []const u8 = "CreateUserPoolClient",
    Request: type = struct {
        user_pool_id: []const u8,
        client_name: []const u8,
        generate_secret: ?bool = null,
        refresh_token_validity: ?i64 = null,
        access_token_validity: ?i64 = null,
        id_token_validity: ?i64 = null,
        token_validity_units: ?TokenValidityUnitsType = null,
        read_attributes: ?[][]const u8 = null,
        write_attributes: ?[][]const u8 = null,
        explicit_auth_flows: ?[][]const u8 = null,
        supported_identity_providers: ?[][]const u8 = null,
        callback_ur_ls: ?[][]const u8 = null,
        logout_ur_ls: ?[][]const u8 = null,
        default_redirect_uri: ?[]const u8 = null,
        allowed_o_auth_flows: ?[][]const u8 = null,
        allowed_o_auth_scopes: ?[][]const u8 = null,
        allowed_o_auth_flows_user_pool_client: ?bool = null,
        analytics_configuration: ?AnalyticsConfigurationType = null,
        prevent_user_existence_errors: ?[]const u8 = null,
        enable_token_revocation: ?bool = null,
        enable_propagate_additional_user_context_data: ?bool = null,
        auth_session_validity: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_name = "ClientName",
                .generate_secret = "GenerateSecret",
                .refresh_token_validity = "RefreshTokenValidity",
                .access_token_validity = "AccessTokenValidity",
                .id_token_validity = "IdTokenValidity",
                .token_validity_units = "TokenValidityUnits",
                .read_attributes = "ReadAttributes",
                .write_attributes = "WriteAttributes",
                .explicit_auth_flows = "ExplicitAuthFlows",
                .supported_identity_providers = "SupportedIdentityProviders",
                .callback_ur_ls = "CallbackURLs",
                .logout_ur_ls = "LogoutURLs",
                .default_redirect_uri = "DefaultRedirectURI",
                .allowed_o_auth_flows = "AllowedOAuthFlows",
                .allowed_o_auth_scopes = "AllowedOAuthScopes",
                .allowed_o_auth_flows_user_pool_client = "AllowedOAuthFlowsUserPoolClient",
                .analytics_configuration = "AnalyticsConfiguration",
                .prevent_user_existence_errors = "PreventUserExistenceErrors",
                .enable_token_revocation = "EnableTokenRevocation",
                .enable_propagate_additional_user_context_data = "EnablePropagateAdditionalUserContextData",
                .auth_session_validity = "AuthSessionValidity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_pool_client) } {
            return .{ .service_metadata = service_metadata, .action = create_user_pool_client };
        }
    },
    Response: type = struct {
        user_pool_client: ?UserPoolClientType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_client = "UserPoolClient",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidOAuthFlow,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        ScopeDoesNotExist,
        TooManyRequests,
    },
} = .{};
pub const create_user_pool_domain: struct {
    action_name: []const u8 = "CreateUserPoolDomain",
    Request: type = struct {
        domain: []const u8,
        user_pool_id: []const u8,
        custom_domain_config: ?CustomDomainConfigType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
                .user_pool_id = "UserPoolId",
                .custom_domain_config = "CustomDomainConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_pool_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_user_pool_domain };
        }
    },
    Response: type = struct {
        cloud_front_domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_front_domain = "CloudFrontDomain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const delete_group: struct {
    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        group_name: []const u8,
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_identity_provider: struct {
    action_name: []const u8 = "DeleteIdentityProvider",
    Request: type = struct {
        user_pool_id: []const u8,
        provider_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .provider_name = "ProviderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_identity_provider) } {
            return .{ .service_metadata = service_metadata, .action = delete_identity_provider };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UnsupportedIdentityProvider,
    },
} = .{};
pub const delete_resource_server: struct {
    action_name: []const u8 = "DeleteResourceServer",
    Request: type = struct {
        user_pool_id: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_server) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_server };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        access_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const delete_user_attributes: struct {
    action_name: []const u8 = "DeleteUserAttributes",
    Request: type = struct {
        user_attribute_names: [][]const u8,
        access_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_attribute_names = "UserAttributeNames",
                .access_token = "AccessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_attributes) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const delete_user_pool: struct {
    action_name: []const u8 = "DeleteUserPool",
    Request: type = struct {
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_pool };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserImportInProgress,
    },
} = .{};
pub const delete_user_pool_client: struct {
    action_name: []const u8 = "DeleteUserPoolClient",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_pool_client) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_pool_client };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_user_pool_domain: struct {
    action_name: []const u8 = "DeleteUserPoolDomain",
    Request: type = struct {
        domain: []const u8,
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_pool_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_pool_domain };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const describe_identity_provider: struct {
    action_name: []const u8 = "DescribeIdentityProvider",
    Request: type = struct {
        user_pool_id: []const u8,
        provider_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .provider_name = "ProviderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_identity_provider) } {
            return .{ .service_metadata = service_metadata, .action = describe_identity_provider };
        }
    },
    Response: type = struct {
        identity_provider: IdentityProviderType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider = "IdentityProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_resource_server: struct {
    action_name: []const u8 = "DescribeResourceServer",
    Request: type = struct {
        user_pool_id: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_server) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_server };
        }
    },
    Response: type = struct {
        resource_server: ResourceServerType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_server = "ResourceServer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_risk_configuration: struct {
    action_name: []const u8 = "DescribeRiskConfiguration",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_risk_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_risk_configuration };
        }
    },
    Response: type = struct {
        risk_configuration: RiskConfigurationType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .risk_configuration = "RiskConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserPoolAddOnNotEnabled,
    },
} = .{};
pub const describe_user_import_job: struct {
    action_name: []const u8 = "DescribeUserImportJob",
    Request: type = struct {
        user_pool_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_import_job };
        }
    },
    Response: type = struct {
        user_import_job: ?UserImportJobType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_import_job = "UserImportJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_user_pool: struct {
    action_name: []const u8 = "DescribeUserPool",
    Request: type = struct {
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_pool) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_pool };
        }
    },
    Response: type = struct {
        user_pool: ?UserPoolType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool = "UserPool",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserPoolTagging,
    },
} = .{};
pub const describe_user_pool_client: struct {
    action_name: []const u8 = "DescribeUserPoolClient",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_pool_client) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_pool_client };
        }
    },
    Response: type = struct {
        user_pool_client: ?UserPoolClientType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_client = "UserPoolClient",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_user_pool_domain: struct {
    action_name: []const u8 = "DescribeUserPoolDomain",
    Request: type = struct {
        domain: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_pool_domain) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_pool_domain };
        }
    },
    Response: type = struct {
        domain_description: ?struct {
            user_pool_id: ?[]const u8 = null,
            aws_account_id: ?[]const u8 = null,
            domain: ?[]const u8 = null,
            s3_bucket: ?[]const u8 = null,
            cloud_front_distribution: ?[]const u8 = null,
            version: ?[]const u8 = null,
            status: ?[]const u8 = null,
            custom_domain_config: ?CustomDomainConfigType = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_pool_id = "UserPoolId",
                    .aws_account_id = "AWSAccountId",
                    .domain = "Domain",
                    .s3_bucket = "S3Bucket",
                    .cloud_front_distribution = "CloudFrontDistribution",
                    .version = "Version",
                    .status = "Status",
                    .custom_domain_config = "CustomDomainConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_description = "DomainDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const forget_device: struct {
    action_name: []const u8 = "ForgetDevice",
    Request: type = struct {
        access_token: ?[]const u8 = null,
        device_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .device_key = "DeviceKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(forget_device) } {
            return .{ .service_metadata = service_metadata, .action = forget_device };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const forgot_password: struct {
    action_name: []const u8 = "ForgotPassword",
    Request: type = struct {
        client_id: []const u8,
        secret_hash: ?[]const u8 = null,
        user_context_data: ?UserContextDataType = null,
        username: []const u8,
        analytics_metadata: ?AnalyticsMetadataType = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "ClientId",
                .secret_hash = "SecretHash",
                .user_context_data = "UserContextData",
                .username = "Username",
                .analytics_metadata = "AnalyticsMetadata",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(forgot_password) } {
            return .{ .service_metadata = service_metadata, .action = forgot_password };
        }
    },
    Response: type = struct {
        code_delivery_details: ?CodeDeliveryDetailsType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_delivery_details = "CodeDeliveryDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeDeliveryFailure,
        Forbidden,
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotFound,
    },
} = .{};
pub const get_csv_header: struct {
    action_name: []const u8 = "GetCSVHeader",
    Request: type = struct {
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_csv_header) } {
            return .{ .service_metadata = service_metadata, .action = get_csv_header };
        }
    },
    Response: type = struct {
        user_pool_id: ?[]const u8 = null,
        csv_header: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .csv_header = "CSVHeader",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_device: struct {
    action_name: []const u8 = "GetDevice",
    Request: type = struct {
        device_key: []const u8,
        access_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_key = "DeviceKey",
                .access_token = "AccessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device) } {
            return .{ .service_metadata = service_metadata, .action = get_device };
        }
    },
    Response: type = struct {
        device: DeviceType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const get_group: struct {
    action_name: []const u8 = "GetGroup",
    Request: type = struct {
        group_name: []const u8,
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group) } {
            return .{ .service_metadata = service_metadata, .action = get_group };
        }
    },
    Response: type = struct {
        group: ?GroupType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_identity_provider_by_identifier: struct {
    action_name: []const u8 = "GetIdentityProviderByIdentifier",
    Request: type = struct {
        user_pool_id: []const u8,
        idp_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .idp_identifier = "IdpIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_provider_by_identifier) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_provider_by_identifier };
        }
    },
    Response: type = struct {
        identity_provider: IdentityProviderType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider = "IdentityProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_log_delivery_configuration: struct {
    action_name: []const u8 = "GetLogDeliveryConfiguration",
    Request: type = struct {
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_log_delivery_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_log_delivery_configuration };
        }
    },
    Response: type = struct {
        log_delivery_configuration: ?LogDeliveryConfigurationType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_delivery_configuration = "LogDeliveryConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_signing_certificate: struct {
    action_name: []const u8 = "GetSigningCertificate",
    Request: type = struct {
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_signing_certificate) } {
            return .{ .service_metadata = service_metadata, .action = get_signing_certificate };
        }
    },
    Response: type = struct {
        certificate: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const get_ui_customization: struct {
    action_name: []const u8 = "GetUICustomization",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ui_customization) } {
            return .{ .service_metadata = service_metadata, .action = get_ui_customization };
        }
    },
    Response: type = struct {
        ui_customization: UICustomizationType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ui_customization = "UICustomization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_user: struct {
    action_name: []const u8 = "GetUser",
    Request: type = struct {
        access_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user) } {
            return .{ .service_metadata = service_metadata, .action = get_user };
        }
    },
    Response: type = struct {
        username: []const u8,
        user_attributes: []AttributeType,
        mfa_options: ?[]MFAOptionType = null,
        preferred_mfa_setting: ?[]const u8 = null,
        user_mfa_setting_list: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .user_attributes = "UserAttributes",
                .mfa_options = "MFAOptions",
                .preferred_mfa_setting = "PreferredMfaSetting",
                .user_mfa_setting_list = "UserMFASettingList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const get_user_attribute_verification_code: struct {
    action_name: []const u8 = "GetUserAttributeVerificationCode",
    Request: type = struct {
        access_token: []const u8,
        attribute_name: []const u8,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .attribute_name = "AttributeName",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_attribute_verification_code) } {
            return .{ .service_metadata = service_metadata, .action = get_user_attribute_verification_code };
        }
    },
    Response: type = struct {
        code_delivery_details: ?CodeDeliveryDetailsType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_delivery_details = "CodeDeliveryDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeDeliveryFailure,
        Forbidden,
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        LimitExceeded,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const get_user_pool_mfa_config: struct {
    action_name: []const u8 = "GetUserPoolMfaConfig",
    Request: type = struct {
        user_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_pool_mfa_config) } {
            return .{ .service_metadata = service_metadata, .action = get_user_pool_mfa_config };
        }
    },
    Response: type = struct {
        sms_mfa_configuration: ?SmsMfaConfigType = null,
        software_token_mfa_configuration: ?SoftwareTokenMfaConfigType = null,
        mfa_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_mfa_configuration = "SmsMfaConfiguration",
                .software_token_mfa_configuration = "SoftwareTokenMfaConfiguration",
                .mfa_configuration = "MfaConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const global_sign_out: struct {
    action_name: []const u8 = "GlobalSignOut",
    Request: type = struct {
        access_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(global_sign_out) } {
            return .{ .service_metadata = service_metadata, .action = global_sign_out };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
    },
} = .{};
pub const initiate_auth: struct {
    action_name: []const u8 = "InitiateAuth",
    Request: type = struct {
        auth_flow: []const u8,
        auth_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_id: []const u8,
        analytics_metadata: ?AnalyticsMetadataType = null,
        user_context_data: ?UserContextDataType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auth_flow = "AuthFlow",
                .auth_parameters = "AuthParameters",
                .client_metadata = "ClientMetadata",
                .client_id = "ClientId",
                .analytics_metadata = "AnalyticsMetadata",
                .user_context_data = "UserContextData",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "auth_parameters", field_name))
                return try serializeMap(self.auth_parameters, self.fieldNameFor("auth_parameters"), options, out_stream);
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initiate_auth) } {
            return .{ .service_metadata = service_metadata, .action = initiate_auth };
        }
    },
    Response: type = struct {
        challenge_name: ?[]const u8 = null,
        session: ?[]const u8 = null,
        challenge_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        authentication_result: ?AuthenticationResultType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .challenge_name = "ChallengeName",
                .session = "Session",
                .challenge_parameters = "ChallengeParameters",
                .authentication_result = "AuthenticationResult",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "challenge_parameters", field_name))
                return try serializeMap(self.challenge_parameters, self.fieldNameFor("challenge_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const list_devices: struct {
    action_name: []const u8 = "ListDevices",
    Request: type = struct {
        access_token: []const u8,
        limit: ?i64 = null,
        pagination_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .limit = "Limit",
                .pagination_token = "PaginationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_devices };
        }
    },
    Response: type = struct {
        devices: ?[]DeviceType = null,
        pagination_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "Devices",
                .pagination_token = "PaginationToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const list_groups: struct {
    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        user_pool_id: []const u8,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        groups: ?[]GroupType = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_identity_providers: struct {
    action_name: []const u8 = "ListIdentityProviders",
    Request: type = struct {
        user_pool_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identity_providers) } {
            return .{ .service_metadata = service_metadata, .action = list_identity_providers };
        }
    },
    Response: type = struct {
        providers: []struct {
            provider_name: ?[]const u8 = null,
            provider_type: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .provider_name = "ProviderName",
                    .provider_type = "ProviderType",
                    .last_modified_date = "LastModifiedDate",
                    .creation_date = "CreationDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .providers = "Providers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_resource_servers: struct {
    action_name: []const u8 = "ListResourceServers",
    Request: type = struct {
        user_pool_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_servers) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_servers };
        }
    },
    Response: type = struct {
        resource_servers: []ResourceServerType,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_servers = "ResourceServers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_user_import_jobs: struct {
    action_name: []const u8 = "ListUserImportJobs",
    Request: type = struct {
        user_pool_id: []const u8,
        max_results: i64,
        pagination_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .max_results = "MaxResults",
                .pagination_token = "PaginationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_user_import_jobs };
        }
    },
    Response: type = struct {
        user_import_jobs: ?[]UserImportJobType = null,
        pagination_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_import_jobs = "UserImportJobs",
                .pagination_token = "PaginationToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_user_pool_clients: struct {
    action_name: []const u8 = "ListUserPoolClients",
    Request: type = struct {
        user_pool_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_pool_clients) } {
            return .{ .service_metadata = service_metadata, .action = list_user_pool_clients };
        }
    },
    Response: type = struct {
        user_pool_clients: ?[]struct {
            client_id: ?[]const u8 = null,
            user_pool_id: ?[]const u8 = null,
            client_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_id = "ClientId",
                    .user_pool_id = "UserPoolId",
                    .client_name = "ClientName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_clients = "UserPoolClients",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_user_pools: struct {
    action_name: []const u8 = "ListUserPools",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_pools) } {
            return .{ .service_metadata = service_metadata, .action = list_user_pools };
        }
    },
    Response: type = struct {
        user_pools: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            lambda_config: ?LambdaConfigType = null,
            status: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .lambda_config = "LambdaConfig",
                    .status = "Status",
                    .last_modified_date = "LastModifiedDate",
                    .creation_date = "CreationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pools = "UserPools",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        TooManyRequests,
    },
} = .{};
pub const list_users: struct {
    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        user_pool_id: []const u8,
        attributes_to_get: ?[][]const u8 = null,
        limit: ?i64 = null,
        pagination_token: ?[]const u8 = null,
        filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .attributes_to_get = "AttributesToGet",
                .limit = "Limit",
                .pagination_token = "PaginationToken",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        users: ?[]UserType = null,
        pagination_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .pagination_token = "PaginationToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_users_in_group: struct {
    action_name: []const u8 = "ListUsersInGroup",
    Request: type = struct {
        user_pool_id: []const u8,
        group_name: []const u8,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .group_name = "GroupName",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users_in_group) } {
            return .{ .service_metadata = service_metadata, .action = list_users_in_group };
        }
    },
    Response: type = struct {
        users: ?[]UserType = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const resend_confirmation_code: struct {
    action_name: []const u8 = "ResendConfirmationCode",
    Request: type = struct {
        client_id: []const u8,
        secret_hash: ?[]const u8 = null,
        user_context_data: ?UserContextDataType = null,
        username: []const u8,
        analytics_metadata: ?AnalyticsMetadataType = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "ClientId",
                .secret_hash = "SecretHash",
                .user_context_data = "UserContextData",
                .username = "Username",
                .analytics_metadata = "AnalyticsMetadata",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resend_confirmation_code) } {
            return .{ .service_metadata = service_metadata, .action = resend_confirmation_code };
        }
    },
    Response: type = struct {
        code_delivery_details: ?CodeDeliveryDetailsType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_delivery_details = "CodeDeliveryDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeDeliveryFailure,
        Forbidden,
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        LimitExceeded,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotFound,
    },
} = .{};
pub const respond_to_auth_challenge: struct {
    action_name: []const u8 = "RespondToAuthChallenge",
    Request: type = struct {
        client_id: []const u8,
        challenge_name: []const u8,
        session: ?[]const u8 = null,
        challenge_responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        analytics_metadata: ?AnalyticsMetadataType = null,
        user_context_data: ?UserContextDataType = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "ClientId",
                .challenge_name = "ChallengeName",
                .session = "Session",
                .challenge_responses = "ChallengeResponses",
                .analytics_metadata = "AnalyticsMetadata",
                .user_context_data = "UserContextData",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "challenge_responses", field_name))
                return try serializeMap(self.challenge_responses, self.fieldNameFor("challenge_responses"), options, out_stream);
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(respond_to_auth_challenge) } {
            return .{ .service_metadata = service_metadata, .action = respond_to_auth_challenge };
        }
    },
    Response: type = struct {
        challenge_name: ?[]const u8 = null,
        session: ?[]const u8 = null,
        challenge_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        authentication_result: ?AuthenticationResultType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .challenge_name = "ChallengeName",
                .session = "Session",
                .challenge_parameters = "ChallengeParameters",
                .authentication_result = "AuthenticationResult",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "challenge_parameters", field_name))
                return try serializeMap(self.challenge_parameters, self.fieldNameFor("challenge_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AliasExists,
        CodeMismatch,
        ExpiredCode,
        Forbidden,
        InternalError,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidPassword,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        InvalidUserPoolConfiguration,
        MFAMethodNotFound,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        SoftwareTokenMFANotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const revoke_token: struct {
    action_name: []const u8 = "RevokeToken",
    Request: type = struct {
        token: []const u8,
        client_id: []const u8,
        client_secret: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token = "Token",
                .client_id = "ClientId",
                .client_secret = "ClientSecret",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_token) } {
            return .{ .service_metadata = service_metadata, .action = revoke_token };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        TooManyRequests,
        Unauthorized,
        UnsupportedOperation,
        UnsupportedTokenType,
    },
} = .{};
pub const set_log_delivery_configuration: struct {
    action_name: []const u8 = "SetLogDeliveryConfiguration",
    Request: type = struct {
        user_pool_id: []const u8,
        log_configurations: []LogConfigurationType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .log_configurations = "LogConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_log_delivery_configuration) } {
            return .{ .service_metadata = service_metadata, .action = set_log_delivery_configuration };
        }
    },
    Response: type = struct {
        log_delivery_configuration: ?LogDeliveryConfigurationType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_delivery_configuration = "LogDeliveryConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const set_risk_configuration: struct {
    action_name: []const u8 = "SetRiskConfiguration",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: ?[]const u8 = null,
        compromised_credentials_risk_configuration: ?CompromisedCredentialsRiskConfigurationType = null,
        account_takeover_risk_configuration: ?AccountTakeoverRiskConfigurationType = null,
        risk_exception_configuration: ?RiskExceptionConfigurationType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
                .compromised_credentials_risk_configuration = "CompromisedCredentialsRiskConfiguration",
                .account_takeover_risk_configuration = "AccountTakeoverRiskConfiguration",
                .risk_exception_configuration = "RiskExceptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_risk_configuration) } {
            return .{ .service_metadata = service_metadata, .action = set_risk_configuration };
        }
    },
    Response: type = struct {
        risk_configuration: RiskConfigurationType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .risk_configuration = "RiskConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeDeliveryFailure,
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserPoolAddOnNotEnabled,
    },
} = .{};
pub const set_ui_customization: struct {
    action_name: []const u8 = "SetUICustomization",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: ?[]const u8 = null,
        css: ?[]const u8 = null,
        image_file: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
                .css = "CSS",
                .image_file = "ImageFile",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_ui_customization) } {
            return .{ .service_metadata = service_metadata, .action = set_ui_customization };
        }
    },
    Response: type = struct {
        ui_customization: UICustomizationType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ui_customization = "UICustomization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const set_user_mfa_preference: struct {
    action_name: []const u8 = "SetUserMFAPreference",
    Request: type = struct {
        sms_mfa_settings: ?SMSMfaSettingsType = null,
        software_token_mfa_settings: ?SoftwareTokenMfaSettingsType = null,
        access_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_mfa_settings = "SMSMfaSettings",
                .software_token_mfa_settings = "SoftwareTokenMfaSettings",
                .access_token = "AccessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_user_mfa_preference) } {
            return .{ .service_metadata = service_metadata, .action = set_user_mfa_preference };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const set_user_pool_mfa_config: struct {
    action_name: []const u8 = "SetUserPoolMfaConfig",
    Request: type = struct {
        user_pool_id: []const u8,
        sms_mfa_configuration: ?SmsMfaConfigType = null,
        software_token_mfa_configuration: ?SoftwareTokenMfaConfigType = null,
        mfa_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .sms_mfa_configuration = "SmsMfaConfiguration",
                .software_token_mfa_configuration = "SoftwareTokenMfaConfiguration",
                .mfa_configuration = "MfaConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_user_pool_mfa_config) } {
            return .{ .service_metadata = service_metadata, .action = set_user_pool_mfa_config };
        }
    },
    Response: type = struct {
        sms_mfa_configuration: ?SmsMfaConfigType = null,
        software_token_mfa_configuration: ?SoftwareTokenMfaConfigType = null,
        mfa_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_mfa_configuration = "SmsMfaConfiguration",
                .software_token_mfa_configuration = "SoftwareTokenMfaConfiguration",
                .mfa_configuration = "MfaConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const set_user_settings: struct {
    action_name: []const u8 = "SetUserSettings",
    Request: type = struct {
        access_token: []const u8,
        mfa_options: []MFAOptionType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .mfa_options = "MFAOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_user_settings) } {
            return .{ .service_metadata = service_metadata, .action = set_user_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const sign_up: struct {
    action_name: []const u8 = "SignUp",
    Request: type = struct {
        client_id: []const u8,
        secret_hash: ?[]const u8 = null,
        username: []const u8,
        password: []const u8,
        user_attributes: ?[]AttributeType = null,
        validation_data: ?[]AttributeType = null,
        analytics_metadata: ?AnalyticsMetadataType = null,
        user_context_data: ?UserContextDataType = null,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "ClientId",
                .secret_hash = "SecretHash",
                .username = "Username",
                .password = "Password",
                .user_attributes = "UserAttributes",
                .validation_data = "ValidationData",
                .analytics_metadata = "AnalyticsMetadata",
                .user_context_data = "UserContextData",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(sign_up) } {
            return .{ .service_metadata = service_metadata, .action = sign_up };
        }
    },
    Response: type = struct {
        user_confirmed: bool,
        code_delivery_details: ?CodeDeliveryDetailsType = null,
        user_sub: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_confirmed = "UserConfirmed",
                .code_delivery_details = "CodeDeliveryDetails",
                .user_sub = "UserSub",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeDeliveryFailure,
        Forbidden,
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidPassword,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UsernameExists,
    },
} = .{};
pub const start_user_import_job: struct {
    action_name: []const u8 = "StartUserImportJob",
    Request: type = struct {
        user_pool_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_user_import_job) } {
            return .{ .service_metadata = service_metadata, .action = start_user_import_job };
        }
    },
    Response: type = struct {
        user_import_job: ?UserImportJobType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_import_job = "UserImportJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PreconditionNotMet,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const stop_user_import_job: struct {
    action_name: []const u8 = "StopUserImportJob",
    Request: type = struct {
        user_pool_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_user_import_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_user_import_job };
        }
    },
    Response: type = struct {
        user_import_job: ?UserImportJobType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_import_job = "UserImportJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        PreconditionNotMet,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const update_auth_event_feedback: struct {
    action_name: []const u8 = "UpdateAuthEventFeedback",
    Request: type = struct {
        user_pool_id: []const u8,
        username: []const u8,
        event_id: []const u8,
        feedback_token: []const u8,
        feedback_value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .username = "Username",
                .event_id = "EventId",
                .feedback_token = "FeedbackToken",
                .feedback_value = "FeedbackValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_auth_event_feedback) } {
            return .{ .service_metadata = service_metadata, .action = update_auth_event_feedback };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserNotFound,
        UserPoolAddOnNotEnabled,
    },
} = .{};
pub const update_device_status: struct {
    action_name: []const u8 = "UpdateDeviceStatus",
    Request: type = struct {
        access_token: []const u8,
        device_key: []const u8,
        device_remembered_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .device_key = "DeviceKey",
                .device_remembered_status = "DeviceRememberedStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device_status) } {
            return .{ .service_metadata = service_metadata, .action = update_device_status };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const update_group: struct {
    action_name: []const u8 = "UpdateGroup",
    Request: type = struct {
        group_name: []const u8,
        user_pool_id: []const u8,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        precedence: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .user_pool_id = "UserPoolId",
                .description = "Description",
                .role_arn = "RoleArn",
                .precedence = "Precedence",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group) } {
            return .{ .service_metadata = service_metadata, .action = update_group };
        }
    },
    Response: type = struct {
        group: ?GroupType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const update_identity_provider: struct {
    action_name: []const u8 = "UpdateIdentityProvider",
    Request: type = struct {
        user_pool_id: []const u8,
        provider_name: []const u8,
        provider_details: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        attribute_mapping: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        idp_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .provider_name = "ProviderName",
                .provider_details = "ProviderDetails",
                .attribute_mapping = "AttributeMapping",
                .idp_identifiers = "IdpIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "provider_details", field_name))
                return try serializeMap(self.provider_details, self.fieldNameFor("provider_details"), options, out_stream);
            if (std.mem.eql(u8, "attribute_mapping", field_name))
                return try serializeMap(self.attribute_mapping, self.fieldNameFor("attribute_mapping"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_identity_provider) } {
            return .{ .service_metadata = service_metadata, .action = update_identity_provider };
        }
    },
    Response: type = struct {
        identity_provider: IdentityProviderType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider = "IdentityProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UnsupportedIdentityProvider,
    },
} = .{};
pub const update_resource_server: struct {
    action_name: []const u8 = "UpdateResourceServer",
    Request: type = struct {
        user_pool_id: []const u8,
        identifier: []const u8,
        name: []const u8,
        scopes: ?[]ResourceServerScopeType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .identifier = "Identifier",
                .name = "Name",
                .scopes = "Scopes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_server) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_server };
        }
    },
    Response: type = struct {
        resource_server: ResourceServerType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_server = "ResourceServer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const update_user_attributes: struct {
    action_name: []const u8 = "UpdateUserAttributes",
    Request: type = struct {
        user_attributes: []AttributeType,
        access_token: []const u8,
        client_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_attributes = "UserAttributes",
                .access_token = "AccessToken",
                .client_metadata = "ClientMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "client_metadata", field_name))
                return try serializeMap(self.client_metadata, self.fieldNameFor("client_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_user_attributes };
        }
    },
    Response: type = struct {
        code_delivery_details_list: ?[]CodeDeliveryDetailsType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_delivery_details_list = "CodeDeliveryDetailsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AliasExists,
        CodeDeliveryFailure,
        CodeMismatch,
        ExpiredCode,
        Forbidden,
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidLambdaResponse,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UnexpectedLambda,
        UserLambdaValidation,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const update_user_pool: struct {
    action_name: []const u8 = "UpdateUserPool",
    Request: type = struct {
        user_pool_id: []const u8,
        policies: ?UserPoolPolicyType = null,
        deletion_protection: ?[]const u8 = null,
        lambda_config: ?LambdaConfigType = null,
        auto_verified_attributes: ?[][]const u8 = null,
        sms_verification_message: ?[]const u8 = null,
        email_verification_message: ?[]const u8 = null,
        email_verification_subject: ?[]const u8 = null,
        verification_message_template: ?VerificationMessageTemplateType = null,
        sms_authentication_message: ?[]const u8 = null,
        user_attribute_update_settings: ?UserAttributeUpdateSettingsType = null,
        mfa_configuration: ?[]const u8 = null,
        device_configuration: ?DeviceConfigurationType = null,
        email_configuration: ?EmailConfigurationType = null,
        sms_configuration: ?SmsConfigurationType = null,
        user_pool_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        admin_create_user_config: ?AdminCreateUserConfigType = null,
        user_pool_add_ons: ?UserPoolAddOnsType = null,
        account_recovery_setting: ?AccountRecoverySettingType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .policies = "Policies",
                .deletion_protection = "DeletionProtection",
                .lambda_config = "LambdaConfig",
                .auto_verified_attributes = "AutoVerifiedAttributes",
                .sms_verification_message = "SmsVerificationMessage",
                .email_verification_message = "EmailVerificationMessage",
                .email_verification_subject = "EmailVerificationSubject",
                .verification_message_template = "VerificationMessageTemplate",
                .sms_authentication_message = "SmsAuthenticationMessage",
                .user_attribute_update_settings = "UserAttributeUpdateSettings",
                .mfa_configuration = "MfaConfiguration",
                .device_configuration = "DeviceConfiguration",
                .email_configuration = "EmailConfiguration",
                .sms_configuration = "SmsConfiguration",
                .user_pool_tags = "UserPoolTags",
                .admin_create_user_config = "AdminCreateUserConfig",
                .user_pool_add_ons = "UserPoolAddOns",
                .account_recovery_setting = "AccountRecoverySetting",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "user_pool_tags", field_name))
                return try serializeMap(self.user_pool_tags, self.fieldNameFor("user_pool_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_pool) } {
            return .{ .service_metadata = service_metadata, .action = update_user_pool };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalError,
        InvalidEmailRoleAccessPolicy,
        InvalidParameter,
        InvalidSmsRoleAccessPolicy,
        InvalidSmsRoleTrustRelationship,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
        UserImportInProgress,
        UserPoolTagging,
    },
} = .{};
pub const update_user_pool_client: struct {
    action_name: []const u8 = "UpdateUserPoolClient",
    Request: type = struct {
        user_pool_id: []const u8,
        client_id: []const u8,
        client_name: ?[]const u8 = null,
        refresh_token_validity: ?i64 = null,
        access_token_validity: ?i64 = null,
        id_token_validity: ?i64 = null,
        token_validity_units: ?TokenValidityUnitsType = null,
        read_attributes: ?[][]const u8 = null,
        write_attributes: ?[][]const u8 = null,
        explicit_auth_flows: ?[][]const u8 = null,
        supported_identity_providers: ?[][]const u8 = null,
        callback_ur_ls: ?[][]const u8 = null,
        logout_ur_ls: ?[][]const u8 = null,
        default_redirect_uri: ?[]const u8 = null,
        allowed_o_auth_flows: ?[][]const u8 = null,
        allowed_o_auth_scopes: ?[][]const u8 = null,
        allowed_o_auth_flows_user_pool_client: ?bool = null,
        analytics_configuration: ?AnalyticsConfigurationType = null,
        prevent_user_existence_errors: ?[]const u8 = null,
        enable_token_revocation: ?bool = null,
        enable_propagate_additional_user_context_data: ?bool = null,
        auth_session_validity: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_id = "UserPoolId",
                .client_id = "ClientId",
                .client_name = "ClientName",
                .refresh_token_validity = "RefreshTokenValidity",
                .access_token_validity = "AccessTokenValidity",
                .id_token_validity = "IdTokenValidity",
                .token_validity_units = "TokenValidityUnits",
                .read_attributes = "ReadAttributes",
                .write_attributes = "WriteAttributes",
                .explicit_auth_flows = "ExplicitAuthFlows",
                .supported_identity_providers = "SupportedIdentityProviders",
                .callback_ur_ls = "CallbackURLs",
                .logout_ur_ls = "LogoutURLs",
                .default_redirect_uri = "DefaultRedirectURI",
                .allowed_o_auth_flows = "AllowedOAuthFlows",
                .allowed_o_auth_scopes = "AllowedOAuthScopes",
                .allowed_o_auth_flows_user_pool_client = "AllowedOAuthFlowsUserPoolClient",
                .analytics_configuration = "AnalyticsConfiguration",
                .prevent_user_existence_errors = "PreventUserExistenceErrors",
                .enable_token_revocation = "EnableTokenRevocation",
                .enable_propagate_additional_user_context_data = "EnablePropagateAdditionalUserContextData",
                .auth_session_validity = "AuthSessionValidity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_pool_client) } {
            return .{ .service_metadata = service_metadata, .action = update_user_pool_client };
        }
    },
    Response: type = struct {
        user_pool_client: ?UserPoolClientType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_pool_client = "UserPoolClient",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalError,
        InvalidOAuthFlow,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        ScopeDoesNotExist,
        TooManyRequests,
    },
} = .{};
pub const update_user_pool_domain: struct {
    action_name: []const u8 = "UpdateUserPoolDomain",
    Request: type = struct {
        domain: []const u8,
        user_pool_id: []const u8,
        custom_domain_config: CustomDomainConfigType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
                .user_pool_id = "UserPoolId",
                .custom_domain_config = "CustomDomainConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_pool_domain) } {
            return .{ .service_metadata = service_metadata, .action = update_user_pool_domain };
        }
    },
    Response: type = struct {
        cloud_front_domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_front_domain = "CloudFrontDomain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const verify_software_token: struct {
    action_name: []const u8 = "VerifySoftwareToken",
    Request: type = struct {
        access_token: ?[]const u8 = null,
        session: ?[]const u8 = null,
        user_code: []const u8,
        friendly_device_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .session = "Session",
                .user_code = "UserCode",
                .friendly_device_name = "FriendlyDeviceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_software_token) } {
            return .{ .service_metadata = service_metadata, .action = verify_software_token };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        session: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .session = "Session",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeMismatch,
        EnableSoftwareTokenMFA,
        Forbidden,
        InternalError,
        InvalidParameter,
        InvalidUserPoolConfiguration,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        SoftwareTokenMFANotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};
pub const verify_user_attribute: struct {
    action_name: []const u8 = "VerifyUserAttribute",
    Request: type = struct {
        access_token: []const u8,
        attribute_name: []const u8,
        code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
                .attribute_name = "AttributeName",
                .code = "Code",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_user_attribute) } {
            return .{ .service_metadata = service_metadata, .action = verify_user_attribute };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AliasExists,
        CodeMismatch,
        ExpiredCode,
        Forbidden,
        InternalError,
        InvalidParameter,
        LimitExceeded,
        NotAuthorized,
        PasswordResetRequired,
        ResourceNotFound,
        TooManyRequests,
        UserNotConfirmed,
        UserNotFound,
    },
} = .{};

pub const CustomDomainConfigType = struct {
    certificate_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "CertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const UserPoolClientType = struct {
    user_pool_id: ?[]const u8 = null,
    client_name: ?[]const u8 = null,
    client_id: ?[]const u8 = null,
    client_secret: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    creation_date: ?i64 = null,
    refresh_token_validity: ?i64 = null,
    access_token_validity: ?i64 = null,
    id_token_validity: ?i64 = null,
    token_validity_units: ?TokenValidityUnitsType = null,
    read_attributes: ?[][]const u8 = null,
    write_attributes: ?[][]const u8 = null,
    explicit_auth_flows: ?[][]const u8 = null,
    supported_identity_providers: ?[][]const u8 = null,
    callback_ur_ls: ?[][]const u8 = null,
    logout_ur_ls: ?[][]const u8 = null,
    default_redirect_uri: ?[]const u8 = null,
    allowed_o_auth_flows: ?[][]const u8 = null,
    allowed_o_auth_scopes: ?[][]const u8 = null,
    allowed_o_auth_flows_user_pool_client: ?bool = null,
    analytics_configuration: ?AnalyticsConfigurationType = null,
    prevent_user_existence_errors: ?[]const u8 = null,
    enable_token_revocation: ?bool = null,
    enable_propagate_additional_user_context_data: ?bool = null,
    auth_session_validity: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_id = "UserPoolId",
            .client_name = "ClientName",
            .client_id = "ClientId",
            .client_secret = "ClientSecret",
            .last_modified_date = "LastModifiedDate",
            .creation_date = "CreationDate",
            .refresh_token_validity = "RefreshTokenValidity",
            .access_token_validity = "AccessTokenValidity",
            .id_token_validity = "IdTokenValidity",
            .token_validity_units = "TokenValidityUnits",
            .read_attributes = "ReadAttributes",
            .write_attributes = "WriteAttributes",
            .explicit_auth_flows = "ExplicitAuthFlows",
            .supported_identity_providers = "SupportedIdentityProviders",
            .callback_ur_ls = "CallbackURLs",
            .logout_ur_ls = "LogoutURLs",
            .default_redirect_uri = "DefaultRedirectURI",
            .allowed_o_auth_flows = "AllowedOAuthFlows",
            .allowed_o_auth_scopes = "AllowedOAuthScopes",
            .allowed_o_auth_flows_user_pool_client = "AllowedOAuthFlowsUserPoolClient",
            .analytics_configuration = "AnalyticsConfiguration",
            .prevent_user_existence_errors = "PreventUserExistenceErrors",
            .enable_token_revocation = "EnableTokenRevocation",
            .enable_propagate_additional_user_context_data = "EnablePropagateAdditionalUserContextData",
            .auth_session_validity = "AuthSessionValidity",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsConfigurationType = struct {
    application_id: ?[]const u8 = null,
    application_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    external_id: ?[]const u8 = null,
    user_data_shared: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .application_arn = "ApplicationArn",
            .role_arn = "RoleArn",
            .external_id = "ExternalId",
            .user_data_shared = "UserDataShared",
        };
        return @field(mappings, field_name);
    }
};

pub const TokenValidityUnitsType = struct {
    access_token: ?[]const u8 = null,
    id_token: ?[]const u8 = null,
    refresh_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_token = "AccessToken",
            .id_token = "IdToken",
            .refresh_token = "RefreshToken",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountRecoverySettingType = struct {
    recovery_mechanisms: ?[]RecoveryOptionType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recovery_mechanisms = "RecoveryMechanisms",
        };
        return @field(mappings, field_name);
    }
};

pub const RecoveryOptionType = struct {
    priority: i64,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "Priority",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const UserPoolAddOnsType = struct {
    advanced_security_mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .advanced_security_mode = "AdvancedSecurityMode",
        };
        return @field(mappings, field_name);
    }
};

pub const AdminCreateUserConfigType = struct {
    allow_admin_create_user_only: ?bool = null,
    unused_account_validity_days: ?i64 = null,
    invite_message_template: ?MessageTemplateType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_admin_create_user_only = "AllowAdminCreateUserOnly",
            .unused_account_validity_days = "UnusedAccountValidityDays",
            .invite_message_template = "InviteMessageTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageTemplateType = struct {
    sms_message: ?[]const u8 = null,
    email_message: ?[]const u8 = null,
    email_subject: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sms_message = "SMSMessage",
            .email_message = "EmailMessage",
            .email_subject = "EmailSubject",
        };
        return @field(mappings, field_name);
    }
};

pub const SmsConfigurationType = struct {
    sns_caller_arn: []const u8,
    external_id: ?[]const u8 = null,
    sns_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_caller_arn = "SnsCallerArn",
            .external_id = "ExternalId",
            .sns_region = "SnsRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailConfigurationType = struct {
    source_arn: ?[]const u8 = null,
    reply_to_email_address: ?[]const u8 = null,
    email_sending_account: ?[]const u8 = null,
    from: ?[]const u8 = null,
    configuration_set: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_arn = "SourceArn",
            .reply_to_email_address = "ReplyToEmailAddress",
            .email_sending_account = "EmailSendingAccount",
            .from = "From",
            .configuration_set = "ConfigurationSet",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceConfigurationType = struct {
    challenge_required_on_new_device: ?bool = null,
    device_only_remembered_on_user_prompt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .challenge_required_on_new_device = "ChallengeRequiredOnNewDevice",
            .device_only_remembered_on_user_prompt = "DeviceOnlyRememberedOnUserPrompt",
        };
        return @field(mappings, field_name);
    }
};

pub const UserAttributeUpdateSettingsType = struct {
    attributes_require_verification_before_update: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes_require_verification_before_update = "AttributesRequireVerificationBeforeUpdate",
        };
        return @field(mappings, field_name);
    }
};

pub const VerificationMessageTemplateType = struct {
    sms_message: ?[]const u8 = null,
    email_message: ?[]const u8 = null,
    email_subject: ?[]const u8 = null,
    email_message_by_link: ?[]const u8 = null,
    email_subject_by_link: ?[]const u8 = null,
    default_email_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sms_message = "SmsMessage",
            .email_message = "EmailMessage",
            .email_subject = "EmailSubject",
            .email_message_by_link = "EmailMessageByLink",
            .email_subject_by_link = "EmailSubjectByLink",
            .default_email_option = "DefaultEmailOption",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaConfigType = struct {
    pre_sign_up: ?[]const u8 = null,
    custom_message: ?[]const u8 = null,
    post_confirmation: ?[]const u8 = null,
    pre_authentication: ?[]const u8 = null,
    post_authentication: ?[]const u8 = null,
    define_auth_challenge: ?[]const u8 = null,
    create_auth_challenge: ?[]const u8 = null,
    verify_auth_challenge_response: ?[]const u8 = null,
    pre_token_generation: ?[]const u8 = null,
    user_migration: ?[]const u8 = null,
    pre_token_generation_config: ?PreTokenGenerationVersionConfigType = null,
    custom_sms_sender: ?CustomSMSLambdaVersionConfigType = null,
    custom_email_sender: ?CustomEmailLambdaVersionConfigType = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pre_sign_up = "PreSignUp",
            .custom_message = "CustomMessage",
            .post_confirmation = "PostConfirmation",
            .pre_authentication = "PreAuthentication",
            .post_authentication = "PostAuthentication",
            .define_auth_challenge = "DefineAuthChallenge",
            .create_auth_challenge = "CreateAuthChallenge",
            .verify_auth_challenge_response = "VerifyAuthChallengeResponse",
            .pre_token_generation = "PreTokenGeneration",
            .user_migration = "UserMigration",
            .pre_token_generation_config = "PreTokenGenerationConfig",
            .custom_sms_sender = "CustomSMSSender",
            .custom_email_sender = "CustomEmailSender",
            .kms_key_id = "KMSKeyID",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomEmailLambdaVersionConfigType = struct {
    lambda_version: []const u8,
    lambda_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_version = "LambdaVersion",
            .lambda_arn = "LambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomSMSLambdaVersionConfigType = struct {
    lambda_version: []const u8,
    lambda_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_version = "LambdaVersion",
            .lambda_arn = "LambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PreTokenGenerationVersionConfigType = struct {
    lambda_version: []const u8,
    lambda_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_version = "LambdaVersion",
            .lambda_arn = "LambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const UserPoolPolicyType = struct {
    password_policy: ?PasswordPolicyType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .password_policy = "PasswordPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const PasswordPolicyType = struct {
    minimum_length: ?i64 = null,
    require_uppercase: ?bool = null,
    require_lowercase: ?bool = null,
    require_numbers: ?bool = null,
    require_symbols: ?bool = null,
    temporary_password_validity_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_length = "MinimumLength",
            .require_uppercase = "RequireUppercase",
            .require_lowercase = "RequireLowercase",
            .require_numbers = "RequireNumbers",
            .require_symbols = "RequireSymbols",
            .temporary_password_validity_days = "TemporaryPasswordValidityDays",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeDeliveryDetailsType = struct {
    destination: ?[]const u8 = null,
    delivery_medium: ?[]const u8 = null,
    attribute_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
            .delivery_medium = "DeliveryMedium",
            .attribute_name = "AttributeName",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeType = struct {
    name: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceServerType = struct {
    user_pool_id: ?[]const u8 = null,
    identifier: ?[]const u8 = null,
    name: ?[]const u8 = null,
    scopes: ?[]ResourceServerScopeType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_id = "UserPoolId",
            .identifier = "Identifier",
            .name = "Name",
            .scopes = "Scopes",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceServerScopeType = struct {
    scope_name: []const u8,
    scope_description: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scope_name = "ScopeName",
            .scope_description = "ScopeDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityProviderType = struct {
    user_pool_id: ?[]const u8 = null,
    provider_name: ?[]const u8 = null,
    provider_type: ?[]const u8 = null,
    provider_details: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    attribute_mapping: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    idp_identifiers: ?[][]const u8 = null,
    last_modified_date: ?i64 = null,
    creation_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_id = "UserPoolId",
            .provider_name = "ProviderName",
            .provider_type = "ProviderType",
            .provider_details = "ProviderDetails",
            .attribute_mapping = "AttributeMapping",
            .idp_identifiers = "IdpIdentifiers",
            .last_modified_date = "LastModifiedDate",
            .creation_date = "CreationDate",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "provider_details", field_name))
            return try serializeMap(self.provider_details, self.fieldNameFor("provider_details"), options, out_stream);
        if (std.mem.eql(u8, "attribute_mapping", field_name))
            return try serializeMap(self.attribute_mapping, self.fieldNameFor("attribute_mapping"), options, out_stream);
        return false;
    }
};

pub const GroupType = struct {
    group_name: ?[]const u8 = null,
    user_pool_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    precedence: ?i64 = null,
    last_modified_date: ?i64 = null,
    creation_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .user_pool_id = "UserPoolId",
            .description = "Description",
            .role_arn = "RoleArn",
            .precedence = "Precedence",
            .last_modified_date = "LastModifiedDate",
            .creation_date = "CreationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const UserImportJobType = struct {
    job_name: ?[]const u8 = null,
    job_id: ?[]const u8 = null,
    user_pool_id: ?[]const u8 = null,
    pre_signed_url: ?[]const u8 = null,
    creation_date: ?i64 = null,
    start_date: ?i64 = null,
    completion_date: ?i64 = null,
    status: ?[]const u8 = null,
    cloud_watch_logs_role_arn: ?[]const u8 = null,
    imported_users: ?i64 = null,
    skipped_users: ?i64 = null,
    failed_users: ?i64 = null,
    completion_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .job_id = "JobId",
            .user_pool_id = "UserPoolId",
            .pre_signed_url = "PreSignedUrl",
            .creation_date = "CreationDate",
            .start_date = "StartDate",
            .completion_date = "CompletionDate",
            .status = "Status",
            .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
            .imported_users = "ImportedUsers",
            .skipped_users = "SkippedUsers",
            .failed_users = "FailedUsers",
            .completion_message = "CompletionMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const UserContextDataType = struct {
    ip_address: ?[]const u8 = null,
    encoded_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "IpAddress",
            .encoded_data = "EncodedData",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsMetadataType = struct {
    analytics_endpoint_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .analytics_endpoint_id = "AnalyticsEndpointId",
        };
        return @field(mappings, field_name);
    }
};

pub const MFAOptionType = struct {
    delivery_medium: ?[]const u8 = null,
    attribute_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_medium = "DeliveryMedium",
            .attribute_name = "AttributeName",
        };
        return @field(mappings, field_name);
    }
};

pub const SoftwareTokenMfaConfigType = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SmsMfaConfigType = struct {
    sms_authentication_message: ?[]const u8 = null,
    sms_configuration: ?SmsConfigurationType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sms_authentication_message = "SmsAuthenticationMessage",
            .sms_configuration = "SmsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SoftwareTokenMfaSettingsType = struct {
    enabled: ?bool = null,
    preferred_mfa: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .preferred_mfa = "PreferredMfa",
        };
        return @field(mappings, field_name);
    }
};

pub const SMSMfaSettingsType = struct {
    enabled: ?bool = null,
    preferred_mfa: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .preferred_mfa = "PreferredMfa",
        };
        return @field(mappings, field_name);
    }
};

pub const UICustomizationType = struct {
    user_pool_id: ?[]const u8 = null,
    client_id: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    css: ?[]const u8 = null,
    css_version: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    creation_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_id = "UserPoolId",
            .client_id = "ClientId",
            .image_url = "ImageUrl",
            .css = "CSS",
            .css_version = "CSSVersion",
            .last_modified_date = "LastModifiedDate",
            .creation_date = "CreationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const RiskConfigurationType = struct {
    user_pool_id: ?[]const u8 = null,
    client_id: ?[]const u8 = null,
    compromised_credentials_risk_configuration: ?CompromisedCredentialsRiskConfigurationType = null,
    account_takeover_risk_configuration: ?AccountTakeoverRiskConfigurationType = null,
    risk_exception_configuration: ?RiskExceptionConfigurationType = null,
    last_modified_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_id = "UserPoolId",
            .client_id = "ClientId",
            .compromised_credentials_risk_configuration = "CompromisedCredentialsRiskConfiguration",
            .account_takeover_risk_configuration = "AccountTakeoverRiskConfiguration",
            .risk_exception_configuration = "RiskExceptionConfiguration",
            .last_modified_date = "LastModifiedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const RiskExceptionConfigurationType = struct {
    blocked_ip_range_list: ?[][]const u8 = null,
    skipped_ip_range_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blocked_ip_range_list = "BlockedIPRangeList",
            .skipped_ip_range_list = "SkippedIPRangeList",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountTakeoverRiskConfigurationType = struct {
    notify_configuration: ?NotifyConfigurationType = null,
    actions: AccountTakeoverActionsType,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notify_configuration = "NotifyConfiguration",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountTakeoverActionsType = struct {
    low_action: ?AccountTakeoverActionType = null,
    medium_action: ?AccountTakeoverActionType = null,
    high_action: ?AccountTakeoverActionType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .low_action = "LowAction",
            .medium_action = "MediumAction",
            .high_action = "HighAction",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountTakeoverActionType = struct {
    notify: bool,
    event_action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notify = "Notify",
            .event_action = "EventAction",
        };
        return @field(mappings, field_name);
    }
};

pub const NotifyConfigurationType = struct {
    from: ?[]const u8 = null,
    reply_to: ?[]const u8 = null,
    source_arn: []const u8,
    block_email: ?NotifyEmailType = null,
    no_action_email: ?NotifyEmailType = null,
    mfa_email: ?NotifyEmailType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "From",
            .reply_to = "ReplyTo",
            .source_arn = "SourceArn",
            .block_email = "BlockEmail",
            .no_action_email = "NoActionEmail",
            .mfa_email = "MfaEmail",
        };
        return @field(mappings, field_name);
    }
};

pub const NotifyEmailType = struct {
    subject: []const u8,
    html_body: ?[]const u8 = null,
    text_body: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subject = "Subject",
            .html_body = "HtmlBody",
            .text_body = "TextBody",
        };
        return @field(mappings, field_name);
    }
};

pub const CompromisedCredentialsRiskConfigurationType = struct {
    event_filter: ?[][]const u8 = null,
    actions: CompromisedCredentialsActionsType,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_filter = "EventFilter",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const CompromisedCredentialsActionsType = struct {
    event_action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_action = "EventAction",
        };
        return @field(mappings, field_name);
    }
};

pub const LogDeliveryConfigurationType = struct {
    user_pool_id: []const u8,
    log_configurations: []LogConfigurationType,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_id = "UserPoolId",
            .log_configurations = "LogConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const LogConfigurationType = struct {
    log_level: []const u8,
    event_source: []const u8,
    cloud_watch_logs_configuration: ?CloudWatchLogsConfigurationType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_level = "LogLevel",
            .event_source = "EventSource",
            .cloud_watch_logs_configuration = "CloudWatchLogsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogsConfigurationType = struct {
    log_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_arn = "LogGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthenticationResultType = struct {
    access_token: ?[]const u8 = null,
    expires_in: ?i64 = null,
    token_type: ?[]const u8 = null,
    refresh_token: ?[]const u8 = null,
    id_token: ?[]const u8 = null,
    new_device_metadata: ?NewDeviceMetadataType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_token = "AccessToken",
            .expires_in = "ExpiresIn",
            .token_type = "TokenType",
            .refresh_token = "RefreshToken",
            .id_token = "IdToken",
            .new_device_metadata = "NewDeviceMetadata",
        };
        return @field(mappings, field_name);
    }
};

pub const NewDeviceMetadataType = struct {
    device_key: ?[]const u8 = null,
    device_group_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_key = "DeviceKey",
            .device_group_key = "DeviceGroupKey",
        };
        return @field(mappings, field_name);
    }
};

pub const UserType = struct {
    username: ?[]const u8 = null,
    attributes: ?[]AttributeType = null,
    user_create_date: ?i64 = null,
    user_last_modified_date: ?i64 = null,
    enabled: ?bool = null,
    user_status: ?[]const u8 = null,
    mfa_options: ?[]MFAOptionType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .attributes = "Attributes",
            .user_create_date = "UserCreateDate",
            .user_last_modified_date = "UserLastModifiedDate",
            .enabled = "Enabled",
            .user_status = "UserStatus",
            .mfa_options = "MFAOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceType = struct {
    device_key: ?[]const u8 = null,
    device_attributes: ?[]AttributeType = null,
    device_create_date: ?i64 = null,
    device_last_modified_date: ?i64 = null,
    device_last_authenticated_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_key = "DeviceKey",
            .device_attributes = "DeviceAttributes",
            .device_create_date = "DeviceCreateDate",
            .device_last_modified_date = "DeviceLastModifiedDate",
            .device_last_authenticated_date = "DeviceLastAuthenticatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const UserPoolType = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    policies: ?UserPoolPolicyType = null,
    deletion_protection: ?[]const u8 = null,
    lambda_config: ?LambdaConfigType = null,
    status: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    creation_date: ?i64 = null,
    schema_attributes: ?[]SchemaAttributeType = null,
    auto_verified_attributes: ?[][]const u8 = null,
    alias_attributes: ?[][]const u8 = null,
    username_attributes: ?[][]const u8 = null,
    sms_verification_message: ?[]const u8 = null,
    email_verification_message: ?[]const u8 = null,
    email_verification_subject: ?[]const u8 = null,
    verification_message_template: ?VerificationMessageTemplateType = null,
    sms_authentication_message: ?[]const u8 = null,
    user_attribute_update_settings: ?UserAttributeUpdateSettingsType = null,
    mfa_configuration: ?[]const u8 = null,
    device_configuration: ?DeviceConfigurationType = null,
    estimated_number_of_users: ?i64 = null,
    email_configuration: ?EmailConfigurationType = null,
    sms_configuration: ?SmsConfigurationType = null,
    user_pool_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    sms_configuration_failure: ?[]const u8 = null,
    email_configuration_failure: ?[]const u8 = null,
    domain: ?[]const u8 = null,
    custom_domain: ?[]const u8 = null,
    admin_create_user_config: ?AdminCreateUserConfigType = null,
    user_pool_add_ons: ?UserPoolAddOnsType = null,
    username_configuration: ?UsernameConfigurationType = null,
    arn: ?[]const u8 = null,
    account_recovery_setting: ?AccountRecoverySettingType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .policies = "Policies",
            .deletion_protection = "DeletionProtection",
            .lambda_config = "LambdaConfig",
            .status = "Status",
            .last_modified_date = "LastModifiedDate",
            .creation_date = "CreationDate",
            .schema_attributes = "SchemaAttributes",
            .auto_verified_attributes = "AutoVerifiedAttributes",
            .alias_attributes = "AliasAttributes",
            .username_attributes = "UsernameAttributes",
            .sms_verification_message = "SmsVerificationMessage",
            .email_verification_message = "EmailVerificationMessage",
            .email_verification_subject = "EmailVerificationSubject",
            .verification_message_template = "VerificationMessageTemplate",
            .sms_authentication_message = "SmsAuthenticationMessage",
            .user_attribute_update_settings = "UserAttributeUpdateSettings",
            .mfa_configuration = "MfaConfiguration",
            .device_configuration = "DeviceConfiguration",
            .estimated_number_of_users = "EstimatedNumberOfUsers",
            .email_configuration = "EmailConfiguration",
            .sms_configuration = "SmsConfiguration",
            .user_pool_tags = "UserPoolTags",
            .sms_configuration_failure = "SmsConfigurationFailure",
            .email_configuration_failure = "EmailConfigurationFailure",
            .domain = "Domain",
            .custom_domain = "CustomDomain",
            .admin_create_user_config = "AdminCreateUserConfig",
            .user_pool_add_ons = "UserPoolAddOns",
            .username_configuration = "UsernameConfiguration",
            .arn = "Arn",
            .account_recovery_setting = "AccountRecoverySetting",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_pool_tags", field_name))
            return try serializeMap(self.user_pool_tags, self.fieldNameFor("user_pool_tags"), options, out_stream);
        return false;
    }
};

pub const UsernameConfigurationType = struct {
    case_sensitive: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .case_sensitive = "CaseSensitive",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaAttributeType = struct {
    name: ?[]const u8 = null,
    attribute_data_type: ?[]const u8 = null,
    developer_only_attribute: ?bool = null,
    mutable: ?bool = null,
    required: ?bool = null,
    number_attribute_constraints: ?NumberAttributeConstraintsType = null,
    string_attribute_constraints: ?StringAttributeConstraintsType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .attribute_data_type = "AttributeDataType",
            .developer_only_attribute = "DeveloperOnlyAttribute",
            .mutable = "Mutable",
            .required = "Required",
            .number_attribute_constraints = "NumberAttributeConstraints",
            .string_attribute_constraints = "StringAttributeConstraints",
        };
        return @field(mappings, field_name);
    }
};

pub const StringAttributeConstraintsType = struct {
    min_length: ?[]const u8 = null,
    max_length: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_length = "MinLength",
            .max_length = "MaxLength",
        };
        return @field(mappings, field_name);
    }
};

pub const NumberAttributeConstraintsType = struct {
    min_value: ?[]const u8 = null,
    max_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_value = "MinValue",
            .max_value = "MaxValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ContextDataType = struct {
    ip_address: []const u8,
    server_name: []const u8,
    server_path: []const u8,
    http_headers: []HttpHeader,
    encoded_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "IpAddress",
            .server_name = "ServerName",
            .server_path = "ServerPath",
            .http_headers = "HttpHeaders",
            .encoded_data = "EncodedData",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpHeader = struct {
    header_name: ?[]const u8 = null,
    header_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_name = "headerName",
            .header_value = "headerValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ProviderUserIdentifierType = struct {
    provider_name: ?[]const u8 = null,
    provider_attribute_name: ?[]const u8 = null,
    provider_attribute_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provider_name = "ProviderName",
            .provider_attribute_name = "ProviderAttributeName",
            .provider_attribute_value = "ProviderAttributeValue",
        };
        return @field(mappings, field_name);
    }
};
