const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-06-30";
pub const sdk_id: []const u8 = "Cognito Sync";
pub const arn_namespace: ?[]const u8 = "cognito-sync";
pub const endpoint_prefix: []const u8 = "cognito-sync";
pub const sigv4_name: []const u8 = "cognito-sync";
pub const name: []const u8 = "AWSCognitoSyncService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2014-06-30",
    sdk_id: []const u8 = "Cognito Sync",
    arn_namespace: ?[]const u8 = "cognito-sync",
    endpoint_prefix: []const u8 = "cognito-sync",
    sigv4_name: []const u8 = "cognito-sync",
    name: []const u8 = "AWSCognitoSyncService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const bulk_publish: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identitypools/{IdentityPoolId}/bulkpublish",
        .success_code = 200,
    };

    action_name: []const u8 = "BulkPublish",
    Request: type = struct {
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(bulk_publish) } {
            return .{ .service_metadata = service_metadata, .action = bulk_publish };
        }
    },
    Response: type = struct {
        identity_pool_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyStreamed,
        DuplicateRequest,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const delete_dataset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/identitypools/{IdentityPoolId}/identities/{IdentityId}/datasets/{DatasetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,
        dataset_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .dataset_name = "DatasetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {
        dataset: ?Dataset = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset = "Dataset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_dataset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/identitypools/{IdentityPoolId}/identities/{IdentityId}/datasets/{DatasetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,
        dataset_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .dataset_name = "DatasetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        dataset: ?Dataset = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset = "Dataset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_identity_pool_usage: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/identitypools/{IdentityPoolId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIdentityPoolUsage",
    Request: type = struct {
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_identity_pool_usage) } {
            return .{ .service_metadata = service_metadata, .action = describe_identity_pool_usage };
        }
    },
    Response: type = struct {
        identity_pool_usage: ?IdentityPoolUsage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_usage = "IdentityPoolUsage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_identity_usage: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/identitypools/{IdentityPoolId}/identities/{IdentityId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIdentityUsage",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_identity_usage) } {
            return .{ .service_metadata = service_metadata, .action = describe_identity_usage };
        }
    },
    Response: type = struct {
        identity_usage: ?struct {
            identity_id: ?[]const u8 = null,
            identity_pool_id: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            dataset_count: ?i64 = null,
            data_storage: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identity_id = "IdentityId",
                    .identity_pool_id = "IdentityPoolId",
                    .last_modified_date = "LastModifiedDate",
                    .dataset_count = "DatasetCount",
                    .data_storage = "DataStorage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_usage = "IdentityUsage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_bulk_publish_details: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identitypools/{IdentityPoolId}/getBulkPublishDetails",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBulkPublishDetails",
    Request: type = struct {
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bulk_publish_details) } {
            return .{ .service_metadata = service_metadata, .action = get_bulk_publish_details };
        }
    },
    Response: type = struct {
        identity_pool_id: ?[]const u8 = null,
        bulk_publish_start_time: ?i64 = null,
        bulk_publish_complete_time: ?i64 = null,
        bulk_publish_status: ?[]const u8 = null,
        failure_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .bulk_publish_start_time = "BulkPublishStartTime",
                .bulk_publish_complete_time = "BulkPublishCompleteTime",
                .bulk_publish_status = "BulkPublishStatus",
                .failure_message = "FailureMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const get_cognito_events: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/identitypools/{IdentityPoolId}/events",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCognitoEvents",
    Request: type = struct {
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cognito_events) } {
            return .{ .service_metadata = service_metadata, .action = get_cognito_events };
        }
    },
    Response: type = struct {
        events: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "Events",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "events", field_name))
                return try serializeMap(self.events, self.fieldNameFor("events"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_identity_pool_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/identitypools/{IdentityPoolId}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIdentityPoolConfiguration",
    Request: type = struct {
        identity_pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_pool_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_pool_configuration };
        }
    },
    Response: type = struct {
        identity_pool_id: ?[]const u8 = null,
        push_sync: ?PushSync = null,
        cognito_streams: ?CognitoStreams = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .push_sync = "PushSync",
                .cognito_streams = "CognitoStreams",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_datasets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/identitypools/{IdentityPoolId}/identities/{IdentityId}/datasets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatasets",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasets) } {
            return .{ .service_metadata = service_metadata, .action = list_datasets };
        }
    },
    Response: type = struct {
        datasets: ?[]Dataset = null,
        count: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datasets = "Datasets",
                .count = "Count",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        TooManyRequests,
    },
} = .{};
pub const list_identity_pool_usage: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/identitypools",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIdentityPoolUsage",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identity_pool_usage) } {
            return .{ .service_metadata = service_metadata, .action = list_identity_pool_usage };
        }
    },
    Response: type = struct {
        identity_pool_usages: ?[]IdentityPoolUsage = null,
        max_results: ?i64 = null,
        count: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_usages = "IdentityPoolUsages",
                .max_results = "MaxResults",
                .count = "Count",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        TooManyRequests,
    },
} = .{};
pub const list_records: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/identitypools/{IdentityPoolId}/identities/{IdentityId}/datasets/{DatasetName}/records",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecords",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,
        dataset_name: []const u8,
        last_sync_count: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sync_session_token: ?[]const u8 = null,

        pub const http_query = .{
            .last_sync_count = "lastSyncCount",
            .next_token = "nextToken",
            .max_results = "maxResults",
            .sync_session_token = "syncSessionToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .dataset_name = "DatasetName",
                .last_sync_count = "LastSyncCount",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sync_session_token = "SyncSessionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_records) } {
            return .{ .service_metadata = service_metadata, .action = list_records };
        }
    },
    Response: type = struct {
        records: ?[]Record = null,
        next_token: ?[]const u8 = null,
        count: ?i64 = null,
        dataset_sync_count: ?i64 = null,
        last_modified_by: ?[]const u8 = null,
        merged_dataset_names: ?[][]const u8 = null,
        dataset_exists: ?bool = null,
        dataset_deleted_after_requested_sync_count: ?bool = null,
        sync_session_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
                .next_token = "NextToken",
                .count = "Count",
                .dataset_sync_count = "DatasetSyncCount",
                .last_modified_by = "LastModifiedBy",
                .merged_dataset_names = "MergedDatasetNames",
                .dataset_exists = "DatasetExists",
                .dataset_deleted_after_requested_sync_count = "DatasetDeletedAfterRequestedSyncCount",
                .sync_session_token = "SyncSessionToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        TooManyRequests,
    },
} = .{};
pub const register_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identitypools/{IdentityPoolId}/identity/{IdentityId}/device",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterDevice",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,
        platform: []const u8,
        token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .platform = "Platform",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_device) } {
            return .{ .service_metadata = service_metadata, .action = register_device };
        }
    },
    Response: type = struct {
        device_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidConfiguration,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const set_cognito_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identitypools/{IdentityPoolId}/events",
        .success_code = 200,
    };

    action_name: []const u8 = "SetCognitoEvents",
    Request: type = struct {
        identity_pool_id: []const u8,
        events: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "events", field_name))
                return try serializeMap(self.events, self.fieldNameFor("events"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_cognito_events) } {
            return .{ .service_metadata = service_metadata, .action = set_cognito_events };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const set_identity_pool_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identitypools/{IdentityPoolId}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "SetIdentityPoolConfiguration",
    Request: type = struct {
        identity_pool_id: []const u8,
        push_sync: ?PushSync = null,
        cognito_streams: ?CognitoStreams = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .push_sync = "PushSync",
                .cognito_streams = "CognitoStreams",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_identity_pool_configuration) } {
            return .{ .service_metadata = service_metadata, .action = set_identity_pool_configuration };
        }
    },
    Response: type = struct {
        identity_pool_id: ?[]const u8 = null,
        push_sync: ?PushSync = null,
        cognito_streams: ?CognitoStreams = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .push_sync = "PushSync",
                .cognito_streams = "CognitoStreams",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalError,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const subscribe_to_dataset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identitypools/{IdentityPoolId}/identities/{IdentityId}/datasets/{DatasetName}/subscriptions/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "SubscribeToDataset",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,
        dataset_name: []const u8,
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .dataset_name = "DatasetName",
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(subscribe_to_dataset) } {
            return .{ .service_metadata = service_metadata, .action = subscribe_to_dataset };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidConfiguration,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const unsubscribe_from_dataset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/identitypools/{IdentityPoolId}/identities/{IdentityId}/datasets/{DatasetName}/subscriptions/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UnsubscribeFromDataset",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,
        dataset_name: []const u8,
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .dataset_name = "DatasetName",
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unsubscribe_from_dataset) } {
            return .{ .service_metadata = service_metadata, .action = unsubscribe_from_dataset };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidConfiguration,
        InvalidParameter,
        NotAuthorized,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const update_records: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identitypools/{IdentityPoolId}/identities/{IdentityId}/datasets/{DatasetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRecords",
    Request: type = struct {
        identity_pool_id: []const u8,
        identity_id: []const u8,
        dataset_name: []const u8,
        device_id: ?[]const u8 = null,
        record_patches: ?[]struct {
            op: []const u8,
            key: []const u8,
            value: ?[]const u8 = null,
            sync_count: i64,
            device_last_modified_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .op = "Op",
                    .key = "Key",
                    .value = "Value",
                    .sync_count = "SyncCount",
                    .device_last_modified_date = "DeviceLastModifiedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sync_session_token: []const u8,
        client_context: ?[]const u8 = null,
        pub const http_header = .{
            .client_context = "x-amz-Client-Context",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_pool_id = "IdentityPoolId",
                .identity_id = "IdentityId",
                .dataset_name = "DatasetName",
                .device_id = "DeviceId",
                .record_patches = "RecordPatches",
                .sync_session_token = "SyncSessionToken",
                .client_context = "ClientContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_records) } {
            return .{ .service_metadata = service_metadata, .action = update_records };
        }
    },
    Response: type = struct {
        records: ?[]Record = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidLambdaFunctionOutput,
        InvalidParameter,
        LambdaThrottled,
        LimitExceeded,
        NotAuthorized,
        ResourceConflict,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};

pub const Record = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    sync_count: ?i64 = null,
    last_modified_date: ?i64 = null,
    last_modified_by: ?[]const u8 = null,
    device_last_modified_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .sync_count = "SyncCount",
            .last_modified_date = "LastModifiedDate",
            .last_modified_by = "LastModifiedBy",
            .device_last_modified_date = "DeviceLastModifiedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const CognitoStreams = struct {
    stream_name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    streaming_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_name = "StreamName",
            .role_arn = "RoleArn",
            .streaming_status = "StreamingStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const PushSync = struct {
    application_arns: ?[][]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_arns = "ApplicationArns",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityPoolUsage = struct {
    identity_pool_id: ?[]const u8 = null,
    sync_sessions_count: ?i64 = null,
    data_storage: ?i64 = null,
    last_modified_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_pool_id = "IdentityPoolId",
            .sync_sessions_count = "SyncSessionsCount",
            .data_storage = "DataStorage",
            .last_modified_date = "LastModifiedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const Dataset = struct {
    identity_id: ?[]const u8 = null,
    dataset_name: ?[]const u8 = null,
    creation_date: ?i64 = null,
    last_modified_date: ?i64 = null,
    last_modified_by: ?[]const u8 = null,
    data_storage: ?i64 = null,
    num_records: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_id = "IdentityId",
            .dataset_name = "DatasetName",
            .creation_date = "CreationDate",
            .last_modified_date = "LastModifiedDate",
            .last_modified_by = "LastModifiedBy",
            .data_storage = "DataStorage",
            .num_records = "NumRecords",
        };
        return @field(mappings, field_name);
    }
};
