const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-11-01";
pub const sdk_id: []const u8 = "Compute Optimizer";
pub const arn_namespace: ?[]const u8 = "compute-optimizer";
pub const endpoint_prefix: []const u8 = "compute-optimizer";
pub const sigv4_name: []const u8 = "compute-optimizer";
pub const name: []const u8 = "ComputeOptimizerService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2019-11-01",
    sdk_id: []const u8 = "Compute Optimizer",
    arn_namespace: ?[]const u8 = "compute-optimizer",
    endpoint_prefix: []const u8 = "compute-optimizer",
    sigv4_name: []const u8 = "compute-optimizer",
    name: []const u8 = "ComputeOptimizerService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const delete_recommendation_preferences: struct {
    action_name: []const u8 = "DeleteRecommendationPreferences",
    Request: type = struct {
        resource_type: []const u8,
        scope: ?Scope = null,
        recommendation_preference_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "resourceType",
                .scope = "scope",
                .recommendation_preference_names = "recommendationPreferenceNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_recommendation_preferences) } {
            return .{ .service_metadata = service_metadata, .action = delete_recommendation_preferences };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_recommendation_export_jobs: struct {
    action_name: []const u8 = "DescribeRecommendationExportJobs",
    Request: type = struct {
        job_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_ids = "jobIds",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recommendation_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = describe_recommendation_export_jobs };
        }
    },
    Response: type = struct {
        recommendation_export_jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            destination: ?struct {
                s3: ?S3Destination = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3 = "s3",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            resource_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .destination = "destination",
                    .resource_type = "resourceType",
                    .status = "status",
                    .creation_timestamp = "creationTimestamp",
                    .last_updated_timestamp = "lastUpdatedTimestamp",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_export_jobs = "recommendationExportJobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_auto_scaling_group_recommendations: struct {
    action_name: []const u8 = "ExportAutoScalingGroupRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,
        recommendation_preferences: ?RecommendationPreferences = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
                .recommendation_preferences = "recommendationPreferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_auto_scaling_group_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_auto_scaling_group_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_ebs_volume_recommendations: struct {
    action_name: []const u8 = "ExportEBSVolumeRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]EBSFilter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_ebs_volume_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_ebs_volume_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_ec2_instance_recommendations: struct {
    action_name: []const u8 = "ExportEC2InstanceRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,
        recommendation_preferences: ?RecommendationPreferences = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
                .recommendation_preferences = "recommendationPreferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_ec2_instance_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_ec2_instance_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_ecs_service_recommendations: struct {
    action_name: []const u8 = "ExportECSServiceRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]ECSServiceRecommendationFilter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_ecs_service_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_ecs_service_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_lambda_function_recommendations: struct {
    action_name: []const u8 = "ExportLambdaFunctionRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]LambdaFunctionRecommendationFilter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_lambda_function_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_lambda_function_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_license_recommendations: struct {
    action_name: []const u8 = "ExportLicenseRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]LicenseRecommendationFilter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_license_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_license_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_auto_scaling_group_recommendations: struct {
    action_name: []const u8 = "GetAutoScalingGroupRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        auto_scaling_group_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        recommendation_preferences: ?RecommendationPreferences = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .auto_scaling_group_arns = "autoScalingGroupArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
                .recommendation_preferences = "recommendationPreferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_auto_scaling_group_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_auto_scaling_group_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        auto_scaling_group_recommendations: ?[]struct {
            account_id: ?[]const u8 = null,
            auto_scaling_group_arn: ?[]const u8 = null,
            auto_scaling_group_name: ?[]const u8 = null,
            finding: ?[]const u8 = null,
            utilization_metrics: ?[]UtilizationMetric = null,
            look_back_period_in_days: ?f64 = null,
            current_configuration: ?AutoScalingGroupConfiguration = null,
            recommendation_options: ?[]struct {
                configuration: ?AutoScalingGroupConfiguration = null,
                projected_utilization_metrics: ?[]UtilizationMetric = null,
                performance_risk: ?f64 = null,
                rank: ?i64 = null,
                savings_opportunity: ?SavingsOpportunity = null,
                migration_effort: ?[]const u8 = null,
                instance_gpu_info: ?GpuInfo = null,
                savings_opportunity_after_discounts: ?struct {
                    savings_opportunity_percentage: ?f64 = null,
                    estimated_monthly_savings: ?struct {
                        currency: ?[]const u8 = null,
                        value: ?f64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .currency = "currency",
                                .value = "value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .savings_opportunity_percentage = "savingsOpportunityPercentage",
                            .estimated_monthly_savings = "estimatedMonthlySavings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .configuration = "configuration",
                        .projected_utilization_metrics = "projectedUtilizationMetrics",
                        .performance_risk = "performanceRisk",
                        .rank = "rank",
                        .savings_opportunity = "savingsOpportunity",
                        .migration_effort = "migrationEffort",
                        .instance_gpu_info = "instanceGpuInfo",
                        .savings_opportunity_after_discounts = "savingsOpportunityAfterDiscounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_refresh_timestamp: ?i64 = null,
            current_performance_risk: ?[]const u8 = null,
            effective_recommendation_preferences: ?EffectiveRecommendationPreferences = null,
            inferred_workload_types: ?[][]const u8 = null,
            current_instance_gpu_info: ?GpuInfo = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .auto_scaling_group_arn = "autoScalingGroupArn",
                    .auto_scaling_group_name = "autoScalingGroupName",
                    .finding = "finding",
                    .utilization_metrics = "utilizationMetrics",
                    .look_back_period_in_days = "lookBackPeriodInDays",
                    .current_configuration = "currentConfiguration",
                    .recommendation_options = "recommendationOptions",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                    .current_performance_risk = "currentPerformanceRisk",
                    .effective_recommendation_preferences = "effectiveRecommendationPreferences",
                    .inferred_workload_types = "inferredWorkloadTypes",
                    .current_instance_gpu_info = "currentInstanceGpuInfo",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]GetRecommendationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .auto_scaling_group_recommendations = "autoScalingGroupRecommendations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_ebs_volume_recommendations: struct {
    action_name: []const u8 = "GetEBSVolumeRecommendations",
    Request: type = struct {
        volume_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]EBSFilter = null,
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arns = "volumeArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ebs_volume_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_ebs_volume_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        volume_recommendations: ?[]struct {
            volume_arn: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            current_configuration: ?VolumeConfiguration = null,
            finding: ?[]const u8 = null,
            utilization_metrics: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            look_back_period_in_days: ?f64 = null,
            volume_recommendation_options: ?[]struct {
                configuration: ?VolumeConfiguration = null,
                performance_risk: ?f64 = null,
                rank: ?i64 = null,
                savings_opportunity: ?SavingsOpportunity = null,
                savings_opportunity_after_discounts: ?struct {
                    savings_opportunity_percentage: ?f64 = null,
                    estimated_monthly_savings: ?struct {
                        currency: ?[]const u8 = null,
                        value: ?f64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .currency = "currency",
                                .value = "value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .savings_opportunity_percentage = "savingsOpportunityPercentage",
                            .estimated_monthly_savings = "estimatedMonthlySavings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .configuration = "configuration",
                        .performance_risk = "performanceRisk",
                        .rank = "rank",
                        .savings_opportunity = "savingsOpportunity",
                        .savings_opportunity_after_discounts = "savingsOpportunityAfterDiscounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_refresh_timestamp: ?i64 = null,
            current_performance_risk: ?[]const u8 = null,
            tags: ?[]Tag = null,
            effective_recommendation_preferences: ?struct {
                savings_estimation_mode: ?struct {
                    source: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .source = "source",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .savings_estimation_mode = "savingsEstimationMode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_arn = "volumeArn",
                    .account_id = "accountId",
                    .current_configuration = "currentConfiguration",
                    .finding = "finding",
                    .utilization_metrics = "utilizationMetrics",
                    .look_back_period_in_days = "lookBackPeriodInDays",
                    .volume_recommendation_options = "volumeRecommendationOptions",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                    .current_performance_risk = "currentPerformanceRisk",
                    .tags = "tags",
                    .effective_recommendation_preferences = "effectiveRecommendationPreferences",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]GetRecommendationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .volume_recommendations = "volumeRecommendations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_ec2_instance_recommendations: struct {
    action_name: []const u8 = "GetEC2InstanceRecommendations",
    Request: type = struct {
        instance_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        account_ids: ?[][]const u8 = null,
        recommendation_preferences: ?RecommendationPreferences = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arns = "instanceArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
                .account_ids = "accountIds",
                .recommendation_preferences = "recommendationPreferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ec2_instance_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_ec2_instance_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        instance_recommendations: ?[]struct {
            instance_arn: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            instance_name: ?[]const u8 = null,
            current_instance_type: ?[]const u8 = null,
            finding: ?[]const u8 = null,
            finding_reason_codes: ?[][]const u8 = null,
            utilization_metrics: ?[]UtilizationMetric = null,
            look_back_period_in_days: ?f64 = null,
            recommendation_options: ?[]struct {
                instance_type: ?[]const u8 = null,
                projected_utilization_metrics: ?[]UtilizationMetric = null,
                platform_differences: ?[][]const u8 = null,
                performance_risk: ?f64 = null,
                rank: ?i64 = null,
                savings_opportunity: ?SavingsOpportunity = null,
                migration_effort: ?[]const u8 = null,
                instance_gpu_info: ?GpuInfo = null,
                savings_opportunity_after_discounts: ?struct {
                    savings_opportunity_percentage: ?f64 = null,
                    estimated_monthly_savings: ?struct {
                        currency: ?[]const u8 = null,
                        value: ?f64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .currency = "currency",
                                .value = "value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .savings_opportunity_percentage = "savingsOpportunityPercentage",
                            .estimated_monthly_savings = "estimatedMonthlySavings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .instance_type = "instanceType",
                        .projected_utilization_metrics = "projectedUtilizationMetrics",
                        .platform_differences = "platformDifferences",
                        .performance_risk = "performanceRisk",
                        .rank = "rank",
                        .savings_opportunity = "savingsOpportunity",
                        .migration_effort = "migrationEffort",
                        .instance_gpu_info = "instanceGpuInfo",
                        .savings_opportunity_after_discounts = "savingsOpportunityAfterDiscounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            recommendation_sources: ?[]struct {
                recommendation_source_arn: ?[]const u8 = null,
                recommendation_source_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .recommendation_source_arn = "recommendationSourceArn",
                        .recommendation_source_type = "recommendationSourceType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_refresh_timestamp: ?i64 = null,
            current_performance_risk: ?[]const u8 = null,
            effective_recommendation_preferences: ?EffectiveRecommendationPreferences = null,
            inferred_workload_types: ?[][]const u8 = null,
            instance_state: ?[]const u8 = null,
            tags: ?[]Tag = null,
            external_metric_status: ?struct {
                status_code: ?[]const u8 = null,
                status_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status_code = "statusCode",
                        .status_reason = "statusReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            current_instance_gpu_info: ?GpuInfo = null,
            idle: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_arn = "instanceArn",
                    .account_id = "accountId",
                    .instance_name = "instanceName",
                    .current_instance_type = "currentInstanceType",
                    .finding = "finding",
                    .finding_reason_codes = "findingReasonCodes",
                    .utilization_metrics = "utilizationMetrics",
                    .look_back_period_in_days = "lookBackPeriodInDays",
                    .recommendation_options = "recommendationOptions",
                    .recommendation_sources = "recommendationSources",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                    .current_performance_risk = "currentPerformanceRisk",
                    .effective_recommendation_preferences = "effectiveRecommendationPreferences",
                    .inferred_workload_types = "inferredWorkloadTypes",
                    .instance_state = "instanceState",
                    .tags = "tags",
                    .external_metric_status = "externalMetricStatus",
                    .current_instance_gpu_info = "currentInstanceGpuInfo",
                    .idle = "idle",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]GetRecommendationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .instance_recommendations = "instanceRecommendations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_ec2_recommendation_projected_metrics: struct {
    action_name: []const u8 = "GetEC2RecommendationProjectedMetrics",
    Request: type = struct {
        instance_arn: []const u8,
        stat: []const u8,
        period: i64,
        start_time: i64,
        end_time: i64,
        recommendation_preferences: ?RecommendationPreferences = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "instanceArn",
                .stat = "stat",
                .period = "period",
                .start_time = "startTime",
                .end_time = "endTime",
                .recommendation_preferences = "recommendationPreferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ec2_recommendation_projected_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_ec2_recommendation_projected_metrics };
        }
    },
    Response: type = struct {
        recommended_option_projected_metrics: ?[]struct {
            recommended_instance_type: ?[]const u8 = null,
            rank: ?i64 = null,
            projected_metrics: ?[]struct {
                name: ?[]const u8 = null,
                timestamps: ?[]i64 = null,
                values: ?[]f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .timestamps = "timestamps",
                        .values = "values",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommended_instance_type = "recommendedInstanceType",
                    .rank = "rank",
                    .projected_metrics = "projectedMetrics",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommended_option_projected_metrics = "recommendedOptionProjectedMetrics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_ecs_service_recommendation_projected_metrics: struct {
    action_name: []const u8 = "GetECSServiceRecommendationProjectedMetrics",
    Request: type = struct {
        service_arn: []const u8,
        stat: []const u8,
        period: i64,
        start_time: i64,
        end_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arn = "serviceArn",
                .stat = "stat",
                .period = "period",
                .start_time = "startTime",
                .end_time = "endTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ecs_service_recommendation_projected_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_ecs_service_recommendation_projected_metrics };
        }
    },
    Response: type = struct {
        recommended_option_projected_metrics: ?[]struct {
            recommended_cpu_units: ?i64 = null,
            recommended_memory_size: ?i64 = null,
            projected_metrics: ?[]struct {
                name: ?[]const u8 = null,
                timestamps: ?[]i64 = null,
                upper_bound_values: ?[]f64 = null,
                lower_bound_values: ?[]f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .timestamps = "timestamps",
                        .upper_bound_values = "upperBoundValues",
                        .lower_bound_values = "lowerBoundValues",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommended_cpu_units = "recommendedCpuUnits",
                    .recommended_memory_size = "recommendedMemorySize",
                    .projected_metrics = "projectedMetrics",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommended_option_projected_metrics = "recommendedOptionProjectedMetrics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_ecs_service_recommendations: struct {
    action_name: []const u8 = "GetECSServiceRecommendations",
    Request: type = struct {
        service_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]ECSServiceRecommendationFilter = null,
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arns = "serviceArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ecs_service_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_ecs_service_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        ecs_service_recommendations: ?[]struct {
            service_arn: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            current_service_configuration: ?struct {
                memory: ?i64 = null,
                cpu: ?i64 = null,
                container_configurations: ?[]struct {
                    container_name: ?[]const u8 = null,
                    memory_size_configuration: ?MemorySizeConfiguration = null,
                    cpu: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .container_name = "containerName",
                            .memory_size_configuration = "memorySizeConfiguration",
                            .cpu = "cpu",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                auto_scaling_configuration: ?[]const u8 = null,
                task_definition_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .memory = "memory",
                        .cpu = "cpu",
                        .container_configurations = "containerConfigurations",
                        .auto_scaling_configuration = "autoScalingConfiguration",
                        .task_definition_arn = "taskDefinitionArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            utilization_metrics: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lookback_period_in_days: ?f64 = null,
            launch_type: ?[]const u8 = null,
            last_refresh_timestamp: ?i64 = null,
            finding: ?[]const u8 = null,
            finding_reason_codes: ?[][]const u8 = null,
            service_recommendation_options: ?[]struct {
                memory: ?i64 = null,
                cpu: ?i64 = null,
                savings_opportunity: ?SavingsOpportunity = null,
                projected_utilization_metrics: ?[]struct {
                    name: ?[]const u8 = null,
                    statistic: ?[]const u8 = null,
                    lower_bound_value: ?f64 = null,
                    upper_bound_value: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .statistic = "statistic",
                            .lower_bound_value = "lowerBoundValue",
                            .upper_bound_value = "upperBoundValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                container_recommendations: ?[]struct {
                    container_name: ?[]const u8 = null,
                    memory_size_configuration: ?MemorySizeConfiguration = null,
                    cpu: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .container_name = "containerName",
                            .memory_size_configuration = "memorySizeConfiguration",
                            .cpu = "cpu",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                savings_opportunity_after_discounts: ?struct {
                    savings_opportunity_percentage: ?f64 = null,
                    estimated_monthly_savings: ?struct {
                        currency: ?[]const u8 = null,
                        value: ?f64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .currency = "currency",
                                .value = "value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .savings_opportunity_percentage = "savingsOpportunityPercentage",
                            .estimated_monthly_savings = "estimatedMonthlySavings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .memory = "memory",
                        .cpu = "cpu",
                        .savings_opportunity = "savingsOpportunity",
                        .projected_utilization_metrics = "projectedUtilizationMetrics",
                        .container_recommendations = "containerRecommendations",
                        .savings_opportunity_after_discounts = "savingsOpportunityAfterDiscounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            current_performance_risk: ?[]const u8 = null,
            tags: ?[]Tag = null,
            effective_recommendation_preferences: ?struct {
                savings_estimation_mode: ?struct {
                    source: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .source = "source",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .savings_estimation_mode = "savingsEstimationMode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_arn = "serviceArn",
                    .account_id = "accountId",
                    .current_service_configuration = "currentServiceConfiguration",
                    .utilization_metrics = "utilizationMetrics",
                    .lookback_period_in_days = "lookbackPeriodInDays",
                    .launch_type = "launchType",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                    .finding = "finding",
                    .finding_reason_codes = "findingReasonCodes",
                    .service_recommendation_options = "serviceRecommendationOptions",
                    .current_performance_risk = "currentPerformanceRisk",
                    .tags = "tags",
                    .effective_recommendation_preferences = "effectiveRecommendationPreferences",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]GetRecommendationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .ecs_service_recommendations = "ecsServiceRecommendations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_effective_recommendation_preferences: struct {
    action_name: []const u8 = "GetEffectiveRecommendationPreferences",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_effective_recommendation_preferences) } {
            return .{ .service_metadata = service_metadata, .action = get_effective_recommendation_preferences };
        }
    },
    Response: type = struct {
        enhanced_infrastructure_metrics: ?[]const u8 = null,
        external_metrics_preference: ?ExternalMetricsPreference = null,
        look_back_period: ?[]const u8 = null,
        utilization_preferences: ?[]UtilizationPreference = null,
        preferred_resources: ?[]EffectivePreferredResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enhanced_infrastructure_metrics = "enhancedInfrastructureMetrics",
                .external_metrics_preference = "externalMetricsPreference",
                .look_back_period = "lookBackPeriod",
                .utilization_preferences = "utilizationPreferences",
                .preferred_resources = "preferredResources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_enrollment_status: struct {
    action_name: []const u8 = "GetEnrollmentStatus",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_enrollment_status) } {
            return .{ .service_metadata = service_metadata, .action = get_enrollment_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        member_accounts_enrolled: ?bool = null,
        last_updated_timestamp: ?i64 = null,
        number_of_member_accounts_opted_in: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .status_reason = "statusReason",
                .member_accounts_enrolled = "memberAccountsEnrolled",
                .last_updated_timestamp = "lastUpdatedTimestamp",
                .number_of_member_accounts_opted_in = "numberOfMemberAccountsOptedIn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_enrollment_statuses_for_organization: struct {
    action_name: []const u8 = "GetEnrollmentStatusesForOrganization",
    Request: type = struct {
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_enrollment_statuses_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = get_enrollment_statuses_for_organization };
        }
    },
    Response: type = struct {
        account_enrollment_statuses: ?[]struct {
            account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .status = "status",
                    .status_reason = "statusReason",
                    .last_updated_timestamp = "lastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_enrollment_statuses = "accountEnrollmentStatuses",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_lambda_function_recommendations: struct {
    action_name: []const u8 = "GetLambdaFunctionRecommendations",
    Request: type = struct {
        function_arns: ?[][]const u8 = null,
        account_ids: ?[][]const u8 = null,
        filters: ?[]LambdaFunctionRecommendationFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_arns = "functionArns",
                .account_ids = "accountIds",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lambda_function_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_lambda_function_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        lambda_function_recommendations: ?[]struct {
            function_arn: ?[]const u8 = null,
            function_version: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            current_memory_size: ?i64 = null,
            number_of_invocations: ?i64 = null,
            utilization_metrics: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lookback_period_in_days: ?f64 = null,
            last_refresh_timestamp: ?i64 = null,
            finding: ?[]const u8 = null,
            finding_reason_codes: ?[][]const u8 = null,
            memory_size_recommendation_options: ?[]struct {
                rank: ?i64 = null,
                memory_size: ?i64 = null,
                projected_utilization_metrics: ?[]struct {
                    name: ?[]const u8 = null,
                    statistic: ?[]const u8 = null,
                    value: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .statistic = "statistic",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                savings_opportunity: ?SavingsOpportunity = null,
                savings_opportunity_after_discounts: ?struct {
                    savings_opportunity_percentage: ?f64 = null,
                    estimated_monthly_savings: ?struct {
                        currency: ?[]const u8 = null,
                        value: ?f64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .currency = "currency",
                                .value = "value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .savings_opportunity_percentage = "savingsOpportunityPercentage",
                            .estimated_monthly_savings = "estimatedMonthlySavings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rank = "rank",
                        .memory_size = "memorySize",
                        .projected_utilization_metrics = "projectedUtilizationMetrics",
                        .savings_opportunity = "savingsOpportunity",
                        .savings_opportunity_after_discounts = "savingsOpportunityAfterDiscounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            current_performance_risk: ?[]const u8 = null,
            tags: ?[]Tag = null,
            effective_recommendation_preferences: ?struct {
                savings_estimation_mode: ?struct {
                    source: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .source = "source",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .savings_estimation_mode = "savingsEstimationMode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .function_arn = "functionArn",
                    .function_version = "functionVersion",
                    .account_id = "accountId",
                    .current_memory_size = "currentMemorySize",
                    .number_of_invocations = "numberOfInvocations",
                    .utilization_metrics = "utilizationMetrics",
                    .lookback_period_in_days = "lookbackPeriodInDays",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                    .finding = "finding",
                    .finding_reason_codes = "findingReasonCodes",
                    .memory_size_recommendation_options = "memorySizeRecommendationOptions",
                    .current_performance_risk = "currentPerformanceRisk",
                    .tags = "tags",
                    .effective_recommendation_preferences = "effectiveRecommendationPreferences",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .lambda_function_recommendations = "lambdaFunctionRecommendations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_license_recommendations: struct {
    action_name: []const u8 = "GetLicenseRecommendations",
    Request: type = struct {
        resource_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]LicenseRecommendationFilter = null,
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "resourceArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_license_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_license_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        license_recommendations: ?[]struct {
            resource_arn: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            current_license_configuration: ?struct {
                number_of_cores: ?i64 = null,
                instance_type: ?[]const u8 = null,
                operating_system: ?[]const u8 = null,
                license_edition: ?[]const u8 = null,
                license_name: ?[]const u8 = null,
                license_model: ?[]const u8 = null,
                license_version: ?[]const u8 = null,
                metrics_source: ?[]struct {
                    provider: ?[]const u8 = null,
                    provider_arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .provider = "provider",
                            .provider_arn = "providerArn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .number_of_cores = "numberOfCores",
                        .instance_type = "instanceType",
                        .operating_system = "operatingSystem",
                        .license_edition = "licenseEdition",
                        .license_name = "licenseName",
                        .license_model = "licenseModel",
                        .license_version = "licenseVersion",
                        .metrics_source = "metricsSource",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lookback_period_in_days: ?f64 = null,
            last_refresh_timestamp: ?i64 = null,
            finding: ?[]const u8 = null,
            finding_reason_codes: ?[][]const u8 = null,
            license_recommendation_options: ?[]struct {
                rank: ?i64 = null,
                operating_system: ?[]const u8 = null,
                license_edition: ?[]const u8 = null,
                license_model: ?[]const u8 = null,
                savings_opportunity: ?SavingsOpportunity = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rank = "rank",
                        .operating_system = "operatingSystem",
                        .license_edition = "licenseEdition",
                        .license_model = "licenseModel",
                        .savings_opportunity = "savingsOpportunity",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "resourceArn",
                    .account_id = "accountId",
                    .current_license_configuration = "currentLicenseConfiguration",
                    .lookback_period_in_days = "lookbackPeriodInDays",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                    .finding = "finding",
                    .finding_reason_codes = "findingReasonCodes",
                    .license_recommendation_options = "licenseRecommendationOptions",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]GetRecommendationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .license_recommendations = "licenseRecommendations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_recommendation_preferences: struct {
    action_name: []const u8 = "GetRecommendationPreferences",
    Request: type = struct {
        resource_type: []const u8,
        scope: ?Scope = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "resourceType",
                .scope = "scope",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommendation_preferences) } {
            return .{ .service_metadata = service_metadata, .action = get_recommendation_preferences };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recommendation_preferences_details: ?[]struct {
            scope: ?Scope = null,
            resource_type: ?[]const u8 = null,
            enhanced_infrastructure_metrics: ?[]const u8 = null,
            inferred_workload_types: ?[]const u8 = null,
            external_metrics_preference: ?ExternalMetricsPreference = null,
            look_back_period: ?[]const u8 = null,
            utilization_preferences: ?[]UtilizationPreference = null,
            preferred_resources: ?[]EffectivePreferredResource = null,
            savings_estimation_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scope = "scope",
                    .resource_type = "resourceType",
                    .enhanced_infrastructure_metrics = "enhancedInfrastructureMetrics",
                    .inferred_workload_types = "inferredWorkloadTypes",
                    .external_metrics_preference = "externalMetricsPreference",
                    .look_back_period = "lookBackPeriod",
                    .utilization_preferences = "utilizationPreferences",
                    .preferred_resources = "preferredResources",
                    .savings_estimation_mode = "savingsEstimationMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .recommendation_preferences_details = "recommendationPreferencesDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_recommendation_summaries: struct {
    action_name: []const u8 = "GetRecommendationSummaries",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommendation_summaries) } {
            return .{ .service_metadata = service_metadata, .action = get_recommendation_summaries };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recommendation_summaries: ?[]struct {
            summaries: ?[]struct {
                name: ?[]const u8 = null,
                value: ?f64 = null,
                reason_code_summaries: ?[]struct {
                    name: ?[]const u8 = null,
                    value: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                        .reason_code_summaries = "reasonCodeSummaries",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            recommendation_resource_type: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            savings_opportunity: ?SavingsOpportunity = null,
            current_performance_risk_ratings: ?struct {
                high: ?i64 = null,
                medium: ?i64 = null,
                low: ?i64 = null,
                very_low: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .high = "high",
                        .medium = "medium",
                        .low = "low",
                        .very_low = "veryLow",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            inferred_workload_savings: ?[]struct {
                inferred_workload_types: ?[][]const u8 = null,
                estimated_monthly_savings: ?EstimatedMonthlySavings = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .inferred_workload_types = "inferredWorkloadTypes",
                        .estimated_monthly_savings = "estimatedMonthlySavings",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .summaries = "summaries",
                    .recommendation_resource_type = "recommendationResourceType",
                    .account_id = "accountId",
                    .savings_opportunity = "savingsOpportunity",
                    .current_performance_risk_ratings = "currentPerformanceRiskRatings",
                    .inferred_workload_savings = "inferredWorkloadSavings",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .recommendation_summaries = "recommendationSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const put_recommendation_preferences: struct {
    action_name: []const u8 = "PutRecommendationPreferences",
    Request: type = struct {
        resource_type: []const u8,
        scope: ?Scope = null,
        enhanced_infrastructure_metrics: ?[]const u8 = null,
        inferred_workload_types: ?[]const u8 = null,
        external_metrics_preference: ?ExternalMetricsPreference = null,
        look_back_period: ?[]const u8 = null,
        utilization_preferences: ?[]UtilizationPreference = null,
        preferred_resources: ?[]struct {
            name: ?[]const u8 = null,
            include_list: ?[][]const u8 = null,
            exclude_list: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .include_list = "includeList",
                    .exclude_list = "excludeList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        savings_estimation_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "resourceType",
                .scope = "scope",
                .enhanced_infrastructure_metrics = "enhancedInfrastructureMetrics",
                .inferred_workload_types = "inferredWorkloadTypes",
                .external_metrics_preference = "externalMetricsPreference",
                .look_back_period = "lookBackPeriod",
                .utilization_preferences = "utilizationPreferences",
                .preferred_resources = "preferredResources",
                .savings_estimation_mode = "savingsEstimationMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_recommendation_preferences) } {
            return .{ .service_metadata = service_metadata, .action = put_recommendation_preferences };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_enrollment_status: struct {
    action_name: []const u8 = "UpdateEnrollmentStatus",
    Request: type = struct {
        status: []const u8,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_enrollment_status) } {
            return .{ .service_metadata = service_metadata, .action = update_enrollment_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .status_reason = "statusReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const UtilizationPreference = struct {
    metric_name: ?[]const u8 = null,
    metric_parameters: ?CustomizableMetricParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "metricName",
            .metric_parameters = "metricParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomizableMetricParameters = struct {
    threshold: ?[]const u8 = null,
    headroom: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .threshold = "threshold",
            .headroom = "headroom",
        };
        return @field(mappings, field_name);
    }
};

pub const ExternalMetricsPreference = struct {
    source: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
        };
        return @field(mappings, field_name);
    }
};

pub const Scope = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const EstimatedMonthlySavings = struct {
    currency: ?[]const u8 = null,
    value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .currency = "currency",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SavingsOpportunity = struct {
    savings_opportunity_percentage: ?f64 = null,
    estimated_monthly_savings: ?EstimatedMonthlySavings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .savings_opportunity_percentage = "savingsOpportunityPercentage",
            .estimated_monthly_savings = "estimatedMonthlySavings",
        };
        return @field(mappings, field_name);
    }
};

pub const EffectivePreferredResource = struct {
    name: ?[]const u8 = null,
    include_list: ?[][]const u8 = null,
    effective_include_list: ?[][]const u8 = null,
    exclude_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .include_list = "includeList",
            .effective_include_list = "effectiveIncludeList",
            .exclude_list = "excludeList",
        };
        return @field(mappings, field_name);
    }
};

pub const GetRecommendationError = struct {
    identifier: ?[]const u8 = null,
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "identifier",
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const LicenseRecommendationFilter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionRecommendationFilter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const MemorySizeConfiguration = struct {
    memory: ?i64 = null,
    memory_reservation: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .memory = "memory",
            .memory_reservation = "memoryReservation",
        };
        return @field(mappings, field_name);
    }
};

pub const ECSServiceRecommendationFilter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const RecommendationPreferences = struct {
    cpu_vendor_architectures: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu_vendor_architectures = "cpuVendorArchitectures",
        };
        return @field(mappings, field_name);
    }
};

pub const GpuInfo = struct {
    gpus: ?[]Gpu = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gpus = "gpus",
        };
        return @field(mappings, field_name);
    }
};

pub const Gpu = struct {
    gpu_count: ?i64 = null,
    gpu_memory_size_in_mib: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gpu_count = "gpuCount",
            .gpu_memory_size_in_mib = "gpuMemorySizeInMiB",
        };
        return @field(mappings, field_name);
    }
};

pub const EffectiveRecommendationPreferences = struct {
    cpu_vendor_architectures: ?[][]const u8 = null,
    enhanced_infrastructure_metrics: ?[]const u8 = null,
    inferred_workload_types: ?[]const u8 = null,
    external_metrics_preference: ?ExternalMetricsPreference = null,
    look_back_period: ?[]const u8 = null,
    utilization_preferences: ?[]UtilizationPreference = null,
    preferred_resources: ?[]EffectivePreferredResource = null,
    savings_estimation_mode: ?InstanceSavingsEstimationMode = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu_vendor_architectures = "cpuVendorArchitectures",
            .enhanced_infrastructure_metrics = "enhancedInfrastructureMetrics",
            .inferred_workload_types = "inferredWorkloadTypes",
            .external_metrics_preference = "externalMetricsPreference",
            .look_back_period = "lookBackPeriod",
            .utilization_preferences = "utilizationPreferences",
            .preferred_resources = "preferredResources",
            .savings_estimation_mode = "savingsEstimationMode",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceSavingsEstimationMode = struct {
    source: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
        };
        return @field(mappings, field_name);
    }
};

pub const UtilizationMetric = struct {
    name: ?[]const u8 = null,
    statistic: ?[]const u8 = null,
    value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .statistic = "statistic",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeConfiguration = struct {
    volume_type: ?[]const u8 = null,
    volume_size: ?i64 = null,
    volume_baseline_iops: ?i64 = null,
    volume_burst_iops: ?i64 = null,
    volume_baseline_throughput: ?i64 = null,
    volume_burst_throughput: ?i64 = null,
    root_volume: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_type = "volumeType",
            .volume_size = "volumeSize",
            .volume_baseline_iops = "volumeBaselineIOPS",
            .volume_burst_iops = "volumeBurstIOPS",
            .volume_baseline_throughput = "volumeBaselineThroughput",
            .volume_burst_throughput = "volumeBurstThroughput",
            .root_volume = "rootVolume",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSFilter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingGroupConfiguration = struct {
    desired_capacity: ?i64 = null,
    min_size: ?i64 = null,
    max_size: ?i64 = null,
    instance_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .desired_capacity = "desiredCapacity",
            .min_size = "minSize",
            .max_size = "maxSize",
            .instance_type = "instanceType",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Destination = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,
    metadata_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key = "key",
            .metadata_key = "metadataKey",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationConfig = struct {
    bucket: ?[]const u8 = null,
    key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key_prefix = "keyPrefix",
        };
        return @field(mappings, field_name);
    }
};
