const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-11-12";
pub const sdk_id: []const u8 = "Config Service";
pub const arn_namespace: ?[]const u8 = "config";
pub const endpoint_prefix: []const u8 = "config";
pub const sigv4_name: []const u8 = "config";
pub const name: []const u8 = "StarlingDoveService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2014-11-12",
    sdk_id: []const u8 = "Config Service",
    arn_namespace: ?[]const u8 = "config",
    endpoint_prefix: []const u8 = "config",
    sigv4_name: []const u8 = "config",
    name: []const u8 = "StarlingDoveService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_get_aggregate_resource_config: struct {
    action_name: []const u8 = "BatchGetAggregateResourceConfig",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        resource_identifiers: []AggregateResourceIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .resource_identifiers = "ResourceIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_aggregate_resource_config) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_aggregate_resource_config };
        }
    },
    Response: type = struct {
        base_configuration_items: ?[]BaseConfigurationItem = null,
        unprocessed_resource_identifiers: ?[]AggregateResourceIdentifier = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .base_configuration_items = "BaseConfigurationItems",
                .unprocessed_resource_identifiers = "UnprocessedResourceIdentifiers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchConfigurationAggregator,
        Validation,
    },
} = .{};
pub const batch_get_resource_config: struct {
    action_name: []const u8 = "BatchGetResourceConfig",
    Request: type = struct {
        resource_keys: []ResourceKey,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_keys = "resourceKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_resource_config) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_resource_config };
        }
    },
    Response: type = struct {
        base_configuration_items: ?[]BaseConfigurationItem = null,
        unprocessed_resource_keys: ?[]ResourceKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .base_configuration_items = "baseConfigurationItems",
                .unprocessed_resource_keys = "unprocessedResourceKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoAvailableConfigurationRecorder,
        Validation,
    },
} = .{};
pub const delete_aggregation_authorization: struct {
    action_name: []const u8 = "DeleteAggregationAuthorization",
    Request: type = struct {
        authorized_account_id: []const u8,
        authorized_aws_region: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorized_account_id = "AuthorizedAccountId",
                .authorized_aws_region = "AuthorizedAwsRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_aggregation_authorization) } {
            return .{ .service_metadata = service_metadata, .action = delete_aggregation_authorization };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
    },
} = .{};
pub const delete_config_rule: struct {
    action_name: []const u8 = "DeleteConfigRule",
    Request: type = struct {
        config_rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_config_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_config_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoSuchConfigRule,
        ResourceInUse,
    },
} = .{};
pub const delete_configuration_aggregator: struct {
    action_name: []const u8 = "DeleteConfigurationAggregator",
    Request: type = struct {
        configuration_aggregator_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_aggregator) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_aggregator };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoSuchConfigurationAggregator,
    },
} = .{};
pub const delete_configuration_recorder: struct {
    action_name: []const u8 = "DeleteConfigurationRecorder",
    Request: type = struct {
        configuration_recorder_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_recorder_name = "ConfigurationRecorderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_recorder) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_recorder };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoSuchConfigurationRecorder,
    },
} = .{};
pub const delete_conformance_pack: struct {
    action_name: []const u8 = "DeleteConformancePack",
    Request: type = struct {
        conformance_pack_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_name = "ConformancePackName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_conformance_pack) } {
            return .{ .service_metadata = service_metadata, .action = delete_conformance_pack };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoSuchConformancePack,
        ResourceInUse,
    },
} = .{};
pub const delete_delivery_channel: struct {
    action_name: []const u8 = "DeleteDeliveryChannel",
    Request: type = struct {
        delivery_channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delivery_channel_name = "DeliveryChannelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_delivery_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_delivery_channel };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        LastDeliveryChannelDeleteFailed,
        NoSuchDeliveryChannel,
    },
} = .{};
pub const delete_evaluation_results: struct {
    action_name: []const u8 = "DeleteEvaluationResults",
    Request: type = struct {
        config_rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_evaluation_results) } {
            return .{ .service_metadata = service_metadata, .action = delete_evaluation_results };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchConfigRule,
        ResourceInUse,
    },
} = .{};
pub const delete_organization_config_rule: struct {
    action_name: []const u8 = "DeleteOrganizationConfigRule",
    Request: type = struct {
        organization_config_rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_name = "OrganizationConfigRuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_organization_config_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_organization_config_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoSuchOrganizationConfigRule,
        OrganizationAccessDenied,
        ResourceInUse,
    },
} = .{};
pub const delete_organization_conformance_pack: struct {
    action_name: []const u8 = "DeleteOrganizationConformancePack",
    Request: type = struct {
        organization_conformance_pack_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_pack_name = "OrganizationConformancePackName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_organization_conformance_pack) } {
            return .{ .service_metadata = service_metadata, .action = delete_organization_conformance_pack };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoSuchOrganizationConformancePack,
        OrganizationAccessDenied,
        ResourceInUse,
    },
} = .{};
pub const delete_pending_aggregation_request: struct {
    action_name: []const u8 = "DeletePendingAggregationRequest",
    Request: type = struct {
        requester_account_id: []const u8,
        requester_aws_region: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .requester_account_id = "RequesterAccountId",
                .requester_aws_region = "RequesterAwsRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pending_aggregation_request) } {
            return .{ .service_metadata = service_metadata, .action = delete_pending_aggregation_request };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
    },
} = .{};
pub const delete_remediation_configuration: struct {
    action_name: []const u8 = "DeleteRemediationConfiguration",
    Request: type = struct {
        config_rule_name: []const u8,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_remediation_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_remediation_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPermissions,
        InvalidParameterValue,
        NoSuchRemediationConfiguration,
        RemediationInProgress,
    },
} = .{};
pub const delete_remediation_exceptions: struct {
    action_name: []const u8 = "DeleteRemediationExceptions",
    Request: type = struct {
        config_rule_name: []const u8,
        resource_keys: []RemediationExceptionResourceKey,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
                .resource_keys = "ResourceKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_remediation_exceptions) } {
            return .{ .service_metadata = service_metadata, .action = delete_remediation_exceptions };
        }
    },
    Response: type = struct {
        failed_batches: ?[]struct {
            failure_message: ?[]const u8 = null,
            failed_items: ?[]RemediationExceptionResourceKey = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .failure_message = "FailureMessage",
                    .failed_items = "FailedItems",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_batches = "FailedBatches",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchRemediationException,
    },
} = .{};
pub const delete_resource_config: struct {
    action_name: []const u8 = "DeleteResourceConfig",
    Request: type = struct {
        resource_type: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoRunningConfigurationRecorder,
        Validation,
    },
} = .{};
pub const delete_retention_configuration: struct {
    action_name: []const u8 = "DeleteRetentionConfiguration",
    Request: type = struct {
        retention_configuration_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention_configuration_name = "RetentionConfigurationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_retention_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_retention_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        NoSuchRetentionConfiguration,
    },
} = .{};
pub const delete_stored_query: struct {
    action_name: []const u8 = "DeleteStoredQuery",
    Request: type = struct {
        query_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_name = "QueryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stored_query) } {
            return .{ .service_metadata = service_metadata, .action = delete_stored_query };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const deliver_config_snapshot: struct {
    action_name: []const u8 = "DeliverConfigSnapshot",
    Request: type = struct {
        delivery_channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delivery_channel_name = "deliveryChannelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deliver_config_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = deliver_config_snapshot };
        }
    },
    Response: type = struct {
        config_snapshot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_snapshot_id = "configSnapshotId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoAvailableConfigurationRecorder,
        NoRunningConfigurationRecorder,
        NoSuchDeliveryChannel,
    },
} = .{};
pub const describe_aggregate_compliance_by_config_rules: struct {
    action_name: []const u8 = "DescribeAggregateComplianceByConfigRules",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        filters: ?struct {
            config_rule_name: ?[]const u8 = null,
            compliance_type: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .config_rule_name = "ConfigRuleName",
                    .compliance_type = "ComplianceType",
                    .account_id = "AccountId",
                    .aws_region = "AwsRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_aggregate_compliance_by_config_rules) } {
            return .{ .service_metadata = service_metadata, .action = describe_aggregate_compliance_by_config_rules };
        }
    },
    Response: type = struct {
        aggregate_compliance_by_config_rules: ?[]struct {
            config_rule_name: ?[]const u8 = null,
            compliance: ?Compliance = null,
            account_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .config_rule_name = "ConfigRuleName",
                    .compliance = "Compliance",
                    .account_id = "AccountId",
                    .aws_region = "AwsRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregate_compliance_by_config_rules = "AggregateComplianceByConfigRules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchConfigurationAggregator,
        Validation,
    },
} = .{};
pub const describe_aggregate_compliance_by_conformance_packs: struct {
    action_name: []const u8 = "DescribeAggregateComplianceByConformancePacks",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        filters: ?struct {
            conformance_pack_name: ?[]const u8 = null,
            compliance_type: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .conformance_pack_name = "ConformancePackName",
                    .compliance_type = "ComplianceType",
                    .account_id = "AccountId",
                    .aws_region = "AwsRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_aggregate_compliance_by_conformance_packs) } {
            return .{ .service_metadata = service_metadata, .action = describe_aggregate_compliance_by_conformance_packs };
        }
    },
    Response: type = struct {
        aggregate_compliance_by_conformance_packs: ?[]struct {
            conformance_pack_name: ?[]const u8 = null,
            compliance: ?struct {
                compliance_type: ?[]const u8 = null,
                compliant_rule_count: ?i64 = null,
                non_compliant_rule_count: ?i64 = null,
                total_rule_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .compliance_type = "ComplianceType",
                        .compliant_rule_count = "CompliantRuleCount",
                        .non_compliant_rule_count = "NonCompliantRuleCount",
                        .total_rule_count = "TotalRuleCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            account_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .conformance_pack_name = "ConformancePackName",
                    .compliance = "Compliance",
                    .account_id = "AccountId",
                    .aws_region = "AwsRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregate_compliance_by_conformance_packs = "AggregateComplianceByConformancePacks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchConfigurationAggregator,
        Validation,
    },
} = .{};
pub const describe_aggregation_authorizations: struct {
    action_name: []const u8 = "DescribeAggregationAuthorizations",
    Request: type = struct {
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_aggregation_authorizations) } {
            return .{ .service_metadata = service_metadata, .action = describe_aggregation_authorizations };
        }
    },
    Response: type = struct {
        aggregation_authorizations: ?[]AggregationAuthorization = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregation_authorizations = "AggregationAuthorizations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
    },
} = .{};
pub const describe_compliance_by_config_rule: struct {
    action_name: []const u8 = "DescribeComplianceByConfigRule",
    Request: type = struct {
        config_rule_names: ?[][]const u8 = null,
        compliance_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_names = "ConfigRuleNames",
                .compliance_types = "ComplianceTypes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_compliance_by_config_rule) } {
            return .{ .service_metadata = service_metadata, .action = describe_compliance_by_config_rule };
        }
    },
    Response: type = struct {
        compliance_by_config_rules: ?[]struct {
            config_rule_name: ?[]const u8 = null,
            compliance: ?Compliance = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .config_rule_name = "ConfigRuleName",
                    .compliance = "Compliance",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compliance_by_config_rules = "ComplianceByConfigRules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConfigRule,
    },
} = .{};
pub const describe_compliance_by_resource: struct {
    action_name: []const u8 = "DescribeComplianceByResource",
    Request: type = struct {
        resource_type: ?[]const u8 = null,
        resource_id: ?[]const u8 = null,
        compliance_types: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
                .compliance_types = "ComplianceTypes",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_compliance_by_resource) } {
            return .{ .service_metadata = service_metadata, .action = describe_compliance_by_resource };
        }
    },
    Response: type = struct {
        compliance_by_resources: ?[]struct {
            resource_type: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            compliance: ?Compliance = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "ResourceType",
                    .resource_id = "ResourceId",
                    .compliance = "Compliance",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compliance_by_resources = "ComplianceByResources",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
    },
} = .{};
pub const describe_config_rule_evaluation_status: struct {
    action_name: []const u8 = "DescribeConfigRuleEvaluationStatus",
    Request: type = struct {
        config_rule_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_names = "ConfigRuleNames",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_config_rule_evaluation_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_config_rule_evaluation_status };
        }
    },
    Response: type = struct {
        config_rules_evaluation_status: ?[]struct {
            config_rule_name: ?[]const u8 = null,
            config_rule_arn: ?[]const u8 = null,
            config_rule_id: ?[]const u8 = null,
            last_successful_invocation_time: ?i64 = null,
            last_failed_invocation_time: ?i64 = null,
            last_successful_evaluation_time: ?i64 = null,
            last_failed_evaluation_time: ?i64 = null,
            first_activated_time: ?i64 = null,
            last_deactivated_time: ?i64 = null,
            last_error_code: ?[]const u8 = null,
            last_error_message: ?[]const u8 = null,
            first_evaluation_started: ?bool = null,
            last_debug_log_delivery_status: ?[]const u8 = null,
            last_debug_log_delivery_status_reason: ?[]const u8 = null,
            last_debug_log_delivery_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .config_rule_name = "ConfigRuleName",
                    .config_rule_arn = "ConfigRuleArn",
                    .config_rule_id = "ConfigRuleId",
                    .last_successful_invocation_time = "LastSuccessfulInvocationTime",
                    .last_failed_invocation_time = "LastFailedInvocationTime",
                    .last_successful_evaluation_time = "LastSuccessfulEvaluationTime",
                    .last_failed_evaluation_time = "LastFailedEvaluationTime",
                    .first_activated_time = "FirstActivatedTime",
                    .last_deactivated_time = "LastDeactivatedTime",
                    .last_error_code = "LastErrorCode",
                    .last_error_message = "LastErrorMessage",
                    .first_evaluation_started = "FirstEvaluationStarted",
                    .last_debug_log_delivery_status = "LastDebugLogDeliveryStatus",
                    .last_debug_log_delivery_status_reason = "LastDebugLogDeliveryStatusReason",
                    .last_debug_log_delivery_time = "LastDebugLogDeliveryTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rules_evaluation_status = "ConfigRulesEvaluationStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConfigRule,
    },
} = .{};
pub const describe_config_rules: struct {
    action_name: []const u8 = "DescribeConfigRules",
    Request: type = struct {
        config_rule_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        filters: ?struct {
            evaluation_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_mode = "EvaluationMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_names = "ConfigRuleNames",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_config_rules) } {
            return .{ .service_metadata = service_metadata, .action = describe_config_rules };
        }
    },
    Response: type = struct {
        config_rules: ?[]ConfigRule = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rules = "ConfigRules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConfigRule,
    },
} = .{};
pub const describe_configuration_aggregators: struct {
    action_name: []const u8 = "DescribeConfigurationAggregators",
    Request: type = struct {
        configuration_aggregator_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_names = "ConfigurationAggregatorNames",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_aggregators) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_aggregators };
        }
    },
    Response: type = struct {
        configuration_aggregators: ?[]ConfigurationAggregator = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregators = "ConfigurationAggregators",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConfigurationAggregator,
    },
} = .{};
pub const describe_configuration_aggregator_sources_status: struct {
    action_name: []const u8 = "DescribeConfigurationAggregatorSourcesStatus",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        update_status: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .update_status = "UpdateStatus",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_aggregator_sources_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_aggregator_sources_status };
        }
    },
    Response: type = struct {
        aggregated_source_status_list: ?[]struct {
            source_id: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,
            last_update_status: ?[]const u8 = null,
            last_update_time: ?i64 = null,
            last_error_code: ?[]const u8 = null,
            last_error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_id = "SourceId",
                    .source_type = "SourceType",
                    .aws_region = "AwsRegion",
                    .last_update_status = "LastUpdateStatus",
                    .last_update_time = "LastUpdateTime",
                    .last_error_code = "LastErrorCode",
                    .last_error_message = "LastErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregated_source_status_list = "AggregatedSourceStatusList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConfigurationAggregator,
    },
} = .{};
pub const describe_configuration_recorders: struct {
    action_name: []const u8 = "DescribeConfigurationRecorders",
    Request: type = struct {
        configuration_recorder_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_recorder_names = "ConfigurationRecorderNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_recorders) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_recorders };
        }
    },
    Response: type = struct {
        configuration_recorders: ?[]ConfigurationRecorder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_recorders = "ConfigurationRecorders",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchConfigurationRecorder,
    },
} = .{};
pub const describe_configuration_recorder_status: struct {
    action_name: []const u8 = "DescribeConfigurationRecorderStatus",
    Request: type = struct {
        configuration_recorder_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_recorder_names = "ConfigurationRecorderNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_recorder_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_recorder_status };
        }
    },
    Response: type = struct {
        configuration_recorders_status: ?[]struct {
            name: ?[]const u8 = null,
            last_start_time: ?i64 = null,
            last_stop_time: ?i64 = null,
            recording: ?bool = null,
            last_status: ?[]const u8 = null,
            last_error_code: ?[]const u8 = null,
            last_error_message: ?[]const u8 = null,
            last_status_change_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .last_start_time = "lastStartTime",
                    .last_stop_time = "lastStopTime",
                    .recording = "recording",
                    .last_status = "lastStatus",
                    .last_error_code = "lastErrorCode",
                    .last_error_message = "lastErrorMessage",
                    .last_status_change_time = "lastStatusChangeTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_recorders_status = "ConfigurationRecordersStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchConfigurationRecorder,
    },
} = .{};
pub const describe_conformance_pack_compliance: struct {
    action_name: []const u8 = "DescribeConformancePackCompliance",
    Request: type = struct {
        conformance_pack_name: []const u8,
        filters: ?struct {
            config_rule_names: ?[][]const u8 = null,
            compliance_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .config_rule_names = "ConfigRuleNames",
                    .compliance_type = "ComplianceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_name = "ConformancePackName",
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_conformance_pack_compliance) } {
            return .{ .service_metadata = service_metadata, .action = describe_conformance_pack_compliance };
        }
    },
    Response: type = struct {
        conformance_pack_name: []const u8,
        conformance_pack_rule_compliance_list: []struct {
            config_rule_name: ?[]const u8 = null,
            compliance_type: ?[]const u8 = null,
            controls: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .config_rule_name = "ConfigRuleName",
                    .compliance_type = "ComplianceType",
                    .controls = "Controls",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_name = "ConformancePackName",
                .conformance_pack_rule_compliance_list = "ConformancePackRuleComplianceList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConfigRuleInConformancePack,
        NoSuchConformancePack,
    },
} = .{};
pub const describe_conformance_packs: struct {
    action_name: []const u8 = "DescribeConformancePacks",
    Request: type = struct {
        conformance_pack_names: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_names = "ConformancePackNames",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_conformance_packs) } {
            return .{ .service_metadata = service_metadata, .action = describe_conformance_packs };
        }
    },
    Response: type = struct {
        conformance_pack_details: ?[]struct {
            conformance_pack_name: []const u8,
            conformance_pack_arn: []const u8,
            conformance_pack_id: []const u8,
            delivery_s3_bucket: ?[]const u8 = null,
            delivery_s3_key_prefix: ?[]const u8 = null,
            conformance_pack_input_parameters: ?[]ConformancePackInputParameter = null,
            last_update_requested_time: ?i64 = null,
            created_by: ?[]const u8 = null,
            template_ssm_document_details: ?TemplateSSMDocumentDetails = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .conformance_pack_name = "ConformancePackName",
                    .conformance_pack_arn = "ConformancePackArn",
                    .conformance_pack_id = "ConformancePackId",
                    .delivery_s3_bucket = "DeliveryS3Bucket",
                    .delivery_s3_key_prefix = "DeliveryS3KeyPrefix",
                    .conformance_pack_input_parameters = "ConformancePackInputParameters",
                    .last_update_requested_time = "LastUpdateRequestedTime",
                    .created_by = "CreatedBy",
                    .template_ssm_document_details = "TemplateSSMDocumentDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_details = "ConformancePackDetails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConformancePack,
    },
} = .{};
pub const describe_conformance_pack_status: struct {
    action_name: []const u8 = "DescribeConformancePackStatus",
    Request: type = struct {
        conformance_pack_names: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_names = "ConformancePackNames",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_conformance_pack_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_conformance_pack_status };
        }
    },
    Response: type = struct {
        conformance_pack_status_details: ?[]struct {
            conformance_pack_name: []const u8,
            conformance_pack_id: []const u8,
            conformance_pack_arn: []const u8,
            conformance_pack_state: []const u8,
            stack_arn: []const u8,
            conformance_pack_status_reason: ?[]const u8 = null,
            last_update_requested_time: i64,
            last_update_completed_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .conformance_pack_name = "ConformancePackName",
                    .conformance_pack_id = "ConformancePackId",
                    .conformance_pack_arn = "ConformancePackArn",
                    .conformance_pack_state = "ConformancePackState",
                    .stack_arn = "StackArn",
                    .conformance_pack_status_reason = "ConformancePackStatusReason",
                    .last_update_requested_time = "LastUpdateRequestedTime",
                    .last_update_completed_time = "LastUpdateCompletedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_status_details = "ConformancePackStatusDetails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
    },
} = .{};
pub const describe_delivery_channels: struct {
    action_name: []const u8 = "DescribeDeliveryChannels",
    Request: type = struct {
        delivery_channel_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delivery_channel_names = "DeliveryChannelNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_delivery_channels) } {
            return .{ .service_metadata = service_metadata, .action = describe_delivery_channels };
        }
    },
    Response: type = struct {
        delivery_channels: ?[]DeliveryChannel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delivery_channels = "DeliveryChannels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchDeliveryChannel,
    },
} = .{};
pub const describe_delivery_channel_status: struct {
    action_name: []const u8 = "DescribeDeliveryChannelStatus",
    Request: type = struct {
        delivery_channel_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delivery_channel_names = "DeliveryChannelNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_delivery_channel_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_delivery_channel_status };
        }
    },
    Response: type = struct {
        delivery_channels_status: ?[]struct {
            name: ?[]const u8 = null,
            config_snapshot_delivery_info: ?ConfigExportDeliveryInfo = null,
            config_history_delivery_info: ?ConfigExportDeliveryInfo = null,
            config_stream_delivery_info: ?struct {
                last_status: ?[]const u8 = null,
                last_error_code: ?[]const u8 = null,
                last_error_message: ?[]const u8 = null,
                last_status_change_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .last_status = "lastStatus",
                        .last_error_code = "lastErrorCode",
                        .last_error_message = "lastErrorMessage",
                        .last_status_change_time = "lastStatusChangeTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .config_snapshot_delivery_info = "configSnapshotDeliveryInfo",
                    .config_history_delivery_info = "configHistoryDeliveryInfo",
                    .config_stream_delivery_info = "configStreamDeliveryInfo",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delivery_channels_status = "DeliveryChannelsStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchDeliveryChannel,
    },
} = .{};
pub const describe_organization_config_rules: struct {
    action_name: []const u8 = "DescribeOrganizationConfigRules",
    Request: type = struct {
        organization_config_rule_names: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_names = "OrganizationConfigRuleNames",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_config_rules) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_config_rules };
        }
    },
    Response: type = struct {
        organization_config_rules: ?[]struct {
            organization_config_rule_name: []const u8,
            organization_config_rule_arn: []const u8,
            organization_managed_rule_metadata: ?OrganizationManagedRuleMetadata = null,
            organization_custom_rule_metadata: ?OrganizationCustomRuleMetadata = null,
            excluded_accounts: ?[][]const u8 = null,
            last_update_time: ?i64 = null,
            organization_custom_policy_rule_metadata: ?struct {
                description: ?[]const u8 = null,
                organization_config_rule_trigger_types: ?[][]const u8 = null,
                input_parameters: ?[]const u8 = null,
                maximum_execution_frequency: ?[]const u8 = null,
                resource_types_scope: ?[][]const u8 = null,
                resource_id_scope: ?[]const u8 = null,
                tag_key_scope: ?[]const u8 = null,
                tag_value_scope: ?[]const u8 = null,
                policy_runtime: ?[]const u8 = null,
                debug_log_delivery_accounts: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .description = "Description",
                        .organization_config_rule_trigger_types = "OrganizationConfigRuleTriggerTypes",
                        .input_parameters = "InputParameters",
                        .maximum_execution_frequency = "MaximumExecutionFrequency",
                        .resource_types_scope = "ResourceTypesScope",
                        .resource_id_scope = "ResourceIdScope",
                        .tag_key_scope = "TagKeyScope",
                        .tag_value_scope = "TagValueScope",
                        .policy_runtime = "PolicyRuntime",
                        .debug_log_delivery_accounts = "DebugLogDeliveryAccounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .organization_config_rule_name = "OrganizationConfigRuleName",
                    .organization_config_rule_arn = "OrganizationConfigRuleArn",
                    .organization_managed_rule_metadata = "OrganizationManagedRuleMetadata",
                    .organization_custom_rule_metadata = "OrganizationCustomRuleMetadata",
                    .excluded_accounts = "ExcludedAccounts",
                    .last_update_time = "LastUpdateTime",
                    .organization_custom_policy_rule_metadata = "OrganizationCustomPolicyRuleMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rules = "OrganizationConfigRules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchOrganizationConfigRule,
        OrganizationAccessDenied,
    },
} = .{};
pub const describe_organization_config_rule_statuses: struct {
    action_name: []const u8 = "DescribeOrganizationConfigRuleStatuses",
    Request: type = struct {
        organization_config_rule_names: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_names = "OrganizationConfigRuleNames",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_config_rule_statuses) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_config_rule_statuses };
        }
    },
    Response: type = struct {
        organization_config_rule_statuses: ?[]struct {
            organization_config_rule_name: []const u8,
            organization_rule_status: []const u8,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .organization_config_rule_name = "OrganizationConfigRuleName",
                    .organization_rule_status = "OrganizationRuleStatus",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                    .last_update_time = "LastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_statuses = "OrganizationConfigRuleStatuses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchOrganizationConfigRule,
        OrganizationAccessDenied,
    },
} = .{};
pub const describe_organization_conformance_packs: struct {
    action_name: []const u8 = "DescribeOrganizationConformancePacks",
    Request: type = struct {
        organization_conformance_pack_names: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_pack_names = "OrganizationConformancePackNames",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_conformance_packs) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_conformance_packs };
        }
    },
    Response: type = struct {
        organization_conformance_packs: ?[]struct {
            organization_conformance_pack_name: []const u8,
            organization_conformance_pack_arn: []const u8,
            delivery_s3_bucket: ?[]const u8 = null,
            delivery_s3_key_prefix: ?[]const u8 = null,
            conformance_pack_input_parameters: ?[]ConformancePackInputParameter = null,
            excluded_accounts: ?[][]const u8 = null,
            last_update_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .organization_conformance_pack_name = "OrganizationConformancePackName",
                    .organization_conformance_pack_arn = "OrganizationConformancePackArn",
                    .delivery_s3_bucket = "DeliveryS3Bucket",
                    .delivery_s3_key_prefix = "DeliveryS3KeyPrefix",
                    .conformance_pack_input_parameters = "ConformancePackInputParameters",
                    .excluded_accounts = "ExcludedAccounts",
                    .last_update_time = "LastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_packs = "OrganizationConformancePacks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchOrganizationConformancePack,
        OrganizationAccessDenied,
    },
} = .{};
pub const describe_organization_conformance_pack_statuses: struct {
    action_name: []const u8 = "DescribeOrganizationConformancePackStatuses",
    Request: type = struct {
        organization_conformance_pack_names: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_pack_names = "OrganizationConformancePackNames",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_conformance_pack_statuses) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_conformance_pack_statuses };
        }
    },
    Response: type = struct {
        organization_conformance_pack_statuses: ?[]struct {
            organization_conformance_pack_name: []const u8,
            status: []const u8,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .organization_conformance_pack_name = "OrganizationConformancePackName",
                    .status = "Status",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                    .last_update_time = "LastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_pack_statuses = "OrganizationConformancePackStatuses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchOrganizationConformancePack,
        OrganizationAccessDenied,
    },
} = .{};
pub const describe_pending_aggregation_requests: struct {
    action_name: []const u8 = "DescribePendingAggregationRequests",
    Request: type = struct {
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pending_aggregation_requests) } {
            return .{ .service_metadata = service_metadata, .action = describe_pending_aggregation_requests };
        }
    },
    Response: type = struct {
        pending_aggregation_requests: ?[]struct {
            requester_account_id: ?[]const u8 = null,
            requester_aws_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .requester_account_id = "RequesterAccountId",
                    .requester_aws_region = "RequesterAwsRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pending_aggregation_requests = "PendingAggregationRequests",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
    },
} = .{};
pub const describe_remediation_configurations: struct {
    action_name: []const u8 = "DescribeRemediationConfigurations",
    Request: type = struct {
        config_rule_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_names = "ConfigRuleNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_remediation_configurations) } {
            return .{ .service_metadata = service_metadata, .action = describe_remediation_configurations };
        }
    },
    Response: type = struct {
        remediation_configurations: ?[]RemediationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remediation_configurations = "RemediationConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_remediation_exceptions: struct {
    action_name: []const u8 = "DescribeRemediationExceptions",
    Request: type = struct {
        config_rule_name: []const u8,
        resource_keys: ?[]RemediationExceptionResourceKey = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
                .resource_keys = "ResourceKeys",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_remediation_exceptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_remediation_exceptions };
        }
    },
    Response: type = struct {
        remediation_exceptions: ?[]RemediationException = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remediation_exceptions = "RemediationExceptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
    },
} = .{};
pub const describe_remediation_execution_status: struct {
    action_name: []const u8 = "DescribeRemediationExecutionStatus",
    Request: type = struct {
        config_rule_name: []const u8,
        resource_keys: ?[]ResourceKey = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
                .resource_keys = "ResourceKeys",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_remediation_execution_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_remediation_execution_status };
        }
    },
    Response: type = struct {
        remediation_execution_statuses: ?[]struct {
            resource_key: ?ResourceKey = null,
            state: ?[]const u8 = null,
            step_details: ?[]struct {
                name: ?[]const u8 = null,
                state: ?[]const u8 = null,
                error_message: ?[]const u8 = null,
                start_time: ?i64 = null,
                stop_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .state = "State",
                        .error_message = "ErrorMessage",
                        .start_time = "StartTime",
                        .stop_time = "StopTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            invocation_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_key = "ResourceKey",
                    .state = "State",
                    .step_details = "StepDetails",
                    .invocation_time = "InvocationTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remediation_execution_statuses = "RemediationExecutionStatuses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchRemediationConfiguration,
    },
} = .{};
pub const describe_retention_configurations: struct {
    action_name: []const u8 = "DescribeRetentionConfigurations",
    Request: type = struct {
        retention_configuration_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention_configuration_names = "RetentionConfigurationNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_retention_configurations) } {
            return .{ .service_metadata = service_metadata, .action = describe_retention_configurations };
        }
    },
    Response: type = struct {
        retention_configurations: ?[]RetentionConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention_configurations = "RetentionConfigurations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchRetentionConfiguration,
    },
} = .{};
pub const get_aggregate_compliance_details_by_config_rule: struct {
    action_name: []const u8 = "GetAggregateComplianceDetailsByConfigRule",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        config_rule_name: []const u8,
        account_id: []const u8,
        aws_region: []const u8,
        compliance_type: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .config_rule_name = "ConfigRuleName",
                .account_id = "AccountId",
                .aws_region = "AwsRegion",
                .compliance_type = "ComplianceType",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_aggregate_compliance_details_by_config_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_aggregate_compliance_details_by_config_rule };
        }
    },
    Response: type = struct {
        aggregate_evaluation_results: ?[]struct {
            evaluation_result_identifier: ?EvaluationResultIdentifier = null,
            compliance_type: ?[]const u8 = null,
            result_recorded_time: ?i64 = null,
            config_rule_invoked_time: ?i64 = null,
            annotation: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_result_identifier = "EvaluationResultIdentifier",
                    .compliance_type = "ComplianceType",
                    .result_recorded_time = "ResultRecordedTime",
                    .config_rule_invoked_time = "ConfigRuleInvokedTime",
                    .annotation = "Annotation",
                    .account_id = "AccountId",
                    .aws_region = "AwsRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregate_evaluation_results = "AggregateEvaluationResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchConfigurationAggregator,
        Validation,
    },
} = .{};
pub const get_aggregate_config_rule_compliance_summary: struct {
    action_name: []const u8 = "GetAggregateConfigRuleComplianceSummary",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        filters: ?struct {
            account_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .aws_region = "AwsRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        group_by_key: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .filters = "Filters",
                .group_by_key = "GroupByKey",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_aggregate_config_rule_compliance_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_aggregate_config_rule_compliance_summary };
        }
    },
    Response: type = struct {
        group_by_key: ?[]const u8 = null,
        aggregate_compliance_counts: ?[]struct {
            group_name: ?[]const u8 = null,
            compliance_summary: ?ComplianceSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_name = "GroupName",
                    .compliance_summary = "ComplianceSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_by_key = "GroupByKey",
                .aggregate_compliance_counts = "AggregateComplianceCounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchConfigurationAggregator,
        Validation,
    },
} = .{};
pub const get_aggregate_conformance_pack_compliance_summary: struct {
    action_name: []const u8 = "GetAggregateConformancePackComplianceSummary",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        filters: ?struct {
            account_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .aws_region = "AwsRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        group_by_key: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .filters = "Filters",
                .group_by_key = "GroupByKey",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_aggregate_conformance_pack_compliance_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_aggregate_conformance_pack_compliance_summary };
        }
    },
    Response: type = struct {
        aggregate_conformance_pack_compliance_summaries: ?[]struct {
            compliance_summary: ?struct {
                compliant_conformance_pack_count: ?i64 = null,
                non_compliant_conformance_pack_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .compliant_conformance_pack_count = "CompliantConformancePackCount",
                        .non_compliant_conformance_pack_count = "NonCompliantConformancePackCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            group_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compliance_summary = "ComplianceSummary",
                    .group_name = "GroupName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        group_by_key: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregate_conformance_pack_compliance_summaries = "AggregateConformancePackComplianceSummaries",
                .group_by_key = "GroupByKey",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchConfigurationAggregator,
        Validation,
    },
} = .{};
pub const get_aggregate_discovered_resource_counts: struct {
    action_name: []const u8 = "GetAggregateDiscoveredResourceCounts",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        filters: ?struct {
            resource_type: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "ResourceType",
                    .account_id = "AccountId",
                    .region = "Region",
                };
                return @field(mappings, field_name);
            }
        } = null,
        group_by_key: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .filters = "Filters",
                .group_by_key = "GroupByKey",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_aggregate_discovered_resource_counts) } {
            return .{ .service_metadata = service_metadata, .action = get_aggregate_discovered_resource_counts };
        }
    },
    Response: type = struct {
        total_discovered_resources: i64,
        group_by_key: ?[]const u8 = null,
        grouped_resource_counts: ?[]struct {
            group_name: []const u8,
            resource_count: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_name = "GroupName",
                    .resource_count = "ResourceCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .total_discovered_resources = "TotalDiscoveredResources",
                .group_by_key = "GroupByKey",
                .grouped_resource_counts = "GroupedResourceCounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchConfigurationAggregator,
        Validation,
    },
} = .{};
pub const get_aggregate_resource_config: struct {
    action_name: []const u8 = "GetAggregateResourceConfig",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        resource_identifier: AggregateResourceIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .resource_identifier = "ResourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_aggregate_resource_config) } {
            return .{ .service_metadata = service_metadata, .action = get_aggregate_resource_config };
        }
    },
    Response: type = struct {
        configuration_item: ?ConfigurationItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_item = "ConfigurationItem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchConfigurationAggregator,
        OversizedConfigurationItem,
        ResourceNotDiscovered,
        Validation,
    },
} = .{};
pub const get_compliance_details_by_config_rule: struct {
    action_name: []const u8 = "GetComplianceDetailsByConfigRule",
    Request: type = struct {
        config_rule_name: []const u8,
        compliance_types: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
                .compliance_types = "ComplianceTypes",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compliance_details_by_config_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_compliance_details_by_config_rule };
        }
    },
    Response: type = struct {
        evaluation_results: ?[]EvaluationResult = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_results = "EvaluationResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConfigRule,
    },
} = .{};
pub const get_compliance_details_by_resource: struct {
    action_name: []const u8 = "GetComplianceDetailsByResource",
    Request: type = struct {
        resource_type: ?[]const u8 = null,
        resource_id: ?[]const u8 = null,
        compliance_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        resource_evaluation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
                .compliance_types = "ComplianceTypes",
                .next_token = "NextToken",
                .resource_evaluation_id = "ResourceEvaluationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compliance_details_by_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_compliance_details_by_resource };
        }
    },
    Response: type = struct {
        evaluation_results: ?[]EvaluationResult = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_results = "EvaluationResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
    },
} = .{};
pub const get_compliance_summary_by_config_rule: struct {
    action_name: []const u8 = "GetComplianceSummaryByConfigRule",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compliance_summary_by_config_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_compliance_summary_by_config_rule };
        }
    },
    Response: type = struct {
        compliance_summary: ?ComplianceSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compliance_summary = "ComplianceSummary",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_compliance_summary_by_resource_type: struct {
    action_name: []const u8 = "GetComplianceSummaryByResourceType",
    Request: type = struct {
        resource_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_types = "ResourceTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compliance_summary_by_resource_type) } {
            return .{ .service_metadata = service_metadata, .action = get_compliance_summary_by_resource_type };
        }
    },
    Response: type = struct {
        compliance_summaries_by_resource_type: ?[]struct {
            resource_type: ?[]const u8 = null,
            compliance_summary: ?ComplianceSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "ResourceType",
                    .compliance_summary = "ComplianceSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compliance_summaries_by_resource_type = "ComplianceSummariesByResourceType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
    },
} = .{};
pub const get_conformance_pack_compliance_details: struct {
    action_name: []const u8 = "GetConformancePackComplianceDetails",
    Request: type = struct {
        conformance_pack_name: []const u8,
        filters: ?struct {
            config_rule_names: ?[][]const u8 = null,
            compliance_type: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .config_rule_names = "ConfigRuleNames",
                    .compliance_type = "ComplianceType",
                    .resource_type = "ResourceType",
                    .resource_ids = "ResourceIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_name = "ConformancePackName",
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_conformance_pack_compliance_details) } {
            return .{ .service_metadata = service_metadata, .action = get_conformance_pack_compliance_details };
        }
    },
    Response: type = struct {
        conformance_pack_name: []const u8,
        conformance_pack_rule_evaluation_results: ?[]struct {
            compliance_type: []const u8,
            evaluation_result_identifier: EvaluationResultIdentifier,
            config_rule_invoked_time: i64,
            result_recorded_time: i64,
            annotation: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compliance_type = "ComplianceType",
                    .evaluation_result_identifier = "EvaluationResultIdentifier",
                    .config_rule_invoked_time = "ConfigRuleInvokedTime",
                    .result_recorded_time = "ResultRecordedTime",
                    .annotation = "Annotation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_name = "ConformancePackName",
                .conformance_pack_rule_evaluation_results = "ConformancePackRuleEvaluationResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
        NoSuchConfigRuleInConformancePack,
        NoSuchConformancePack,
    },
} = .{};
pub const get_conformance_pack_compliance_summary: struct {
    action_name: []const u8 = "GetConformancePackComplianceSummary",
    Request: type = struct {
        conformance_pack_names: [][]const u8,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_names = "ConformancePackNames",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_conformance_pack_compliance_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_conformance_pack_compliance_summary };
        }
    },
    Response: type = struct {
        conformance_pack_compliance_summary_list: ?[]struct {
            conformance_pack_name: []const u8,
            conformance_pack_compliance_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .conformance_pack_name = "ConformancePackName",
                    .conformance_pack_compliance_status = "ConformancePackComplianceStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_compliance_summary_list = "ConformancePackComplianceSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchConformancePack,
    },
} = .{};
pub const get_custom_rule_policy: struct {
    action_name: []const u8 = "GetCustomRulePolicy",
    Request: type = struct {
        config_rule_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_custom_rule_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_custom_rule_policy };
        }
    },
    Response: type = struct {
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_text = "PolicyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchConfigRule,
    },
} = .{};
pub const get_discovered_resource_counts: struct {
    action_name: []const u8 = "GetDiscoveredResourceCounts",
    Request: type = struct {
        resource_types: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_types = "resourceTypes",
                .limit = "limit",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_discovered_resource_counts) } {
            return .{ .service_metadata = service_metadata, .action = get_discovered_resource_counts };
        }
    },
    Response: type = struct {
        total_discovered_resources: ?i64 = null,
        resource_counts: ?[]struct {
            resource_type: ?[]const u8 = null,
            count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "resourceType",
                    .count = "count",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .total_discovered_resources = "totalDiscoveredResources",
                .resource_counts = "resourceCounts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const get_organization_config_rule_detailed_status: struct {
    action_name: []const u8 = "GetOrganizationConfigRuleDetailedStatus",
    Request: type = struct {
        organization_config_rule_name: []const u8,
        filters: ?struct {
            account_id: ?[]const u8 = null,
            member_account_rule_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .member_account_rule_status = "MemberAccountRuleStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_name = "OrganizationConfigRuleName",
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_organization_config_rule_detailed_status) } {
            return .{ .service_metadata = service_metadata, .action = get_organization_config_rule_detailed_status };
        }
    },
    Response: type = struct {
        organization_config_rule_detailed_status: ?[]struct {
            account_id: []const u8,
            config_rule_name: []const u8,
            member_account_rule_status: []const u8,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .config_rule_name = "ConfigRuleName",
                    .member_account_rule_status = "MemberAccountRuleStatus",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                    .last_update_time = "LastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_detailed_status = "OrganizationConfigRuleDetailedStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchOrganizationConfigRule,
        OrganizationAccessDenied,
    },
} = .{};
pub const get_organization_conformance_pack_detailed_status: struct {
    action_name: []const u8 = "GetOrganizationConformancePackDetailedStatus",
    Request: type = struct {
        organization_conformance_pack_name: []const u8,
        filters: ?struct {
            account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_pack_name = "OrganizationConformancePackName",
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_organization_conformance_pack_detailed_status) } {
            return .{ .service_metadata = service_metadata, .action = get_organization_conformance_pack_detailed_status };
        }
    },
    Response: type = struct {
        organization_conformance_pack_detailed_statuses: ?[]struct {
            account_id: []const u8,
            conformance_pack_name: []const u8,
            status: []const u8,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .conformance_pack_name = "ConformancePackName",
                    .status = "Status",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                    .last_update_time = "LastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_pack_detailed_statuses = "OrganizationConformancePackDetailedStatuses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchOrganizationConformancePack,
        OrganizationAccessDenied,
    },
} = .{};
pub const get_organization_custom_rule_policy: struct {
    action_name: []const u8 = "GetOrganizationCustomRulePolicy",
    Request: type = struct {
        organization_config_rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_name = "OrganizationConfigRuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_organization_custom_rule_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_organization_custom_rule_policy };
        }
    },
    Response: type = struct {
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_text = "PolicyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchOrganizationConfigRule,
        OrganizationAccessDenied,
    },
} = .{};
pub const get_resource_config_history: struct {
    action_name: []const u8 = "GetResourceConfigHistory",
    Request: type = struct {
        resource_type: []const u8,
        resource_id: []const u8,
        later_time: ?i64 = null,
        earlier_time: ?i64 = null,
        chronological_order: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "resourceType",
                .resource_id = "resourceId",
                .later_time = "laterTime",
                .earlier_time = "earlierTime",
                .chronological_order = "chronologicalOrder",
                .limit = "limit",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_config_history) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_config_history };
        }
    },
    Response: type = struct {
        configuration_items: ?[]ConfigurationItem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_items = "configurationItems",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidTimeRange,
        NoAvailableConfigurationRecorder,
        ResourceNotDiscovered,
        Validation,
    },
} = .{};
pub const get_resource_evaluation_summary: struct {
    action_name: []const u8 = "GetResourceEvaluationSummary",
    Request: type = struct {
        resource_evaluation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_evaluation_id = "ResourceEvaluationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_evaluation_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_evaluation_summary };
        }
    },
    Response: type = struct {
        resource_evaluation_id: ?[]const u8 = null,
        evaluation_mode: ?[]const u8 = null,
        evaluation_status: ?struct {
            status: []const u8,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        evaluation_start_timestamp: ?i64 = null,
        compliance: ?[]const u8 = null,
        evaluation_context: ?EvaluationContext = null,
        resource_details: ?ResourceDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_evaluation_id = "ResourceEvaluationId",
                .evaluation_mode = "EvaluationMode",
                .evaluation_status = "EvaluationStatus",
                .evaluation_start_timestamp = "EvaluationStartTimestamp",
                .compliance = "Compliance",
                .evaluation_context = "EvaluationContext",
                .resource_details = "ResourceDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const get_stored_query: struct {
    action_name: []const u8 = "GetStoredQuery",
    Request: type = struct {
        query_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_name = "QueryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stored_query) } {
            return .{ .service_metadata = service_metadata, .action = get_stored_query };
        }
    },
    Response: type = struct {
        stored_query: ?StoredQuery = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stored_query = "StoredQuery",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_aggregate_discovered_resources: struct {
    action_name: []const u8 = "ListAggregateDiscoveredResources",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        resource_type: []const u8,
        filters: ?struct {
            account_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_name: ?[]const u8 = null,
            region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .resource_id = "ResourceId",
                    .resource_name = "ResourceName",
                    .region = "Region",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .resource_type = "ResourceType",
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_aggregate_discovered_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_aggregate_discovered_resources };
        }
    },
    Response: type = struct {
        resource_identifiers: ?[]AggregateResourceIdentifier = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifiers = "ResourceIdentifiers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoSuchConfigurationAggregator,
        Validation,
    },
} = .{};
pub const list_conformance_pack_compliance_scores: struct {
    action_name: []const u8 = "ListConformancePackComplianceScores",
    Request: type = struct {
        filters: ?struct {
            conformance_pack_names: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .conformance_pack_names = "ConformancePackNames",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort_order: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .sort_order = "SortOrder",
                .sort_by = "SortBy",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_conformance_pack_compliance_scores) } {
            return .{ .service_metadata = service_metadata, .action = list_conformance_pack_compliance_scores };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        conformance_pack_compliance_scores: []struct {
            score: ?[]const u8 = null,
            conformance_pack_name: ?[]const u8 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .score = "Score",
                    .conformance_pack_name = "ConformancePackName",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .conformance_pack_compliance_scores = "ConformancePackComplianceScores",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        InvalidParameterValue,
    },
} = .{};
pub const list_discovered_resources: struct {
    action_name: []const u8 = "ListDiscoveredResources",
    Request: type = struct {
        resource_type: []const u8,
        resource_ids: ?[][]const u8 = null,
        resource_name: ?[]const u8 = null,
        limit: ?i64 = null,
        include_deleted_resources: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "resourceType",
                .resource_ids = "resourceIds",
                .resource_name = "resourceName",
                .limit = "limit",
                .include_deleted_resources = "includeDeletedResources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_discovered_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_discovered_resources };
        }
    },
    Response: type = struct {
        resource_identifiers: ?[]struct {
            resource_type: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_name: ?[]const u8 = null,
            resource_deletion_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "resourceType",
                    .resource_id = "resourceId",
                    .resource_name = "resourceName",
                    .resource_deletion_time = "resourceDeletionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifiers = "resourceIdentifiers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        NoAvailableConfigurationRecorder,
        Validation,
    },
} = .{};
pub const list_resource_evaluations: struct {
    action_name: []const u8 = "ListResourceEvaluations",
    Request: type = struct {
        filters: ?struct {
            evaluation_mode: ?[]const u8 = null,
            time_window: ?struct {
                start_time: ?i64 = null,
                end_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_time = "StartTime",
                        .end_time = "EndTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            evaluation_context_identifier: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_mode = "EvaluationMode",
                    .time_window = "TimeWindow",
                    .evaluation_context_identifier = "EvaluationContextIdentifier",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_evaluations) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_evaluations };
        }
    },
    Response: type = struct {
        resource_evaluations: ?[]struct {
            resource_evaluation_id: ?[]const u8 = null,
            evaluation_mode: ?[]const u8 = null,
            evaluation_start_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_evaluation_id = "ResourceEvaluationId",
                    .evaluation_mode = "EvaluationMode",
                    .evaluation_start_timestamp = "EvaluationStartTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_evaluations = "ResourceEvaluations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameterValue,
        InvalidTimeRange,
    },
} = .{};
pub const list_stored_queries: struct {
    action_name: []const u8 = "ListStoredQueries",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_stored_queries) } {
            return .{ .service_metadata = service_metadata, .action = list_stored_queries };
        }
    },
    Response: type = struct {
        stored_query_metadata: ?[]struct {
            query_id: []const u8,
            query_arn: []const u8,
            query_name: []const u8,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .query_id = "QueryId",
                    .query_arn = "QueryArn",
                    .query_name = "QueryName",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stored_query_metadata = "StoredQueryMetadata",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLimit,
        InvalidNextToken,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_aggregation_authorization: struct {
    action_name: []const u8 = "PutAggregationAuthorization",
    Request: type = struct {
        authorized_account_id: []const u8,
        authorized_aws_region: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorized_account_id = "AuthorizedAccountId",
                .authorized_aws_region = "AuthorizedAwsRegion",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_aggregation_authorization) } {
            return .{ .service_metadata = service_metadata, .action = put_aggregation_authorization };
        }
    },
    Response: type = struct {
        aggregation_authorization: ?AggregationAuthorization = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregation_authorization = "AggregationAuthorization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
    },
} = .{};
pub const put_config_rule: struct {
    action_name: []const u8 = "PutConfigRule",
    Request: type = struct {
        config_rule: ConfigRule,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule = "ConfigRule",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_config_rule) } {
            return .{ .service_metadata = service_metadata, .action = put_config_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientPermissions,
        InvalidParameterValue,
        MaxNumberOfConfigRulesExceeded,
        NoAvailableConfigurationRecorder,
        ResourceInUse,
    },
} = .{};
pub const put_configuration_aggregator: struct {
    action_name: []const u8 = "PutConfigurationAggregator",
    Request: type = struct {
        configuration_aggregator_name: []const u8,
        account_aggregation_sources: ?[]AccountAggregationSource = null,
        organization_aggregation_source: ?OrganizationAggregationSource = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .account_aggregation_sources = "AccountAggregationSources",
                .organization_aggregation_source = "OrganizationAggregationSource",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_aggregator) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_aggregator };
        }
    },
    Response: type = struct {
        configuration_aggregator: ?ConfigurationAggregator = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_aggregator = "ConfigurationAggregator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRole,
        LimitExceeded,
        NoAvailableOrganization,
        OrganizationAccessDenied,
        OrganizationAllFeaturesNotEnabled,
    },
} = .{};
pub const put_configuration_recorder: struct {
    action_name: []const u8 = "PutConfigurationRecorder",
    Request: type = struct {
        configuration_recorder: ConfigurationRecorder,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_recorder = "ConfigurationRecorder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_recorder) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_recorder };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidConfigurationRecorderName,
        InvalidRecordingGroup,
        InvalidRole,
        MaxNumberOfConfigurationRecordersExceeded,
        Validation,
    },
} = .{};
pub const put_conformance_pack: struct {
    action_name: []const u8 = "PutConformancePack",
    Request: type = struct {
        conformance_pack_name: []const u8,
        template_s3_uri: ?[]const u8 = null,
        template_body: ?[]const u8 = null,
        delivery_s3_bucket: ?[]const u8 = null,
        delivery_s3_key_prefix: ?[]const u8 = null,
        conformance_pack_input_parameters: ?[]ConformancePackInputParameter = null,
        template_ssm_document_details: ?TemplateSSMDocumentDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_name = "ConformancePackName",
                .template_s3_uri = "TemplateS3Uri",
                .template_body = "TemplateBody",
                .delivery_s3_bucket = "DeliveryS3Bucket",
                .delivery_s3_key_prefix = "DeliveryS3KeyPrefix",
                .conformance_pack_input_parameters = "ConformancePackInputParameters",
                .template_ssm_document_details = "TemplateSSMDocumentDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_conformance_pack) } {
            return .{ .service_metadata = service_metadata, .action = put_conformance_pack };
        }
    },
    Response: type = struct {
        conformance_pack_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conformance_pack_arn = "ConformancePackArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConformancePackTemplateValidation,
        InsufficientPermissions,
        InvalidParameterValue,
        MaxNumberOfConformancePacksExceeded,
        ResourceInUse,
    },
} = .{};
pub const put_delivery_channel: struct {
    action_name: []const u8 = "PutDeliveryChannel",
    Request: type = struct {
        delivery_channel: DeliveryChannel,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delivery_channel = "DeliveryChannel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_delivery_channel) } {
            return .{ .service_metadata = service_metadata, .action = put_delivery_channel };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientDeliveryPolicy,
        InvalidDeliveryChannelName,
        InvalidS3KeyPrefix,
        InvalidS3KmsKeyArn,
        InvalidSNSTopicARN,
        MaxNumberOfDeliveryChannelsExceeded,
        NoAvailableConfigurationRecorder,
        NoSuchBucket,
    },
} = .{};
pub const put_evaluations: struct {
    action_name: []const u8 = "PutEvaluations",
    Request: type = struct {
        evaluations: ?[]Evaluation = null,
        result_token: []const u8,
        test_mode: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluations = "Evaluations",
                .result_token = "ResultToken",
                .test_mode = "TestMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_evaluations) } {
            return .{ .service_metadata = service_metadata, .action = put_evaluations };
        }
    },
    Response: type = struct {
        failed_evaluations: ?[]Evaluation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_evaluations = "FailedEvaluations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidResultToken,
        NoSuchConfigRule,
    },
} = .{};
pub const put_external_evaluation: struct {
    action_name: []const u8 = "PutExternalEvaluation",
    Request: type = struct {
        config_rule_name: []const u8,
        external_evaluation: struct {
            compliance_resource_type: []const u8,
            compliance_resource_id: []const u8,
            compliance_type: []const u8,
            annotation: ?[]const u8 = null,
            ordering_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compliance_resource_type = "ComplianceResourceType",
                    .compliance_resource_id = "ComplianceResourceId",
                    .compliance_type = "ComplianceType",
                    .annotation = "Annotation",
                    .ordering_timestamp = "OrderingTimestamp",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
                .external_evaluation = "ExternalEvaluation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_external_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = put_external_evaluation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        NoSuchConfigRule,
    },
} = .{};
pub const put_organization_config_rule: struct {
    action_name: []const u8 = "PutOrganizationConfigRule",
    Request: type = struct {
        organization_config_rule_name: []const u8,
        organization_managed_rule_metadata: ?OrganizationManagedRuleMetadata = null,
        organization_custom_rule_metadata: ?OrganizationCustomRuleMetadata = null,
        excluded_accounts: ?[][]const u8 = null,
        organization_custom_policy_rule_metadata: ?struct {
            description: ?[]const u8 = null,
            organization_config_rule_trigger_types: ?[][]const u8 = null,
            input_parameters: ?[]const u8 = null,
            maximum_execution_frequency: ?[]const u8 = null,
            resource_types_scope: ?[][]const u8 = null,
            resource_id_scope: ?[]const u8 = null,
            tag_key_scope: ?[]const u8 = null,
            tag_value_scope: ?[]const u8 = null,
            policy_runtime: []const u8,
            policy_text: []const u8,
            debug_log_delivery_accounts: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .organization_config_rule_trigger_types = "OrganizationConfigRuleTriggerTypes",
                    .input_parameters = "InputParameters",
                    .maximum_execution_frequency = "MaximumExecutionFrequency",
                    .resource_types_scope = "ResourceTypesScope",
                    .resource_id_scope = "ResourceIdScope",
                    .tag_key_scope = "TagKeyScope",
                    .tag_value_scope = "TagValueScope",
                    .policy_runtime = "PolicyRuntime",
                    .policy_text = "PolicyText",
                    .debug_log_delivery_accounts = "DebugLogDeliveryAccounts",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_name = "OrganizationConfigRuleName",
                .organization_managed_rule_metadata = "OrganizationManagedRuleMetadata",
                .organization_custom_rule_metadata = "OrganizationCustomRuleMetadata",
                .excluded_accounts = "ExcludedAccounts",
                .organization_custom_policy_rule_metadata = "OrganizationCustomPolicyRuleMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_organization_config_rule) } {
            return .{ .service_metadata = service_metadata, .action = put_organization_config_rule };
        }
    },
    Response: type = struct {
        organization_config_rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_config_rule_arn = "OrganizationConfigRuleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPermissions,
        InvalidParameterValue,
        MaxNumberOfOrganizationConfigRulesExceeded,
        NoAvailableOrganization,
        OrganizationAccessDenied,
        OrganizationAllFeaturesNotEnabled,
        ResourceInUse,
        Validation,
    },
} = .{};
pub const put_organization_conformance_pack: struct {
    action_name: []const u8 = "PutOrganizationConformancePack",
    Request: type = struct {
        organization_conformance_pack_name: []const u8,
        template_s3_uri: ?[]const u8 = null,
        template_body: ?[]const u8 = null,
        delivery_s3_bucket: ?[]const u8 = null,
        delivery_s3_key_prefix: ?[]const u8 = null,
        conformance_pack_input_parameters: ?[]ConformancePackInputParameter = null,
        excluded_accounts: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_pack_name = "OrganizationConformancePackName",
                .template_s3_uri = "TemplateS3Uri",
                .template_body = "TemplateBody",
                .delivery_s3_bucket = "DeliveryS3Bucket",
                .delivery_s3_key_prefix = "DeliveryS3KeyPrefix",
                .conformance_pack_input_parameters = "ConformancePackInputParameters",
                .excluded_accounts = "ExcludedAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_organization_conformance_pack) } {
            return .{ .service_metadata = service_metadata, .action = put_organization_conformance_pack };
        }
    },
    Response: type = struct {
        organization_conformance_pack_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_conformance_pack_arn = "OrganizationConformancePackArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPermissions,
        MaxNumberOfOrganizationConformancePacksExceeded,
        NoAvailableOrganization,
        OrganizationAccessDenied,
        OrganizationAllFeaturesNotEnabled,
        OrganizationConformancePackTemplateValidation,
        ResourceInUse,
        Validation,
    },
} = .{};
pub const put_remediation_configurations: struct {
    action_name: []const u8 = "PutRemediationConfigurations",
    Request: type = struct {
        remediation_configurations: []RemediationConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remediation_configurations = "RemediationConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_remediation_configurations) } {
            return .{ .service_metadata = service_metadata, .action = put_remediation_configurations };
        }
    },
    Response: type = struct {
        failed_batches: ?[]struct {
            failure_message: ?[]const u8 = null,
            failed_items: ?[]RemediationConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .failure_message = "FailureMessage",
                    .failed_items = "FailedItems",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_batches = "FailedBatches",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPermissions,
        InvalidParameterValue,
    },
} = .{};
pub const put_remediation_exceptions: struct {
    action_name: []const u8 = "PutRemediationExceptions",
    Request: type = struct {
        config_rule_name: []const u8,
        resource_keys: []RemediationExceptionResourceKey,
        message: ?[]const u8 = null,
        expiration_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
                .resource_keys = "ResourceKeys",
                .message = "Message",
                .expiration_time = "ExpirationTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_remediation_exceptions) } {
            return .{ .service_metadata = service_metadata, .action = put_remediation_exceptions };
        }
    },
    Response: type = struct {
        failed_batches: ?[]struct {
            failure_message: ?[]const u8 = null,
            failed_items: ?[]RemediationException = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .failure_message = "FailureMessage",
                    .failed_items = "FailedItems",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_batches = "FailedBatches",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPermissions,
        InvalidParameterValue,
    },
} = .{};
pub const put_resource_config: struct {
    action_name: []const u8 = "PutResourceConfig",
    Request: type = struct {
        resource_type: []const u8,
        schema_version_id: []const u8,
        resource_id: []const u8,
        resource_name: ?[]const u8 = null,
        configuration: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .schema_version_id = "SchemaVersionId",
                .resource_id = "ResourceId",
                .resource_name = "ResourceName",
                .configuration = "Configuration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_config) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientPermissions,
        MaxActiveResourcesExceeded,
        NoRunningConfigurationRecorder,
        Validation,
    },
} = .{};
pub const put_retention_configuration: struct {
    action_name: []const u8 = "PutRetentionConfiguration",
    Request: type = struct {
        retention_period_in_days: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention_period_in_days = "RetentionPeriodInDays",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_retention_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_retention_configuration };
        }
    },
    Response: type = struct {
        retention_configuration: ?RetentionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention_configuration = "RetentionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MaxNumberOfRetentionConfigurationsExceeded,
    },
} = .{};
pub const put_stored_query: struct {
    action_name: []const u8 = "PutStoredQuery",
    Request: type = struct {
        stored_query: StoredQuery,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stored_query = "StoredQuery",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_stored_query) } {
            return .{ .service_metadata = service_metadata, .action = put_stored_query };
        }
    },
    Response: type = struct {
        query_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_arn = "QueryArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceConcurrentModification,
        TooManyTags,
        Validation,
    },
} = .{};
pub const select_aggregate_resource_config: struct {
    action_name: []const u8 = "SelectAggregateResourceConfig",
    Request: type = struct {
        expression: []const u8,
        configuration_aggregator_name: []const u8,
        limit: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .expression = "Expression",
                .configuration_aggregator_name = "ConfigurationAggregatorName",
                .limit = "Limit",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(select_aggregate_resource_config) } {
            return .{ .service_metadata = service_metadata, .action = select_aggregate_resource_config };
        }
    },
    Response: type = struct {
        results: ?[][]const u8 = null,
        query_info: ?QueryInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .query_info = "QueryInfo",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidExpression,
        InvalidLimit,
        InvalidNextToken,
        NoSuchConfigurationAggregator,
    },
} = .{};
pub const select_resource_config: struct {
    action_name: []const u8 = "SelectResourceConfig",
    Request: type = struct {
        expression: []const u8,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .expression = "Expression",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(select_resource_config) } {
            return .{ .service_metadata = service_metadata, .action = select_resource_config };
        }
    },
    Response: type = struct {
        results: ?[][]const u8 = null,
        query_info: ?QueryInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .query_info = "QueryInfo",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidExpression,
        InvalidLimit,
        InvalidNextToken,
    },
} = .{};
pub const start_config_rules_evaluation: struct {
    action_name: []const u8 = "StartConfigRulesEvaluation",
    Request: type = struct {
        config_rule_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_names = "ConfigRuleNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_config_rules_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = start_config_rules_evaluation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        LimitExceeded,
        NoSuchConfigRule,
        ResourceInUse,
    },
} = .{};
pub const start_configuration_recorder: struct {
    action_name: []const u8 = "StartConfigurationRecorder",
    Request: type = struct {
        configuration_recorder_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_recorder_name = "ConfigurationRecorderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_configuration_recorder) } {
            return .{ .service_metadata = service_metadata, .action = start_configuration_recorder };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoAvailableDeliveryChannel,
        NoSuchConfigurationRecorder,
    },
} = .{};
pub const start_remediation_execution: struct {
    action_name: []const u8 = "StartRemediationExecution",
    Request: type = struct {
        config_rule_name: []const u8,
        resource_keys: []ResourceKey,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_rule_name = "ConfigRuleName",
                .resource_keys = "ResourceKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_remediation_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_remediation_execution };
        }
    },
    Response: type = struct {
        failure_message: ?[]const u8 = null,
        failed_items: ?[]ResourceKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failure_message = "FailureMessage",
                .failed_items = "FailedItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPermissions,
        InvalidParameterValue,
        NoSuchRemediationConfiguration,
    },
} = .{};
pub const start_resource_evaluation: struct {
    action_name: []const u8 = "StartResourceEvaluation",
    Request: type = struct {
        resource_details: ResourceDetails,
        evaluation_context: ?EvaluationContext = null,
        evaluation_mode: []const u8,
        evaluation_timeout: ?i64 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_details = "ResourceDetails",
                .evaluation_context = "EvaluationContext",
                .evaluation_mode = "EvaluationMode",
                .evaluation_timeout = "EvaluationTimeout",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_resource_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = start_resource_evaluation };
        }
    },
    Response: type = struct {
        resource_evaluation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_evaluation_id = "ResourceEvaluationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidParameterValue,
    },
} = .{};
pub const stop_configuration_recorder: struct {
    action_name: []const u8 = "StopConfigurationRecorder",
    Request: type = struct {
        configuration_recorder_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_recorder_name = "ConfigurationRecorderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_configuration_recorder) } {
            return .{ .service_metadata = service_metadata, .action = stop_configuration_recorder };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        NoSuchConfigurationRecorder,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
        TooManyTags,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationContext = struct {
    evaluation_context_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .evaluation_context_identifier = "EvaluationContextIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDetails = struct {
    resource_id: []const u8,
    resource_type: []const u8,
    resource_configuration: []const u8,
    resource_configuration_schema_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id = "ResourceId",
            .resource_type = "ResourceType",
            .resource_configuration = "ResourceConfiguration",
            .resource_configuration_schema_type = "ResourceConfigurationSchemaType",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceKey = struct {
    resource_type: []const u8,
    resource_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .resource_id = "resourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryInfo = struct {
    select_fields: ?[]FieldInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .select_fields = "SelectFields",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldInfo = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const StoredQuery = struct {
    query_id: ?[]const u8 = null,
    query_arn: ?[]const u8 = null,
    query_name: []const u8,
    description: ?[]const u8 = null,
    expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_id = "QueryId",
            .query_arn = "QueryArn",
            .query_name = "QueryName",
            .description = "Description",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const RetentionConfiguration = struct {
    name: []const u8,
    retention_period_in_days: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .retention_period_in_days = "RetentionPeriodInDays",
        };
        return @field(mappings, field_name);
    }
};

pub const RemediationException = struct {
    config_rule_name: []const u8,
    resource_type: []const u8,
    resource_id: []const u8,
    message: ?[]const u8 = null,
    expiration_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .config_rule_name = "ConfigRuleName",
            .resource_type = "ResourceType",
            .resource_id = "ResourceId",
            .message = "Message",
            .expiration_time = "ExpirationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const RemediationExceptionResourceKey = struct {
    resource_type: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .resource_id = "ResourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const RemediationConfiguration = struct {
    config_rule_name: []const u8,
    target_type: []const u8,
    target_id: []const u8,
    target_version: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?RemediationParameterValue = null,
    } = null,
    resource_type: ?[]const u8 = null,
    automatic: ?bool = null,
    execution_controls: ?ExecutionControls = null,
    maximum_automatic_attempts: ?i64 = null,
    retry_attempt_seconds: ?i64 = null,
    arn: ?[]const u8 = null,
    created_by_service: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .config_rule_name = "ConfigRuleName",
            .target_type = "TargetType",
            .target_id = "TargetId",
            .target_version = "TargetVersion",
            .parameters = "Parameters",
            .resource_type = "ResourceType",
            .automatic = "Automatic",
            .execution_controls = "ExecutionControls",
            .maximum_automatic_attempts = "MaximumAutomaticAttempts",
            .retry_attempt_seconds = "RetryAttemptSeconds",
            .arn = "Arn",
            .created_by_service = "CreatedByService",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const ExecutionControls = struct {
    ssm_controls: ?SsmControls = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ssm_controls = "SsmControls",
        };
        return @field(mappings, field_name);
    }
};

pub const SsmControls = struct {
    concurrent_execution_rate_percentage: ?i64 = null,
    error_percentage: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .concurrent_execution_rate_percentage = "ConcurrentExecutionRatePercentage",
            .error_percentage = "ErrorPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const RemediationParameterValue = struct {
    resource_value: ?ResourceValue = null,
    static_value: ?StaticValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_value = "ResourceValue",
            .static_value = "StaticValue",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticValue = struct {
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceValue = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ConformancePackInputParameter = struct {
    parameter_name: []const u8,
    parameter_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_value = "ParameterValue",
        };
        return @field(mappings, field_name);
    }
};

pub const OrganizationCustomRuleMetadata = struct {
    description: ?[]const u8 = null,
    lambda_function_arn: []const u8,
    organization_config_rule_trigger_types: [][]const u8,
    input_parameters: ?[]const u8 = null,
    maximum_execution_frequency: ?[]const u8 = null,
    resource_types_scope: ?[][]const u8 = null,
    resource_id_scope: ?[]const u8 = null,
    tag_key_scope: ?[]const u8 = null,
    tag_value_scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .lambda_function_arn = "LambdaFunctionArn",
            .organization_config_rule_trigger_types = "OrganizationConfigRuleTriggerTypes",
            .input_parameters = "InputParameters",
            .maximum_execution_frequency = "MaximumExecutionFrequency",
            .resource_types_scope = "ResourceTypesScope",
            .resource_id_scope = "ResourceIdScope",
            .tag_key_scope = "TagKeyScope",
            .tag_value_scope = "TagValueScope",
        };
        return @field(mappings, field_name);
    }
};

pub const OrganizationManagedRuleMetadata = struct {
    description: ?[]const u8 = null,
    rule_identifier: []const u8,
    input_parameters: ?[]const u8 = null,
    maximum_execution_frequency: ?[]const u8 = null,
    resource_types_scope: ?[][]const u8 = null,
    resource_id_scope: ?[]const u8 = null,
    tag_key_scope: ?[]const u8 = null,
    tag_value_scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .rule_identifier = "RuleIdentifier",
            .input_parameters = "InputParameters",
            .maximum_execution_frequency = "MaximumExecutionFrequency",
            .resource_types_scope = "ResourceTypesScope",
            .resource_id_scope = "ResourceIdScope",
            .tag_key_scope = "TagKeyScope",
            .tag_value_scope = "TagValueScope",
        };
        return @field(mappings, field_name);
    }
};

pub const Evaluation = struct {
    compliance_resource_type: []const u8,
    compliance_resource_id: []const u8,
    compliance_type: []const u8,
    annotation: ?[]const u8 = null,
    ordering_timestamp: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compliance_resource_type = "ComplianceResourceType",
            .compliance_resource_id = "ComplianceResourceId",
            .compliance_type = "ComplianceType",
            .annotation = "Annotation",
            .ordering_timestamp = "OrderingTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const DeliveryChannel = struct {
    name: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,
    s3_kms_key_arn: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    config_snapshot_delivery_properties: ?ConfigSnapshotDeliveryProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .s3_bucket_name = "s3BucketName",
            .s3_key_prefix = "s3KeyPrefix",
            .s3_kms_key_arn = "s3KmsKeyArn",
            .sns_topic_arn = "snsTopicARN",
            .config_snapshot_delivery_properties = "configSnapshotDeliveryProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigSnapshotDeliveryProperties = struct {
    delivery_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_frequency = "deliveryFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateSSMDocumentDetails = struct {
    document_name: []const u8,
    document_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_name = "DocumentName",
            .document_version = "DocumentVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationRecorder = struct {
    name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    recording_group: ?RecordingGroup = null,
    recording_mode: ?RecordingMode = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .role_arn = "roleARN",
            .recording_group = "recordingGroup",
            .recording_mode = "recordingMode",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordingMode = struct {
    recording_frequency: []const u8,
    recording_mode_overrides: ?[]RecordingModeOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recording_frequency = "recordingFrequency",
            .recording_mode_overrides = "recordingModeOverrides",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordingModeOverride = struct {
    description: ?[]const u8 = null,
    resource_types: [][]const u8,
    recording_frequency: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .resource_types = "resourceTypes",
            .recording_frequency = "recordingFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordingGroup = struct {
    all_supported: ?bool = null,
    include_global_resource_types: ?bool = null,
    resource_types: ?[][]const u8 = null,
    exclusion_by_resource_types: ?ExclusionByResourceTypes = null,
    recording_strategy: ?RecordingStrategy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .all_supported = "allSupported",
            .include_global_resource_types = "includeGlobalResourceTypes",
            .resource_types = "resourceTypes",
            .exclusion_by_resource_types = "exclusionByResourceTypes",
            .recording_strategy = "recordingStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordingStrategy = struct {
    use_only: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .use_only = "useOnly",
        };
        return @field(mappings, field_name);
    }
};

pub const ExclusionByResourceTypes = struct {
    resource_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_types = "resourceTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationAggregator = struct {
    configuration_aggregator_name: ?[]const u8 = null,
    configuration_aggregator_arn: ?[]const u8 = null,
    account_aggregation_sources: ?[]AccountAggregationSource = null,
    organization_aggregation_source: ?OrganizationAggregationSource = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    created_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration_aggregator_name = "ConfigurationAggregatorName",
            .configuration_aggregator_arn = "ConfigurationAggregatorArn",
            .account_aggregation_sources = "AccountAggregationSources",
            .organization_aggregation_source = "OrganizationAggregationSource",
            .creation_time = "CreationTime",
            .last_updated_time = "LastUpdatedTime",
            .created_by = "CreatedBy",
        };
        return @field(mappings, field_name);
    }
};

pub const OrganizationAggregationSource = struct {
    role_arn: []const u8,
    aws_regions: ?[][]const u8 = null,
    all_aws_regions: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .aws_regions = "AwsRegions",
            .all_aws_regions = "AllAwsRegions",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountAggregationSource = struct {
    account_ids: [][]const u8,
    all_aws_regions: ?bool = null,
    aws_regions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_ids = "AccountIds",
            .all_aws_regions = "AllAwsRegions",
            .aws_regions = "AwsRegions",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigRule = struct {
    config_rule_name: ?[]const u8 = null,
    config_rule_arn: ?[]const u8 = null,
    config_rule_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    scope: ?Scope = null,
    source: Source,
    input_parameters: ?[]const u8 = null,
    maximum_execution_frequency: ?[]const u8 = null,
    config_rule_state: ?[]const u8 = null,
    created_by: ?[]const u8 = null,
    evaluation_modes: ?[]EvaluationModeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .config_rule_name = "ConfigRuleName",
            .config_rule_arn = "ConfigRuleArn",
            .config_rule_id = "ConfigRuleId",
            .description = "Description",
            .scope = "Scope",
            .source = "Source",
            .input_parameters = "InputParameters",
            .maximum_execution_frequency = "MaximumExecutionFrequency",
            .config_rule_state = "ConfigRuleState",
            .created_by = "CreatedBy",
            .evaluation_modes = "EvaluationModes",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationModeConfiguration = struct {
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const Source = struct {
    owner: []const u8,
    source_identifier: ?[]const u8 = null,
    source_details: ?[]SourceDetail = null,
    custom_policy_details: ?CustomPolicyDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner = "Owner",
            .source_identifier = "SourceIdentifier",
            .source_details = "SourceDetails",
            .custom_policy_details = "CustomPolicyDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomPolicyDetails = struct {
    policy_runtime: []const u8,
    policy_text: []const u8,
    enable_debug_log_delivery: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_runtime = "PolicyRuntime",
            .policy_text = "PolicyText",
            .enable_debug_log_delivery = "EnableDebugLogDelivery",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceDetail = struct {
    event_source: ?[]const u8 = null,
    message_type: ?[]const u8 = null,
    maximum_execution_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_source = "EventSource",
            .message_type = "MessageType",
            .maximum_execution_frequency = "MaximumExecutionFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const Scope = struct {
    compliance_resource_types: ?[][]const u8 = null,
    tag_key: ?[]const u8 = null,
    tag_value: ?[]const u8 = null,
    compliance_resource_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compliance_resource_types = "ComplianceResourceTypes",
            .tag_key = "TagKey",
            .tag_value = "TagValue",
            .compliance_resource_id = "ComplianceResourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregationAuthorization = struct {
    aggregation_authorization_arn: ?[]const u8 = null,
    authorized_account_id: ?[]const u8 = null,
    authorized_aws_region: ?[]const u8 = null,
    creation_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aggregation_authorization_arn = "AggregationAuthorizationArn",
            .authorized_account_id = "AuthorizedAccountId",
            .authorized_aws_region = "AuthorizedAwsRegion",
            .creation_time = "CreationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregateResourceIdentifier = struct {
    source_account_id: []const u8,
    source_region: []const u8,
    resource_id: []const u8,
    resource_type: []const u8,
    resource_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_account_id = "SourceAccountId",
            .source_region = "SourceRegion",
            .resource_id = "ResourceId",
            .resource_type = "ResourceType",
            .resource_name = "ResourceName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationItem = struct {
    version: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    configuration_item_capture_time: ?i64 = null,
    configuration_item_status: ?[]const u8 = null,
    configuration_state_id: ?[]const u8 = null,
    configuration_item_md5_hash: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_name: ?[]const u8 = null,
    aws_region: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    resource_creation_time: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    related_events: ?[][]const u8 = null,
    relationships: ?[]Relationship = null,
    configuration: ?[]const u8 = null,
    supplementary_configuration: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    recording_frequency: ?[]const u8 = null,
    configuration_item_delivery_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "version",
            .account_id = "accountId",
            .configuration_item_capture_time = "configurationItemCaptureTime",
            .configuration_item_status = "configurationItemStatus",
            .configuration_state_id = "configurationStateId",
            .configuration_item_md5_hash = "configurationItemMD5Hash",
            .arn = "arn",
            .resource_type = "resourceType",
            .resource_id = "resourceId",
            .resource_name = "resourceName",
            .aws_region = "awsRegion",
            .availability_zone = "availabilityZone",
            .resource_creation_time = "resourceCreationTime",
            .tags = "tags",
            .related_events = "relatedEvents",
            .relationships = "relationships",
            .configuration = "configuration",
            .supplementary_configuration = "supplementaryConfiguration",
            .recording_frequency = "recordingFrequency",
            .configuration_item_delivery_time = "configurationItemDeliveryTime",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        if (std.mem.eql(u8, "supplementary_configuration", field_name))
            return try serializeMap(self.supplementary_configuration, self.fieldNameFor("supplementary_configuration"), options, out_stream);
        return false;
    }
};

pub const Relationship = struct {
    resource_type: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_name: ?[]const u8 = null,
    relationship_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .resource_id = "resourceId",
            .resource_name = "resourceName",
            .relationship_name = "relationshipName",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationResultIdentifier = struct {
    evaluation_result_qualifier: ?EvaluationResultQualifier = null,
    ordering_timestamp: ?i64 = null,
    resource_evaluation_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .evaluation_result_qualifier = "EvaluationResultQualifier",
            .ordering_timestamp = "OrderingTimestamp",
            .resource_evaluation_id = "ResourceEvaluationId",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationResultQualifier = struct {
    config_rule_name: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    evaluation_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .config_rule_name = "ConfigRuleName",
            .resource_type = "ResourceType",
            .resource_id = "ResourceId",
            .evaluation_mode = "EvaluationMode",
        };
        return @field(mappings, field_name);
    }
};

pub const ComplianceSummary = struct {
    compliant_resource_count: ?ComplianceContributorCount = null,
    non_compliant_resource_count: ?ComplianceContributorCount = null,
    compliance_summary_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compliant_resource_count = "CompliantResourceCount",
            .non_compliant_resource_count = "NonCompliantResourceCount",
            .compliance_summary_timestamp = "ComplianceSummaryTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const ComplianceContributorCount = struct {
    capped_count: ?i64 = null,
    cap_exceeded: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capped_count = "CappedCount",
            .cap_exceeded = "CapExceeded",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationResult = struct {
    evaluation_result_identifier: ?EvaluationResultIdentifier = null,
    compliance_type: ?[]const u8 = null,
    result_recorded_time: ?i64 = null,
    config_rule_invoked_time: ?i64 = null,
    annotation: ?[]const u8 = null,
    result_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .evaluation_result_identifier = "EvaluationResultIdentifier",
            .compliance_type = "ComplianceType",
            .result_recorded_time = "ResultRecordedTime",
            .config_rule_invoked_time = "ConfigRuleInvokedTime",
            .annotation = "Annotation",
            .result_token = "ResultToken",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigExportDeliveryInfo = struct {
    last_status: ?[]const u8 = null,
    last_error_code: ?[]const u8 = null,
    last_error_message: ?[]const u8 = null,
    last_attempt_time: ?i64 = null,
    last_successful_time: ?i64 = null,
    next_delivery_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_status = "lastStatus",
            .last_error_code = "lastErrorCode",
            .last_error_message = "lastErrorMessage",
            .last_attempt_time = "lastAttemptTime",
            .last_successful_time = "lastSuccessfulTime",
            .next_delivery_time = "nextDeliveryTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Compliance = struct {
    compliance_type: ?[]const u8 = null,
    compliance_contributor_count: ?ComplianceContributorCount = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compliance_type = "ComplianceType",
            .compliance_contributor_count = "ComplianceContributorCount",
        };
        return @field(mappings, field_name);
    }
};

pub const BaseConfigurationItem = struct {
    version: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    configuration_item_capture_time: ?i64 = null,
    configuration_item_status: ?[]const u8 = null,
    configuration_state_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_name: ?[]const u8 = null,
    aws_region: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    resource_creation_time: ?i64 = null,
    configuration: ?[]const u8 = null,
    supplementary_configuration: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    recording_frequency: ?[]const u8 = null,
    configuration_item_delivery_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "version",
            .account_id = "accountId",
            .configuration_item_capture_time = "configurationItemCaptureTime",
            .configuration_item_status = "configurationItemStatus",
            .configuration_state_id = "configurationStateId",
            .arn = "arn",
            .resource_type = "resourceType",
            .resource_id = "resourceId",
            .resource_name = "resourceName",
            .aws_region = "awsRegion",
            .availability_zone = "availabilityZone",
            .resource_creation_time = "resourceCreationTime",
            .configuration = "configuration",
            .supplementary_configuration = "supplementaryConfiguration",
            .recording_frequency = "recordingFrequency",
            .configuration_item_delivery_time = "configurationItemDeliveryTime",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "supplementary_configuration", field_name))
            return try serializeMap(self.supplementary_configuration, self.fieldNameFor("supplementary_configuration"), options, out_stream);
        return false;
    }
};
