const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-01-30";
pub const sdk_id: []const u8 = "ConnectCampaigns";
pub const arn_namespace: ?[]const u8 = "connect-campaigns";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "connect-campaigns";
pub const name: []const u8 = "AmazonConnectCampaignService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-01-30",
    sdk_id: []const u8 = "ConnectCampaigns",
    arn_namespace: ?[]const u8 = "connect-campaigns",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "connect-campaigns",
    name: []const u8 = "AmazonConnectCampaignService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_campaign: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/campaigns",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCampaign",
    Request: type = struct {
        name: []const u8,
        connect_instance_id: []const u8,
        dialer_config: DialerConfig,
        outbound_call_config: OutboundCallConfig,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .connect_instance_id = "connectInstanceId",
                .dialer_config = "dialerConfig",
                .outbound_call_config = "outboundCallConfig",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_campaign) } {
            return .{ .service_metadata = service_metadata, .action = create_campaign };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_campaign: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/campaigns/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCampaign",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_campaign) } {
            return .{ .service_metadata = service_metadata, .action = delete_campaign };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_connect_instance_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/connect-instance/{connectInstanceId}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConnectInstanceConfig",
    Request: type = struct {
        connect_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_instance_id = "connectInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connect_instance_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_connect_instance_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidState,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_instance_onboarding_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/connect-instance/{connectInstanceId}/onboarding",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInstanceOnboardingJob",
    Request: type = struct {
        connect_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_instance_id = "connectInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance_onboarding_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance_onboarding_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_campaign: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/campaigns/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCampaign",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_campaign) } {
            return .{ .service_metadata = service_metadata, .action = describe_campaign };
        }
    },
    Response: type = struct {
        campaign: ?struct {
            id: []const u8,
            arn: []const u8,
            name: []const u8,
            connect_instance_id: []const u8,
            dialer_config: DialerConfig,
            outbound_call_config: OutboundCallConfig,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .name = "name",
                    .connect_instance_id = "connectInstanceId",
                    .dialer_config = "dialerConfig",
                    .outbound_call_config = "outboundCallConfig",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign = "campaign",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_campaign_state: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/campaigns/{id}/state",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCampaignState",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_campaign_state) } {
            return .{ .service_metadata = service_metadata, .action = get_campaign_state };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_campaign_state_batch: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns-state",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCampaignStateBatch",
    Request: type = struct {
        campaign_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_ids = "campaignIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_campaign_state_batch) } {
            return .{ .service_metadata = service_metadata, .action = get_campaign_state_batch };
        }
    },
    Response: type = struct {
        successful_requests: ?[]struct {
            campaign_id: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .campaign_id = "campaignId",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failed_requests: ?[]struct {
            campaign_id: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .campaign_id = "campaignId",
                    .failure_code = "failureCode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_requests = "successfulRequests",
                .failed_requests = "failedRequests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_connect_instance_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/connect-instance/{connectInstanceId}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnectInstanceConfig",
    Request: type = struct {
        connect_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_instance_id = "connectInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connect_instance_config) } {
            return .{ .service_metadata = service_metadata, .action = get_connect_instance_config };
        }
    },
    Response: type = struct {
        connect_instance_config: ?struct {
            connect_instance_id: []const u8,
            service_linked_role_arn: []const u8,
            encryption_config: EncryptionConfig,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connect_instance_id = "connectInstanceId",
                    .service_linked_role_arn = "serviceLinkedRoleArn",
                    .encryption_config = "encryptionConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_instance_config = "connectInstanceConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_instance_onboarding_job_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/connect-instance/{connectInstanceId}/onboarding",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInstanceOnboardingJobStatus",
    Request: type = struct {
        connect_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_instance_id = "connectInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_instance_onboarding_job_status) } {
            return .{ .service_metadata = service_metadata, .action = get_instance_onboarding_job_status };
        }
    },
    Response: type = struct {
        connect_instance_onboarding_job_status: ?InstanceOnboardingJobStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_instance_onboarding_job_status = "connectInstanceOnboardingJobStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_campaigns: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns-summary",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCampaigns",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?struct {
            instance_id_filter: ?struct {
                value: []const u8,
                operator: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .value = "value",
                        .operator = "operator",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id_filter = "instanceIdFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_campaigns) } {
            return .{ .service_metadata = service_metadata, .action = list_campaigns };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        campaign_summary_list: ?[]struct {
            id: []const u8,
            arn: []const u8,
            name: []const u8,
            connect_instance_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .name = "name",
                    .connect_instance_id = "connectInstanceId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .campaign_summary_list = "campaignSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const pause_campaign: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns/{id}/pause",
        .success_code = 200,
    };

    action_name: []const u8 = "PauseCampaign",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(pause_campaign) } {
            return .{ .service_metadata = service_metadata, .action = pause_campaign };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidCampaignState,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_dial_request_batch: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/campaigns/{id}/dial-requests",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDialRequestBatch",
    Request: type = struct {
        id: []const u8,
        dial_requests: []struct {
            client_token: []const u8,
            phone_number: []const u8,
            expiration_time: i64,
            attributes: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_token = "clientToken",
                    .phone_number = "phoneNumber",
                    .expiration_time = "expirationTime",
                    .attributes = "attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .dial_requests = "dialRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_dial_request_batch) } {
            return .{ .service_metadata = service_metadata, .action = put_dial_request_batch };
        }
    },
    Response: type = struct {
        successful_requests: ?[]struct {
            client_token: ?[]const u8 = null,
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_token = "clientToken",
                    .id = "id",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failed_requests: ?[]struct {
            client_token: ?[]const u8 = null,
            id: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_token = "clientToken",
                    .id = "id",
                    .failure_code = "failureCode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_requests = "successfulRequests",
                .failed_requests = "failedRequests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidCampaignState,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const resume_campaign: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns/{id}/resume",
        .success_code = 200,
    };

    action_name: []const u8 = "ResumeCampaign",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_campaign) } {
            return .{ .service_metadata = service_metadata, .action = resume_campaign };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidCampaignState,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_campaign: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns/{id}/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartCampaign",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_campaign) } {
            return .{ .service_metadata = service_metadata, .action = start_campaign };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidCampaignState,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_instance_onboarding_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/connect-instance/{connectInstanceId}/onboarding",
        .success_code = 200,
    };

    action_name: []const u8 = "StartInstanceOnboardingJob",
    Request: type = struct {
        connect_instance_id: []const u8,
        encryption_config: EncryptionConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_instance_id = "connectInstanceId",
                .encryption_config = "encryptionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_instance_onboarding_job) } {
            return .{ .service_metadata = service_metadata, .action = start_instance_onboarding_job };
        }
    },
    Response: type = struct {
        connect_instance_onboarding_job_status: ?InstanceOnboardingJobStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_instance_onboarding_job_status = "connectInstanceOnboardingJobStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_campaign: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns/{id}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopCampaign",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_campaign) } {
            return .{ .service_metadata = service_metadata, .action = stop_campaign };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidCampaignState,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_campaign_dialer_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns/{id}/dialer-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCampaignDialerConfig",
    Request: type = struct {
        id: []const u8,
        dialer_config: DialerConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .dialer_config = "dialerConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_campaign_dialer_config) } {
            return .{ .service_metadata = service_metadata, .action = update_campaign_dialer_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_campaign_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns/{id}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCampaignName",
    Request: type = struct {
        id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_campaign_name) } {
            return .{ .service_metadata = service_metadata, .action = update_campaign_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_campaign_outbound_call_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/campaigns/{id}/outbound-call-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCampaignOutboundCallConfig",
    Request: type = struct {
        id: []const u8,
        connect_contact_flow_id: ?[]const u8 = null,
        connect_source_phone_number: ?[]const u8 = null,
        answer_machine_detection_config: ?AnswerMachineDetectionConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .connect_contact_flow_id = "connectContactFlowId",
                .connect_source_phone_number = "connectSourcePhoneNumber",
                .answer_machine_detection_config = "answerMachineDetectionConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_campaign_outbound_call_config) } {
            return .{ .service_metadata = service_metadata, .action = update_campaign_outbound_call_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const AnswerMachineDetectionConfig = struct {
    enable_answer_machine_detection: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_answer_machine_detection = "enableAnswerMachineDetection",
        };
        return @field(mappings, field_name);
    }
};

pub const DialerConfig = union {
    progressive_dialer_config: ?ProgressiveDialerConfig,
    predictive_dialer_config: ?PredictiveDialerConfig,
    agentless_dialer_config: ?AgentlessDialerConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .progressive_dialer_config = "progressiveDialerConfig",
            .predictive_dialer_config = "predictiveDialerConfig",
            .agentless_dialer_config = "agentlessDialerConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AgentlessDialerConfig = struct {
    dialing_capacity: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dialing_capacity = "dialingCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const PredictiveDialerConfig = struct {
    bandwidth_allocation: f64,
    dialing_capacity: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bandwidth_allocation = "bandwidthAllocation",
            .dialing_capacity = "dialingCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const ProgressiveDialerConfig = struct {
    bandwidth_allocation: f64,
    dialing_capacity: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bandwidth_allocation = "bandwidthAllocation",
            .dialing_capacity = "dialingCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceOnboardingJobStatus = struct {
    connect_instance_id: []const u8,
    status: []const u8,
    failure_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connect_instance_id = "connectInstanceId",
            .status = "status",
            .failure_code = "failureCode",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfig = struct {
    enabled: bool,
    encryption_type: ?[]const u8 = null,
    key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .encryption_type = "encryptionType",
            .key_arn = "keyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const OutboundCallConfig = struct {
    connect_contact_flow_id: []const u8,
    connect_source_phone_number: ?[]const u8 = null,
    connect_queue_id: ?[]const u8 = null,
    answer_machine_detection_config: ?AnswerMachineDetectionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connect_contact_flow_id = "connectContactFlowId",
            .connect_source_phone_number = "connectSourcePhoneNumber",
            .connect_queue_id = "connectQueueId",
            .answer_machine_detection_config = "answerMachineDetectionConfig",
        };
        return @field(mappings, field_name);
    }
};
