const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-21";
pub const sdk_id: []const u8 = "Connect Contact Lens";
pub const arn_namespace: ?[]const u8 = "connect";
pub const endpoint_prefix: []const u8 = "contact-lens";
pub const sigv4_name: []const u8 = "connect";
pub const name: []const u8 = "AmazonConnectContactLens";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-21",
    sdk_id: []const u8 = "Connect Contact Lens",
    arn_namespace: ?[]const u8 = "connect",
    endpoint_prefix: []const u8 = "contact-lens",
    sigv4_name: []const u8 = "connect",
    name: []const u8 = "AmazonConnectContactLens",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const list_realtime_contact_analysis_segments: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/realtime-contact-analysis/analysis-segments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRealtimeContactAnalysisSegments",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_realtime_contact_analysis_segments) } {
            return .{ .service_metadata = service_metadata, .action = list_realtime_contact_analysis_segments };
        }
    },
    Response: type = struct {
        segments: []struct {
            transcript: ?struct {
                id: []const u8,
                participant_id: []const u8,
                participant_role: []const u8,
                content: []const u8,
                begin_offset_millis: i64,
                end_offset_millis: i64,
                sentiment: []const u8,
                issues_detected: ?[]struct {
                    character_offsets: struct {
                        begin_offset_char: i64,
                        end_offset_char: i64,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .begin_offset_char = "BeginOffsetChar",
                                .end_offset_char = "EndOffsetChar",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .character_offsets = "CharacterOffsets",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .participant_id = "ParticipantId",
                        .participant_role = "ParticipantRole",
                        .content = "Content",
                        .begin_offset_millis = "BeginOffsetMillis",
                        .end_offset_millis = "EndOffsetMillis",
                        .sentiment = "Sentiment",
                        .issues_detected = "IssuesDetected",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            categories: ?struct {
                matched_categories: [][]const u8,
                matched_details: []struct {
                    key: ?[]const u8 = null,
                    value: ?struct {
                        points_of_interest: []struct {
                            begin_offset_millis: i64,
                            end_offset_millis: i64,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .begin_offset_millis = "BeginOffsetMillis",
                                    .end_offset_millis = "EndOffsetMillis",
                                };
                                return @field(mappings, field_name);
                            }
                        },

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .points_of_interest = "PointsOfInterest",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .matched_categories = "MatchedCategories",
                        .matched_details = "MatchedDetails",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "matched_details", field_name))
                        return try serializeMap(self.matched_details, self.fieldNameFor("matched_details"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transcript = "Transcript",
                    .categories = "Categories",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .segments = "Segments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
