const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-09-07";
pub const sdk_id: []const u8 = "ConnectParticipant";
pub const arn_namespace: ?[]const u8 = "connect";
pub const endpoint_prefix: []const u8 = "participant.connect";
pub const sigv4_name: []const u8 = "execute-api";
pub const name: []const u8 = "AmazonConnectParticipantServiceLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-09-07",
    sdk_id: []const u8 = "ConnectParticipant",
    arn_namespace: ?[]const u8 = "connect",
    endpoint_prefix: []const u8 = "participant.connect",
    sigv4_name: []const u8 = "execute-api",
    name: []const u8 = "AmazonConnectParticipantServiceLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const complete_attachment_upload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/participant/complete-attachment-upload",
        .success_code = 200,
    };

    action_name: []const u8 = "CompleteAttachmentUpload",
    Request: type = struct {
        attachment_ids: [][]const u8,
        client_token: []const u8,
        connection_token: []const u8,
        pub const http_header = .{
            .connection_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_ids = "AttachmentIds",
                .client_token = "ClientToken",
                .connection_token = "ConnectionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(complete_attachment_upload) } {
            return .{ .service_metadata = service_metadata, .action = complete_attachment_upload };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_participant_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/participant/connection",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateParticipantConnection",
    Request: type = struct {
        type: ?[][]const u8 = null,
        participant_token: []const u8,
        connect_participant: ?bool = null,
        pub const http_header = .{
            .participant_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .participant_token = "ParticipantToken",
                .connect_participant = "ConnectParticipant",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_participant_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_participant_connection };
        }
    },
    Response: type = struct {
        websocket: ?struct {
            url: ?[]const u8 = null,
            connection_expiry: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .url = "Url",
                    .connection_expiry = "ConnectionExpiry",
                };
                return @field(mappings, field_name);
            }
        } = null,
        connection_credentials: ?struct {
            connection_token: ?[]const u8 = null,
            expiry: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connection_token = "ConnectionToken",
                    .expiry = "Expiry",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .websocket = "Websocket",
                .connection_credentials = "ConnectionCredentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_view: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/participant/views/{ViewToken}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeView",
    Request: type = struct {
        view_token: []const u8,
        connection_token: []const u8,
        pub const http_header = .{
            .connection_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view_token = "ViewToken",
                .connection_token = "ConnectionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_view) } {
            return .{ .service_metadata = service_metadata, .action = describe_view };
        }
    },
    Response: type = struct {
        view: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?i64 = null,
            content: ?struct {
                input_schema: ?[]const u8 = null,
                template: ?[]const u8 = null,
                actions: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input_schema = "InputSchema",
                        .template = "Template",
                        .actions = "Actions",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .version = "Version",
                    .content = "Content",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view = "View",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disconnect_participant: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/participant/disconnect",
        .success_code = 200,
    };

    action_name: []const u8 = "DisconnectParticipant",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        connection_token: []const u8,
        pub const http_header = .{
            .connection_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .connection_token = "ConnectionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disconnect_participant) } {
            return .{ .service_metadata = service_metadata, .action = disconnect_participant };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_attachment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/participant/attachment",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAttachment",
    Request: type = struct {
        attachment_id: []const u8,
        connection_token: []const u8,
        pub const http_header = .{
            .connection_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
                .connection_token = "ConnectionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_attachment) } {
            return .{ .service_metadata = service_metadata, .action = get_attachment };
        }
    },
    Response: type = struct {
        url: ?[]const u8 = null,
        url_expiry: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .url = "Url",
                .url_expiry = "UrlExpiry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_transcript: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/participant/transcript",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTranscript",
    Request: type = struct {
        contact_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        scan_direction: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        start_position: ?struct {
            id: ?[]const u8 = null,
            absolute_time: ?[]const u8 = null,
            most_recent: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .absolute_time = "AbsoluteTime",
                    .most_recent = "MostRecent",
                };
                return @field(mappings, field_name);
            }
        } = null,
        connection_token: []const u8,
        pub const http_header = .{
            .connection_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .scan_direction = "ScanDirection",
                .sort_order = "SortOrder",
                .start_position = "StartPosition",
                .connection_token = "ConnectionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transcript) } {
            return .{ .service_metadata = service_metadata, .action = get_transcript };
        }
    },
    Response: type = struct {
        initial_contact_id: ?[]const u8 = null,
        transcript: ?[]struct {
            absolute_time: ?[]const u8 = null,
            content: ?[]const u8 = null,
            content_type: ?[]const u8 = null,
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            participant_id: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            participant_role: ?[]const u8 = null,
            attachments: ?[]struct {
                content_type: ?[]const u8 = null,
                attachment_id: ?[]const u8 = null,
                attachment_name: ?[]const u8 = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .content_type = "ContentType",
                        .attachment_id = "AttachmentId",
                        .attachment_name = "AttachmentName",
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            message_metadata: ?struct {
                message_id: ?[]const u8 = null,
                receipts: ?[]struct {
                    delivered_timestamp: ?[]const u8 = null,
                    read_timestamp: ?[]const u8 = null,
                    recipient_participant_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .delivered_timestamp = "DeliveredTimestamp",
                            .read_timestamp = "ReadTimestamp",
                            .recipient_participant_id = "RecipientParticipantId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .message_id = "MessageId",
                        .receipts = "Receipts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            related_contact_id: ?[]const u8 = null,
            contact_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .absolute_time = "AbsoluteTime",
                    .content = "Content",
                    .content_type = "ContentType",
                    .id = "Id",
                    .type = "Type",
                    .participant_id = "ParticipantId",
                    .display_name = "DisplayName",
                    .participant_role = "ParticipantRole",
                    .attachments = "Attachments",
                    .message_metadata = "MessageMetadata",
                    .related_contact_id = "RelatedContactId",
                    .contact_id = "ContactId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .initial_contact_id = "InitialContactId",
                .transcript = "Transcript",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const send_event: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/participant/event",
        .success_code = 200,
    };

    action_name: []const u8 = "SendEvent",
    Request: type = struct {
        content_type: []const u8,
        content: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        connection_token: []const u8,
        pub const http_header = .{
            .connection_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "ContentType",
                .content = "Content",
                .client_token = "ClientToken",
                .connection_token = "ConnectionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_event) } {
            return .{ .service_metadata = service_metadata, .action = send_event };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        absolute_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .absolute_time = "AbsoluteTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const send_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/participant/message",
        .success_code = 200,
    };

    action_name: []const u8 = "SendMessage",
    Request: type = struct {
        content_type: []const u8,
        content: []const u8,
        client_token: ?[]const u8 = null,
        connection_token: []const u8,
        pub const http_header = .{
            .connection_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "ContentType",
                .content = "Content",
                .client_token = "ClientToken",
                .connection_token = "ConnectionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_message) } {
            return .{ .service_metadata = service_metadata, .action = send_message };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        absolute_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .absolute_time = "AbsoluteTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const start_attachment_upload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/participant/start-attachment-upload",
        .success_code = 200,
    };

    action_name: []const u8 = "StartAttachmentUpload",
    Request: type = struct {
        content_type: []const u8,
        attachment_size_in_bytes: i64,
        attachment_name: []const u8,
        client_token: []const u8,
        connection_token: []const u8,
        pub const http_header = .{
            .connection_token = "X-Amz-Bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "ContentType",
                .attachment_size_in_bytes = "AttachmentSizeInBytes",
                .attachment_name = "AttachmentName",
                .client_token = "ClientToken",
                .connection_token = "ConnectionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_attachment_upload) } {
            return .{ .service_metadata = service_metadata, .action = start_attachment_upload };
        }
    },
    Response: type = struct {
        attachment_id: ?[]const u8 = null,
        upload_metadata: ?struct {
            url: ?[]const u8 = null,
            url_expiry: ?[]const u8 = null,
            headers_to_include: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .url = "Url",
                    .url_expiry = "UrlExpiry",
                    .headers_to_include = "HeadersToInclude",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "headers_to_include", field_name))
                    return try serializeMap(self.headers_to_include, self.fieldNameFor("headers_to_include"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
                .upload_metadata = "UploadMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
