const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "ControlTower";
pub const arn_namespace: ?[]const u8 = "controltower";
pub const endpoint_prefix: []const u8 = "controltower";
pub const sigv4_name: []const u8 = "controltower";
pub const name: []const u8 = "AWSControlTowerApis";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "ControlTower",
    arn_namespace: ?[]const u8 = "controltower",
    endpoint_prefix: []const u8 = "controltower",
    sigv4_name: []const u8 = "controltower",
    name: []const u8 = "AWSControlTowerApis",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const disable_control: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/disable-control",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableControl",
    Request: type = struct {
        control_identifier: []const u8,
        target_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_identifier = "controlIdentifier",
                .target_identifier = "targetIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_control) } {
            return .{ .service_metadata = service_metadata, .action = disable_control };
        }
    },
    Response: type = struct {
        operation_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_identifier = "operationIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const enable_control: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/enable-control",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableControl",
    Request: type = struct {
        control_identifier: []const u8,
        target_identifier: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        parameters: ?[]EnabledControlParameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_identifier = "controlIdentifier",
                .target_identifier = "targetIdentifier",
                .tags = "tags",
                .parameters = "parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_control) } {
            return .{ .service_metadata = service_metadata, .action = enable_control };
        }
    },
    Response: type = struct {
        operation_identifier: []const u8,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_identifier = "operationIdentifier",
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_control_operation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-control-operation",
        .success_code = 200,
    };

    action_name: []const u8 = "GetControlOperation",
    Request: type = struct {
        operation_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_identifier = "operationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_control_operation) } {
            return .{ .service_metadata = service_metadata, .action = get_control_operation };
        }
    },
    Response: type = struct {
        control_operation: struct {
            operation_type: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operation_type = "operationType",
                    .start_time = "startTime",
                    .end_time = "endTime",
                    .status = "status",
                    .status_message = "statusMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_operation = "controlOperation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_enabled_control: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-enabled-control",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnabledControl",
    Request: type = struct {
        enabled_control_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enabled_control_identifier = "enabledControlIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_enabled_control) } {
            return .{ .service_metadata = service_metadata, .action = get_enabled_control };
        }
    },
    Response: type = struct {
        enabled_control_details: struct {
            arn: ?[]const u8 = null,
            control_identifier: ?[]const u8 = null,
            target_identifier: ?[]const u8 = null,
            target_regions: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status_summary: ?EnablementStatusSummary = null,
            drift_status_summary: ?DriftStatusSummary = null,
            parameters: ?[]struct {
                key: []const u8,
                value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "key",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .control_identifier = "controlIdentifier",
                    .target_identifier = "targetIdentifier",
                    .target_regions = "targetRegions",
                    .status_summary = "statusSummary",
                    .drift_status_summary = "driftStatusSummary",
                    .parameters = "parameters",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enabled_control_details = "enabledControlDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_enabled_controls: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-enabled-controls",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnabledControls",
    Request: type = struct {
        target_identifier: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_identifier = "targetIdentifier",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_enabled_controls) } {
            return .{ .service_metadata = service_metadata, .action = list_enabled_controls };
        }
    },
    Response: type = struct {
        enabled_controls: []struct {
            control_identifier: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            target_identifier: ?[]const u8 = null,
            status_summary: ?EnablementStatusSummary = null,
            drift_status_summary: ?DriftStatusSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .control_identifier = "controlIdentifier",
                    .arn = "arn",
                    .target_identifier = "targetIdentifier",
                    .status_summary = "statusSummary",
                    .drift_status_summary = "driftStatusSummary",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enabled_controls = "enabledControls",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_enabled_control: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-enabled-control",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEnabledControl",
    Request: type = struct {
        parameters: []EnabledControlParameter,
        enabled_control_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "parameters",
                .enabled_control_identifier = "enabledControlIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_enabled_control) } {
            return .{ .service_metadata = service_metadata, .action = update_enabled_control };
        }
    },
    Response: type = struct {
        operation_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_identifier = "operationIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const EnabledControlParameter = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DriftStatusSummary = struct {
    drift_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .drift_status = "driftStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const EnablementStatusSummary = struct {
    status: ?[]const u8 = null,
    last_operation_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .last_operation_identifier = "lastOperationIdentifier",
        };
        return @field(mappings, field_name);
    }
};
