const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-25";
pub const sdk_id: []const u8 = "Cost Explorer";
pub const arn_namespace: ?[]const u8 = "ce";
pub const endpoint_prefix: []const u8 = "ce";
pub const sigv4_name: []const u8 = "ce";
pub const name: []const u8 = "AWSInsightsIndexService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-25",
    sdk_id: []const u8 = "Cost Explorer",
    arn_namespace: ?[]const u8 = "ce",
    endpoint_prefix: []const u8 = "ce",
    sigv4_name: []const u8 = "ce",
    name: []const u8 = "AWSInsightsIndexService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_anomaly_monitor: struct {
    action_name: []const u8 = "CreateAnomalyMonitor",
    Request: type = struct {
        anomaly_monitor: AnomalyMonitor,
        resource_tags: ?[]ResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_monitor = "AnomalyMonitor",
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_anomaly_monitor) } {
            return .{ .service_metadata = service_metadata, .action = create_anomaly_monitor };
        }
    },
    Response: type = struct {
        monitor_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitor_arn = "MonitorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const create_anomaly_subscription: struct {
    action_name: []const u8 = "CreateAnomalySubscription",
    Request: type = struct {
        anomaly_subscription: AnomalySubscription,
        resource_tags: ?[]ResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_subscription = "AnomalySubscription",
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_anomaly_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_anomaly_subscription };
        }
    },
    Response: type = struct {
        subscription_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        UnknownMonitor,
    },
} = .{};
pub const create_cost_category_definition: struct {
    action_name: []const u8 = "CreateCostCategoryDefinition",
    Request: type = struct {
        name: []const u8,
        effective_start: ?[]const u8 = null,
        rule_version: []const u8,
        rules: []CostCategoryRule,
        default_value: ?[]const u8 = null,
        split_charge_rules: ?[]CostCategorySplitChargeRule = null,
        resource_tags: ?[]ResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .effective_start = "EffectiveStart",
                .rule_version = "RuleVersion",
                .rules = "Rules",
                .default_value = "DefaultValue",
                .split_charge_rules = "SplitChargeRules",
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cost_category_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_cost_category_definition };
        }
    },
    Response: type = struct {
        cost_category_arn: ?[]const u8 = null,
        effective_start: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_category_arn = "CostCategoryArn",
                .effective_start = "EffectiveStart",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ServiceQuotaExceeded,
    },
} = .{};
pub const delete_anomaly_monitor: struct {
    action_name: []const u8 = "DeleteAnomalyMonitor",
    Request: type = struct {
        monitor_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitor_arn = "MonitorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_anomaly_monitor) } {
            return .{ .service_metadata = service_metadata, .action = delete_anomaly_monitor };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        UnknownMonitor,
    },
} = .{};
pub const delete_anomaly_subscription: struct {
    action_name: []const u8 = "DeleteAnomalySubscription",
    Request: type = struct {
        subscription_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_anomaly_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_anomaly_subscription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        UnknownSubscription,
    },
} = .{};
pub const delete_cost_category_definition: struct {
    action_name: []const u8 = "DeleteCostCategoryDefinition",
    Request: type = struct {
        cost_category_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_category_arn = "CostCategoryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cost_category_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_cost_category_definition };
        }
    },
    Response: type = struct {
        cost_category_arn: ?[]const u8 = null,
        effective_end: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_category_arn = "CostCategoryArn",
                .effective_end = "EffectiveEnd",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const describe_cost_category_definition: struct {
    action_name: []const u8 = "DescribeCostCategoryDefinition",
    Request: type = struct {
        cost_category_arn: []const u8,
        effective_on: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_category_arn = "CostCategoryArn",
                .effective_on = "EffectiveOn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cost_category_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_cost_category_definition };
        }
    },
    Response: type = struct {
        cost_category: ?struct {
            cost_category_arn: []const u8,
            effective_start: []const u8,
            effective_end: ?[]const u8 = null,
            name: []const u8,
            rule_version: []const u8,
            rules: []CostCategoryRule,
            split_charge_rules: ?[]CostCategorySplitChargeRule = null,
            processing_status: ?[]CostCategoryProcessingStatus = null,
            default_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cost_category_arn = "CostCategoryArn",
                    .effective_start = "EffectiveStart",
                    .effective_end = "EffectiveEnd",
                    .name = "Name",
                    .rule_version = "RuleVersion",
                    .rules = "Rules",
                    .split_charge_rules = "SplitChargeRules",
                    .processing_status = "ProcessingStatus",
                    .default_value = "DefaultValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_category = "CostCategory",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_anomalies: struct {
    action_name: []const u8 = "GetAnomalies",
    Request: type = struct {
        monitor_arn: ?[]const u8 = null,
        date_interval: struct {
            start_date: []const u8,
            end_date: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_date = "StartDate",
                    .end_date = "EndDate",
                };
                return @field(mappings, field_name);
            }
        },
        feedback: ?[]const u8 = null,
        total_impact: ?struct {
            numeric_operator: []const u8,
            start_value: f64,
            end_value: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .numeric_operator = "NumericOperator",
                    .start_value = "StartValue",
                    .end_value = "EndValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitor_arn = "MonitorArn",
                .date_interval = "DateInterval",
                .feedback = "Feedback",
                .total_impact = "TotalImpact",
                .next_page_token = "NextPageToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_anomalies) } {
            return .{ .service_metadata = service_metadata, .action = get_anomalies };
        }
    },
    Response: type = struct {
        anomalies: []struct {
            anomaly_id: []const u8,
            anomaly_start_date: ?[]const u8 = null,
            anomaly_end_date: ?[]const u8 = null,
            dimension_value: ?[]const u8 = null,
            root_causes: ?[]struct {
                service: ?[]const u8 = null,
                region: ?[]const u8 = null,
                linked_account: ?[]const u8 = null,
                usage_type: ?[]const u8 = null,
                linked_account_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .service = "Service",
                        .region = "Region",
                        .linked_account = "LinkedAccount",
                        .usage_type = "UsageType",
                        .linked_account_name = "LinkedAccountName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            anomaly_score: struct {
                max_score: f64,
                current_score: f64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .max_score = "MaxScore",
                        .current_score = "CurrentScore",
                    };
                    return @field(mappings, field_name);
                }
            },
            impact: struct {
                max_impact: f64,
                total_impact: ?f64 = null,
                total_actual_spend: ?f64 = null,
                total_expected_spend: ?f64 = null,
                total_impact_percentage: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .max_impact = "MaxImpact",
                        .total_impact = "TotalImpact",
                        .total_actual_spend = "TotalActualSpend",
                        .total_expected_spend = "TotalExpectedSpend",
                        .total_impact_percentage = "TotalImpactPercentage",
                    };
                    return @field(mappings, field_name);
                }
            },
            monitor_arn: []const u8,
            feedback: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .anomaly_id = "AnomalyId",
                    .anomaly_start_date = "AnomalyStartDate",
                    .anomaly_end_date = "AnomalyEndDate",
                    .dimension_value = "DimensionValue",
                    .root_causes = "RootCauses",
                    .anomaly_score = "AnomalyScore",
                    .impact = "Impact",
                    .monitor_arn = "MonitorArn",
                    .feedback = "Feedback",
                };
                return @field(mappings, field_name);
            }
        },
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomalies = "Anomalies",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const get_anomaly_monitors: struct {
    action_name: []const u8 = "GetAnomalyMonitors",
    Request: type = struct {
        monitor_arn_list: ?[][]const u8 = null,
        next_page_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitor_arn_list = "MonitorArnList",
                .next_page_token = "NextPageToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_anomaly_monitors) } {
            return .{ .service_metadata = service_metadata, .action = get_anomaly_monitors };
        }
    },
    Response: type = struct {
        anomaly_monitors: []AnomalyMonitor,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_monitors = "AnomalyMonitors",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        LimitExceeded,
        UnknownMonitor,
    },
} = .{};
pub const get_anomaly_subscriptions: struct {
    action_name: []const u8 = "GetAnomalySubscriptions",
    Request: type = struct {
        subscription_arn_list: ?[][]const u8 = null,
        monitor_arn: ?[]const u8 = null,
        next_page_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn_list = "SubscriptionArnList",
                .monitor_arn = "MonitorArn",
                .next_page_token = "NextPageToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_anomaly_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = get_anomaly_subscriptions };
        }
    },
    Response: type = struct {
        anomaly_subscriptions: []AnomalySubscription,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_subscriptions = "AnomalySubscriptions",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        LimitExceeded,
        UnknownSubscription,
    },
} = .{};
pub const get_approximate_usage_records: struct {
    action_name: []const u8 = "GetApproximateUsageRecords",
    Request: type = struct {
        granularity: []const u8,
        services: ?[][]const u8 = null,
        approximation_dimension: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .granularity = "Granularity",
                .services = "Services",
                .approximation_dimension = "ApproximationDimension",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_approximate_usage_records) } {
            return .{ .service_metadata = service_metadata, .action = get_approximate_usage_records };
        }
    },
    Response: type = struct {
        services: ?[]struct {
            key: ?[]const u8 = null,
            value: ?i64 = null,
        } = null,
        total_records: ?i64 = null,
        lookback_period: ?DateInterval = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .services = "Services",
                .total_records = "TotalRecords",
                .lookback_period = "LookbackPeriod",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "services", field_name))
                return try serializeMap(self.services, self.fieldNameFor("services"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        LimitExceeded,
    },
} = .{};
pub const get_cost_and_usage: struct {
    action_name: []const u8 = "GetCostAndUsage",
    Request: type = struct {
        time_period: DateInterval,
        granularity: []const u8,
        filter: ?Expression = null,
        metrics: [][]const u8,
        group_by: ?[]GroupDefinition = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .granularity = "Granularity",
                .filter = "Filter",
                .metrics = "Metrics",
                .group_by = "GroupBy",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cost_and_usage) } {
            return .{ .service_metadata = service_metadata, .action = get_cost_and_usage };
        }
    },
    Response: type = struct {
        next_page_token: ?[]const u8 = null,
        group_definitions: ?[]GroupDefinition = null,
        results_by_time: ?[]ResultByTime = null,
        dimension_value_attributes: ?[]DimensionValuesWithAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_page_token = "NextPageToken",
                .group_definitions = "GroupDefinitions",
                .results_by_time = "ResultsByTime",
                .dimension_value_attributes = "DimensionValueAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BillExpiration,
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
        RequestChanged,
    },
} = .{};
pub const get_cost_and_usage_with_resources: struct {
    action_name: []const u8 = "GetCostAndUsageWithResources",
    Request: type = struct {
        time_period: DateInterval,
        granularity: []const u8,
        filter: Expression,
        metrics: ?[][]const u8 = null,
        group_by: ?[]GroupDefinition = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .granularity = "Granularity",
                .filter = "Filter",
                .metrics = "Metrics",
                .group_by = "GroupBy",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cost_and_usage_with_resources) } {
            return .{ .service_metadata = service_metadata, .action = get_cost_and_usage_with_resources };
        }
    },
    Response: type = struct {
        next_page_token: ?[]const u8 = null,
        group_definitions: ?[]GroupDefinition = null,
        results_by_time: ?[]ResultByTime = null,
        dimension_value_attributes: ?[]DimensionValuesWithAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_page_token = "NextPageToken",
                .group_definitions = "GroupDefinitions",
                .results_by_time = "ResultsByTime",
                .dimension_value_attributes = "DimensionValueAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BillExpiration,
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
        RequestChanged,
    },
} = .{};
pub const get_cost_categories: struct {
    action_name: []const u8 = "GetCostCategories",
    Request: type = struct {
        search_string: ?[]const u8 = null,
        time_period: DateInterval,
        cost_category_name: ?[]const u8 = null,
        filter: ?Expression = null,
        sort_by: ?[]SortDefinition = null,
        max_results: ?i64 = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .search_string = "SearchString",
                .time_period = "TimePeriod",
                .cost_category_name = "CostCategoryName",
                .filter = "Filter",
                .sort_by = "SortBy",
                .max_results = "MaxResults",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cost_categories) } {
            return .{ .service_metadata = service_metadata, .action = get_cost_categories };
        }
    },
    Response: type = struct {
        next_page_token: ?[]const u8 = null,
        cost_category_names: ?[][]const u8 = null,
        cost_category_values: ?[][]const u8 = null,
        return_size: i64,
        total_size: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_page_token = "NextPageToken",
                .cost_category_names = "CostCategoryNames",
                .cost_category_values = "CostCategoryValues",
                .return_size = "ReturnSize",
                .total_size = "TotalSize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BillExpiration,
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
        RequestChanged,
    },
} = .{};
pub const get_cost_forecast: struct {
    action_name: []const u8 = "GetCostForecast",
    Request: type = struct {
        time_period: DateInterval,
        metric: []const u8,
        granularity: []const u8,
        filter: ?Expression = null,
        prediction_interval_level: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .metric = "Metric",
                .granularity = "Granularity",
                .filter = "Filter",
                .prediction_interval_level = "PredictionIntervalLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cost_forecast) } {
            return .{ .service_metadata = service_metadata, .action = get_cost_forecast };
        }
    },
    Response: type = struct {
        total: ?MetricValue = null,
        forecast_results_by_time: ?[]ForecastResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .total = "Total",
                .forecast_results_by_time = "ForecastResultsByTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        LimitExceeded,
    },
} = .{};
pub const get_dimension_values: struct {
    action_name: []const u8 = "GetDimensionValues",
    Request: type = struct {
        search_string: ?[]const u8 = null,
        time_period: DateInterval,
        dimension: []const u8,
        context: ?[]const u8 = null,
        filter: ?Expression = null,
        sort_by: ?[]SortDefinition = null,
        max_results: ?i64 = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .search_string = "SearchString",
                .time_period = "TimePeriod",
                .dimension = "Dimension",
                .context = "Context",
                .filter = "Filter",
                .sort_by = "SortBy",
                .max_results = "MaxResults",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dimension_values) } {
            return .{ .service_metadata = service_metadata, .action = get_dimension_values };
        }
    },
    Response: type = struct {
        dimension_values: []DimensionValuesWithAttributes,
        return_size: i64,
        total_size: i64,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dimension_values = "DimensionValues",
                .return_size = "ReturnSize",
                .total_size = "TotalSize",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BillExpiration,
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
        RequestChanged,
    },
} = .{};
pub const get_reservation_coverage: struct {
    action_name: []const u8 = "GetReservationCoverage",
    Request: type = struct {
        time_period: DateInterval,
        group_by: ?[]GroupDefinition = null,
        granularity: ?[]const u8 = null,
        filter: ?Expression = null,
        metrics: ?[][]const u8 = null,
        next_page_token: ?[]const u8 = null,
        sort_by: ?SortDefinition = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .group_by = "GroupBy",
                .granularity = "Granularity",
                .filter = "Filter",
                .metrics = "Metrics",
                .next_page_token = "NextPageToken",
                .sort_by = "SortBy",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reservation_coverage) } {
            return .{ .service_metadata = service_metadata, .action = get_reservation_coverage };
        }
    },
    Response: type = struct {
        coverages_by_time: []struct {
            time_period: ?DateInterval = null,
            groups: ?[]struct {
                attributes: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                coverage: ?Coverage = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attributes = "Attributes",
                        .coverage = "Coverage",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "attributes", field_name))
                        return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                    return false;
                }
            } = null,
            total: ?Coverage = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time_period = "TimePeriod",
                    .groups = "Groups",
                    .total = "Total",
                };
                return @field(mappings, field_name);
            }
        },
        total: ?Coverage = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coverages_by_time = "CoveragesByTime",
                .total = "Total",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const get_reservation_purchase_recommendation: struct {
    action_name: []const u8 = "GetReservationPurchaseRecommendation",
    Request: type = struct {
        account_id: ?[]const u8 = null,
        service: []const u8,
        filter: ?Expression = null,
        account_scope: ?[]const u8 = null,
        lookback_period_in_days: ?[]const u8 = null,
        term_in_years: ?[]const u8 = null,
        payment_option: ?[]const u8 = null,
        service_specification: ?ServiceSpecification = null,
        page_size: ?i64 = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .service = "Service",
                .filter = "Filter",
                .account_scope = "AccountScope",
                .lookback_period_in_days = "LookbackPeriodInDays",
                .term_in_years = "TermInYears",
                .payment_option = "PaymentOption",
                .service_specification = "ServiceSpecification",
                .page_size = "PageSize",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reservation_purchase_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = get_reservation_purchase_recommendation };
        }
    },
    Response: type = struct {
        metadata: ?struct {
            recommendation_id: ?[]const u8 = null,
            generation_timestamp: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_id = "RecommendationId",
                    .generation_timestamp = "GenerationTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        recommendations: ?[]struct {
            account_scope: ?[]const u8 = null,
            lookback_period_in_days: ?[]const u8 = null,
            term_in_years: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            service_specification: ?ServiceSpecification = null,
            recommendation_details: ?[]struct {
                account_id: ?[]const u8 = null,
                instance_details: ?struct {
                    ec2_instance_details: ?struct {
                        family: ?[]const u8 = null,
                        instance_type: ?[]const u8 = null,
                        region: ?[]const u8 = null,
                        availability_zone: ?[]const u8 = null,
                        platform: ?[]const u8 = null,
                        tenancy: ?[]const u8 = null,
                        current_generation: ?bool = null,
                        size_flex_eligible: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .family = "Family",
                                .instance_type = "InstanceType",
                                .region = "Region",
                                .availability_zone = "AvailabilityZone",
                                .platform = "Platform",
                                .tenancy = "Tenancy",
                                .current_generation = "CurrentGeneration",
                                .size_flex_eligible = "SizeFlexEligible",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    rds_instance_details: ?struct {
                        family: ?[]const u8 = null,
                        instance_type: ?[]const u8 = null,
                        region: ?[]const u8 = null,
                        database_engine: ?[]const u8 = null,
                        database_edition: ?[]const u8 = null,
                        deployment_option: ?[]const u8 = null,
                        license_model: ?[]const u8 = null,
                        current_generation: ?bool = null,
                        size_flex_eligible: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .family = "Family",
                                .instance_type = "InstanceType",
                                .region = "Region",
                                .database_engine = "DatabaseEngine",
                                .database_edition = "DatabaseEdition",
                                .deployment_option = "DeploymentOption",
                                .license_model = "LicenseModel",
                                .current_generation = "CurrentGeneration",
                                .size_flex_eligible = "SizeFlexEligible",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    redshift_instance_details: ?struct {
                        family: ?[]const u8 = null,
                        node_type: ?[]const u8 = null,
                        region: ?[]const u8 = null,
                        current_generation: ?bool = null,
                        size_flex_eligible: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .family = "Family",
                                .node_type = "NodeType",
                                .region = "Region",
                                .current_generation = "CurrentGeneration",
                                .size_flex_eligible = "SizeFlexEligible",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    elasti_cache_instance_details: ?struct {
                        family: ?[]const u8 = null,
                        node_type: ?[]const u8 = null,
                        region: ?[]const u8 = null,
                        product_description: ?[]const u8 = null,
                        current_generation: ?bool = null,
                        size_flex_eligible: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .family = "Family",
                                .node_type = "NodeType",
                                .region = "Region",
                                .product_description = "ProductDescription",
                                .current_generation = "CurrentGeneration",
                                .size_flex_eligible = "SizeFlexEligible",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    es_instance_details: ?struct {
                        instance_class: ?[]const u8 = null,
                        instance_size: ?[]const u8 = null,
                        region: ?[]const u8 = null,
                        current_generation: ?bool = null,
                        size_flex_eligible: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .instance_class = "InstanceClass",
                                .instance_size = "InstanceSize",
                                .region = "Region",
                                .current_generation = "CurrentGeneration",
                                .size_flex_eligible = "SizeFlexEligible",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    memory_db_instance_details: ?struct {
                        family: ?[]const u8 = null,
                        node_type: ?[]const u8 = null,
                        region: ?[]const u8 = null,
                        current_generation: ?bool = null,
                        size_flex_eligible: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .family = "Family",
                                .node_type = "NodeType",
                                .region = "Region",
                                .current_generation = "CurrentGeneration",
                                .size_flex_eligible = "SizeFlexEligible",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .ec2_instance_details = "EC2InstanceDetails",
                            .rds_instance_details = "RDSInstanceDetails",
                            .redshift_instance_details = "RedshiftInstanceDetails",
                            .elasti_cache_instance_details = "ElastiCacheInstanceDetails",
                            .es_instance_details = "ESInstanceDetails",
                            .memory_db_instance_details = "MemoryDBInstanceDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                recommended_number_of_instances_to_purchase: ?[]const u8 = null,
                recommended_normalized_units_to_purchase: ?[]const u8 = null,
                minimum_number_of_instances_used_per_hour: ?[]const u8 = null,
                minimum_normalized_units_used_per_hour: ?[]const u8 = null,
                maximum_number_of_instances_used_per_hour: ?[]const u8 = null,
                maximum_normalized_units_used_per_hour: ?[]const u8 = null,
                average_number_of_instances_used_per_hour: ?[]const u8 = null,
                average_normalized_units_used_per_hour: ?[]const u8 = null,
                average_utilization: ?[]const u8 = null,
                estimated_break_even_in_months: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,
                estimated_monthly_savings_amount: ?[]const u8 = null,
                estimated_monthly_savings_percentage: ?[]const u8 = null,
                estimated_monthly_on_demand_cost: ?[]const u8 = null,
                estimated_reservation_cost_for_lookback_period: ?[]const u8 = null,
                upfront_cost: ?[]const u8 = null,
                recurring_standard_monthly_cost: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .account_id = "AccountId",
                        .instance_details = "InstanceDetails",
                        .recommended_number_of_instances_to_purchase = "RecommendedNumberOfInstancesToPurchase",
                        .recommended_normalized_units_to_purchase = "RecommendedNormalizedUnitsToPurchase",
                        .minimum_number_of_instances_used_per_hour = "MinimumNumberOfInstancesUsedPerHour",
                        .minimum_normalized_units_used_per_hour = "MinimumNormalizedUnitsUsedPerHour",
                        .maximum_number_of_instances_used_per_hour = "MaximumNumberOfInstancesUsedPerHour",
                        .maximum_normalized_units_used_per_hour = "MaximumNormalizedUnitsUsedPerHour",
                        .average_number_of_instances_used_per_hour = "AverageNumberOfInstancesUsedPerHour",
                        .average_normalized_units_used_per_hour = "AverageNormalizedUnitsUsedPerHour",
                        .average_utilization = "AverageUtilization",
                        .estimated_break_even_in_months = "EstimatedBreakEvenInMonths",
                        .currency_code = "CurrencyCode",
                        .estimated_monthly_savings_amount = "EstimatedMonthlySavingsAmount",
                        .estimated_monthly_savings_percentage = "EstimatedMonthlySavingsPercentage",
                        .estimated_monthly_on_demand_cost = "EstimatedMonthlyOnDemandCost",
                        .estimated_reservation_cost_for_lookback_period = "EstimatedReservationCostForLookbackPeriod",
                        .upfront_cost = "UpfrontCost",
                        .recurring_standard_monthly_cost = "RecurringStandardMonthlyCost",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            recommendation_summary: ?struct {
                total_estimated_monthly_savings_amount: ?[]const u8 = null,
                total_estimated_monthly_savings_percentage: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total_estimated_monthly_savings_amount = "TotalEstimatedMonthlySavingsAmount",
                        .total_estimated_monthly_savings_percentage = "TotalEstimatedMonthlySavingsPercentage",
                        .currency_code = "CurrencyCode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_scope = "AccountScope",
                    .lookback_period_in_days = "LookbackPeriodInDays",
                    .term_in_years = "TermInYears",
                    .payment_option = "PaymentOption",
                    .service_specification = "ServiceSpecification",
                    .recommendation_details = "RecommendationDetails",
                    .recommendation_summary = "RecommendationSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .recommendations = "Recommendations",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const get_reservation_utilization: struct {
    action_name: []const u8 = "GetReservationUtilization",
    Request: type = struct {
        time_period: DateInterval,
        group_by: ?[]GroupDefinition = null,
        granularity: ?[]const u8 = null,
        filter: ?Expression = null,
        sort_by: ?SortDefinition = null,
        next_page_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .group_by = "GroupBy",
                .granularity = "Granularity",
                .filter = "Filter",
                .sort_by = "SortBy",
                .next_page_token = "NextPageToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reservation_utilization) } {
            return .{ .service_metadata = service_metadata, .action = get_reservation_utilization };
        }
    },
    Response: type = struct {
        utilizations_by_time: []struct {
            time_period: ?DateInterval = null,
            groups: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
                attributes: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                utilization: ?ReservationAggregates = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .value = "Value",
                        .attributes = "Attributes",
                        .utilization = "Utilization",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "attributes", field_name))
                        return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                    return false;
                }
            } = null,
            total: ?ReservationAggregates = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time_period = "TimePeriod",
                    .groups = "Groups",
                    .total = "Total",
                };
                return @field(mappings, field_name);
            }
        },
        total: ?ReservationAggregates = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .utilizations_by_time = "UtilizationsByTime",
                .total = "Total",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const get_rightsizing_recommendation: struct {
    action_name: []const u8 = "GetRightsizingRecommendation",
    Request: type = struct {
        filter: ?Expression = null,
        configuration: ?RightsizingRecommendationConfiguration = null,
        service: []const u8,
        page_size: ?i64 = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .configuration = "Configuration",
                .service = "Service",
                .page_size = "PageSize",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rightsizing_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = get_rightsizing_recommendation };
        }
    },
    Response: type = struct {
        metadata: ?struct {
            recommendation_id: ?[]const u8 = null,
            generation_timestamp: ?[]const u8 = null,
            lookback_period_in_days: ?[]const u8 = null,
            additional_metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_id = "RecommendationId",
                    .generation_timestamp = "GenerationTimestamp",
                    .lookback_period_in_days = "LookbackPeriodInDays",
                    .additional_metadata = "AdditionalMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        summary: ?struct {
            total_recommendation_count: ?[]const u8 = null,
            estimated_total_monthly_savings_amount: ?[]const u8 = null,
            savings_currency_code: ?[]const u8 = null,
            savings_percentage: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .total_recommendation_count = "TotalRecommendationCount",
                    .estimated_total_monthly_savings_amount = "EstimatedTotalMonthlySavingsAmount",
                    .savings_currency_code = "SavingsCurrencyCode",
                    .savings_percentage = "SavingsPercentage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        rightsizing_recommendations: ?[]struct {
            account_id: ?[]const u8 = null,
            current_instance: ?struct {
                resource_id: ?[]const u8 = null,
                instance_name: ?[]const u8 = null,
                tags: ?[]TagValues = null,
                resource_details: ?ResourceDetails = null,
                resource_utilization: ?ResourceUtilization = null,
                reservation_covered_hours_in_lookback_period: ?[]const u8 = null,
                savings_plans_covered_hours_in_lookback_period: ?[]const u8 = null,
                on_demand_hours_in_lookback_period: ?[]const u8 = null,
                total_running_hours_in_lookback_period: ?[]const u8 = null,
                monthly_cost: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_id = "ResourceId",
                        .instance_name = "InstanceName",
                        .tags = "Tags",
                        .resource_details = "ResourceDetails",
                        .resource_utilization = "ResourceUtilization",
                        .reservation_covered_hours_in_lookback_period = "ReservationCoveredHoursInLookbackPeriod",
                        .savings_plans_covered_hours_in_lookback_period = "SavingsPlansCoveredHoursInLookbackPeriod",
                        .on_demand_hours_in_lookback_period = "OnDemandHoursInLookbackPeriod",
                        .total_running_hours_in_lookback_period = "TotalRunningHoursInLookbackPeriod",
                        .monthly_cost = "MonthlyCost",
                        .currency_code = "CurrencyCode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            rightsizing_type: ?[]const u8 = null,
            modify_recommendation_detail: ?struct {
                target_instances: ?[]struct {
                    estimated_monthly_cost: ?[]const u8 = null,
                    estimated_monthly_savings: ?[]const u8 = null,
                    currency_code: ?[]const u8 = null,
                    default_target_instance: ?bool = null,
                    resource_details: ?ResourceDetails = null,
                    expected_resource_utilization: ?ResourceUtilization = null,
                    platform_differences: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .estimated_monthly_cost = "EstimatedMonthlyCost",
                            .estimated_monthly_savings = "EstimatedMonthlySavings",
                            .currency_code = "CurrencyCode",
                            .default_target_instance = "DefaultTargetInstance",
                            .resource_details = "ResourceDetails",
                            .expected_resource_utilization = "ExpectedResourceUtilization",
                            .platform_differences = "PlatformDifferences",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .target_instances = "TargetInstances",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            terminate_recommendation_detail: ?struct {
                estimated_monthly_savings: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .estimated_monthly_savings = "EstimatedMonthlySavings",
                        .currency_code = "CurrencyCode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            finding_reason_codes: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .current_instance = "CurrentInstance",
                    .rightsizing_type = "RightsizingType",
                    .modify_recommendation_detail = "ModifyRecommendationDetail",
                    .terminate_recommendation_detail = "TerminateRecommendationDetail",
                    .finding_reason_codes = "FindingReasonCodes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,
        configuration: ?RightsizingRecommendationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .summary = "Summary",
                .rightsizing_recommendations = "RightsizingRecommendations",
                .next_page_token = "NextPageToken",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const get_savings_plan_purchase_recommendation_details: struct {
    action_name: []const u8 = "GetSavingsPlanPurchaseRecommendationDetails",
    Request: type = struct {
        recommendation_detail_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_detail_id = "RecommendationDetailId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_savings_plan_purchase_recommendation_details) } {
            return .{ .service_metadata = service_metadata, .action = get_savings_plan_purchase_recommendation_details };
        }
    },
    Response: type = struct {
        recommendation_detail_id: ?[]const u8 = null,
        recommendation_detail_data: ?struct {
            account_scope: ?[]const u8 = null,
            lookback_period_in_days: ?[]const u8 = null,
            savings_plans_type: ?[]const u8 = null,
            term_in_years: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            currency_code: ?[]const u8 = null,
            instance_family: ?[]const u8 = null,
            region: ?[]const u8 = null,
            offering_id: ?[]const u8 = null,
            generation_timestamp: ?[]const u8 = null,
            latest_usage_timestamp: ?[]const u8 = null,
            current_average_hourly_on_demand_spend: ?[]const u8 = null,
            current_maximum_hourly_on_demand_spend: ?[]const u8 = null,
            current_minimum_hourly_on_demand_spend: ?[]const u8 = null,
            estimated_average_utilization: ?[]const u8 = null,
            estimated_monthly_savings_amount: ?[]const u8 = null,
            estimated_on_demand_cost: ?[]const u8 = null,
            estimated_on_demand_cost_with_current_commitment: ?[]const u8 = null,
            estimated_roi: ?[]const u8 = null,
            estimated_sp_cost: ?[]const u8 = null,
            estimated_savings_amount: ?[]const u8 = null,
            estimated_savings_percentage: ?[]const u8 = null,
            existing_hourly_commitment: ?[]const u8 = null,
            hourly_commitment_to_purchase: ?[]const u8 = null,
            upfront_cost: ?[]const u8 = null,
            current_average_coverage: ?[]const u8 = null,
            estimated_average_coverage: ?[]const u8 = null,
            metrics_over_lookback_period: ?[]struct {
                start_time: ?[]const u8 = null,
                estimated_on_demand_cost: ?[]const u8 = null,
                current_coverage: ?[]const u8 = null,
                estimated_coverage: ?[]const u8 = null,
                estimated_new_commitment_utilization: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_time = "StartTime",
                        .estimated_on_demand_cost = "EstimatedOnDemandCost",
                        .current_coverage = "CurrentCoverage",
                        .estimated_coverage = "EstimatedCoverage",
                        .estimated_new_commitment_utilization = "EstimatedNewCommitmentUtilization",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_scope = "AccountScope",
                    .lookback_period_in_days = "LookbackPeriodInDays",
                    .savings_plans_type = "SavingsPlansType",
                    .term_in_years = "TermInYears",
                    .payment_option = "PaymentOption",
                    .account_id = "AccountId",
                    .currency_code = "CurrencyCode",
                    .instance_family = "InstanceFamily",
                    .region = "Region",
                    .offering_id = "OfferingId",
                    .generation_timestamp = "GenerationTimestamp",
                    .latest_usage_timestamp = "LatestUsageTimestamp",
                    .current_average_hourly_on_demand_spend = "CurrentAverageHourlyOnDemandSpend",
                    .current_maximum_hourly_on_demand_spend = "CurrentMaximumHourlyOnDemandSpend",
                    .current_minimum_hourly_on_demand_spend = "CurrentMinimumHourlyOnDemandSpend",
                    .estimated_average_utilization = "EstimatedAverageUtilization",
                    .estimated_monthly_savings_amount = "EstimatedMonthlySavingsAmount",
                    .estimated_on_demand_cost = "EstimatedOnDemandCost",
                    .estimated_on_demand_cost_with_current_commitment = "EstimatedOnDemandCostWithCurrentCommitment",
                    .estimated_roi = "EstimatedROI",
                    .estimated_sp_cost = "EstimatedSPCost",
                    .estimated_savings_amount = "EstimatedSavingsAmount",
                    .estimated_savings_percentage = "EstimatedSavingsPercentage",
                    .existing_hourly_commitment = "ExistingHourlyCommitment",
                    .hourly_commitment_to_purchase = "HourlyCommitmentToPurchase",
                    .upfront_cost = "UpfrontCost",
                    .current_average_coverage = "CurrentAverageCoverage",
                    .estimated_average_coverage = "EstimatedAverageCoverage",
                    .metrics_over_lookback_period = "MetricsOverLookbackPeriod",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_detail_id = "RecommendationDetailId",
                .recommendation_detail_data = "RecommendationDetailData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        LimitExceeded,
    },
} = .{};
pub const get_savings_plans_coverage: struct {
    action_name: []const u8 = "GetSavingsPlansCoverage",
    Request: type = struct {
        time_period: DateInterval,
        group_by: ?[]GroupDefinition = null,
        granularity: ?[]const u8 = null,
        filter: ?Expression = null,
        metrics: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_by: ?SortDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .group_by = "GroupBy",
                .granularity = "Granularity",
                .filter = "Filter",
                .metrics = "Metrics",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_savings_plans_coverage) } {
            return .{ .service_metadata = service_metadata, .action = get_savings_plans_coverage };
        }
    },
    Response: type = struct {
        savings_plans_coverages: []struct {
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            coverage: ?struct {
                spend_covered_by_savings_plans: ?[]const u8 = null,
                on_demand_cost: ?[]const u8 = null,
                total_cost: ?[]const u8 = null,
                coverage_percentage: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .spend_covered_by_savings_plans = "SpendCoveredBySavingsPlans",
                        .on_demand_cost = "OnDemandCost",
                        .total_cost = "TotalCost",
                        .coverage_percentage = "CoveragePercentage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            time_period: ?DateInterval = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attributes = "Attributes",
                    .coverage = "Coverage",
                    .time_period = "TimePeriod",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plans_coverages = "SavingsPlansCoverages",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const get_savings_plans_purchase_recommendation: struct {
    action_name: []const u8 = "GetSavingsPlansPurchaseRecommendation",
    Request: type = struct {
        savings_plans_type: []const u8,
        term_in_years: []const u8,
        payment_option: []const u8,
        account_scope: ?[]const u8 = null,
        next_page_token: ?[]const u8 = null,
        page_size: ?i64 = null,
        lookback_period_in_days: []const u8,
        filter: ?Expression = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plans_type = "SavingsPlansType",
                .term_in_years = "TermInYears",
                .payment_option = "PaymentOption",
                .account_scope = "AccountScope",
                .next_page_token = "NextPageToken",
                .page_size = "PageSize",
                .lookback_period_in_days = "LookbackPeriodInDays",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_savings_plans_purchase_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = get_savings_plans_purchase_recommendation };
        }
    },
    Response: type = struct {
        metadata: ?struct {
            recommendation_id: ?[]const u8 = null,
            generation_timestamp: ?[]const u8 = null,
            additional_metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_id = "RecommendationId",
                    .generation_timestamp = "GenerationTimestamp",
                    .additional_metadata = "AdditionalMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        savings_plans_purchase_recommendation: ?struct {
            account_scope: ?[]const u8 = null,
            savings_plans_type: ?[]const u8 = null,
            term_in_years: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            lookback_period_in_days: ?[]const u8 = null,
            savings_plans_purchase_recommendation_details: ?[]struct {
                savings_plans_details: ?struct {
                    region: ?[]const u8 = null,
                    instance_family: ?[]const u8 = null,
                    offering_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .region = "Region",
                            .instance_family = "InstanceFamily",
                            .offering_id = "OfferingId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                account_id: ?[]const u8 = null,
                upfront_cost: ?[]const u8 = null,
                estimated_roi: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,
                estimated_sp_cost: ?[]const u8 = null,
                estimated_on_demand_cost: ?[]const u8 = null,
                estimated_on_demand_cost_with_current_commitment: ?[]const u8 = null,
                estimated_savings_amount: ?[]const u8 = null,
                estimated_savings_percentage: ?[]const u8 = null,
                hourly_commitment_to_purchase: ?[]const u8 = null,
                estimated_average_utilization: ?[]const u8 = null,
                estimated_monthly_savings_amount: ?[]const u8 = null,
                current_minimum_hourly_on_demand_spend: ?[]const u8 = null,
                current_maximum_hourly_on_demand_spend: ?[]const u8 = null,
                current_average_hourly_on_demand_spend: ?[]const u8 = null,
                recommendation_detail_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .savings_plans_details = "SavingsPlansDetails",
                        .account_id = "AccountId",
                        .upfront_cost = "UpfrontCost",
                        .estimated_roi = "EstimatedROI",
                        .currency_code = "CurrencyCode",
                        .estimated_sp_cost = "EstimatedSPCost",
                        .estimated_on_demand_cost = "EstimatedOnDemandCost",
                        .estimated_on_demand_cost_with_current_commitment = "EstimatedOnDemandCostWithCurrentCommitment",
                        .estimated_savings_amount = "EstimatedSavingsAmount",
                        .estimated_savings_percentage = "EstimatedSavingsPercentage",
                        .hourly_commitment_to_purchase = "HourlyCommitmentToPurchase",
                        .estimated_average_utilization = "EstimatedAverageUtilization",
                        .estimated_monthly_savings_amount = "EstimatedMonthlySavingsAmount",
                        .current_minimum_hourly_on_demand_spend = "CurrentMinimumHourlyOnDemandSpend",
                        .current_maximum_hourly_on_demand_spend = "CurrentMaximumHourlyOnDemandSpend",
                        .current_average_hourly_on_demand_spend = "CurrentAverageHourlyOnDemandSpend",
                        .recommendation_detail_id = "RecommendationDetailId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            savings_plans_purchase_recommendation_summary: ?struct {
                estimated_roi: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,
                estimated_total_cost: ?[]const u8 = null,
                current_on_demand_spend: ?[]const u8 = null,
                estimated_savings_amount: ?[]const u8 = null,
                total_recommendation_count: ?[]const u8 = null,
                daily_commitment_to_purchase: ?[]const u8 = null,
                hourly_commitment_to_purchase: ?[]const u8 = null,
                estimated_savings_percentage: ?[]const u8 = null,
                estimated_monthly_savings_amount: ?[]const u8 = null,
                estimated_on_demand_cost_with_current_commitment: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .estimated_roi = "EstimatedROI",
                        .currency_code = "CurrencyCode",
                        .estimated_total_cost = "EstimatedTotalCost",
                        .current_on_demand_spend = "CurrentOnDemandSpend",
                        .estimated_savings_amount = "EstimatedSavingsAmount",
                        .total_recommendation_count = "TotalRecommendationCount",
                        .daily_commitment_to_purchase = "DailyCommitmentToPurchase",
                        .hourly_commitment_to_purchase = "HourlyCommitmentToPurchase",
                        .estimated_savings_percentage = "EstimatedSavingsPercentage",
                        .estimated_monthly_savings_amount = "EstimatedMonthlySavingsAmount",
                        .estimated_on_demand_cost_with_current_commitment = "EstimatedOnDemandCostWithCurrentCommitment",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_scope = "AccountScope",
                    .savings_plans_type = "SavingsPlansType",
                    .term_in_years = "TermInYears",
                    .payment_option = "PaymentOption",
                    .lookback_period_in_days = "LookbackPeriodInDays",
                    .savings_plans_purchase_recommendation_details = "SavingsPlansPurchaseRecommendationDetails",
                    .savings_plans_purchase_recommendation_summary = "SavingsPlansPurchaseRecommendationSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .savings_plans_purchase_recommendation = "SavingsPlansPurchaseRecommendation",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const get_savings_plans_utilization: struct {
    action_name: []const u8 = "GetSavingsPlansUtilization",
    Request: type = struct {
        time_period: DateInterval,
        granularity: ?[]const u8 = null,
        filter: ?Expression = null,
        sort_by: ?SortDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .granularity = "Granularity",
                .filter = "Filter",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_savings_plans_utilization) } {
            return .{ .service_metadata = service_metadata, .action = get_savings_plans_utilization };
        }
    },
    Response: type = struct {
        savings_plans_utilizations_by_time: ?[]struct {
            time_period: DateInterval,
            utilization: SavingsPlansUtilization,
            savings: ?SavingsPlansSavings = null,
            amortized_commitment: ?SavingsPlansAmortizedCommitment = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time_period = "TimePeriod",
                    .utilization = "Utilization",
                    .savings = "Savings",
                    .amortized_commitment = "AmortizedCommitment",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total: SavingsPlansUtilizationAggregates,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plans_utilizations_by_time = "SavingsPlansUtilizationsByTime",
                .total = "Total",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        LimitExceeded,
    },
} = .{};
pub const get_savings_plans_utilization_details: struct {
    action_name: []const u8 = "GetSavingsPlansUtilizationDetails",
    Request: type = struct {
        time_period: DateInterval,
        filter: ?Expression = null,
        data_type: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_by: ?SortDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .filter = "Filter",
                .data_type = "DataType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_savings_plans_utilization_details) } {
            return .{ .service_metadata = service_metadata, .action = get_savings_plans_utilization_details };
        }
    },
    Response: type = struct {
        savings_plans_utilization_details: []struct {
            savings_plan_arn: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            utilization: ?SavingsPlansUtilization = null,
            savings: ?SavingsPlansSavings = null,
            amortized_commitment: ?SavingsPlansAmortizedCommitment = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .savings_plan_arn = "SavingsPlanArn",
                    .attributes = "Attributes",
                    .utilization = "Utilization",
                    .savings = "Savings",
                    .amortized_commitment = "AmortizedCommitment",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },
        total: ?SavingsPlansUtilizationAggregates = null,
        time_period: DateInterval,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plans_utilization_details = "SavingsPlansUtilizationDetails",
                .total = "Total",
                .time_period = "TimePeriod",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const get_tags: struct {
    action_name: []const u8 = "GetTags",
    Request: type = struct {
        search_string: ?[]const u8 = null,
        time_period: DateInterval,
        tag_key: ?[]const u8 = null,
        filter: ?Expression = null,
        sort_by: ?[]SortDefinition = null,
        max_results: ?i64 = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .search_string = "SearchString",
                .time_period = "TimePeriod",
                .tag_key = "TagKey",
                .filter = "Filter",
                .sort_by = "SortBy",
                .max_results = "MaxResults",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_tags) } {
            return .{ .service_metadata = service_metadata, .action = get_tags };
        }
    },
    Response: type = struct {
        next_page_token: ?[]const u8 = null,
        tags: [][]const u8,
        return_size: i64,
        total_size: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_page_token = "NextPageToken",
                .tags = "Tags",
                .return_size = "ReturnSize",
                .total_size = "TotalSize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BillExpiration,
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
        RequestChanged,
    },
} = .{};
pub const get_usage_forecast: struct {
    action_name: []const u8 = "GetUsageForecast",
    Request: type = struct {
        time_period: DateInterval,
        metric: []const u8,
        granularity: []const u8,
        filter: ?Expression = null,
        prediction_interval_level: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_period = "TimePeriod",
                .metric = "Metric",
                .granularity = "Granularity",
                .filter = "Filter",
                .prediction_interval_level = "PredictionIntervalLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage_forecast) } {
            return .{ .service_metadata = service_metadata, .action = get_usage_forecast };
        }
    },
    Response: type = struct {
        total: ?MetricValue = null,
        forecast_results_by_time: ?[]ForecastResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .total = "Total",
                .forecast_results_by_time = "ForecastResultsByTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        LimitExceeded,
        UnresolvableUsageUnit,
    },
} = .{};
pub const list_cost_allocation_tags: struct {
    action_name: []const u8 = "ListCostAllocationTags",
    Request: type = struct {
        status: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .tag_keys = "TagKeys",
                .type = "Type",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cost_allocation_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_cost_allocation_tags };
        }
    },
    Response: type = struct {
        cost_allocation_tags: ?[]struct {
            tag_key: []const u8,
            type: []const u8,
            status: []const u8,
            last_updated_date: ?[]const u8 = null,
            last_used_date: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_key = "TagKey",
                    .type = "Type",
                    .status = "Status",
                    .last_updated_date = "LastUpdatedDate",
                    .last_used_date = "LastUsedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_allocation_tags = "CostAllocationTags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const list_cost_category_definitions: struct {
    action_name: []const u8 = "ListCostCategoryDefinitions",
    Request: type = struct {
        effective_on: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effective_on = "EffectiveOn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cost_category_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_cost_category_definitions };
        }
    },
    Response: type = struct {
        cost_category_references: ?[]struct {
            cost_category_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            effective_start: ?[]const u8 = null,
            effective_end: ?[]const u8 = null,
            number_of_rules: ?i64 = null,
            processing_status: ?[]CostCategoryProcessingStatus = null,
            values: ?[][]const u8 = null,
            default_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cost_category_arn = "CostCategoryArn",
                    .name = "Name",
                    .effective_start = "EffectiveStart",
                    .effective_end = "EffectiveEnd",
                    .number_of_rules = "NumberOfRules",
                    .processing_status = "ProcessingStatus",
                    .values = "Values",
                    .default_value = "DefaultValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_category_references = "CostCategoryReferences",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const list_savings_plans_purchase_recommendation_generation: struct {
    action_name: []const u8 = "ListSavingsPlansPurchaseRecommendationGeneration",
    Request: type = struct {
        generation_status: ?[]const u8 = null,
        recommendation_ids: ?[][]const u8 = null,
        page_size: ?i64 = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .generation_status = "GenerationStatus",
                .recommendation_ids = "RecommendationIds",
                .page_size = "PageSize",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_savings_plans_purchase_recommendation_generation) } {
            return .{ .service_metadata = service_metadata, .action = list_savings_plans_purchase_recommendation_generation };
        }
    },
    Response: type = struct {
        generation_summary_list: ?[]struct {
            recommendation_id: ?[]const u8 = null,
            generation_status: ?[]const u8 = null,
            generation_started_time: ?[]const u8 = null,
            generation_completion_time: ?[]const u8 = null,
            estimated_completion_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_id = "RecommendationId",
                    .generation_status = "GenerationStatus",
                    .generation_started_time = "GenerationStartedTime",
                    .generation_completion_time = "GenerationCompletionTime",
                    .estimated_completion_time = "EstimatedCompletionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .generation_summary_list = "GenerationSummaryList",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        InvalidNextToken,
        LimitExceeded,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_tags: ?[]ResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const provide_anomaly_feedback: struct {
    action_name: []const u8 = "ProvideAnomalyFeedback",
    Request: type = struct {
        anomaly_id: []const u8,
        feedback: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_id = "AnomalyId",
                .feedback = "Feedback",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provide_anomaly_feedback) } {
            return .{ .service_metadata = service_metadata, .action = provide_anomaly_feedback };
        }
    },
    Response: type = struct {
        anomaly_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_id = "AnomalyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const start_savings_plans_purchase_recommendation_generation: struct {
    action_name: []const u8 = "StartSavingsPlansPurchaseRecommendationGeneration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_savings_plans_purchase_recommendation_generation) } {
            return .{ .service_metadata = service_metadata, .action = start_savings_plans_purchase_recommendation_generation };
        }
    },
    Response: type = struct {
        recommendation_id: ?[]const u8 = null,
        generation_started_time: ?[]const u8 = null,
        estimated_completion_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_id = "RecommendationId",
                .generation_started_time = "GenerationStartedTime",
                .estimated_completion_time = "EstimatedCompletionTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DataUnavailable,
        GenerationExists,
        LimitExceeded,
        ServiceQuotaExceeded,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        resource_tags: []ResourceTag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        resource_tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_tag_keys = "ResourceTagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_anomaly_monitor: struct {
    action_name: []const u8 = "UpdateAnomalyMonitor",
    Request: type = struct {
        monitor_arn: []const u8,
        monitor_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitor_arn = "MonitorArn",
                .monitor_name = "MonitorName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_anomaly_monitor) } {
            return .{ .service_metadata = service_metadata, .action = update_anomaly_monitor };
        }
    },
    Response: type = struct {
        monitor_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitor_arn = "MonitorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        UnknownMonitor,
    },
} = .{};
pub const update_anomaly_subscription: struct {
    action_name: []const u8 = "UpdateAnomalySubscription",
    Request: type = struct {
        subscription_arn: []const u8,
        threshold: ?f64 = null,
        frequency: ?[]const u8 = null,
        monitor_arn_list: ?[][]const u8 = null,
        subscribers: ?[]Subscriber = null,
        subscription_name: ?[]const u8 = null,
        threshold_expression: ?Expression = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
                .threshold = "Threshold",
                .frequency = "Frequency",
                .monitor_arn_list = "MonitorArnList",
                .subscribers = "Subscribers",
                .subscription_name = "SubscriptionName",
                .threshold_expression = "ThresholdExpression",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_anomaly_subscription) } {
            return .{ .service_metadata = service_metadata, .action = update_anomaly_subscription };
        }
    },
    Response: type = struct {
        subscription_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        UnknownMonitor,
        UnknownSubscription,
    },
} = .{};
pub const update_cost_allocation_tags_status: struct {
    action_name: []const u8 = "UpdateCostAllocationTagsStatus",
    Request: type = struct {
        cost_allocation_tags_status: []struct {
            tag_key: []const u8,
            status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_key = "TagKey",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_allocation_tags_status = "CostAllocationTagsStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cost_allocation_tags_status) } {
            return .{ .service_metadata = service_metadata, .action = update_cost_allocation_tags_status };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            tag_key: ?[]const u8 = null,
            code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_key = "TagKey",
                    .code = "Code",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const update_cost_category_definition: struct {
    action_name: []const u8 = "UpdateCostCategoryDefinition",
    Request: type = struct {
        cost_category_arn: []const u8,
        effective_start: ?[]const u8 = null,
        rule_version: []const u8,
        rules: []CostCategoryRule,
        default_value: ?[]const u8 = null,
        split_charge_rules: ?[]CostCategorySplitChargeRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_category_arn = "CostCategoryArn",
                .effective_start = "EffectiveStart",
                .rule_version = "RuleVersion",
                .rules = "Rules",
                .default_value = "DefaultValue",
                .split_charge_rules = "SplitChargeRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cost_category_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_cost_category_definition };
        }
    },
    Response: type = struct {
        cost_category_arn: ?[]const u8 = null,
        effective_start: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cost_category_arn = "CostCategoryArn",
                .effective_start = "EffectiveStart",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
    },
} = .{};

pub const CostCategorySplitChargeRule = struct {
    source: []const u8,
    targets: [][]const u8,
    method: []const u8,
    parameters: ?[]CostCategorySplitChargeRuleParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
            .targets = "Targets",
            .method = "Method",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }
};

pub const CostCategorySplitChargeRuleParameter = struct {
    type: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const CostCategoryRule = struct {
    value: ?[]const u8 = null,
    rule: ?Expression = null,
    inherited_value: ?CostCategoryInheritedValueDimension = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .rule = "Rule",
            .inherited_value = "InheritedValue",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const CostCategoryInheritedValueDimension = struct {
    dimension_name: ?[]const u8 = null,
    dimension_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_name = "DimensionName",
            .dimension_key = "DimensionKey",
        };
        return @field(mappings, field_name);
    }
};

pub const Expression = struct {
    @"or": ?[]Expression = null,
    @"and": ?[]Expression = null,
    @"not": ?Expression = null,
    dimensions: ?DimensionValues = null,
    tags: ?TagValues = null,
    cost_categories: ?CostCategoryValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .@"or" = "Or",
            .@"and" = "And",
            .@"not" = "Not",
            .dimensions = "Dimensions",
            .tags = "Tags",
            .cost_categories = "CostCategories",
        };
        return @field(mappings, field_name);
    }
};

pub const CostCategoryValues = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,
    match_options: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
            .match_options = "MatchOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TagValues = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,
    match_options: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
            .match_options = "MatchOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DimensionValues = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,
    match_options: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
            .match_options = "MatchOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const Subscriber = struct {
    address: ?[]const u8 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .type = "Type",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceTag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const CostCategoryProcessingStatus = struct {
    component: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component = "Component",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ForecastResult = struct {
    time_period: ?DateInterval = null,
    mean_value: ?[]const u8 = null,
    prediction_interval_lower_bound: ?[]const u8 = null,
    prediction_interval_upper_bound: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_period = "TimePeriod",
            .mean_value = "MeanValue",
            .prediction_interval_lower_bound = "PredictionIntervalLowerBound",
            .prediction_interval_upper_bound = "PredictionIntervalUpperBound",
        };
        return @field(mappings, field_name);
    }
};

pub const DateInterval = struct {
    start: []const u8,
    end: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start = "Start",
            .end = "End",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricValue = struct {
    amount: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amount = "Amount",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const SortDefinition = struct {
    key: []const u8,
    sort_order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .sort_order = "SortOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const SavingsPlansUtilizationAggregates = struct {
    utilization: SavingsPlansUtilization,
    savings: ?SavingsPlansSavings = null,
    amortized_commitment: ?SavingsPlansAmortizedCommitment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .utilization = "Utilization",
            .savings = "Savings",
            .amortized_commitment = "AmortizedCommitment",
        };
        return @field(mappings, field_name);
    }
};

pub const SavingsPlansAmortizedCommitment = struct {
    amortized_recurring_commitment: ?[]const u8 = null,
    amortized_upfront_commitment: ?[]const u8 = null,
    total_amortized_commitment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amortized_recurring_commitment = "AmortizedRecurringCommitment",
            .amortized_upfront_commitment = "AmortizedUpfrontCommitment",
            .total_amortized_commitment = "TotalAmortizedCommitment",
        };
        return @field(mappings, field_name);
    }
};

pub const SavingsPlansSavings = struct {
    net_savings: ?[]const u8 = null,
    on_demand_cost_equivalent: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .net_savings = "NetSavings",
            .on_demand_cost_equivalent = "OnDemandCostEquivalent",
        };
        return @field(mappings, field_name);
    }
};

pub const SavingsPlansUtilization = struct {
    total_commitment: ?[]const u8 = null,
    used_commitment: ?[]const u8 = null,
    unused_commitment: ?[]const u8 = null,
    utilization_percentage: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_commitment = "TotalCommitment",
            .used_commitment = "UsedCommitment",
            .unused_commitment = "UnusedCommitment",
            .utilization_percentage = "UtilizationPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupDefinition = struct {
    type: ?[]const u8 = null,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const RightsizingRecommendationConfiguration = struct {
    recommendation_target: []const u8,
    benefits_considered: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recommendation_target = "RecommendationTarget",
            .benefits_considered = "BenefitsConsidered",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceUtilization = struct {
    ec2_resource_utilization: ?EC2ResourceUtilization = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ec2_resource_utilization = "EC2ResourceUtilization",
        };
        return @field(mappings, field_name);
    }
};

pub const EC2ResourceUtilization = struct {
    max_cpu_utilization_percentage: ?[]const u8 = null,
    max_memory_utilization_percentage: ?[]const u8 = null,
    max_storage_utilization_percentage: ?[]const u8 = null,
    ebs_resource_utilization: ?EBSResourceUtilization = null,
    disk_resource_utilization: ?DiskResourceUtilization = null,
    network_resource_utilization: ?NetworkResourceUtilization = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_cpu_utilization_percentage = "MaxCpuUtilizationPercentage",
            .max_memory_utilization_percentage = "MaxMemoryUtilizationPercentage",
            .max_storage_utilization_percentage = "MaxStorageUtilizationPercentage",
            .ebs_resource_utilization = "EBSResourceUtilization",
            .disk_resource_utilization = "DiskResourceUtilization",
            .network_resource_utilization = "NetworkResourceUtilization",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkResourceUtilization = struct {
    network_in_bytes_per_second: ?[]const u8 = null,
    network_out_bytes_per_second: ?[]const u8 = null,
    network_packets_in_per_second: ?[]const u8 = null,
    network_packets_out_per_second: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_in_bytes_per_second = "NetworkInBytesPerSecond",
            .network_out_bytes_per_second = "NetworkOutBytesPerSecond",
            .network_packets_in_per_second = "NetworkPacketsInPerSecond",
            .network_packets_out_per_second = "NetworkPacketsOutPerSecond",
        };
        return @field(mappings, field_name);
    }
};

pub const DiskResourceUtilization = struct {
    disk_read_ops_per_second: ?[]const u8 = null,
    disk_write_ops_per_second: ?[]const u8 = null,
    disk_read_bytes_per_second: ?[]const u8 = null,
    disk_write_bytes_per_second: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disk_read_ops_per_second = "DiskReadOpsPerSecond",
            .disk_write_ops_per_second = "DiskWriteOpsPerSecond",
            .disk_read_bytes_per_second = "DiskReadBytesPerSecond",
            .disk_write_bytes_per_second = "DiskWriteBytesPerSecond",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSResourceUtilization = struct {
    ebs_read_ops_per_second: ?[]const u8 = null,
    ebs_write_ops_per_second: ?[]const u8 = null,
    ebs_read_bytes_per_second: ?[]const u8 = null,
    ebs_write_bytes_per_second: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_read_ops_per_second = "EbsReadOpsPerSecond",
            .ebs_write_ops_per_second = "EbsWriteOpsPerSecond",
            .ebs_read_bytes_per_second = "EbsReadBytesPerSecond",
            .ebs_write_bytes_per_second = "EbsWriteBytesPerSecond",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDetails = struct {
    ec2_resource_details: ?EC2ResourceDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ec2_resource_details = "EC2ResourceDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const EC2ResourceDetails = struct {
    hourly_on_demand_rate: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    region: ?[]const u8 = null,
    sku: ?[]const u8 = null,
    memory: ?[]const u8 = null,
    network_performance: ?[]const u8 = null,
    storage: ?[]const u8 = null,
    vcpu: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hourly_on_demand_rate = "HourlyOnDemandRate",
            .instance_type = "InstanceType",
            .platform = "Platform",
            .region = "Region",
            .sku = "Sku",
            .memory = "Memory",
            .network_performance = "NetworkPerformance",
            .storage = "Storage",
            .vcpu = "Vcpu",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservationAggregates = struct {
    utilization_percentage: ?[]const u8 = null,
    utilization_percentage_in_units: ?[]const u8 = null,
    purchased_hours: ?[]const u8 = null,
    purchased_units: ?[]const u8 = null,
    total_actual_hours: ?[]const u8 = null,
    total_actual_units: ?[]const u8 = null,
    unused_hours: ?[]const u8 = null,
    unused_units: ?[]const u8 = null,
    on_demand_cost_of_ri_hours_used: ?[]const u8 = null,
    net_ri_savings: ?[]const u8 = null,
    total_potential_ri_savings: ?[]const u8 = null,
    amortized_upfront_fee: ?[]const u8 = null,
    amortized_recurring_fee: ?[]const u8 = null,
    total_amortized_fee: ?[]const u8 = null,
    ri_cost_for_unused_hours: ?[]const u8 = null,
    realized_savings: ?[]const u8 = null,
    unrealized_savings: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .utilization_percentage = "UtilizationPercentage",
            .utilization_percentage_in_units = "UtilizationPercentageInUnits",
            .purchased_hours = "PurchasedHours",
            .purchased_units = "PurchasedUnits",
            .total_actual_hours = "TotalActualHours",
            .total_actual_units = "TotalActualUnits",
            .unused_hours = "UnusedHours",
            .unused_units = "UnusedUnits",
            .on_demand_cost_of_ri_hours_used = "OnDemandCostOfRIHoursUsed",
            .net_ri_savings = "NetRISavings",
            .total_potential_ri_savings = "TotalPotentialRISavings",
            .amortized_upfront_fee = "AmortizedUpfrontFee",
            .amortized_recurring_fee = "AmortizedRecurringFee",
            .total_amortized_fee = "TotalAmortizedFee",
            .ri_cost_for_unused_hours = "RICostForUnusedHours",
            .realized_savings = "RealizedSavings",
            .unrealized_savings = "UnrealizedSavings",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceSpecification = struct {
    ec2_specification: ?EC2Specification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ec2_specification = "EC2Specification",
        };
        return @field(mappings, field_name);
    }
};

pub const EC2Specification = struct {
    offering_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .offering_class = "OfferingClass",
        };
        return @field(mappings, field_name);
    }
};

pub const Coverage = struct {
    coverage_hours: ?CoverageHours = null,
    coverage_normalized_units: ?CoverageNormalizedUnits = null,
    coverage_cost: ?CoverageCost = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .coverage_hours = "CoverageHours",
            .coverage_normalized_units = "CoverageNormalizedUnits",
            .coverage_cost = "CoverageCost",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageCost = struct {
    on_demand_cost: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .on_demand_cost = "OnDemandCost",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageNormalizedUnits = struct {
    on_demand_normalized_units: ?[]const u8 = null,
    reserved_normalized_units: ?[]const u8 = null,
    total_running_normalized_units: ?[]const u8 = null,
    coverage_normalized_units_percentage: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .on_demand_normalized_units = "OnDemandNormalizedUnits",
            .reserved_normalized_units = "ReservedNormalizedUnits",
            .total_running_normalized_units = "TotalRunningNormalizedUnits",
            .coverage_normalized_units_percentage = "CoverageNormalizedUnitsPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageHours = struct {
    on_demand_hours: ?[]const u8 = null,
    reserved_hours: ?[]const u8 = null,
    total_running_hours: ?[]const u8 = null,
    coverage_hours_percentage: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .on_demand_hours = "OnDemandHours",
            .reserved_hours = "ReservedHours",
            .total_running_hours = "TotalRunningHours",
            .coverage_hours_percentage = "CoverageHoursPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const DimensionValuesWithAttributes = struct {
    value: ?[]const u8 = null,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .attributes = "Attributes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const ResultByTime = struct {
    time_period: ?DateInterval = null,
    total: ?[]struct {
        key: ?[]const u8 = null,
        value: ?MetricValue = null,
    } = null,
    groups: ?[]Group = null,
    estimated: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_period = "TimePeriod",
            .total = "Total",
            .groups = "Groups",
            .estimated = "Estimated",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "total", field_name))
            return try serializeMap(self.total, self.fieldNameFor("total"), options, out_stream);
        return false;
    }
};

pub const Group = struct {
    keys: ?[][]const u8 = null,
    metrics: ?[]struct {
        key: ?[]const u8 = null,
        value: ?MetricValue = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .keys = "Keys",
            .metrics = "Metrics",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "metrics", field_name))
            return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
        return false;
    }
};

pub const AnomalySubscription = struct {
    subscription_arn: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    monitor_arn_list: [][]const u8,
    subscribers: []Subscriber,
    threshold: ?f64 = null,
    frequency: []const u8,
    subscription_name: []const u8,
    threshold_expression: ?Expression = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subscription_arn = "SubscriptionArn",
            .account_id = "AccountId",
            .monitor_arn_list = "MonitorArnList",
            .subscribers = "Subscribers",
            .threshold = "Threshold",
            .frequency = "Frequency",
            .subscription_name = "SubscriptionName",
            .threshold_expression = "ThresholdExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalyMonitor = struct {
    monitor_arn: ?[]const u8 = null,
    monitor_name: []const u8,
    creation_date: ?[]const u8 = null,
    last_updated_date: ?[]const u8 = null,
    last_evaluated_date: ?[]const u8 = null,
    monitor_type: []const u8,
    monitor_dimension: ?[]const u8 = null,
    monitor_specification: ?Expression = null,
    dimensional_value_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .monitor_arn = "MonitorArn",
            .monitor_name = "MonitorName",
            .creation_date = "CreationDate",
            .last_updated_date = "LastUpdatedDate",
            .last_evaluated_date = "LastEvaluatedDate",
            .monitor_type = "MonitorType",
            .monitor_dimension = "MonitorDimension",
            .monitor_specification = "MonitorSpecification",
            .dimensional_value_count = "DimensionalValueCount",
        };
        return @field(mappings, field_name);
    }
};
