const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-07-26";
pub const sdk_id: []const u8 = "Cost Optimization Hub";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "cost-optimization-hub";
pub const sigv4_name: []const u8 = "cost-optimization-hub";
pub const name: []const u8 = "CostOptimizationHubService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2022-07-26",
    sdk_id: []const u8 = "Cost Optimization Hub",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "cost-optimization-hub",
    sigv4_name: []const u8 = "cost-optimization-hub",
    name: []const u8 = "CostOptimizationHubService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const get_preferences: struct {
    action_name: []const u8 = "GetPreferences",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_preferences) } {
            return .{ .service_metadata = service_metadata, .action = get_preferences };
        }
    },
    Response: type = struct {
        savings_estimation_mode: ?[]const u8 = null,
        member_account_discount_visibility: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_estimation_mode = "savingsEstimationMode",
                .member_account_discount_visibility = "memberAccountDiscountVisibility",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_recommendation: struct {
    action_name: []const u8 = "GetRecommendation",
    Request: type = struct {
        recommendation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_id = "recommendationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = get_recommendation };
        }
    },
    Response: type = struct {
        recommendation_id: ?[]const u8 = null,
        resource_id: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        account_id: ?[]const u8 = null,
        currency_code: ?[]const u8 = null,
        recommendation_lookback_period_in_days: ?i64 = null,
        cost_calculation_lookback_period_in_days: ?i64 = null,
        estimated_savings_percentage: ?f64 = null,
        estimated_savings_over_cost_calculation_lookback_period: ?f64 = null,
        current_resource_type: ?[]const u8 = null,
        recommended_resource_type: ?[]const u8 = null,
        region: ?[]const u8 = null,
        source: ?[]const u8 = null,
        last_refresh_timestamp: ?i64 = null,
        estimated_monthly_savings: ?f64 = null,
        estimated_monthly_cost: ?f64 = null,
        implementation_effort: ?[]const u8 = null,
        restart_needed: ?bool = null,
        action_type: ?[]const u8 = null,
        rollback_possible: ?bool = null,
        current_resource_details: ?ResourceDetails = null,
        recommended_resource_details: ?ResourceDetails = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_id = "recommendationId",
                .resource_id = "resourceId",
                .resource_arn = "resourceArn",
                .account_id = "accountId",
                .currency_code = "currencyCode",
                .recommendation_lookback_period_in_days = "recommendationLookbackPeriodInDays",
                .cost_calculation_lookback_period_in_days = "costCalculationLookbackPeriodInDays",
                .estimated_savings_percentage = "estimatedSavingsPercentage",
                .estimated_savings_over_cost_calculation_lookback_period = "estimatedSavingsOverCostCalculationLookbackPeriod",
                .current_resource_type = "currentResourceType",
                .recommended_resource_type = "recommendedResourceType",
                .region = "region",
                .source = "source",
                .last_refresh_timestamp = "lastRefreshTimestamp",
                .estimated_monthly_savings = "estimatedMonthlySavings",
                .estimated_monthly_cost = "estimatedMonthlyCost",
                .implementation_effort = "implementationEffort",
                .restart_needed = "restartNeeded",
                .action_type = "actionType",
                .rollback_possible = "rollbackPossible",
                .current_resource_details = "currentResourceDetails",
                .recommended_resource_details = "recommendedResourceDetails",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_enrollment_statuses: struct {
    action_name: []const u8 = "ListEnrollmentStatuses",
    Request: type = struct {
        include_organization_info: ?bool = null,
        account_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .include_organization_info = "includeOrganizationInfo",
                .account_id = "accountId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_enrollment_statuses) } {
            return .{ .service_metadata = service_metadata, .action = list_enrollment_statuses };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            last_updated_timestamp: ?i64 = null,
            created_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .status = "status",
                    .last_updated_timestamp = "lastUpdatedTimestamp",
                    .created_timestamp = "createdTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        include_member_accounts: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .include_member_accounts = "includeMemberAccounts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommendations: struct {
    action_name: []const u8 = "ListRecommendations",
    Request: type = struct {
        filter: ?Filter = null,
        order_by: ?struct {
            dimension: ?[]const u8 = null,
            order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimension = "dimension",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        include_all_recommendations: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .order_by = "orderBy",
                .include_all_recommendations = "includeAllRecommendations",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendations };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            recommendation_id: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            region: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            current_resource_type: ?[]const u8 = null,
            recommended_resource_type: ?[]const u8 = null,
            estimated_monthly_savings: ?f64 = null,
            estimated_savings_percentage: ?f64 = null,
            estimated_monthly_cost: ?f64 = null,
            currency_code: ?[]const u8 = null,
            implementation_effort: ?[]const u8 = null,
            restart_needed: ?bool = null,
            action_type: ?[]const u8 = null,
            rollback_possible: ?bool = null,
            current_resource_summary: ?[]const u8 = null,
            recommended_resource_summary: ?[]const u8 = null,
            last_refresh_timestamp: ?i64 = null,
            recommendation_lookback_period_in_days: ?i64 = null,
            source: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_id = "recommendationId",
                    .account_id = "accountId",
                    .region = "region",
                    .resource_id = "resourceId",
                    .resource_arn = "resourceArn",
                    .current_resource_type = "currentResourceType",
                    .recommended_resource_type = "recommendedResourceType",
                    .estimated_monthly_savings = "estimatedMonthlySavings",
                    .estimated_savings_percentage = "estimatedSavingsPercentage",
                    .estimated_monthly_cost = "estimatedMonthlyCost",
                    .currency_code = "currencyCode",
                    .implementation_effort = "implementationEffort",
                    .restart_needed = "restartNeeded",
                    .action_type = "actionType",
                    .rollback_possible = "rollbackPossible",
                    .current_resource_summary = "currentResourceSummary",
                    .recommended_resource_summary = "recommendedResourceSummary",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                    .recommendation_lookback_period_in_days = "recommendationLookbackPeriodInDays",
                    .source = "source",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommendation_summaries: struct {
    action_name: []const u8 = "ListRecommendationSummaries",
    Request: type = struct {
        filter: ?Filter = null,
        group_by: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .group_by = "groupBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendation_summaries) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendation_summaries };
        }
    },
    Response: type = struct {
        estimated_total_deduped_savings: ?f64 = null,
        items: ?[]struct {
            group: ?[]const u8 = null,
            estimated_monthly_savings: ?f64 = null,
            recommendation_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group = "group",
                    .estimated_monthly_savings = "estimatedMonthlySavings",
                    .recommendation_count = "recommendationCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        group_by: ?[]const u8 = null,
        currency_code: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .estimated_total_deduped_savings = "estimatedTotalDedupedSavings",
                .items = "items",
                .group_by = "groupBy",
                .currency_code = "currencyCode",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_enrollment_status: struct {
    action_name: []const u8 = "UpdateEnrollmentStatus",
    Request: type = struct {
        status: []const u8,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_enrollment_status) } {
            return .{ .service_metadata = service_metadata, .action = update_enrollment_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_preferences: struct {
    action_name: []const u8 = "UpdatePreferences",
    Request: type = struct {
        savings_estimation_mode: ?[]const u8 = null,
        member_account_discount_visibility: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_estimation_mode = "savingsEstimationMode",
                .member_account_discount_visibility = "memberAccountDiscountVisibility",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_preferences) } {
            return .{ .service_metadata = service_metadata, .action = update_preferences };
        }
    },
    Response: type = struct {
        savings_estimation_mode: ?[]const u8 = null,
        member_account_discount_visibility: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_estimation_mode = "savingsEstimationMode",
                .member_account_discount_visibility = "memberAccountDiscountVisibility",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const Filter = struct {
    restart_needed: ?bool = null,
    rollback_possible: ?bool = null,
    implementation_efforts: ?[][]const u8 = null,
    account_ids: ?[][]const u8 = null,
    regions: ?[][]const u8 = null,
    resource_types: ?[][]const u8 = null,
    action_types: ?[][]const u8 = null,
    tags: ?[]Tag = null,
    resource_ids: ?[][]const u8 = null,
    resource_arns: ?[][]const u8 = null,
    recommendation_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .restart_needed = "restartNeeded",
            .rollback_possible = "rollbackPossible",
            .implementation_efforts = "implementationEfforts",
            .account_ids = "accountIds",
            .regions = "regions",
            .resource_types = "resourceTypes",
            .action_types = "actionTypes",
            .tags = "tags",
            .resource_ids = "resourceIds",
            .resource_arns = "resourceArns",
            .recommendation_ids = "recommendationIds",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDetails = union {
    lambda_function: ?LambdaFunction,
    ecs_service: ?EcsService,
    ec2_instance: ?Ec2Instance,
    ebs_volume: ?EbsVolume,
    ec2_auto_scaling_group: ?Ec2AutoScalingGroup,
    ec2_reserved_instances: ?Ec2ReservedInstances,
    rds_reserved_instances: ?RdsReservedInstances,
    elasti_cache_reserved_instances: ?ElastiCacheReservedInstances,
    open_search_reserved_instances: ?OpenSearchReservedInstances,
    redshift_reserved_instances: ?RedshiftReservedInstances,
    ec2_instance_savings_plans: ?Ec2InstanceSavingsPlans,
    compute_savings_plans: ?ComputeSavingsPlans,
    sage_maker_savings_plans: ?SageMakerSavingsPlans,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_function = "lambdaFunction",
            .ecs_service = "ecsService",
            .ec2_instance = "ec2Instance",
            .ebs_volume = "ebsVolume",
            .ec2_auto_scaling_group = "ec2AutoScalingGroup",
            .ec2_reserved_instances = "ec2ReservedInstances",
            .rds_reserved_instances = "rdsReservedInstances",
            .elasti_cache_reserved_instances = "elastiCacheReservedInstances",
            .open_search_reserved_instances = "openSearchReservedInstances",
            .redshift_reserved_instances = "redshiftReservedInstances",
            .ec2_instance_savings_plans = "ec2InstanceSavingsPlans",
            .compute_savings_plans = "computeSavingsPlans",
            .sage_maker_savings_plans = "sageMakerSavingsPlans",
        };
        return @field(mappings, field_name);
    }
};

pub const SageMakerSavingsPlans = struct {
    configuration: ?SageMakerSavingsPlansConfiguration = null,
    cost_calculation: ?SavingsPlansCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const SavingsPlansCostCalculation = struct {
    pricing: ?SavingsPlansPricing = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pricing = "pricing",
        };
        return @field(mappings, field_name);
    }
};

pub const SavingsPlansPricing = struct {
    monthly_savings_plans_eligible_cost: ?f64 = null,
    estimated_monthly_commitment: ?f64 = null,
    savings_percentage: ?f64 = null,
    estimated_on_demand_cost: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .monthly_savings_plans_eligible_cost = "monthlySavingsPlansEligibleCost",
            .estimated_monthly_commitment = "estimatedMonthlyCommitment",
            .savings_percentage = "savingsPercentage",
            .estimated_on_demand_cost = "estimatedOnDemandCost",
        };
        return @field(mappings, field_name);
    }
};

pub const SageMakerSavingsPlansConfiguration = struct {
    account_scope: ?[]const u8 = null,
    term: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    hourly_commitment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_scope = "accountScope",
            .term = "term",
            .payment_option = "paymentOption",
            .hourly_commitment = "hourlyCommitment",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeSavingsPlans = struct {
    configuration: ?ComputeSavingsPlansConfiguration = null,
    cost_calculation: ?SavingsPlansCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeSavingsPlansConfiguration = struct {
    account_scope: ?[]const u8 = null,
    term: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    hourly_commitment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_scope = "accountScope",
            .term = "term",
            .payment_option = "paymentOption",
            .hourly_commitment = "hourlyCommitment",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2InstanceSavingsPlans = struct {
    configuration: ?Ec2InstanceSavingsPlansConfiguration = null,
    cost_calculation: ?SavingsPlansCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2InstanceSavingsPlansConfiguration = struct {
    account_scope: ?[]const u8 = null,
    term: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    hourly_commitment: ?[]const u8 = null,
    instance_family: ?[]const u8 = null,
    savings_plans_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_scope = "accountScope",
            .term = "term",
            .payment_option = "paymentOption",
            .hourly_commitment = "hourlyCommitment",
            .instance_family = "instanceFamily",
            .savings_plans_region = "savingsPlansRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftReservedInstances = struct {
    configuration: ?RedshiftReservedInstancesConfiguration = null,
    cost_calculation: ?ReservedInstancesCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedInstancesCostCalculation = struct {
    pricing: ?ReservedInstancesPricing = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pricing = "pricing",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedInstancesPricing = struct {
    estimated_on_demand_cost: ?f64 = null,
    monthly_reservation_eligible_cost: ?f64 = null,
    savings_percentage: ?f64 = null,
    estimated_monthly_amortized_reservation_cost: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .estimated_on_demand_cost = "estimatedOnDemandCost",
            .monthly_reservation_eligible_cost = "monthlyReservationEligibleCost",
            .savings_percentage = "savingsPercentage",
            .estimated_monthly_amortized_reservation_cost = "estimatedMonthlyAmortizedReservationCost",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftReservedInstancesConfiguration = struct {
    account_scope: ?[]const u8 = null,
    service: ?[]const u8 = null,
    normalized_units_to_purchase: ?[]const u8 = null,
    term: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    number_of_instances_to_purchase: ?[]const u8 = null,
    instance_family: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    reserved_instances_region: ?[]const u8 = null,
    size_flex_eligible: ?bool = null,
    current_generation: ?[]const u8 = null,
    upfront_cost: ?[]const u8 = null,
    monthly_recurring_cost: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_scope = "accountScope",
            .service = "service",
            .normalized_units_to_purchase = "normalizedUnitsToPurchase",
            .term = "term",
            .payment_option = "paymentOption",
            .number_of_instances_to_purchase = "numberOfInstancesToPurchase",
            .instance_family = "instanceFamily",
            .instance_type = "instanceType",
            .reserved_instances_region = "reservedInstancesRegion",
            .size_flex_eligible = "sizeFlexEligible",
            .current_generation = "currentGeneration",
            .upfront_cost = "upfrontCost",
            .monthly_recurring_cost = "monthlyRecurringCost",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenSearchReservedInstances = struct {
    configuration: ?OpenSearchReservedInstancesConfiguration = null,
    cost_calculation: ?ReservedInstancesCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenSearchReservedInstancesConfiguration = struct {
    account_scope: ?[]const u8 = null,
    service: ?[]const u8 = null,
    normalized_units_to_purchase: ?[]const u8 = null,
    term: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    number_of_instances_to_purchase: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    reserved_instances_region: ?[]const u8 = null,
    current_generation: ?[]const u8 = null,
    size_flex_eligible: ?bool = null,
    upfront_cost: ?[]const u8 = null,
    monthly_recurring_cost: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_scope = "accountScope",
            .service = "service",
            .normalized_units_to_purchase = "normalizedUnitsToPurchase",
            .term = "term",
            .payment_option = "paymentOption",
            .number_of_instances_to_purchase = "numberOfInstancesToPurchase",
            .instance_type = "instanceType",
            .reserved_instances_region = "reservedInstancesRegion",
            .current_generation = "currentGeneration",
            .size_flex_eligible = "sizeFlexEligible",
            .upfront_cost = "upfrontCost",
            .monthly_recurring_cost = "monthlyRecurringCost",
        };
        return @field(mappings, field_name);
    }
};

pub const ElastiCacheReservedInstances = struct {
    configuration: ?ElastiCacheReservedInstancesConfiguration = null,
    cost_calculation: ?ReservedInstancesCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const ElastiCacheReservedInstancesConfiguration = struct {
    account_scope: ?[]const u8 = null,
    service: ?[]const u8 = null,
    normalized_units_to_purchase: ?[]const u8 = null,
    term: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    number_of_instances_to_purchase: ?[]const u8 = null,
    instance_family: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    reserved_instances_region: ?[]const u8 = null,
    current_generation: ?[]const u8 = null,
    size_flex_eligible: ?bool = null,
    upfront_cost: ?[]const u8 = null,
    monthly_recurring_cost: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_scope = "accountScope",
            .service = "service",
            .normalized_units_to_purchase = "normalizedUnitsToPurchase",
            .term = "term",
            .payment_option = "paymentOption",
            .number_of_instances_to_purchase = "numberOfInstancesToPurchase",
            .instance_family = "instanceFamily",
            .instance_type = "instanceType",
            .reserved_instances_region = "reservedInstancesRegion",
            .current_generation = "currentGeneration",
            .size_flex_eligible = "sizeFlexEligible",
            .upfront_cost = "upfrontCost",
            .monthly_recurring_cost = "monthlyRecurringCost",
        };
        return @field(mappings, field_name);
    }
};

pub const RdsReservedInstances = struct {
    configuration: ?RdsReservedInstancesConfiguration = null,
    cost_calculation: ?ReservedInstancesCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const RdsReservedInstancesConfiguration = struct {
    account_scope: ?[]const u8 = null,
    service: ?[]const u8 = null,
    normalized_units_to_purchase: ?[]const u8 = null,
    term: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    number_of_instances_to_purchase: ?[]const u8 = null,
    instance_family: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    reserved_instances_region: ?[]const u8 = null,
    size_flex_eligible: ?bool = null,
    current_generation: ?[]const u8 = null,
    upfront_cost: ?[]const u8 = null,
    monthly_recurring_cost: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    database_edition: ?[]const u8 = null,
    database_engine: ?[]const u8 = null,
    deployment_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_scope = "accountScope",
            .service = "service",
            .normalized_units_to_purchase = "normalizedUnitsToPurchase",
            .term = "term",
            .payment_option = "paymentOption",
            .number_of_instances_to_purchase = "numberOfInstancesToPurchase",
            .instance_family = "instanceFamily",
            .instance_type = "instanceType",
            .reserved_instances_region = "reservedInstancesRegion",
            .size_flex_eligible = "sizeFlexEligible",
            .current_generation = "currentGeneration",
            .upfront_cost = "upfrontCost",
            .monthly_recurring_cost = "monthlyRecurringCost",
            .license_model = "licenseModel",
            .database_edition = "databaseEdition",
            .database_engine = "databaseEngine",
            .deployment_option = "deploymentOption",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2ReservedInstances = struct {
    configuration: ?Ec2ReservedInstancesConfiguration = null,
    cost_calculation: ?ReservedInstancesCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2ReservedInstancesConfiguration = struct {
    account_scope: ?[]const u8 = null,
    service: ?[]const u8 = null,
    normalized_units_to_purchase: ?[]const u8 = null,
    term: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    number_of_instances_to_purchase: ?[]const u8 = null,
    offering_class: ?[]const u8 = null,
    instance_family: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    reserved_instances_region: ?[]const u8 = null,
    current_generation: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    tenancy: ?[]const u8 = null,
    size_flex_eligible: ?bool = null,
    upfront_cost: ?[]const u8 = null,
    monthly_recurring_cost: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_scope = "accountScope",
            .service = "service",
            .normalized_units_to_purchase = "normalizedUnitsToPurchase",
            .term = "term",
            .payment_option = "paymentOption",
            .number_of_instances_to_purchase = "numberOfInstancesToPurchase",
            .offering_class = "offeringClass",
            .instance_family = "instanceFamily",
            .instance_type = "instanceType",
            .reserved_instances_region = "reservedInstancesRegion",
            .current_generation = "currentGeneration",
            .platform = "platform",
            .tenancy = "tenancy",
            .size_flex_eligible = "sizeFlexEligible",
            .upfront_cost = "upfrontCost",
            .monthly_recurring_cost = "monthlyRecurringCost",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2AutoScalingGroup = struct {
    configuration: ?Ec2AutoScalingGroupConfiguration = null,
    cost_calculation: ?ResourceCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceCostCalculation = struct {
    usages: ?[]Usage = null,
    pricing: ?ResourcePricing = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .usages = "usages",
            .pricing = "pricing",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePricing = struct {
    estimated_cost_before_discounts: ?f64 = null,
    estimated_net_unused_amortized_commitments: ?f64 = null,
    estimated_discounts: ?EstimatedDiscounts = null,
    estimated_cost_after_discounts: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .estimated_cost_before_discounts = "estimatedCostBeforeDiscounts",
            .estimated_net_unused_amortized_commitments = "estimatedNetUnusedAmortizedCommitments",
            .estimated_discounts = "estimatedDiscounts",
            .estimated_cost_after_discounts = "estimatedCostAfterDiscounts",
        };
        return @field(mappings, field_name);
    }
};

pub const EstimatedDiscounts = struct {
    savings_plans_discount: ?f64 = null,
    reserved_instances_discount: ?f64 = null,
    other_discount: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .savings_plans_discount = "savingsPlansDiscount",
            .reserved_instances_discount = "reservedInstancesDiscount",
            .other_discount = "otherDiscount",
        };
        return @field(mappings, field_name);
    }
};

pub const Usage = struct {
    usage_type: ?[]const u8 = null,
    usage_amount: ?f64 = null,
    operation: ?[]const u8 = null,
    product_code: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .usage_type = "usageType",
            .usage_amount = "usageAmount",
            .operation = "operation",
            .product_code = "productCode",
            .unit = "unit",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2AutoScalingGroupConfiguration = struct {
    instance: ?InstanceConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance = "instance",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceConfiguration = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsVolume = struct {
    configuration: ?EbsVolumeConfiguration = null,
    cost_calculation: ?ResourceCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsVolumeConfiguration = struct {
    storage: ?StorageConfiguration = null,
    performance: ?BlockStoragePerformanceConfiguration = null,
    attachment_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage = "storage",
            .performance = "performance",
            .attachment_state = "attachmentState",
        };
        return @field(mappings, field_name);
    }
};

pub const BlockStoragePerformanceConfiguration = struct {
    iops: ?f64 = null,
    throughput: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iops = "iops",
            .throughput = "throughput",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageConfiguration = struct {
    type: ?[]const u8 = null,
    size_in_gb: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .size_in_gb = "sizeInGb",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2Instance = struct {
    configuration: ?Ec2InstanceConfiguration = null,
    cost_calculation: ?ResourceCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2InstanceConfiguration = struct {
    instance: ?InstanceConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance = "instance",
        };
        return @field(mappings, field_name);
    }
};

pub const EcsService = struct {
    configuration: ?EcsServiceConfiguration = null,
    cost_calculation: ?ResourceCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const EcsServiceConfiguration = struct {
    compute: ?ComputeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compute = "compute",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeConfiguration = struct {
    v_cpu: ?f64 = null,
    memory_size_in_mb: ?i64 = null,
    architecture: ?[]const u8 = null,
    platform: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .v_cpu = "vCpu",
            .memory_size_in_mb = "memorySizeInMB",
            .architecture = "architecture",
            .platform = "platform",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunction = struct {
    configuration: ?LambdaFunctionConfiguration = null,
    cost_calculation: ?ResourceCostCalculation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "configuration",
            .cost_calculation = "costCalculation",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionConfiguration = struct {
    compute: ?ComputeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compute = "compute",
        };
        return @field(mappings, field_name);
    }
};
