const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-15";
pub const sdk_id: []const u8 = "Customer Profiles";
pub const arn_namespace: ?[]const u8 = "profile";
pub const endpoint_prefix: []const u8 = "profile";
pub const sigv4_name: []const u8 = "profile";
pub const name: []const u8 = "CustomerProfiles_20200815";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-15",
    sdk_id: []const u8 = "Customer Profiles",
    arn_namespace: ?[]const u8 = "profile",
    endpoint_prefix: []const u8 = "profile",
    sigv4_name: []const u8 = "profile",
    name: []const u8 = "CustomerProfiles_20200815",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_profile_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/keys",
        .success_code = 200,
    };

    action_name: []const u8 = "AddProfileKey",
    Request: type = struct {
        profile_id: []const u8,
        key_name: []const u8,
        values: [][]const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .key_name = "KeyName",
                .values = "Values",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_profile_key) } {
            return .{ .service_metadata = service_metadata, .action = add_profile_key };
        }
    },
    Response: type = struct {
        key_name: ?[]const u8 = null,
        values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_name = "KeyName",
                .values = "Values",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_calculated_attribute_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/calculated-attributes/{CalculatedAttributeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCalculatedAttributeDefinition",
    Request: type = struct {
        domain_name: []const u8,
        calculated_attribute_name: []const u8,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        attribute_details: AttributeDetails,
        conditions: ?Conditions = null,
        statistic: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .calculated_attribute_name = "CalculatedAttributeName",
                .display_name = "DisplayName",
                .description = "Description",
                .attribute_details = "AttributeDetails",
                .conditions = "Conditions",
                .statistic = "Statistic",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_calculated_attribute_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_calculated_attribute_definition };
        }
    },
    Response: type = struct {
        calculated_attribute_name: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        attribute_details: ?AttributeDetails = null,
        conditions: ?Conditions = null,
        statistic: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculated_attribute_name = "CalculatedAttributeName",
                .display_name = "DisplayName",
                .description = "Description",
                .attribute_details = "AttributeDetails",
                .conditions = "Conditions",
                .statistic = "Statistic",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDomain",
    Request: type = struct {
        domain_name: []const u8,
        default_expiration_days: i64,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        matching: ?MatchingRequest = null,
        rule_based_matching: ?RuleBasedMatchingRequest = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .matching = "Matching",
                .rule_based_matching = "RuleBasedMatching",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_domain };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        default_expiration_days: i64,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        matching: ?MatchingResponse = null,
        rule_based_matching: ?RuleBasedMatchingResponse = null,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .matching = "Matching",
                .rule_based_matching = "RuleBasedMatching",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_event_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/event-streams/{EventStreamName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEventStream",
    Request: type = struct {
        domain_name: []const u8,
        uri: []const u8,
        event_stream_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
                .event_stream_name = "EventStreamName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_stream) } {
            return .{ .service_metadata = service_metadata, .action = create_event_stream };
        }
    },
    Response: type = struct {
        event_stream_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_stream_arn = "EventStreamArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_integration_workflow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/workflows/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIntegrationWorkflow",
    Request: type = struct {
        domain_name: []const u8,
        workflow_type: []const u8,
        integration_config: struct {
            appflow_integration: ?struct {
                flow_definition: FlowDefinition,
                batches: ?[]struct {
                    start_time: i64,
                    end_time: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .start_time = "StartTime",
                            .end_time = "EndTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .flow_definition = "FlowDefinition",
                        .batches = "Batches",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .appflow_integration = "AppflowIntegration",
                };
                return @field(mappings, field_name);
            }
        },
        object_type_name: []const u8,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .workflow_type = "WorkflowType",
                .integration_config = "IntegrationConfig",
                .object_type_name = "ObjectTypeName",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_integration_workflow) } {
            return .{ .service_metadata = service_metadata, .action = create_integration_workflow };
        }
    },
    Response: type = struct {
        workflow_id: []const u8,
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_id = "WorkflowId",
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProfile",
    Request: type = struct {
        domain_name: []const u8,
        account_number: ?[]const u8 = null,
        additional_information: ?[]const u8 = null,
        party_type: ?[]const u8 = null,
        business_name: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        middle_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        birth_date: ?[]const u8 = null,
        gender: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,
        mobile_phone_number: ?[]const u8 = null,
        home_phone_number: ?[]const u8 = null,
        business_phone_number: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        personal_email_address: ?[]const u8 = null,
        business_email_address: ?[]const u8 = null,
        address: ?Address = null,
        shipping_address: ?Address = null,
        mailing_address: ?Address = null,
        billing_address: ?Address = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        party_type_string: ?[]const u8 = null,
        gender_string: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .account_number = "AccountNumber",
                .additional_information = "AdditionalInformation",
                .party_type = "PartyType",
                .business_name = "BusinessName",
                .first_name = "FirstName",
                .middle_name = "MiddleName",
                .last_name = "LastName",
                .birth_date = "BirthDate",
                .gender = "Gender",
                .phone_number = "PhoneNumber",
                .mobile_phone_number = "MobilePhoneNumber",
                .home_phone_number = "HomePhoneNumber",
                .business_phone_number = "BusinessPhoneNumber",
                .email_address = "EmailAddress",
                .personal_email_address = "PersonalEmailAddress",
                .business_email_address = "BusinessEmailAddress",
                .address = "Address",
                .shipping_address = "ShippingAddress",
                .mailing_address = "MailingAddress",
                .billing_address = "BillingAddress",
                .attributes = "Attributes",
                .party_type_string = "PartyTypeString",
                .gender_string = "GenderString",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_profile };
        }
    },
    Response: type = struct {
        profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_calculated_attribute_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domains/{DomainName}/calculated-attributes/{CalculatedAttributeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCalculatedAttributeDefinition",
    Request: type = struct {
        domain_name: []const u8,
        calculated_attribute_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .calculated_attribute_name = "CalculatedAttributeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_calculated_attribute_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_calculated_attribute_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_domain: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domains/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDomain",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_event_stream: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domains/{DomainName}/event-streams/{EventStreamName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEventStream",
    Request: type = struct {
        domain_name: []const u8,
        event_stream_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .event_stream_name = "EventStreamName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_stream) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_integration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/integrations/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIntegration",
    Request: type = struct {
        domain_name: []const u8,
        uri: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_integration) } {
            return .{ .service_metadata = service_metadata, .action = delete_integration };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfile",
    Request: type = struct {
        profile_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_profile_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/keys/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfileKey",
    Request: type = struct {
        profile_id: []const u8,
        key_name: []const u8,
        values: [][]const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .key_name = "KeyName",
                .values = "Values",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile_key };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_profile_object: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/objects/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfileObject",
    Request: type = struct {
        profile_id: []const u8,
        profile_object_unique_key: []const u8,
        object_type_name: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .profile_object_unique_key = "ProfileObjectUniqueKey",
                .object_type_name = "ObjectTypeName",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile_object) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile_object };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_profile_object_type: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domains/{DomainName}/object-types/{ObjectTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfileObjectType",
    Request: type = struct {
        domain_name: []const u8,
        object_type_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .object_type_name = "ObjectTypeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile_object_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile_object_type };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_workflow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domains/{DomainName}/workflows/{WorkflowId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkflow",
    Request: type = struct {
        domain_name: []const u8,
        workflow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .workflow_id = "WorkflowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workflow) } {
            return .{ .service_metadata = service_metadata, .action = delete_workflow };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const detect_profile_object_type: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/detect/object-types",
        .success_code = 200,
    };

    action_name: []const u8 = "DetectProfileObjectType",
    Request: type = struct {
        objects: [][]const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .objects = "Objects",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_profile_object_type) } {
            return .{ .service_metadata = service_metadata, .action = detect_profile_object_type };
        }
    },
    Response: type = struct {
        detected_profile_object_types: ?[]struct {
            source_last_updated_timestamp_format: ?[]const u8 = null,
            fields: ?[]struct {
                key: ?[]const u8 = null,
                value: ?ObjectTypeField = null,
            } = null,
            keys: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]ObjectTypeKey = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_last_updated_timestamp_format = "SourceLastUpdatedTimestampFormat",
                    .fields = "Fields",
                    .keys = "Keys",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "fields", field_name))
                    return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
                if (std.mem.eql(u8, "keys", field_name))
                    return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detected_profile_object_types = "DetectedProfileObjectTypes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_auto_merging_preview: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/identity-resolution-jobs/auto-merging-preview",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAutoMergingPreview",
    Request: type = struct {
        domain_name: []const u8,
        consolidation: Consolidation,
        conflict_resolution: ConflictResolution,
        min_allowed_confidence_score_for_merging: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .consolidation = "Consolidation",
                .conflict_resolution = "ConflictResolution",
                .min_allowed_confidence_score_for_merging = "MinAllowedConfidenceScoreForMerging",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_auto_merging_preview) } {
            return .{ .service_metadata = service_metadata, .action = get_auto_merging_preview };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        number_of_matches_in_sample: ?i64 = null,
        number_of_profiles_in_sample: ?i64 = null,
        number_of_profiles_will_be_merged: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .number_of_matches_in_sample = "NumberOfMatchesInSample",
                .number_of_profiles_in_sample = "NumberOfProfilesInSample",
                .number_of_profiles_will_be_merged = "NumberOfProfilesWillBeMerged",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_calculated_attribute_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/calculated-attributes/{CalculatedAttributeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCalculatedAttributeDefinition",
    Request: type = struct {
        domain_name: []const u8,
        calculated_attribute_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .calculated_attribute_name = "CalculatedAttributeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_calculated_attribute_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_calculated_attribute_definition };
        }
    },
    Response: type = struct {
        calculated_attribute_name: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        statistic: ?[]const u8 = null,
        conditions: ?Conditions = null,
        attribute_details: ?AttributeDetails = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculated_attribute_name = "CalculatedAttributeName",
                .display_name = "DisplayName",
                .description = "Description",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .statistic = "Statistic",
                .conditions = "Conditions",
                .attribute_details = "AttributeDetails",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_calculated_attribute_for_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/profile/{ProfileId}/calculated-attributes/{CalculatedAttributeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCalculatedAttributeForProfile",
    Request: type = struct {
        domain_name: []const u8,
        profile_id: []const u8,
        calculated_attribute_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .profile_id = "ProfileId",
                .calculated_attribute_name = "CalculatedAttributeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_calculated_attribute_for_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_calculated_attribute_for_profile };
        }
    },
    Response: type = struct {
        calculated_attribute_name: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        is_data_partial: ?[]const u8 = null,
        value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculated_attribute_name = "CalculatedAttributeName",
                .display_name = "DisplayName",
                .is_data_partial = "IsDataPartial",
                .value = "Value",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomain",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain) } {
            return .{ .service_metadata = service_metadata, .action = get_domain };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        default_expiration_days: ?i64 = null,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        stats: ?struct {
            profile_count: ?i64 = null,
            metering_profile_count: ?i64 = null,
            object_count: ?i64 = null,
            total_size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .profile_count = "ProfileCount",
                    .metering_profile_count = "MeteringProfileCount",
                    .object_count = "ObjectCount",
                    .total_size = "TotalSize",
                };
                return @field(mappings, field_name);
            }
        } = null,
        matching: ?MatchingResponse = null,
        rule_based_matching: ?RuleBasedMatchingResponse = null,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .stats = "Stats",
                .matching = "Matching",
                .rule_based_matching = "RuleBasedMatching",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_event_stream: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/event-streams/{EventStreamName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEventStream",
    Request: type = struct {
        domain_name: []const u8,
        event_stream_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .event_stream_name = "EventStreamName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_stream) } {
            return .{ .service_metadata = service_metadata, .action = get_event_stream };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        event_stream_arn: []const u8,
        created_at: i64,
        state: []const u8,
        stopped_since: ?i64 = null,
        destination_details: struct {
            uri: []const u8,
            status: []const u8,
            unhealthy_since: ?i64 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .uri = "Uri",
                    .status = "Status",
                    .unhealthy_since = "UnhealthySince",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .event_stream_arn = "EventStreamArn",
                .created_at = "CreatedAt",
                .state = "State",
                .stopped_since = "StoppedSince",
                .destination_details = "DestinationDetails",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_identity_resolution_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/identity-resolution-jobs/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIdentityResolutionJob",
    Request: type = struct {
        domain_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_resolution_job) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_resolution_job };
        }
    },
    Response: type = struct {
        domain_name: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        message: ?[]const u8 = null,
        job_start_time: ?i64 = null,
        job_end_time: ?i64 = null,
        last_updated_at: ?i64 = null,
        job_expiration_time: ?i64 = null,
        auto_merging: ?AutoMerging = null,
        exporting_location: ?ExportingLocation = null,
        job_stats: ?JobStats = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .job_id = "JobId",
                .status = "Status",
                .message = "Message",
                .job_start_time = "JobStartTime",
                .job_end_time = "JobEndTime",
                .last_updated_at = "LastUpdatedAt",
                .job_expiration_time = "JobExpirationTime",
                .auto_merging = "AutoMerging",
                .exporting_location = "ExportingLocation",
                .job_stats = "JobStats",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_integration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntegration",
    Request: type = struct {
        domain_name: []const u8,
        uri: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_integration) } {
            return .{ .service_metadata = service_metadata, .action = get_integration };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        uri: []const u8,
        object_type_name: ?[]const u8 = null,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        object_type_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        workflow_id: ?[]const u8 = null,
        is_unstructured: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
                .object_type_name = "ObjectTypeName",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
                .object_type_names = "ObjectTypeNames",
                .workflow_id = "WorkflowId",
                .is_unstructured = "IsUnstructured",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "object_type_names", field_name))
                return try serializeMap(self.object_type_names, self.fieldNameFor("object_type_names"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_matches: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/matches",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMatches",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_matches) } {
            return .{ .service_metadata = service_metadata, .action = get_matches };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        match_generation_date: ?i64 = null,
        potential_matches: ?i64 = null,
        matches: ?[]struct {
            match_id: ?[]const u8 = null,
            profile_ids: ?[][]const u8 = null,
            confidence_score: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .match_id = "MatchId",
                    .profile_ids = "ProfileIds",
                    .confidence_score = "ConfidenceScore",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .match_generation_date = "MatchGenerationDate",
                .potential_matches = "PotentialMatches",
                .matches = "Matches",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_profile_object_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/object-types/{ObjectTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProfileObjectType",
    Request: type = struct {
        domain_name: []const u8,
        object_type_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .object_type_name = "ObjectTypeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_profile_object_type) } {
            return .{ .service_metadata = service_metadata, .action = get_profile_object_type };
        }
    },
    Response: type = struct {
        object_type_name: []const u8,
        description: []const u8,
        template_id: ?[]const u8 = null,
        expiration_days: ?i64 = null,
        encryption_key: ?[]const u8 = null,
        allow_profile_creation: ?bool = null,
        source_last_updated_timestamp_format: ?[]const u8 = null,
        fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ObjectTypeField = null,
        } = null,
        keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ObjectTypeKey = null,
        } = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_type_name = "ObjectTypeName",
                .description = "Description",
                .template_id = "TemplateId",
                .expiration_days = "ExpirationDays",
                .encryption_key = "EncryptionKey",
                .allow_profile_creation = "AllowProfileCreation",
                .source_last_updated_timestamp_format = "SourceLastUpdatedTimestampFormat",
                .fields = "Fields",
                .keys = "Keys",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "fields", field_name))
                return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
            if (std.mem.eql(u8, "keys", field_name))
                return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_profile_object_type_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProfileObjectTypeTemplate",
    Request: type = struct {
        template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_profile_object_type_template) } {
            return .{ .service_metadata = service_metadata, .action = get_profile_object_type_template };
        }
    },
    Response: type = struct {
        template_id: ?[]const u8 = null,
        source_name: ?[]const u8 = null,
        source_object: ?[]const u8 = null,
        allow_profile_creation: ?bool = null,
        source_last_updated_timestamp_format: ?[]const u8 = null,
        fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ObjectTypeField = null,
        } = null,
        keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ObjectTypeKey = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
                .source_name = "SourceName",
                .source_object = "SourceObject",
                .allow_profile_creation = "AllowProfileCreation",
                .source_last_updated_timestamp_format = "SourceLastUpdatedTimestampFormat",
                .fields = "Fields",
                .keys = "Keys",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "fields", field_name))
                return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
            if (std.mem.eql(u8, "keys", field_name))
                return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_similar_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/matches",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSimilarProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,
        match_type: []const u8,
        search_key: []const u8,
        search_value: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
                .match_type = "MatchType",
                .search_key = "SearchKey",
                .search_value = "SearchValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_similar_profiles) } {
            return .{ .service_metadata = service_metadata, .action = get_similar_profiles };
        }
    },
    Response: type = struct {
        profile_ids: ?[][]const u8 = null,
        match_id: ?[]const u8 = null,
        match_type: ?[]const u8 = null,
        rule_level: ?i64 = null,
        confidence_score: ?f64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_ids = "ProfileIds",
                .match_id = "MatchId",
                .match_type = "MatchType",
                .rule_level = "RuleLevel",
                .confidence_score = "ConfidenceScore",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_workflow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/workflows/{WorkflowId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkflow",
    Request: type = struct {
        domain_name: []const u8,
        workflow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .workflow_id = "WorkflowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow };
        }
    },
    Response: type = struct {
        workflow_id: ?[]const u8 = null,
        workflow_type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        error_description: ?[]const u8 = null,
        start_date: ?i64 = null,
        last_updated_at: ?i64 = null,
        attributes: ?struct {
            appflow_integration: ?struct {
                source_connector_type: []const u8,
                connector_profile_name: []const u8,
                role_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .source_connector_type = "SourceConnectorType",
                        .connector_profile_name = "ConnectorProfileName",
                        .role_arn = "RoleArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .appflow_integration = "AppflowIntegration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        metrics: ?struct {
            appflow_integration: ?struct {
                records_processed: i64,
                steps_completed: i64,
                total_steps: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .records_processed = "RecordsProcessed",
                        .steps_completed = "StepsCompleted",
                        .total_steps = "TotalSteps",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .appflow_integration = "AppflowIntegration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_id = "WorkflowId",
                .workflow_type = "WorkflowType",
                .status = "Status",
                .error_description = "ErrorDescription",
                .start_date = "StartDate",
                .last_updated_at = "LastUpdatedAt",
                .attributes = "Attributes",
                .metrics = "Metrics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_workflow_steps: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/workflows/{WorkflowId}/steps",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkflowSteps",
    Request: type = struct {
        domain_name: []const u8,
        workflow_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .workflow_id = "WorkflowId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_steps) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_steps };
        }
    },
    Response: type = struct {
        workflow_id: ?[]const u8 = null,
        workflow_type: ?[]const u8 = null,
        items: ?[]struct {
            appflow_integration: ?struct {
                flow_name: []const u8,
                status: []const u8,
                execution_message: []const u8,
                records_processed: i64,
                batch_records_start_time: []const u8,
                batch_records_end_time: []const u8,
                created_at: i64,
                last_updated_at: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .flow_name = "FlowName",
                        .status = "Status",
                        .execution_message = "ExecutionMessage",
                        .records_processed = "RecordsProcessed",
                        .batch_records_start_time = "BatchRecordsStartTime",
                        .batch_records_end_time = "BatchRecordsEndTime",
                        .created_at = "CreatedAt",
                        .last_updated_at = "LastUpdatedAt",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .appflow_integration = "AppflowIntegration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_id = "WorkflowId",
                .workflow_type = "WorkflowType",
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_account_integrations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccountIntegrations",
    Request: type = struct {
        uri: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        include_hidden: ?bool = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
            .include_hidden = "include-hidden",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uri = "Uri",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .include_hidden = "IncludeHidden",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_integrations) } {
            return .{ .service_metadata = service_metadata, .action = list_account_integrations };
        }
    },
    Response: type = struct {
        items: ?[]ListIntegrationItem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_calculated_attribute_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/calculated-attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCalculatedAttributeDefinitions",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_calculated_attribute_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_calculated_attribute_definitions };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            calculated_attribute_name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .calculated_attribute_name = "CalculatedAttributeName",
                    .display_name = "DisplayName",
                    .description = "Description",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_calculated_attributes_for_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/profile/{ProfileId}/calculated-attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCalculatedAttributesForProfile",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,
        profile_id: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_calculated_attributes_for_profile) } {
            return .{ .service_metadata = service_metadata, .action = list_calculated_attributes_for_profile };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            calculated_attribute_name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            is_data_partial: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .calculated_attribute_name = "CalculatedAttributeName",
                    .display_name = "DisplayName",
                    .is_data_partial = "IsDataPartial",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_domains: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomains",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domains) } {
            return .{ .service_metadata = service_metadata, .action = list_domains };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            domain_name: []const u8,
            created_at: i64,
            last_updated_at: i64,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_event_streams: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/event-streams",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEventStreams",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_streams) } {
            return .{ .service_metadata = service_metadata, .action = list_event_streams };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            domain_name: []const u8,
            event_stream_name: []const u8,
            event_stream_arn: []const u8,
            state: []const u8,
            stopped_since: ?i64 = null,
            destination_summary: ?struct {
                uri: []const u8,
                status: []const u8,
                unhealthy_since: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .uri = "Uri",
                        .status = "Status",
                        .unhealthy_since = "UnhealthySince",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .event_stream_name = "EventStreamName",
                    .event_stream_arn = "EventStreamArn",
                    .state = "State",
                    .stopped_since = "StoppedSince",
                    .destination_summary = "DestinationSummary",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_identity_resolution_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/identity-resolution-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIdentityResolutionJobs",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identity_resolution_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_identity_resolution_jobs };
        }
    },
    Response: type = struct {
        identity_resolution_jobs_list: ?[]struct {
            domain_name: ?[]const u8 = null,
            job_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            job_start_time: ?i64 = null,
            job_end_time: ?i64 = null,
            job_stats: ?JobStats = null,
            exporting_location: ?ExportingLocation = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .job_id = "JobId",
                    .status = "Status",
                    .job_start_time = "JobStartTime",
                    .job_end_time = "JobEndTime",
                    .job_stats = "JobStats",
                    .exporting_location = "ExportingLocation",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_resolution_jobs_list = "IdentityResolutionJobsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_integrations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntegrations",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        include_hidden: ?bool = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
            .include_hidden = "include-hidden",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .include_hidden = "IncludeHidden",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_integrations) } {
            return .{ .service_metadata = service_metadata, .action = list_integrations };
        }
    },
    Response: type = struct {
        items: ?[]ListIntegrationItem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_profile_objects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/objects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfileObjects",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,
        object_type_name: []const u8,
        profile_id: []const u8,
        object_filter: ?struct {
            key_name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key_name = "KeyName",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
                .object_type_name = "ObjectTypeName",
                .profile_id = "ProfileId",
                .object_filter = "ObjectFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_objects) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_objects };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            object_type_name: ?[]const u8 = null,
            profile_object_unique_key: ?[]const u8 = null,
            object: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .object_type_name = "ObjectTypeName",
                    .profile_object_unique_key = "ProfileObjectUniqueKey",
                    .object = "Object",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_profile_object_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/object-types",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfileObjectTypes",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_object_types) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_object_types };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            object_type_name: []const u8,
            description: []const u8,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .object_type_name = "ObjectTypeName",
                    .description = "Description",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_profile_object_type_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfileObjectTypeTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_object_type_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_object_type_templates };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            template_id: ?[]const u8 = null,
            source_name: ?[]const u8 = null,
            source_object: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template_id = "TemplateId",
                    .source_name = "SourceName",
                    .source_object = "SourceObject",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_rule_based_matches: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/profiles/ruleBasedMatches",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRuleBasedMatches",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rule_based_matches) } {
            return .{ .service_metadata = service_metadata, .action = list_rule_based_matches };
        }
    },
    Response: type = struct {
        match_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .match_ids = "MatchIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_workflows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/workflows",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkflows",
    Request: type = struct {
        domain_name: []const u8,
        workflow_type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        query_start_date: ?i64 = null,
        query_end_date: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .workflow_type = "WorkflowType",
                .status = "Status",
                .query_start_date = "QueryStartDate",
                .query_end_date = "QueryEndDate",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflows) } {
            return .{ .service_metadata = service_metadata, .action = list_workflows };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            workflow_type: []const u8,
            workflow_id: []const u8,
            status: []const u8,
            status_description: []const u8,
            created_at: i64,
            last_updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workflow_type = "WorkflowType",
                    .workflow_id = "WorkflowId",
                    .status = "Status",
                    .status_description = "StatusDescription",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const merge_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/objects/merge",
        .success_code = 200,
    };

    action_name: []const u8 = "MergeProfiles",
    Request: type = struct {
        domain_name: []const u8,
        main_profile_id: []const u8,
        profile_ids_to_be_merged: [][]const u8,
        field_source_profile_ids: ?struct {
            account_number: ?[]const u8 = null,
            additional_information: ?[]const u8 = null,
            party_type: ?[]const u8 = null,
            business_name: ?[]const u8 = null,
            first_name: ?[]const u8 = null,
            middle_name: ?[]const u8 = null,
            last_name: ?[]const u8 = null,
            birth_date: ?[]const u8 = null,
            gender: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,
            mobile_phone_number: ?[]const u8 = null,
            home_phone_number: ?[]const u8 = null,
            business_phone_number: ?[]const u8 = null,
            email_address: ?[]const u8 = null,
            personal_email_address: ?[]const u8 = null,
            business_email_address: ?[]const u8 = null,
            address: ?[]const u8 = null,
            shipping_address: ?[]const u8 = null,
            mailing_address: ?[]const u8 = null,
            billing_address: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_number = "AccountNumber",
                    .additional_information = "AdditionalInformation",
                    .party_type = "PartyType",
                    .business_name = "BusinessName",
                    .first_name = "FirstName",
                    .middle_name = "MiddleName",
                    .last_name = "LastName",
                    .birth_date = "BirthDate",
                    .gender = "Gender",
                    .phone_number = "PhoneNumber",
                    .mobile_phone_number = "MobilePhoneNumber",
                    .home_phone_number = "HomePhoneNumber",
                    .business_phone_number = "BusinessPhoneNumber",
                    .email_address = "EmailAddress",
                    .personal_email_address = "PersonalEmailAddress",
                    .business_email_address = "BusinessEmailAddress",
                    .address = "Address",
                    .shipping_address = "ShippingAddress",
                    .mailing_address = "MailingAddress",
                    .billing_address = "BillingAddress",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .main_profile_id = "MainProfileId",
                .profile_ids_to_be_merged = "ProfileIdsToBeMerged",
                .field_source_profile_ids = "FieldSourceProfileIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_profiles) } {
            return .{ .service_metadata = service_metadata, .action = merge_profiles };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_integration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "PutIntegration",
    Request: type = struct {
        domain_name: []const u8,
        uri: ?[]const u8 = null,
        object_type_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        flow_definition: ?FlowDefinition = null,
        object_type_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
                .object_type_name = "ObjectTypeName",
                .tags = "Tags",
                .flow_definition = "FlowDefinition",
                .object_type_names = "ObjectTypeNames",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "object_type_names", field_name))
                return try serializeMap(self.object_type_names, self.fieldNameFor("object_type_names"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_integration) } {
            return .{ .service_metadata = service_metadata, .action = put_integration };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        uri: []const u8,
        object_type_name: ?[]const u8 = null,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        object_type_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        workflow_id: ?[]const u8 = null,
        is_unstructured: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
                .object_type_name = "ObjectTypeName",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
                .object_type_names = "ObjectTypeNames",
                .workflow_id = "WorkflowId",
                .is_unstructured = "IsUnstructured",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "object_type_names", field_name))
                return try serializeMap(self.object_type_names, self.fieldNameFor("object_type_names"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_profile_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/profiles/objects",
        .success_code = 200,
    };

    action_name: []const u8 = "PutProfileObject",
    Request: type = struct {
        object_type_name: []const u8,
        object: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_type_name = "ObjectTypeName",
                .object = "Object",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_profile_object) } {
            return .{ .service_metadata = service_metadata, .action = put_profile_object };
        }
    },
    Response: type = struct {
        profile_object_unique_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_object_unique_key = "ProfileObjectUniqueKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_profile_object_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/object-types/{ObjectTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutProfileObjectType",
    Request: type = struct {
        domain_name: []const u8,
        object_type_name: []const u8,
        description: []const u8,
        template_id: ?[]const u8 = null,
        expiration_days: ?i64 = null,
        encryption_key: ?[]const u8 = null,
        allow_profile_creation: ?bool = null,
        source_last_updated_timestamp_format: ?[]const u8 = null,
        fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ObjectTypeField = null,
        } = null,
        keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ObjectTypeKey = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .object_type_name = "ObjectTypeName",
                .description = "Description",
                .template_id = "TemplateId",
                .expiration_days = "ExpirationDays",
                .encryption_key = "EncryptionKey",
                .allow_profile_creation = "AllowProfileCreation",
                .source_last_updated_timestamp_format = "SourceLastUpdatedTimestampFormat",
                .fields = "Fields",
                .keys = "Keys",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "fields", field_name))
                return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
            if (std.mem.eql(u8, "keys", field_name))
                return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_profile_object_type) } {
            return .{ .service_metadata = service_metadata, .action = put_profile_object_type };
        }
    },
    Response: type = struct {
        object_type_name: []const u8,
        description: []const u8,
        template_id: ?[]const u8 = null,
        expiration_days: ?i64 = null,
        encryption_key: ?[]const u8 = null,
        allow_profile_creation: ?bool = null,
        source_last_updated_timestamp_format: ?[]const u8 = null,
        fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ObjectTypeField = null,
        } = null,
        keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ObjectTypeKey = null,
        } = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_type_name = "ObjectTypeName",
                .description = "Description",
                .template_id = "TemplateId",
                .expiration_days = "ExpirationDays",
                .encryption_key = "EncryptionKey",
                .allow_profile_creation = "AllowProfileCreation",
                .source_last_updated_timestamp_format = "SourceLastUpdatedTimestampFormat",
                .fields = "Fields",
                .keys = "Keys",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "fields", field_name))
                return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
            if (std.mem.eql(u8, "keys", field_name))
                return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,
        key_name: []const u8,
        values: [][]const u8,
        additional_search_keys: ?[]struct {
            key_name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key_name = "KeyName",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        logical_operator: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
                .key_name = "KeyName",
                .values = "Values",
                .additional_search_keys = "AdditionalSearchKeys",
                .logical_operator = "LogicalOperator",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_profiles) } {
            return .{ .service_metadata = service_metadata, .action = search_profiles };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            profile_id: ?[]const u8 = null,
            account_number: ?[]const u8 = null,
            additional_information: ?[]const u8 = null,
            party_type: ?[]const u8 = null,
            business_name: ?[]const u8 = null,
            first_name: ?[]const u8 = null,
            middle_name: ?[]const u8 = null,
            last_name: ?[]const u8 = null,
            birth_date: ?[]const u8 = null,
            gender: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,
            mobile_phone_number: ?[]const u8 = null,
            home_phone_number: ?[]const u8 = null,
            business_phone_number: ?[]const u8 = null,
            email_address: ?[]const u8 = null,
            personal_email_address: ?[]const u8 = null,
            business_email_address: ?[]const u8 = null,
            address: ?Address = null,
            shipping_address: ?Address = null,
            mailing_address: ?Address = null,
            billing_address: ?Address = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            found_by_items: ?[]struct {
                key_name: ?[]const u8 = null,
                values: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key_name = "KeyName",
                        .values = "Values",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            party_type_string: ?[]const u8 = null,
            gender_string: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .profile_id = "ProfileId",
                    .account_number = "AccountNumber",
                    .additional_information = "AdditionalInformation",
                    .party_type = "PartyType",
                    .business_name = "BusinessName",
                    .first_name = "FirstName",
                    .middle_name = "MiddleName",
                    .last_name = "LastName",
                    .birth_date = "BirthDate",
                    .gender = "Gender",
                    .phone_number = "PhoneNumber",
                    .mobile_phone_number = "MobilePhoneNumber",
                    .home_phone_number = "HomePhoneNumber",
                    .business_phone_number = "BusinessPhoneNumber",
                    .email_address = "EmailAddress",
                    .personal_email_address = "PersonalEmailAddress",
                    .business_email_address = "BusinessEmailAddress",
                    .address = "Address",
                    .shipping_address = "ShippingAddress",
                    .mailing_address = "MailingAddress",
                    .billing_address = "BillingAddress",
                    .attributes = "Attributes",
                    .found_by_items = "FoundByItems",
                    .party_type_string = "PartyTypeString",
                    .gender_string = "GenderString",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_calculated_attribute_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/calculated-attributes/{CalculatedAttributeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCalculatedAttributeDefinition",
    Request: type = struct {
        domain_name: []const u8,
        calculated_attribute_name: []const u8,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        conditions: ?Conditions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .calculated_attribute_name = "CalculatedAttributeName",
                .display_name = "DisplayName",
                .description = "Description",
                .conditions = "Conditions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_calculated_attribute_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_calculated_attribute_definition };
        }
    },
    Response: type = struct {
        calculated_attribute_name: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        statistic: ?[]const u8 = null,
        conditions: ?Conditions = null,
        attribute_details: ?AttributeDetails = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calculated_attribute_name = "CalculatedAttributeName",
                .display_name = "DisplayName",
                .description = "Description",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .statistic = "Statistic",
                .conditions = "Conditions",
                .attribute_details = "AttributeDetails",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_domain: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDomain",
    Request: type = struct {
        domain_name: []const u8,
        default_expiration_days: ?i64 = null,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        matching: ?MatchingRequest = null,
        rule_based_matching: ?RuleBasedMatchingRequest = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .matching = "Matching",
                .rule_based_matching = "RuleBasedMatching",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain) } {
            return .{ .service_metadata = service_metadata, .action = update_domain };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        default_expiration_days: ?i64 = null,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        matching: ?MatchingResponse = null,
        rule_based_matching: ?RuleBasedMatchingResponse = null,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .matching = "Matching",
                .rule_based_matching = "RuleBasedMatching",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProfile",
    Request: type = struct {
        domain_name: []const u8,
        profile_id: []const u8,
        additional_information: ?[]const u8 = null,
        account_number: ?[]const u8 = null,
        party_type: ?[]const u8 = null,
        business_name: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        middle_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        birth_date: ?[]const u8 = null,
        gender: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,
        mobile_phone_number: ?[]const u8 = null,
        home_phone_number: ?[]const u8 = null,
        business_phone_number: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        personal_email_address: ?[]const u8 = null,
        business_email_address: ?[]const u8 = null,
        address: ?UpdateAddress = null,
        shipping_address: ?UpdateAddress = null,
        mailing_address: ?UpdateAddress = null,
        billing_address: ?UpdateAddress = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        party_type_string: ?[]const u8 = null,
        gender_string: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .profile_id = "ProfileId",
                .additional_information = "AdditionalInformation",
                .account_number = "AccountNumber",
                .party_type = "PartyType",
                .business_name = "BusinessName",
                .first_name = "FirstName",
                .middle_name = "MiddleName",
                .last_name = "LastName",
                .birth_date = "BirthDate",
                .gender = "Gender",
                .phone_number = "PhoneNumber",
                .mobile_phone_number = "MobilePhoneNumber",
                .home_phone_number = "HomePhoneNumber",
                .business_phone_number = "BusinessPhoneNumber",
                .email_address = "EmailAddress",
                .personal_email_address = "PersonalEmailAddress",
                .business_email_address = "BusinessEmailAddress",
                .address = "Address",
                .shipping_address = "ShippingAddress",
                .mailing_address = "MailingAddress",
                .billing_address = "BillingAddress",
                .attributes = "Attributes",
                .party_type_string = "PartyTypeString",
                .gender_string = "GenderString",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_profile };
        }
    },
    Response: type = struct {
        profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const UpdateAddress = struct {
    address1: ?[]const u8 = null,
    address2: ?[]const u8 = null,
    address3: ?[]const u8 = null,
    address4: ?[]const u8 = null,
    city: ?[]const u8 = null,
    county: ?[]const u8 = null,
    state: ?[]const u8 = null,
    province: ?[]const u8 = null,
    country: ?[]const u8 = null,
    postal_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address1 = "Address1",
            .address2 = "Address2",
            .address3 = "Address3",
            .address4 = "Address4",
            .city = "City",
            .county = "County",
            .state = "State",
            .province = "Province",
            .country = "Country",
            .postal_code = "PostalCode",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleBasedMatchingResponse = struct {
    enabled: ?bool = null,
    matching_rules: ?[]MatchingRule = null,
    status: ?[]const u8 = null,
    max_allowed_rule_level_for_merging: ?i64 = null,
    max_allowed_rule_level_for_matching: ?i64 = null,
    attribute_types_selector: ?AttributeTypesSelector = null,
    conflict_resolution: ?ConflictResolution = null,
    exporting_config: ?ExportingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .matching_rules = "MatchingRules",
            .status = "Status",
            .max_allowed_rule_level_for_merging = "MaxAllowedRuleLevelForMerging",
            .max_allowed_rule_level_for_matching = "MaxAllowedRuleLevelForMatching",
            .attribute_types_selector = "AttributeTypesSelector",
            .conflict_resolution = "ConflictResolution",
            .exporting_config = "ExportingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportingConfig = struct {
    s3_exporting: ?S3ExportingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_exporting = "S3Exporting",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ExportingConfig = struct {
    s3_bucket_name: []const u8,
    s3_key_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "S3BucketName",
            .s3_key_name = "S3KeyName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConflictResolution = struct {
    conflict_resolving_model: []const u8,
    source_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conflict_resolving_model = "ConflictResolvingModel",
            .source_name = "SourceName",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeTypesSelector = struct {
    attribute_matching_model: []const u8,
    address: ?[][]const u8 = null,
    phone_number: ?[][]const u8 = null,
    email_address: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_matching_model = "AttributeMatchingModel",
            .address = "Address",
            .phone_number = "PhoneNumber",
            .email_address = "EmailAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchingRule = struct {
    rule: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule = "Rule",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchingResponse = struct {
    enabled: ?bool = null,
    job_schedule: ?JobSchedule = null,
    auto_merging: ?AutoMerging = null,
    exporting_config: ?ExportingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .job_schedule = "JobSchedule",
            .auto_merging = "AutoMerging",
            .exporting_config = "ExportingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMerging = struct {
    enabled: bool,
    consolidation: ?Consolidation = null,
    conflict_resolution: ?ConflictResolution = null,
    min_allowed_confidence_score_for_merging: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .consolidation = "Consolidation",
            .conflict_resolution = "ConflictResolution",
            .min_allowed_confidence_score_for_merging = "MinAllowedConfidenceScoreForMerging",
        };
        return @field(mappings, field_name);
    }
};

pub const Consolidation = struct {
    matching_attributes_list: [][][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .matching_attributes_list = "MatchingAttributesList",
        };
        return @field(mappings, field_name);
    }
};

pub const JobSchedule = struct {
    day_of_the_week: []const u8,
    time: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .day_of_the_week = "DayOfTheWeek",
            .time = "Time",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleBasedMatchingRequest = struct {
    enabled: bool,
    matching_rules: ?[]MatchingRule = null,
    max_allowed_rule_level_for_merging: ?i64 = null,
    max_allowed_rule_level_for_matching: ?i64 = null,
    attribute_types_selector: ?AttributeTypesSelector = null,
    conflict_resolution: ?ConflictResolution = null,
    exporting_config: ?ExportingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .matching_rules = "MatchingRules",
            .max_allowed_rule_level_for_merging = "MaxAllowedRuleLevelForMerging",
            .max_allowed_rule_level_for_matching = "MaxAllowedRuleLevelForMatching",
            .attribute_types_selector = "AttributeTypesSelector",
            .conflict_resolution = "ConflictResolution",
            .exporting_config = "ExportingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchingRequest = struct {
    enabled: bool,
    job_schedule: ?JobSchedule = null,
    auto_merging: ?AutoMerging = null,
    exporting_config: ?ExportingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .job_schedule = "JobSchedule",
            .auto_merging = "AutoMerging",
            .exporting_config = "ExportingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeDetails = struct {
    attributes: []AttributeItem,
    expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "Attributes",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeItem = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Conditions = struct {
    range: ?Range = null,
    object_count: ?i64 = null,
    threshold: ?Threshold = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .range = "Range",
            .object_count = "ObjectCount",
            .threshold = "Threshold",
        };
        return @field(mappings, field_name);
    }
};

pub const Threshold = struct {
    value: []const u8,
    operator: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .operator = "Operator",
        };
        return @field(mappings, field_name);
    }
};

pub const Range = struct {
    value: i64,
    unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const Address = struct {
    address1: ?[]const u8 = null,
    address2: ?[]const u8 = null,
    address3: ?[]const u8 = null,
    address4: ?[]const u8 = null,
    city: ?[]const u8 = null,
    county: ?[]const u8 = null,
    state: ?[]const u8 = null,
    province: ?[]const u8 = null,
    country: ?[]const u8 = null,
    postal_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address1 = "Address1",
            .address2 = "Address2",
            .address3 = "Address3",
            .address4 = "Address4",
            .city = "City",
            .county = "County",
            .state = "State",
            .province = "Province",
            .country = "Country",
            .postal_code = "PostalCode",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectTypeKey = struct {
    standard_identifiers: ?[][]const u8 = null,
    field_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standard_identifiers = "StandardIdentifiers",
            .field_names = "FieldNames",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectTypeField = struct {
    source: ?[]const u8 = null,
    target: ?[]const u8 = null,
    content_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
            .target = "Target",
            .content_type = "ContentType",
        };
        return @field(mappings, field_name);
    }
};

pub const FlowDefinition = struct {
    description: ?[]const u8 = null,
    flow_name: []const u8,
    kms_arn: []const u8,
    source_flow_config: SourceFlowConfig,
    tasks: []Task,
    trigger_config: TriggerConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .flow_name = "FlowName",
            .kms_arn = "KmsArn",
            .source_flow_config = "SourceFlowConfig",
            .tasks = "Tasks",
            .trigger_config = "TriggerConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const TriggerConfig = struct {
    trigger_type: []const u8,
    trigger_properties: ?TriggerProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trigger_type = "TriggerType",
            .trigger_properties = "TriggerProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const TriggerProperties = struct {
    scheduled: ?ScheduledTriggerProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scheduled = "Scheduled",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduledTriggerProperties = struct {
    schedule_expression: []const u8,
    data_pull_mode: ?[]const u8 = null,
    schedule_start_time: ?i64 = null,
    schedule_end_time: ?i64 = null,
    timezone: ?[]const u8 = null,
    schedule_offset: ?i64 = null,
    first_execution_from: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "ScheduleExpression",
            .data_pull_mode = "DataPullMode",
            .schedule_start_time = "ScheduleStartTime",
            .schedule_end_time = "ScheduleEndTime",
            .timezone = "Timezone",
            .schedule_offset = "ScheduleOffset",
            .first_execution_from = "FirstExecutionFrom",
        };
        return @field(mappings, field_name);
    }
};

pub const Task = struct {
    connector_operator: ?ConnectorOperator = null,
    destination_field: ?[]const u8 = null,
    source_fields: [][]const u8,
    task_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    task_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_operator = "ConnectorOperator",
            .destination_field = "DestinationField",
            .source_fields = "SourceFields",
            .task_properties = "TaskProperties",
            .task_type = "TaskType",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "task_properties", field_name))
            return try serializeMap(self.task_properties, self.fieldNameFor("task_properties"), options, out_stream);
        return false;
    }
};

pub const ConnectorOperator = struct {
    marketo: ?[]const u8 = null,
    s3: ?[]const u8 = null,
    salesforce: ?[]const u8 = null,
    service_now: ?[]const u8 = null,
    zendesk: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .marketo = "Marketo",
            .s3 = "S3",
            .salesforce = "Salesforce",
            .service_now = "ServiceNow",
            .zendesk = "Zendesk",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceFlowConfig = struct {
    connector_profile_name: ?[]const u8 = null,
    connector_type: []const u8,
    incremental_pull_config: ?IncrementalPullConfig = null,
    source_connector_properties: SourceConnectorProperties,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_profile_name = "ConnectorProfileName",
            .connector_type = "ConnectorType",
            .incremental_pull_config = "IncrementalPullConfig",
            .source_connector_properties = "SourceConnectorProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConnectorProperties = struct {
    marketo: ?MarketoSourceProperties = null,
    s3: ?S3SourceProperties = null,
    salesforce: ?SalesforceSourceProperties = null,
    service_now: ?ServiceNowSourceProperties = null,
    zendesk: ?ZendeskSourceProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .marketo = "Marketo",
            .s3 = "S3",
            .salesforce = "Salesforce",
            .service_now = "ServiceNow",
            .zendesk = "Zendesk",
        };
        return @field(mappings, field_name);
    }
};

pub const ZendeskSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "Object",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "Object",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceSourceProperties = struct {
    object: []const u8,
    enable_dynamic_field_update: ?bool = null,
    include_deleted_records: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "Object",
            .enable_dynamic_field_update = "EnableDynamicFieldUpdate",
            .include_deleted_records = "IncludeDeletedRecords",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SourceProperties = struct {
    bucket_name: []const u8,
    bucket_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .bucket_prefix = "BucketPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const MarketoSourceProperties = struct {
    object: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object = "Object",
        };
        return @field(mappings, field_name);
    }
};

pub const IncrementalPullConfig = struct {
    datetime_type_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .datetime_type_field_name = "DatetimeTypeFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ListIntegrationItem = struct {
    domain_name: []const u8,
    uri: []const u8,
    object_type_name: ?[]const u8 = null,
    created_at: i64,
    last_updated_at: i64,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    object_type_names: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    workflow_id: ?[]const u8 = null,
    is_unstructured: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .uri = "Uri",
            .object_type_name = "ObjectTypeName",
            .created_at = "CreatedAt",
            .last_updated_at = "LastUpdatedAt",
            .tags = "Tags",
            .object_type_names = "ObjectTypeNames",
            .workflow_id = "WorkflowId",
            .is_unstructured = "IsUnstructured",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        if (std.mem.eql(u8, "object_type_names", field_name))
            return try serializeMap(self.object_type_names, self.fieldNameFor("object_type_names"), options, out_stream);
        return false;
    }
};

pub const ExportingLocation = struct {
    s3_exporting: ?S3ExportingLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_exporting = "S3Exporting",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ExportingLocation = struct {
    s3_bucket_name: ?[]const u8 = null,
    s3_key_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "S3BucketName",
            .s3_key_name = "S3KeyName",
        };
        return @field(mappings, field_name);
    }
};

pub const JobStats = struct {
    number_of_profiles_reviewed: ?i64 = null,
    number_of_matches_found: ?i64 = null,
    number_of_merges_done: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_profiles_reviewed = "NumberOfProfilesReviewed",
            .number_of_matches_found = "NumberOfMatchesFound",
            .number_of_merges_done = "NumberOfMergesDone",
        };
        return @field(mappings, field_name);
    }
};
