const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "DataBrew";
pub const arn_namespace: ?[]const u8 = "databrew";
pub const endpoint_prefix: []const u8 = "databrew";
pub const sigv4_name: []const u8 = "databrew";
pub const name: []const u8 = "AWSGlueDataBrew";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "DataBrew",
    arn_namespace: ?[]const u8 = "databrew",
    endpoint_prefix: []const u8 = "databrew",
    sigv4_name: []const u8 = "databrew",
    name: []const u8 = "AWSGlueDataBrew",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_delete_recipe_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/recipes/{Name}/batchDeleteRecipeVersion",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeleteRecipeVersion",
    Request: type = struct {
        name: []const u8,
        recipe_versions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .recipe_versions = "RecipeVersions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_recipe_version) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_recipe_version };
        }
    },
    Response: type = struct {
        name: []const u8,
        errors: ?[]struct {
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            recipe_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                    .recipe_version = "RecipeVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_dataset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        name: []const u8,
        format: ?[]const u8 = null,
        format_options: ?FormatOptions = null,
        input: Input,
        path_options: ?PathOptions = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .format = "Format",
                .format_options = "FormatOptions",
                .input = "Input",
                .path_options = "PathOptions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_profile_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/profileJobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProfileJob",
    Request: type = struct {
        dataset_name: []const u8,
        encryption_key_arn: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        name: []const u8,
        log_subscription: ?[]const u8 = null,
        max_capacity: ?i64 = null,
        max_retries: ?i64 = null,
        output_location: S3Location,
        configuration: ?ProfileConfiguration = null,
        validation_configurations: ?[]ValidationConfiguration = null,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        timeout: ?i64 = null,
        job_sample: ?JobSample = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .encryption_key_arn = "EncryptionKeyArn",
                .encryption_mode = "EncryptionMode",
                .name = "Name",
                .log_subscription = "LogSubscription",
                .max_capacity = "MaxCapacity",
                .max_retries = "MaxRetries",
                .output_location = "OutputLocation",
                .configuration = "Configuration",
                .validation_configurations = "ValidationConfigurations",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .timeout = "Timeout",
                .job_sample = "JobSample",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_profile_job) } {
            return .{ .service_metadata = service_metadata, .action = create_profile_job };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_project: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        dataset_name: []const u8,
        name: []const u8,
        recipe_name: []const u8,
        sample: ?Sample = null,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .name = "Name",
                .recipe_name = "RecipeName",
                .sample = "Sample",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_recipe: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/recipes",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRecipe",
    Request: type = struct {
        description: ?[]const u8 = null,
        name: []const u8,
        steps: []RecipeStep,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .name = "Name",
                .steps = "Steps",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_recipe) } {
            return .{ .service_metadata = service_metadata, .action = create_recipe };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_recipe_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/recipeJobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRecipeJob",
    Request: type = struct {
        dataset_name: ?[]const u8 = null,
        encryption_key_arn: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        name: []const u8,
        log_subscription: ?[]const u8 = null,
        max_capacity: ?i64 = null,
        max_retries: ?i64 = null,
        outputs: ?[]Output = null,
        data_catalog_outputs: ?[]DataCatalogOutput = null,
        database_outputs: ?[]DatabaseOutput = null,
        project_name: ?[]const u8 = null,
        recipe_reference: ?RecipeReference = null,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        timeout: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .encryption_key_arn = "EncryptionKeyArn",
                .encryption_mode = "EncryptionMode",
                .name = "Name",
                .log_subscription = "LogSubscription",
                .max_capacity = "MaxCapacity",
                .max_retries = "MaxRetries",
                .outputs = "Outputs",
                .data_catalog_outputs = "DataCatalogOutputs",
                .database_outputs = "DatabaseOutputs",
                .project_name = "ProjectName",
                .recipe_reference = "RecipeReference",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .timeout = "Timeout",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_recipe_job) } {
            return .{ .service_metadata = service_metadata, .action = create_recipe_job };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_ruleset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rulesets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRuleset",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        target_arn: []const u8,
        rules: []Rule,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .target_arn = "TargetArn",
                .rules = "Rules",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ruleset) } {
            return .{ .service_metadata = service_metadata, .action = create_ruleset };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_schedule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/schedules",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSchedule",
    Request: type = struct {
        job_names: ?[][]const u8 = null,
        cron_expression: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_names = "JobNames",
                .cron_expression = "CronExpression",
                .tags = "Tags",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_schedule) } {
            return .{ .service_metadata = service_metadata, .action = create_schedule };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_dataset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/datasets/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/jobs/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJob",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_job };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_project: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/projects/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_recipe_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/recipes/{Name}/recipeVersion/{RecipeVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRecipeVersion",
    Request: type = struct {
        name: []const u8,
        recipe_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .recipe_version = "RecipeVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_recipe_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_recipe_version };
        }
    },
    Response: type = struct {
        name: []const u8,
        recipe_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .recipe_version = "RecipeVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_ruleset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/rulesets/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRuleset",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ruleset) } {
            return .{ .service_metadata = service_metadata, .action = delete_ruleset };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_schedule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/schedules/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSchedule",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schedule) } {
            return .{ .service_metadata = service_metadata, .action = delete_schedule };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_dataset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        created_by: ?[]const u8 = null,
        create_date: ?i64 = null,
        name: []const u8,
        format: ?[]const u8 = null,
        format_options: ?FormatOptions = null,
        input: Input,
        last_modified_date: ?i64 = null,
        last_modified_by: ?[]const u8 = null,
        source: ?[]const u8 = null,
        path_options: ?PathOptions = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_by = "CreatedBy",
                .create_date = "CreateDate",
                .name = "Name",
                .format = "Format",
                .format_options = "FormatOptions",
                .input = "Input",
                .last_modified_date = "LastModifiedDate",
                .last_modified_by = "LastModifiedBy",
                .source = "Source",
                .path_options = "PathOptions",
                .tags = "Tags",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJob",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_job };
        }
    },
    Response: type = struct {
        create_date: ?i64 = null,
        created_by: ?[]const u8 = null,
        dataset_name: ?[]const u8 = null,
        encryption_key_arn: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        name: []const u8,
        type: ?[]const u8 = null,
        last_modified_by: ?[]const u8 = null,
        last_modified_date: ?i64 = null,
        log_subscription: ?[]const u8 = null,
        max_capacity: ?i64 = null,
        max_retries: ?i64 = null,
        outputs: ?[]Output = null,
        data_catalog_outputs: ?[]DataCatalogOutput = null,
        database_outputs: ?[]DatabaseOutput = null,
        project_name: ?[]const u8 = null,
        profile_configuration: ?ProfileConfiguration = null,
        validation_configurations: ?[]ValidationConfiguration = null,
        recipe_reference: ?RecipeReference = null,
        resource_arn: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        timeout: ?i64 = null,
        job_sample: ?JobSample = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_date = "CreateDate",
                .created_by = "CreatedBy",
                .dataset_name = "DatasetName",
                .encryption_key_arn = "EncryptionKeyArn",
                .encryption_mode = "EncryptionMode",
                .name = "Name",
                .type = "Type",
                .last_modified_by = "LastModifiedBy",
                .last_modified_date = "LastModifiedDate",
                .log_subscription = "LogSubscription",
                .max_capacity = "MaxCapacity",
                .max_retries = "MaxRetries",
                .outputs = "Outputs",
                .data_catalog_outputs = "DataCatalogOutputs",
                .database_outputs = "DatabaseOutputs",
                .project_name = "ProjectName",
                .profile_configuration = "ProfileConfiguration",
                .validation_configurations = "ValidationConfigurations",
                .recipe_reference = "RecipeReference",
                .resource_arn = "ResourceArn",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .timeout = "Timeout",
                .job_sample = "JobSample",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_job_run: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{Name}/jobRun/{RunId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobRun",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_run) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_run };
        }
    },
    Response: type = struct {
        attempt: ?i64 = null,
        completed_on: ?i64 = null,
        dataset_name: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        execution_time: ?i64 = null,
        job_name: []const u8,
        profile_configuration: ?ProfileConfiguration = null,
        validation_configurations: ?[]ValidationConfiguration = null,
        run_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        log_subscription: ?[]const u8 = null,
        log_group_name: ?[]const u8 = null,
        outputs: ?[]Output = null,
        data_catalog_outputs: ?[]DataCatalogOutput = null,
        database_outputs: ?[]DatabaseOutput = null,
        recipe_reference: ?RecipeReference = null,
        started_by: ?[]const u8 = null,
        started_on: ?i64 = null,
        job_sample: ?JobSample = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attempt = "Attempt",
                .completed_on = "CompletedOn",
                .dataset_name = "DatasetName",
                .error_message = "ErrorMessage",
                .execution_time = "ExecutionTime",
                .job_name = "JobName",
                .profile_configuration = "ProfileConfiguration",
                .validation_configurations = "ValidationConfigurations",
                .run_id = "RunId",
                .state = "State",
                .log_subscription = "LogSubscription",
                .log_group_name = "LogGroupName",
                .outputs = "Outputs",
                .data_catalog_outputs = "DataCatalogOutputs",
                .database_outputs = "DatabaseOutputs",
                .recipe_reference = "RecipeReference",
                .started_by = "StartedBy",
                .started_on = "StartedOn",
                .job_sample = "JobSample",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_project: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProject",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project) } {
            return .{ .service_metadata = service_metadata, .action = describe_project };
        }
    },
    Response: type = struct {
        create_date: ?i64 = null,
        created_by: ?[]const u8 = null,
        dataset_name: ?[]const u8 = null,
        last_modified_date: ?i64 = null,
        last_modified_by: ?[]const u8 = null,
        name: []const u8,
        recipe_name: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        sample: ?Sample = null,
        role_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        session_status: ?[]const u8 = null,
        opened_by: ?[]const u8 = null,
        open_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_date = "CreateDate",
                .created_by = "CreatedBy",
                .dataset_name = "DatasetName",
                .last_modified_date = "LastModifiedDate",
                .last_modified_by = "LastModifiedBy",
                .name = "Name",
                .recipe_name = "RecipeName",
                .resource_arn = "ResourceArn",
                .sample = "Sample",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .session_status = "SessionStatus",
                .opened_by = "OpenedBy",
                .open_date = "OpenDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_recipe: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/recipes/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRecipe",
    Request: type = struct {
        name: []const u8,
        recipe_version: ?[]const u8 = null,

        pub const http_query = .{
            .recipe_version = "recipeVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .recipe_version = "RecipeVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recipe) } {
            return .{ .service_metadata = service_metadata, .action = describe_recipe };
        }
    },
    Response: type = struct {
        created_by: ?[]const u8 = null,
        create_date: ?i64 = null,
        last_modified_by: ?[]const u8 = null,
        last_modified_date: ?i64 = null,
        project_name: ?[]const u8 = null,
        published_by: ?[]const u8 = null,
        published_date: ?i64 = null,
        description: ?[]const u8 = null,
        name: []const u8,
        steps: ?[]RecipeStep = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        resource_arn: ?[]const u8 = null,
        recipe_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_by = "CreatedBy",
                .create_date = "CreateDate",
                .last_modified_by = "LastModifiedBy",
                .last_modified_date = "LastModifiedDate",
                .project_name = "ProjectName",
                .published_by = "PublishedBy",
                .published_date = "PublishedDate",
                .description = "Description",
                .name = "Name",
                .steps = "Steps",
                .tags = "Tags",
                .resource_arn = "ResourceArn",
                .recipe_version = "RecipeVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_ruleset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rulesets/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRuleset",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ruleset) } {
            return .{ .service_metadata = service_metadata, .action = describe_ruleset };
        }
    },
    Response: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        target_arn: ?[]const u8 = null,
        rules: ?[]Rule = null,
        create_date: ?i64 = null,
        created_by: ?[]const u8 = null,
        last_modified_by: ?[]const u8 = null,
        last_modified_date: ?i64 = null,
        resource_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .target_arn = "TargetArn",
                .rules = "Rules",
                .create_date = "CreateDate",
                .created_by = "CreatedBy",
                .last_modified_by = "LastModifiedBy",
                .last_modified_date = "LastModifiedDate",
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_schedule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/schedules/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSchedule",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_schedule) } {
            return .{ .service_metadata = service_metadata, .action = describe_schedule };
        }
    },
    Response: type = struct {
        create_date: ?i64 = null,
        created_by: ?[]const u8 = null,
        job_names: ?[][]const u8 = null,
        last_modified_by: ?[]const u8 = null,
        last_modified_date: ?i64 = null,
        resource_arn: ?[]const u8 = null,
        cron_expression: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_date = "CreateDate",
                .created_by = "CreatedBy",
                .job_names = "JobNames",
                .last_modified_by = "LastModifiedBy",
                .last_modified_date = "LastModifiedDate",
                .resource_arn = "ResourceArn",
                .cron_expression = "CronExpression",
                .tags = "Tags",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_datasets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatasets",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasets) } {
            return .{ .service_metadata = service_metadata, .action = list_datasets };
        }
    },
    Response: type = struct {
        datasets: []struct {
            account_id: ?[]const u8 = null,
            created_by: ?[]const u8 = null,
            create_date: ?i64 = null,
            name: []const u8,
            format: ?[]const u8 = null,
            format_options: ?FormatOptions = null,
            input: Input,
            last_modified_date: ?i64 = null,
            last_modified_by: ?[]const u8 = null,
            source: ?[]const u8 = null,
            path_options: ?PathOptions = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            resource_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .created_by = "CreatedBy",
                    .create_date = "CreateDate",
                    .name = "Name",
                    .format = "Format",
                    .format_options = "FormatOptions",
                    .input = "Input",
                    .last_modified_date = "LastModifiedDate",
                    .last_modified_by = "LastModifiedBy",
                    .source = "Source",
                    .path_options = "PathOptions",
                    .tags = "Tags",
                    .resource_arn = "ResourceArn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datasets = "Datasets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_job_runs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{Name}/jobRuns",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobRuns",
    Request: type = struct {
        name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_job_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_job_runs };
        }
    },
    Response: type = struct {
        job_runs: []struct {
            attempt: ?i64 = null,
            completed_on: ?i64 = null,
            dataset_name: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            execution_time: ?i64 = null,
            job_name: ?[]const u8 = null,
            run_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            log_subscription: ?[]const u8 = null,
            log_group_name: ?[]const u8 = null,
            outputs: ?[]Output = null,
            data_catalog_outputs: ?[]DataCatalogOutput = null,
            database_outputs: ?[]DatabaseOutput = null,
            recipe_reference: ?RecipeReference = null,
            started_by: ?[]const u8 = null,
            started_on: ?i64 = null,
            job_sample: ?JobSample = null,
            validation_configurations: ?[]ValidationConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attempt = "Attempt",
                    .completed_on = "CompletedOn",
                    .dataset_name = "DatasetName",
                    .error_message = "ErrorMessage",
                    .execution_time = "ExecutionTime",
                    .job_name = "JobName",
                    .run_id = "RunId",
                    .state = "State",
                    .log_subscription = "LogSubscription",
                    .log_group_name = "LogGroupName",
                    .outputs = "Outputs",
                    .data_catalog_outputs = "DataCatalogOutputs",
                    .database_outputs = "DatabaseOutputs",
                    .recipe_reference = "RecipeReference",
                    .started_by = "StartedBy",
                    .started_on = "StartedOn",
                    .job_sample = "JobSample",
                    .validation_configurations = "ValidationConfigurations",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_runs = "JobRuns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        dataset_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        project_name: ?[]const u8 = null,

        pub const http_query = .{
            .dataset_name = "datasetName",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .project_name = "projectName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .project_name = "ProjectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        jobs: []struct {
            account_id: ?[]const u8 = null,
            created_by: ?[]const u8 = null,
            create_date: ?i64 = null,
            dataset_name: ?[]const u8 = null,
            encryption_key_arn: ?[]const u8 = null,
            encryption_mode: ?[]const u8 = null,
            name: []const u8,
            type: ?[]const u8 = null,
            last_modified_by: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            log_subscription: ?[]const u8 = null,
            max_capacity: ?i64 = null,
            max_retries: ?i64 = null,
            outputs: ?[]Output = null,
            data_catalog_outputs: ?[]DataCatalogOutput = null,
            database_outputs: ?[]DatabaseOutput = null,
            project_name: ?[]const u8 = null,
            recipe_reference: ?RecipeReference = null,
            resource_arn: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            timeout: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            job_sample: ?JobSample = null,
            validation_configurations: ?[]ValidationConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .created_by = "CreatedBy",
                    .create_date = "CreateDate",
                    .dataset_name = "DatasetName",
                    .encryption_key_arn = "EncryptionKeyArn",
                    .encryption_mode = "EncryptionMode",
                    .name = "Name",
                    .type = "Type",
                    .last_modified_by = "LastModifiedBy",
                    .last_modified_date = "LastModifiedDate",
                    .log_subscription = "LogSubscription",
                    .max_capacity = "MaxCapacity",
                    .max_retries = "MaxRetries",
                    .outputs = "Outputs",
                    .data_catalog_outputs = "DataCatalogOutputs",
                    .database_outputs = "DatabaseOutputs",
                    .project_name = "ProjectName",
                    .recipe_reference = "RecipeReference",
                    .resource_arn = "ResourceArn",
                    .role_arn = "RoleArn",
                    .timeout = "Timeout",
                    .tags = "Tags",
                    .job_sample = "JobSample",
                    .validation_configurations = "ValidationConfigurations",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_projects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        projects: []struct {
            account_id: ?[]const u8 = null,
            create_date: ?i64 = null,
            created_by: ?[]const u8 = null,
            dataset_name: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            last_modified_by: ?[]const u8 = null,
            name: []const u8,
            recipe_name: []const u8,
            resource_arn: ?[]const u8 = null,
            sample: ?Sample = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            role_arn: ?[]const u8 = null,
            opened_by: ?[]const u8 = null,
            open_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .create_date = "CreateDate",
                    .created_by = "CreatedBy",
                    .dataset_name = "DatasetName",
                    .last_modified_date = "LastModifiedDate",
                    .last_modified_by = "LastModifiedBy",
                    .name = "Name",
                    .recipe_name = "RecipeName",
                    .resource_arn = "ResourceArn",
                    .sample = "Sample",
                    .tags = "Tags",
                    .role_arn = "RoleArn",
                    .opened_by = "OpenedBy",
                    .open_date = "OpenDate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .projects = "Projects",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_recipes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/recipes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecipes",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        recipe_version: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .recipe_version = "recipeVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .recipe_version = "RecipeVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recipes) } {
            return .{ .service_metadata = service_metadata, .action = list_recipes };
        }
    },
    Response: type = struct {
        recipes: []Recipe,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recipes = "Recipes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_recipe_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/recipeVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecipeVersions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        name: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .name = "name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recipe_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_recipe_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recipes: []Recipe,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .recipes = "Recipes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_rulesets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rulesets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRulesets",
    Request: type = struct {
        target_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .target_arn = "targetArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rulesets) } {
            return .{ .service_metadata = service_metadata, .action = list_rulesets };
        }
    },
    Response: type = struct {
        rulesets: []struct {
            account_id: ?[]const u8 = null,
            created_by: ?[]const u8 = null,
            create_date: ?i64 = null,
            description: ?[]const u8 = null,
            last_modified_by: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            name: []const u8,
            resource_arn: ?[]const u8 = null,
            rule_count: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            target_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .created_by = "CreatedBy",
                    .create_date = "CreateDate",
                    .description = "Description",
                    .last_modified_by = "LastModifiedBy",
                    .last_modified_date = "LastModifiedDate",
                    .name = "Name",
                    .resource_arn = "ResourceArn",
                    .rule_count = "RuleCount",
                    .tags = "Tags",
                    .target_arn = "TargetArn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rulesets = "Rulesets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_schedules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/schedules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSchedules",
    Request: type = struct {
        job_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .job_name = "jobName",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schedules) } {
            return .{ .service_metadata = service_metadata, .action = list_schedules };
        }
    },
    Response: type = struct {
        schedules: []struct {
            account_id: ?[]const u8 = null,
            created_by: ?[]const u8 = null,
            create_date: ?i64 = null,
            job_names: ?[][]const u8 = null,
            last_modified_by: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            resource_arn: ?[]const u8 = null,
            cron_expression: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .created_by = "CreatedBy",
                    .create_date = "CreateDate",
                    .job_names = "JobNames",
                    .last_modified_by = "LastModifiedBy",
                    .last_modified_date = "LastModifiedDate",
                    .resource_arn = "ResourceArn",
                    .cron_expression = "CronExpression",
                    .tags = "Tags",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schedules = "Schedules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const publish_recipe: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/recipes/{Name}/publishRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "PublishRecipe",
    Request: type = struct {
        description: ?[]const u8 = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_recipe) } {
            return .{ .service_metadata = service_metadata, .action = publish_recipe };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const send_project_session_action: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/projects/{Name}/sendProjectSessionAction",
        .success_code = 200,
    };

    action_name: []const u8 = "SendProjectSessionAction",
    Request: type = struct {
        preview: ?bool = null,
        name: []const u8,
        recipe_step: ?RecipeStep = null,
        step_index: ?i64 = null,
        client_session_id: ?[]const u8 = null,
        view_frame: ?struct {
            start_column_index: i64,
            column_range: ?i64 = null,
            hidden_columns: ?[][]const u8 = null,
            start_row_index: ?i64 = null,
            row_range: ?i64 = null,
            analytics: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_column_index = "StartColumnIndex",
                    .column_range = "ColumnRange",
                    .hidden_columns = "HiddenColumns",
                    .start_row_index = "StartRowIndex",
                    .row_range = "RowRange",
                    .analytics = "Analytics",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preview = "Preview",
                .name = "Name",
                .recipe_step = "RecipeStep",
                .step_index = "StepIndex",
                .client_session_id = "ClientSessionId",
                .view_frame = "ViewFrame",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_project_session_action) } {
            return .{ .service_metadata = service_metadata, .action = send_project_session_action };
        }
    },
    Response: type = struct {
        result: ?[]const u8 = null,
        name: []const u8,
        action_id: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "Result",
                .name = "Name",
                .action_id = "ActionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_job_run: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/jobs/{Name}/startJobRun",
        .success_code = 200,
    };

    action_name: []const u8 = "StartJobRun",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_job_run) } {
            return .{ .service_metadata = service_metadata, .action = start_job_run };
        }
    },
    Response: type = struct {
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const start_project_session: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/projects/{Name}/startProjectSession",
        .success_code = 200,
    };

    action_name: []const u8 = "StartProjectSession",
    Request: type = struct {
        name: []const u8,
        assume_control: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .assume_control = "AssumeControl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_project_session) } {
            return .{ .service_metadata = service_metadata, .action = start_project_session };
        }
    },
    Response: type = struct {
        name: []const u8,
        client_session_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .client_session_id = "ClientSessionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const stop_job_run: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/jobs/{Name}/jobRun/{RunId}/stopJobRun",
        .success_code = 200,
    };

    action_name: []const u8 = "StopJobRun",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_job_run) } {
            return .{ .service_metadata = service_metadata, .action = stop_job_run };
        }
    },
    Response: type = struct {
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_dataset: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/datasets/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataset",
    Request: type = struct {
        name: []const u8,
        format: ?[]const u8 = null,
        format_options: ?FormatOptions = null,
        input: Input,
        path_options: ?PathOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .format = "Format",
                .format_options = "FormatOptions",
                .input = "Input",
                .path_options = "PathOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dataset) } {
            return .{ .service_metadata = service_metadata, .action = update_dataset };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_profile_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/profileJobs/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProfileJob",
    Request: type = struct {
        configuration: ?ProfileConfiguration = null,
        encryption_key_arn: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        name: []const u8,
        log_subscription: ?[]const u8 = null,
        max_capacity: ?i64 = null,
        max_retries: ?i64 = null,
        output_location: S3Location,
        validation_configurations: ?[]ValidationConfiguration = null,
        role_arn: []const u8,
        timeout: ?i64 = null,
        job_sample: ?JobSample = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "Configuration",
                .encryption_key_arn = "EncryptionKeyArn",
                .encryption_mode = "EncryptionMode",
                .name = "Name",
                .log_subscription = "LogSubscription",
                .max_capacity = "MaxCapacity",
                .max_retries = "MaxRetries",
                .output_location = "OutputLocation",
                .validation_configurations = "ValidationConfigurations",
                .role_arn = "RoleArn",
                .timeout = "Timeout",
                .job_sample = "JobSample",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_profile_job) } {
            return .{ .service_metadata = service_metadata, .action = update_profile_job };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_project: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/projects/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProject",
    Request: type = struct {
        sample: ?Sample = null,
        role_arn: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sample = "Sample",
                .role_arn = "RoleArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_project) } {
            return .{ .service_metadata = service_metadata, .action = update_project };
        }
    },
    Response: type = struct {
        last_modified_date: ?i64 = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .last_modified_date = "LastModifiedDate",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_recipe: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/recipes/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRecipe",
    Request: type = struct {
        description: ?[]const u8 = null,
        name: []const u8,
        steps: ?[]RecipeStep = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .name = "Name",
                .steps = "Steps",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_recipe) } {
            return .{ .service_metadata = service_metadata, .action = update_recipe };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_recipe_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/recipeJobs/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRecipeJob",
    Request: type = struct {
        encryption_key_arn: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        name: []const u8,
        log_subscription: ?[]const u8 = null,
        max_capacity: ?i64 = null,
        max_retries: ?i64 = null,
        outputs: ?[]Output = null,
        data_catalog_outputs: ?[]DataCatalogOutput = null,
        database_outputs: ?[]DatabaseOutput = null,
        role_arn: []const u8,
        timeout: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_key_arn = "EncryptionKeyArn",
                .encryption_mode = "EncryptionMode",
                .name = "Name",
                .log_subscription = "LogSubscription",
                .max_capacity = "MaxCapacity",
                .max_retries = "MaxRetries",
                .outputs = "Outputs",
                .data_catalog_outputs = "DataCatalogOutputs",
                .database_outputs = "DatabaseOutputs",
                .role_arn = "RoleArn",
                .timeout = "Timeout",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_recipe_job) } {
            return .{ .service_metadata = service_metadata, .action = update_recipe_job };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_ruleset: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/rulesets/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRuleset",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        rules: []Rule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ruleset) } {
            return .{ .service_metadata = service_metadata, .action = update_ruleset };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_schedule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/schedules/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSchedule",
    Request: type = struct {
        job_names: ?[][]const u8 = null,
        cron_expression: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_names = "JobNames",
                .cron_expression = "CronExpression",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_schedule };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};

pub const Rule = struct {
    name: []const u8,
    disabled: ?bool = null,
    check_expression: []const u8,
    substitution_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    threshold: ?Threshold = null,
    column_selectors: ?[]ColumnSelector = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .disabled = "Disabled",
            .check_expression = "CheckExpression",
            .substitution_map = "SubstitutionMap",
            .threshold = "Threshold",
            .column_selectors = "ColumnSelectors",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "substitution_map", field_name))
            return try serializeMap(self.substitution_map, self.fieldNameFor("substitution_map"), options, out_stream);
        return false;
    }
};

pub const ColumnSelector = struct {
    regex: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .regex = "Regex",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Threshold = struct {
    value: f64,
    type: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .type = "Type",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseOutput = struct {
    glue_connection_name: []const u8,
    database_options: DatabaseTableOutputOptions,
    database_output_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .glue_connection_name = "GlueConnectionName",
            .database_options = "DatabaseOptions",
            .database_output_mode = "DatabaseOutputMode",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseTableOutputOptions = struct {
    temp_directory: ?S3Location = null,
    table_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .temp_directory = "TempDirectory",
            .table_name = "TableName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    bucket: []const u8,
    key: ?[]const u8 = null,
    bucket_owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
            .bucket_owner = "BucketOwner",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCatalogOutput = struct {
    catalog_id: ?[]const u8 = null,
    database_name: []const u8,
    table_name: []const u8,
    s3_options: ?S3TableOutputOptions = null,
    database_options: ?DatabaseTableOutputOptions = null,
    overwrite: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .s3_options = "S3Options",
            .database_options = "DatabaseOptions",
            .overwrite = "Overwrite",
        };
        return @field(mappings, field_name);
    }
};

pub const S3TableOutputOptions = struct {
    location: S3Location,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .location = "Location",
        };
        return @field(mappings, field_name);
    }
};

pub const Output = struct {
    compression_format: ?[]const u8 = null,
    format: ?[]const u8 = null,
    partition_columns: ?[][]const u8 = null,
    location: S3Location,
    overwrite: ?bool = null,
    format_options: ?OutputFormatOptions = null,
    max_output_files: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compression_format = "CompressionFormat",
            .format = "Format",
            .partition_columns = "PartitionColumns",
            .location = "Location",
            .overwrite = "Overwrite",
            .format_options = "FormatOptions",
            .max_output_files = "MaxOutputFiles",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputFormatOptions = struct {
    csv: ?CsvOutputOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv = "Csv",
        };
        return @field(mappings, field_name);
    }
};

pub const CsvOutputOptions = struct {
    delimiter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delimiter = "Delimiter",
        };
        return @field(mappings, field_name);
    }
};

pub const RecipeStep = struct {
    action: RecipeAction,
    condition_expressions: ?[]ConditionExpression = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .condition_expressions = "ConditionExpressions",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionExpression = struct {
    condition: []const u8,
    value: ?[]const u8 = null,
    target_column: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition = "Condition",
            .value = "Value",
            .target_column = "TargetColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const RecipeAction = struct {
    operation: []const u8,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .operation = "Operation",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const Sample = struct {
    size: ?i64 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .size = "Size",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const JobSample = struct {
    mode: ?[]const u8 = null,
    size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .size = "Size",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationConfiguration = struct {
    ruleset_arn: []const u8,
    validation_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ruleset_arn = "RulesetArn",
            .validation_mode = "ValidationMode",
        };
        return @field(mappings, field_name);
    }
};

pub const ProfileConfiguration = struct {
    dataset_statistics_configuration: ?StatisticsConfiguration = null,
    profile_columns: ?[]ColumnSelector = null,
    column_statistics_configurations: ?[]ColumnStatisticsConfiguration = null,
    entity_detector_configuration: ?EntityDetectorConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dataset_statistics_configuration = "DatasetStatisticsConfiguration",
            .profile_columns = "ProfileColumns",
            .column_statistics_configurations = "ColumnStatisticsConfigurations",
            .entity_detector_configuration = "EntityDetectorConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const EntityDetectorConfiguration = struct {
    entity_types: [][]const u8,
    allowed_statistics: ?[]AllowedStatistics = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_types = "EntityTypes",
            .allowed_statistics = "AllowedStatistics",
        };
        return @field(mappings, field_name);
    }
};

pub const AllowedStatistics = struct {
    statistics: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statistics = "Statistics",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnStatisticsConfiguration = struct {
    selectors: ?[]ColumnSelector = null,
    statistics: StatisticsConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selectors = "Selectors",
            .statistics = "Statistics",
        };
        return @field(mappings, field_name);
    }
};

pub const StatisticsConfiguration = struct {
    included_statistics: ?[][]const u8 = null,
    overrides: ?[]StatisticOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .included_statistics = "IncludedStatistics",
            .overrides = "Overrides",
        };
        return @field(mappings, field_name);
    }
};

pub const StatisticOverride = struct {
    statistic: []const u8,
    parameters: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statistic = "Statistic",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const PathOptions = struct {
    last_modified_date_condition: ?FilterExpression = null,
    files_limit: ?FilesLimit = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?DatasetParameter = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_modified_date_condition = "LastModifiedDateCondition",
            .files_limit = "FilesLimit",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const DatasetParameter = struct {
    name: []const u8,
    type: []const u8,
    datetime_options: ?DatetimeOptions = null,
    create_column: ?bool = null,
    filter: ?FilterExpression = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .datetime_options = "DatetimeOptions",
            .create_column = "CreateColumn",
            .filter = "Filter",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterExpression = struct {
    expression: []const u8,
    values_map: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .values_map = "ValuesMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "values_map", field_name))
            return try serializeMap(self.values_map, self.fieldNameFor("values_map"), options, out_stream);
        return false;
    }
};

pub const DatetimeOptions = struct {
    format: []const u8,
    timezone_offset: ?[]const u8 = null,
    locale_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .timezone_offset = "TimezoneOffset",
            .locale_code = "LocaleCode",
        };
        return @field(mappings, field_name);
    }
};

pub const FilesLimit = struct {
    max_files: i64,
    ordered_by: ?[]const u8 = null,
    order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_files = "MaxFiles",
            .ordered_by = "OrderedBy",
            .order = "Order",
        };
        return @field(mappings, field_name);
    }
};

pub const Input = struct {
    s3_input_definition: ?S3Location = null,
    data_catalog_input_definition: ?DataCatalogInputDefinition = null,
    database_input_definition: ?DatabaseInputDefinition = null,
    metadata: ?Metadata = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_input_definition = "S3InputDefinition",
            .data_catalog_input_definition = "DataCatalogInputDefinition",
            .database_input_definition = "DatabaseInputDefinition",
            .metadata = "Metadata",
        };
        return @field(mappings, field_name);
    }
};

pub const Metadata = struct {
    source_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_arn = "SourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseInputDefinition = struct {
    glue_connection_name: []const u8,
    database_table_name: ?[]const u8 = null,
    temp_directory: ?S3Location = null,
    query_string: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .glue_connection_name = "GlueConnectionName",
            .database_table_name = "DatabaseTableName",
            .temp_directory = "TempDirectory",
            .query_string = "QueryString",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCatalogInputDefinition = struct {
    catalog_id: ?[]const u8 = null,
    database_name: []const u8,
    table_name: []const u8,
    temp_directory: ?S3Location = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .temp_directory = "TempDirectory",
        };
        return @field(mappings, field_name);
    }
};

pub const FormatOptions = struct {
    json: ?JsonOptions = null,
    excel: ?ExcelOptions = null,
    csv: ?CsvOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .json = "Json",
            .excel = "Excel",
            .csv = "Csv",
        };
        return @field(mappings, field_name);
    }
};

pub const CsvOptions = struct {
    delimiter: ?[]const u8 = null,
    header_row: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delimiter = "Delimiter",
            .header_row = "HeaderRow",
        };
        return @field(mappings, field_name);
    }
};

pub const ExcelOptions = struct {
    sheet_names: ?[][]const u8 = null,
    sheet_indexes: ?[]i64 = null,
    header_row: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_names = "SheetNames",
            .sheet_indexes = "SheetIndexes",
            .header_row = "HeaderRow",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonOptions = struct {
    multi_line: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .multi_line = "MultiLine",
        };
        return @field(mappings, field_name);
    }
};

pub const Recipe = struct {
    created_by: ?[]const u8 = null,
    create_date: ?i64 = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    project_name: ?[]const u8 = null,
    published_by: ?[]const u8 = null,
    published_date: ?i64 = null,
    description: ?[]const u8 = null,
    name: []const u8,
    resource_arn: ?[]const u8 = null,
    steps: ?[]RecipeStep = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    recipe_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .created_by = "CreatedBy",
            .create_date = "CreateDate",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .project_name = "ProjectName",
            .published_by = "PublishedBy",
            .published_date = "PublishedDate",
            .description = "Description",
            .name = "Name",
            .resource_arn = "ResourceArn",
            .steps = "Steps",
            .tags = "Tags",
            .recipe_version = "RecipeVersion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const RecipeReference = struct {
    name: []const u8,
    recipe_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .recipe_version = "RecipeVersion",
        };
        return @field(mappings, field_name);
    }
};
