const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "DataExchange";
pub const arn_namespace: ?[]const u8 = "dataexchange";
pub const endpoint_prefix: []const u8 = "dataexchange";
pub const sigv4_name: []const u8 = "dataexchange";
pub const name: []const u8 = "DataExchange";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "DataExchange",
    arn_namespace: ?[]const u8 = "dataexchange",
    endpoint_prefix: []const u8 = "dataexchange",
    sigv4_name: []const u8 = "dataexchange",
    name: []const u8 = "DataExchange",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/jobs/{JobId}",
        .success_code = 204,
    };

    action_name: []const u8 = "CancelJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_data_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/data-sets",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDataSet",
    Request: type = struct {
        asset_type: []const u8,
        description: []const u8,
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_type = "AssetType",
                .description = "Description",
                .name = "Name",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_set) } {
            return .{ .service_metadata = service_metadata, .action = create_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        asset_type: ?[]const u8 = null,
        created_at: ?i64 = null,
        description: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        origin: ?[]const u8 = null,
        origin_details: ?OriginDetails = null,
        source_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .asset_type = "AssetType",
                .created_at = "CreatedAt",
                .description = "Description",
                .id = "Id",
                .name = "Name",
                .origin = "Origin",
                .origin_details = "OriginDetails",
                .source_id = "SourceId",
                .tags = "Tags",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceLimitExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_event_action: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/event-actions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateEventAction",
    Request: type = struct {
        action: Action,
        event: Event,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "Action",
                .event = "Event",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_action) } {
            return .{ .service_metadata = service_metadata, .action = create_event_action };
        }
    },
    Response: type = struct {
        action: ?Action = null,
        arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        event: ?Event = null,
        id: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "Action",
                .arn = "Arn",
                .created_at = "CreatedAt",
                .event = "Event",
                .id = "Id",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceLimitExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/jobs",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        details: struct {
            export_asset_to_signed_url: ?struct {
                asset_id: []const u8,
                data_set_id: []const u8,
                revision_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .asset_id = "AssetId",
                        .data_set_id = "DataSetId",
                        .revision_id = "RevisionId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            export_assets_to_s3: ?struct {
                asset_destinations: []AssetDestinationEntry,
                data_set_id: []const u8,
                encryption: ?ExportServerSideEncryption = null,
                revision_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .asset_destinations = "AssetDestinations",
                        .data_set_id = "DataSetId",
                        .encryption = "Encryption",
                        .revision_id = "RevisionId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            export_revisions_to_s3: ?struct {
                data_set_id: []const u8,
                encryption: ?ExportServerSideEncryption = null,
                revision_destinations: []RevisionDestinationEntry,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .data_set_id = "DataSetId",
                        .encryption = "Encryption",
                        .revision_destinations = "RevisionDestinations",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            import_asset_from_signed_url: ?struct {
                asset_name: []const u8,
                data_set_id: []const u8,
                md5_hash: []const u8,
                revision_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .asset_name = "AssetName",
                        .data_set_id = "DataSetId",
                        .md5_hash = "Md5Hash",
                        .revision_id = "RevisionId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            import_assets_from_s3: ?struct {
                asset_sources: []AssetSourceEntry,
                data_set_id: []const u8,
                revision_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .asset_sources = "AssetSources",
                        .data_set_id = "DataSetId",
                        .revision_id = "RevisionId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            import_assets_from_redshift_data_shares: ?struct {
                asset_sources: []RedshiftDataShareAssetSourceEntry,
                data_set_id: []const u8,
                revision_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .asset_sources = "AssetSources",
                        .data_set_id = "DataSetId",
                        .revision_id = "RevisionId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            import_asset_from_api_gateway_api: ?struct {
                api_description: ?[]const u8 = null,
                api_id: []const u8,
                api_key: ?[]const u8 = null,
                api_name: []const u8,
                api_specification_md5_hash: []const u8,
                data_set_id: []const u8,
                protocol_type: []const u8,
                revision_id: []const u8,
                stage: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .api_description = "ApiDescription",
                        .api_id = "ApiId",
                        .api_key = "ApiKey",
                        .api_name = "ApiName",
                        .api_specification_md5_hash = "ApiSpecificationMd5Hash",
                        .data_set_id = "DataSetId",
                        .protocol_type = "ProtocolType",
                        .revision_id = "RevisionId",
                        .stage = "Stage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            create_s3_data_access_from_s3_bucket: ?struct {
                asset_source: S3DataAccessAssetSourceEntry,
                data_set_id: []const u8,
                revision_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .asset_source = "AssetSource",
                        .data_set_id = "DataSetId",
                        .revision_id = "RevisionId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            import_assets_from_lake_formation_tag_policy: ?struct {
                catalog_id: []const u8,
                database: ?DatabaseLFTagPolicyAndPermissions = null,
                table: ?TableLFTagPolicyAndPermissions = null,
                role_arn: []const u8,
                data_set_id: []const u8,
                revision_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .catalog_id = "CatalogId",
                        .database = "Database",
                        .table = "Table",
                        .role_arn = "RoleArn",
                        .data_set_id = "DataSetId",
                        .revision_id = "RevisionId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .export_asset_to_signed_url = "ExportAssetToSignedUrl",
                    .export_assets_to_s3 = "ExportAssetsToS3",
                    .export_revisions_to_s3 = "ExportRevisionsToS3",
                    .import_asset_from_signed_url = "ImportAssetFromSignedUrl",
                    .import_assets_from_s3 = "ImportAssetsFromS3",
                    .import_assets_from_redshift_data_shares = "ImportAssetsFromRedshiftDataShares",
                    .import_asset_from_api_gateway_api = "ImportAssetFromApiGatewayApi",
                    .create_s3_data_access_from_s3_bucket = "CreateS3DataAccessFromS3Bucket",
                    .import_assets_from_lake_formation_tag_policy = "ImportAssetsFromLakeFormationTagPolicy",
                };
                return @field(mappings, field_name);
            }
        },
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .details = "Details",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        details: ?ResponseDetails = null,
        errors: ?[]JobError = null,
        id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        type: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .created_at = "CreatedAt",
                .details = "Details",
                .errors = "Errors",
                .id = "Id",
                .state = "State",
                .type = "Type",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_revision: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/data-sets/{DataSetId}/revisions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRevision",
    Request: type = struct {
        comment: ?[]const u8 = null,
        data_set_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment = "Comment",
                .data_set_id = "DataSetId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_revision) } {
            return .{ .service_metadata = service_metadata, .action = create_revision };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        comment: ?[]const u8 = null,
        created_at: ?i64 = null,
        data_set_id: ?[]const u8 = null,
        finalized: ?bool = null,
        id: ?[]const u8 = null,
        source_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        updated_at: ?i64 = null,
        revocation_comment: ?[]const u8 = null,
        revoked: ?bool = null,
        revoked_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .comment = "Comment",
                .created_at = "CreatedAt",
                .data_set_id = "DataSetId",
                .finalized = "Finalized",
                .id = "Id",
                .source_id = "SourceId",
                .tags = "Tags",
                .updated_at = "UpdatedAt",
                .revocation_comment = "RevocationComment",
                .revoked = "Revoked",
                .revoked_at = "RevokedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_asset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/data-sets/{DataSetId}/revisions/{RevisionId}/assets/{AssetId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAsset",
    Request: type = struct {
        asset_id: []const u8,
        data_set_id: []const u8,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "AssetId",
                .data_set_id = "DataSetId",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_asset) } {
            return .{ .service_metadata = service_metadata, .action = delete_asset };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_data_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/data-sets/{DataSetId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDataSet",
    Request: type = struct {
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_set };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_event_action: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/event-actions/{EventActionId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteEventAction",
    Request: type = struct {
        event_action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_action_id = "EventActionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_action) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_action };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_revision: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/data-sets/{DataSetId}/revisions/{RevisionId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRevision",
    Request: type = struct {
        data_set_id: []const u8,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_revision) } {
            return .{ .service_metadata = service_metadata, .action = delete_revision };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_asset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/data-sets/{DataSetId}/revisions/{RevisionId}/assets/{AssetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAsset",
    Request: type = struct {
        asset_id: []const u8,
        data_set_id: []const u8,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "AssetId",
                .data_set_id = "DataSetId",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_asset) } {
            return .{ .service_metadata = service_metadata, .action = get_asset };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        asset_details: ?AssetDetails = null,
        asset_type: ?[]const u8 = null,
        created_at: ?i64 = null,
        data_set_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        source_id: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .asset_details = "AssetDetails",
                .asset_type = "AssetType",
                .created_at = "CreatedAt",
                .data_set_id = "DataSetId",
                .id = "Id",
                .name = "Name",
                .revision_id = "RevisionId",
                .source_id = "SourceId",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_data_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/data-sets/{DataSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataSet",
    Request: type = struct {
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_set) } {
            return .{ .service_metadata = service_metadata, .action = get_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        asset_type: ?[]const u8 = null,
        created_at: ?i64 = null,
        description: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        origin: ?[]const u8 = null,
        origin_details: ?OriginDetails = null,
        source_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .asset_type = "AssetType",
                .created_at = "CreatedAt",
                .description = "Description",
                .id = "Id",
                .name = "Name",
                .origin = "Origin",
                .origin_details = "OriginDetails",
                .source_id = "SourceId",
                .tags = "Tags",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_event_action: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/event-actions/{EventActionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEventAction",
    Request: type = struct {
        event_action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_action_id = "EventActionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_action) } {
            return .{ .service_metadata = service_metadata, .action = get_event_action };
        }
    },
    Response: type = struct {
        action: ?Action = null,
        arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        event: ?Event = null,
        id: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "Action",
                .arn = "Arn",
                .created_at = "CreatedAt",
                .event = "Event",
                .id = "Id",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/jobs/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job) } {
            return .{ .service_metadata = service_metadata, .action = get_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        details: ?ResponseDetails = null,
        errors: ?[]JobError = null,
        id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        type: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .created_at = "CreatedAt",
                .details = "Details",
                .errors = "Errors",
                .id = "Id",
                .state = "State",
                .type = "Type",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_revision: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/data-sets/{DataSetId}/revisions/{RevisionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRevision",
    Request: type = struct {
        data_set_id: []const u8,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_revision) } {
            return .{ .service_metadata = service_metadata, .action = get_revision };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        comment: ?[]const u8 = null,
        created_at: ?i64 = null,
        data_set_id: ?[]const u8 = null,
        finalized: ?bool = null,
        id: ?[]const u8 = null,
        source_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        updated_at: ?i64 = null,
        revocation_comment: ?[]const u8 = null,
        revoked: ?bool = null,
        revoked_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .comment = "Comment",
                .created_at = "CreatedAt",
                .data_set_id = "DataSetId",
                .finalized = "Finalized",
                .id = "Id",
                .source_id = "SourceId",
                .tags = "Tags",
                .updated_at = "UpdatedAt",
                .revocation_comment = "RevocationComment",
                .revoked = "Revoked",
                .revoked_at = "RevokedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_set_revisions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/data-sets/{DataSetId}/revisions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSetRevisions",
    Request: type = struct {
        data_set_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_set_revisions) } {
            return .{ .service_metadata = service_metadata, .action = list_data_set_revisions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        revisions: ?[]struct {
            arn: []const u8,
            comment: ?[]const u8 = null,
            created_at: i64,
            data_set_id: []const u8,
            finalized: ?bool = null,
            id: []const u8,
            source_id: ?[]const u8 = null,
            updated_at: i64,
            revocation_comment: ?[]const u8 = null,
            revoked: ?bool = null,
            revoked_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .comment = "Comment",
                    .created_at = "CreatedAt",
                    .data_set_id = "DataSetId",
                    .finalized = "Finalized",
                    .id = "Id",
                    .source_id = "SourceId",
                    .updated_at = "UpdatedAt",
                    .revocation_comment = "RevocationComment",
                    .revoked = "Revoked",
                    .revoked_at = "RevokedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .revisions = "Revisions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/data-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSets",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        origin: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .origin = "origin",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .origin = "Origin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sets };
        }
    },
    Response: type = struct {
        data_sets: ?[]struct {
            arn: []const u8,
            asset_type: []const u8,
            created_at: i64,
            description: []const u8,
            id: []const u8,
            name: []const u8,
            origin: []const u8,
            origin_details: ?OriginDetails = null,
            source_id: ?[]const u8 = null,
            updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .asset_type = "AssetType",
                    .created_at = "CreatedAt",
                    .description = "Description",
                    .id = "Id",
                    .name = "Name",
                    .origin = "Origin",
                    .origin_details = "OriginDetails",
                    .source_id = "SourceId",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_sets = "DataSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_event_actions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/event-actions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEventActions",
    Request: type = struct {
        event_source_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .event_source_id = "eventSourceId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_source_id = "EventSourceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_event_actions };
        }
    },
    Response: type = struct {
        event_actions: ?[]struct {
            action: Action,
            arn: []const u8,
            created_at: i64,
            event: Event,
            id: []const u8,
            updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .arn = "Arn",
                    .created_at = "CreatedAt",
                    .event = "Event",
                    .id = "Id",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_actions = "EventActions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        data_set_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .data_set_id = "dataSetId",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .revision_id = "revisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            arn: []const u8,
            created_at: i64,
            details: ResponseDetails,
            errors: ?[]JobError = null,
            id: []const u8,
            state: []const u8,
            type: []const u8,
            updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .created_at = "CreatedAt",
                    .details = "Details",
                    .errors = "Errors",
                    .id = "Id",
                    .state = "State",
                    .type = "Type",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_revision_assets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/data-sets/{DataSetId}/revisions/{RevisionId}/assets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRevisionAssets",
    Request: type = struct {
        data_set_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        revision_id: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_revision_assets) } {
            return .{ .service_metadata = service_metadata, .action = list_revision_assets };
        }
    },
    Response: type = struct {
        assets: ?[]struct {
            arn: []const u8,
            asset_details: AssetDetails,
            asset_type: []const u8,
            created_at: i64,
            data_set_id: []const u8,
            id: []const u8,
            name: []const u8,
            revision_id: []const u8,
            source_id: ?[]const u8 = null,
            updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .asset_details = "AssetDetails",
                    .asset_type = "AssetType",
                    .created_at = "CreatedAt",
                    .data_set_id = "DataSetId",
                    .id = "Id",
                    .name = "Name",
                    .revision_id = "RevisionId",
                    .source_id = "SourceId",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assets = "Assets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const revoke_revision: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/data-sets/{DataSetId}/revisions/{RevisionId}/revoke",
        .success_code = 200,
    };

    action_name: []const u8 = "RevokeRevision",
    Request: type = struct {
        data_set_id: []const u8,
        revision_id: []const u8,
        revocation_comment: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .revision_id = "RevisionId",
                .revocation_comment = "RevocationComment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_revision) } {
            return .{ .service_metadata = service_metadata, .action = revoke_revision };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        comment: ?[]const u8 = null,
        created_at: ?i64 = null,
        data_set_id: ?[]const u8 = null,
        finalized: ?bool = null,
        id: ?[]const u8 = null,
        source_id: ?[]const u8 = null,
        updated_at: ?i64 = null,
        revocation_comment: ?[]const u8 = null,
        revoked: ?bool = null,
        revoked_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .comment = "Comment",
                .created_at = "CreatedAt",
                .data_set_id = "DataSetId",
                .finalized = "Finalized",
                .id = "Id",
                .source_id = "SourceId",
                .updated_at = "UpdatedAt",
                .revocation_comment = "RevocationComment",
                .revoked = "Revoked",
                .revoked_at = "RevokedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const send_api_asset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1",
        .success_code = 200,
    };

    action_name: []const u8 = "SendApiAsset",
    Request: type = struct {
        body: ?[]const u8 = null,
        query_string_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        asset_id: []const u8,
        data_set_id: []const u8,
        request_headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        method: ?[]const u8 = null,
        path: ?[]const u8 = null,
        revision_id: []const u8,
        pub const http_header = .{
            .asset_id = "x-amzn-dataexchange-asset-id",
            .data_set_id = "x-amzn-dataexchange-data-set-id",
            .method = "x-amzn-dataexchange-http-method",
            .path = "x-amzn-dataexchange-path",
            .revision_id = "x-amzn-dataexchange-revision-id",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .query_string_parameters = "QueryStringParameters",
                .asset_id = "AssetId",
                .data_set_id = "DataSetId",
                .request_headers = "RequestHeaders",
                .method = "Method",
                .path = "Path",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "query_string_parameters", field_name))
                return try serializeMap(self.query_string_parameters, self.fieldNameFor("query_string_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_headers", field_name))
                return try serializeMap(self.request_headers, self.fieldNameFor("request_headers"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_api_asset) } {
            return .{ .service_metadata = service_metadata, .action = send_api_asset };
        }
    },
    Response: type = struct {
        body: ?[]const u8 = null,
        response_headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .response_headers = "ResponseHeaders",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_headers", field_name))
                return try serializeMap(self.response_headers, self.fieldNameFor("response_headers"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const send_data_set_notification: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/data-sets/{DataSetId}/notification",
        .success_code = 202,
    };

    action_name: []const u8 = "SendDataSetNotification",
    Request: type = struct {
        scope: ?struct {
            lake_formation_tag_policies: ?[]struct {
                database: ?[]const u8 = null,
                table: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .database = "Database",
                        .table = "Table",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            redshift_data_shares: ?[]struct {
                arn: []const u8,
                database: []const u8,
                function: ?[]const u8 = null,
                table: ?[]const u8 = null,
                schema: ?[]const u8 = null,
                view: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "Arn",
                        .database = "Database",
                        .function = "Function",
                        .table = "Table",
                        .schema = "Schema",
                        .view = "View",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            s3_data_accesses: ?[]struct {
                key_prefixes: ?[][]const u8 = null,
                keys: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key_prefixes = "KeyPrefixes",
                        .keys = "Keys",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lake_formation_tag_policies = "LakeFormationTagPolicies",
                    .redshift_data_shares = "RedshiftDataShares",
                    .s3_data_accesses = "S3DataAccesses",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,
        comment: ?[]const u8 = null,
        data_set_id: []const u8,
        details: ?struct {
            data_update: ?struct {
                data_updated_at: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .data_updated_at = "DataUpdatedAt",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            deprecation: ?struct {
                deprecation_at: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .deprecation_at = "DeprecationAt",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            schema_change: ?struct {
                changes: ?[]struct {
                    name: []const u8,
                    type: []const u8,
                    description: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .type = "Type",
                            .description = "Description",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                schema_change_at: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .changes = "Changes",
                        .schema_change_at = "SchemaChangeAt",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_update = "DataUpdate",
                    .deprecation = "Deprecation",
                    .schema_change = "SchemaChange",
                };
                return @field(mappings, field_name);
            }
        } = null,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .client_token = "ClientToken",
                .comment = "Comment",
                .data_set_id = "DataSetId",
                .details = "Details",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_data_set_notification) } {
            return .{ .service_metadata = service_metadata, .action = send_data_set_notification };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_job: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v1/jobs/{JobId}",
        .success_code = 202,
    };

    action_name: []const u8 = "StartJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_job) } {
            return .{ .service_metadata = service_metadata, .action = start_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
} = .{};
pub const update_asset: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v1/data-sets/{DataSetId}/revisions/{RevisionId}/assets/{AssetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAsset",
    Request: type = struct {
        asset_id: []const u8,
        data_set_id: []const u8,
        name: []const u8,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "AssetId",
                .data_set_id = "DataSetId",
                .name = "Name",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_asset) } {
            return .{ .service_metadata = service_metadata, .action = update_asset };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        asset_details: ?AssetDetails = null,
        asset_type: ?[]const u8 = null,
        created_at: ?i64 = null,
        data_set_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        source_id: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .asset_details = "AssetDetails",
                .asset_type = "AssetType",
                .created_at = "CreatedAt",
                .data_set_id = "DataSetId",
                .id = "Id",
                .name = "Name",
                .revision_id = "RevisionId",
                .source_id = "SourceId",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_data_set: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v1/data-sets/{DataSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSet",
    Request: type = struct {
        data_set_id: []const u8,
        description: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .description = "Description",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_set) } {
            return .{ .service_metadata = service_metadata, .action = update_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        asset_type: ?[]const u8 = null,
        created_at: ?i64 = null,
        description: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        origin: ?[]const u8 = null,
        origin_details: ?OriginDetails = null,
        source_id: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .asset_type = "AssetType",
                .created_at = "CreatedAt",
                .description = "Description",
                .id = "Id",
                .name = "Name",
                .origin = "Origin",
                .origin_details = "OriginDetails",
                .source_id = "SourceId",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_event_action: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v1/event-actions/{EventActionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEventAction",
    Request: type = struct {
        action: ?Action = null,
        event_action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "Action",
                .event_action_id = "EventActionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_event_action) } {
            return .{ .service_metadata = service_metadata, .action = update_event_action };
        }
    },
    Response: type = struct {
        action: ?Action = null,
        arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        event: ?Event = null,
        id: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "Action",
                .arn = "Arn",
                .created_at = "CreatedAt",
                .event = "Event",
                .id = "Id",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_revision: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v1/data-sets/{DataSetId}/revisions/{RevisionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRevision",
    Request: type = struct {
        comment: ?[]const u8 = null,
        data_set_id: []const u8,
        finalized: ?bool = null,
        revision_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment = "Comment",
                .data_set_id = "DataSetId",
                .finalized = "Finalized",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_revision) } {
            return .{ .service_metadata = service_metadata, .action = update_revision };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        comment: ?[]const u8 = null,
        created_at: ?i64 = null,
        data_set_id: ?[]const u8 = null,
        finalized: ?bool = null,
        id: ?[]const u8 = null,
        source_id: ?[]const u8 = null,
        updated_at: ?i64 = null,
        revocation_comment: ?[]const u8 = null,
        revoked: ?bool = null,
        revoked_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .comment = "Comment",
                .created_at = "CreatedAt",
                .data_set_id = "DataSetId",
                .finalized = "Finalized",
                .id = "Id",
                .source_id = "SourceId",
                .updated_at = "UpdatedAt",
                .revocation_comment = "RevocationComment",
                .revoked = "Revoked",
                .revoked_at = "RevokedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Event = struct {
    revision_published: ?RevisionPublished = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .revision_published = "RevisionPublished",
        };
        return @field(mappings, field_name);
    }
};

pub const RevisionPublished = struct {
    data_set_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_id = "DataSetId",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    export_revision_to_s3: ?AutoExportRevisionToS3RequestDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .export_revision_to_s3 = "ExportRevisionToS3",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoExportRevisionToS3RequestDetails = struct {
    encryption: ?ExportServerSideEncryption = null,
    revision_destination: AutoExportRevisionDestinationEntry,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption = "Encryption",
            .revision_destination = "RevisionDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoExportRevisionDestinationEntry = struct {
    bucket: []const u8,
    key_pattern: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key_pattern = "KeyPattern",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportServerSideEncryption = struct {
    kms_key_arn: ?[]const u8 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "KmsKeyArn",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginDetails = struct {
    product_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_id = "ProductId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetDetails = struct {
    s3_snapshot_asset: ?S3SnapshotAsset = null,
    redshift_data_share_asset: ?RedshiftDataShareAsset = null,
    api_gateway_api_asset: ?ApiGatewayApiAsset = null,
    s3_data_access_asset: ?S3DataAccessAsset = null,
    lake_formation_data_permission_asset: ?LakeFormationDataPermissionAsset = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_snapshot_asset = "S3SnapshotAsset",
            .redshift_data_share_asset = "RedshiftDataShareAsset",
            .api_gateway_api_asset = "ApiGatewayApiAsset",
            .s3_data_access_asset = "S3DataAccessAsset",
            .lake_formation_data_permission_asset = "LakeFormationDataPermissionAsset",
        };
        return @field(mappings, field_name);
    }
};

pub const LakeFormationDataPermissionAsset = struct {
    lake_formation_data_permission_details: LakeFormationDataPermissionDetails,
    lake_formation_data_permission_type: []const u8,
    permissions: [][]const u8,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lake_formation_data_permission_details = "LakeFormationDataPermissionDetails",
            .lake_formation_data_permission_type = "LakeFormationDataPermissionType",
            .permissions = "Permissions",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LakeFormationDataPermissionDetails = struct {
    lf_tag_policy: ?LFTagPolicyDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lf_tag_policy = "LFTagPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagPolicyDetails = struct {
    catalog_id: []const u8,
    resource_type: []const u8,
    resource_details: LFResourceDetails,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .resource_type = "ResourceType",
            .resource_details = "ResourceDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const LFResourceDetails = struct {
    database: ?DatabaseLFTagPolicy = null,
    table: ?TableLFTagPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const TableLFTagPolicy = struct {
    expression: []LFTag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTag = struct {
    tag_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_key = "TagKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseLFTagPolicy = struct {
    expression: []LFTag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DataAccessAsset = struct {
    bucket: []const u8,
    key_prefixes: ?[][]const u8 = null,
    keys: ?[][]const u8 = null,
    s3_access_point_alias: ?[]const u8 = null,
    s3_access_point_arn: ?[]const u8 = null,
    kms_keys_to_grant: ?[]KmsKeyToGrant = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key_prefixes = "KeyPrefixes",
            .keys = "Keys",
            .s3_access_point_alias = "S3AccessPointAlias",
            .s3_access_point_arn = "S3AccessPointArn",
            .kms_keys_to_grant = "KmsKeysToGrant",
        };
        return @field(mappings, field_name);
    }
};

pub const KmsKeyToGrant = struct {
    kms_key_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ApiGatewayApiAsset = struct {
    api_description: ?[]const u8 = null,
    api_endpoint: ?[]const u8 = null,
    api_id: ?[]const u8 = null,
    api_key: ?[]const u8 = null,
    api_name: ?[]const u8 = null,
    api_specification_download_url: ?[]const u8 = null,
    api_specification_download_url_expires_at: ?i64 = null,
    protocol_type: ?[]const u8 = null,
    stage: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_description = "ApiDescription",
            .api_endpoint = "ApiEndpoint",
            .api_id = "ApiId",
            .api_key = "ApiKey",
            .api_name = "ApiName",
            .api_specification_download_url = "ApiSpecificationDownloadUrl",
            .api_specification_download_url_expires_at = "ApiSpecificationDownloadUrlExpiresAt",
            .protocol_type = "ProtocolType",
            .stage = "Stage",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftDataShareAsset = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SnapshotAsset = struct {
    size: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .size = "Size",
        };
        return @field(mappings, field_name);
    }
};

pub const JobError = struct {
    code: []const u8,
    details: ?Details = null,
    limit_name: ?[]const u8 = null,
    limit_value: ?f64 = null,
    message: []const u8,
    resource_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .details = "Details",
            .limit_name = "LimitName",
            .limit_value = "LimitValue",
            .message = "Message",
            .resource_id = "ResourceId",
            .resource_type = "ResourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const Details = struct {
    import_asset_from_signed_url_job_error_details: ?ImportAssetFromSignedUrlJobErrorDetails = null,
    import_assets_from_s3_job_error_details: ?[]AssetSourceEntry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .import_asset_from_signed_url_job_error_details = "ImportAssetFromSignedUrlJobErrorDetails",
            .import_assets_from_s3_job_error_details = "ImportAssetsFromS3JobErrorDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetSourceEntry = struct {
    bucket: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportAssetFromSignedUrlJobErrorDetails = struct {
    asset_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_name = "AssetName",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseDetails = struct {
    export_asset_to_signed_url: ?ExportAssetToSignedUrlResponseDetails = null,
    export_assets_to_s3: ?ExportAssetsToS3ResponseDetails = null,
    export_revisions_to_s3: ?ExportRevisionsToS3ResponseDetails = null,
    import_asset_from_signed_url: ?ImportAssetFromSignedUrlResponseDetails = null,
    import_assets_from_s3: ?ImportAssetsFromS3ResponseDetails = null,
    import_assets_from_redshift_data_shares: ?ImportAssetsFromRedshiftDataSharesResponseDetails = null,
    import_asset_from_api_gateway_api: ?ImportAssetFromApiGatewayApiResponseDetails = null,
    create_s3_data_access_from_s3_bucket: ?CreateS3DataAccessFromS3BucketResponseDetails = null,
    import_assets_from_lake_formation_tag_policy: ?ImportAssetsFromLakeFormationTagPolicyResponseDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .export_asset_to_signed_url = "ExportAssetToSignedUrl",
            .export_assets_to_s3 = "ExportAssetsToS3",
            .export_revisions_to_s3 = "ExportRevisionsToS3",
            .import_asset_from_signed_url = "ImportAssetFromSignedUrl",
            .import_assets_from_s3 = "ImportAssetsFromS3",
            .import_assets_from_redshift_data_shares = "ImportAssetsFromRedshiftDataShares",
            .import_asset_from_api_gateway_api = "ImportAssetFromApiGatewayApi",
            .create_s3_data_access_from_s3_bucket = "CreateS3DataAccessFromS3Bucket",
            .import_assets_from_lake_formation_tag_policy = "ImportAssetsFromLakeFormationTagPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportAssetsFromLakeFormationTagPolicyResponseDetails = struct {
    catalog_id: []const u8,
    database: ?DatabaseLFTagPolicyAndPermissions = null,
    table: ?TableLFTagPolicyAndPermissions = null,
    role_arn: []const u8,
    data_set_id: []const u8,
    revision_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database = "Database",
            .table = "Table",
            .role_arn = "RoleArn",
            .data_set_id = "DataSetId",
            .revision_id = "RevisionId",
        };
        return @field(mappings, field_name);
    }
};

pub const TableLFTagPolicyAndPermissions = struct {
    expression: []LFTag,
    permissions: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseLFTagPolicyAndPermissions = struct {
    expression: []LFTag,
    permissions: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateS3DataAccessFromS3BucketResponseDetails = struct {
    asset_source: S3DataAccessAssetSourceEntry,
    data_set_id: []const u8,
    revision_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_source = "AssetSource",
            .data_set_id = "DataSetId",
            .revision_id = "RevisionId",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DataAccessAssetSourceEntry = struct {
    bucket: []const u8,
    key_prefixes: ?[][]const u8 = null,
    keys: ?[][]const u8 = null,
    kms_keys_to_grant: ?[]KmsKeyToGrant = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key_prefixes = "KeyPrefixes",
            .keys = "Keys",
            .kms_keys_to_grant = "KmsKeysToGrant",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportAssetFromApiGatewayApiResponseDetails = struct {
    api_description: ?[]const u8 = null,
    api_id: []const u8,
    api_key: ?[]const u8 = null,
    api_name: []const u8,
    api_specification_md5_hash: []const u8,
    api_specification_upload_url: []const u8,
    api_specification_upload_url_expires_at: i64,
    data_set_id: []const u8,
    protocol_type: []const u8,
    revision_id: []const u8,
    stage: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_description = "ApiDescription",
            .api_id = "ApiId",
            .api_key = "ApiKey",
            .api_name = "ApiName",
            .api_specification_md5_hash = "ApiSpecificationMd5Hash",
            .api_specification_upload_url = "ApiSpecificationUploadUrl",
            .api_specification_upload_url_expires_at = "ApiSpecificationUploadUrlExpiresAt",
            .data_set_id = "DataSetId",
            .protocol_type = "ProtocolType",
            .revision_id = "RevisionId",
            .stage = "Stage",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportAssetsFromRedshiftDataSharesResponseDetails = struct {
    asset_sources: []RedshiftDataShareAssetSourceEntry,
    data_set_id: []const u8,
    revision_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_sources = "AssetSources",
            .data_set_id = "DataSetId",
            .revision_id = "RevisionId",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftDataShareAssetSourceEntry = struct {
    data_share_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_share_arn = "DataShareArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportAssetsFromS3ResponseDetails = struct {
    asset_sources: []AssetSourceEntry,
    data_set_id: []const u8,
    revision_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_sources = "AssetSources",
            .data_set_id = "DataSetId",
            .revision_id = "RevisionId",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportAssetFromSignedUrlResponseDetails = struct {
    asset_name: []const u8,
    data_set_id: []const u8,
    md5_hash: ?[]const u8 = null,
    revision_id: []const u8,
    signed_url: ?[]const u8 = null,
    signed_url_expires_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_name = "AssetName",
            .data_set_id = "DataSetId",
            .md5_hash = "Md5Hash",
            .revision_id = "RevisionId",
            .signed_url = "SignedUrl",
            .signed_url_expires_at = "SignedUrlExpiresAt",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportRevisionsToS3ResponseDetails = struct {
    data_set_id: []const u8,
    encryption: ?ExportServerSideEncryption = null,
    revision_destinations: []RevisionDestinationEntry,
    event_action_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_id = "DataSetId",
            .encryption = "Encryption",
            .revision_destinations = "RevisionDestinations",
            .event_action_arn = "EventActionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RevisionDestinationEntry = struct {
    bucket: []const u8,
    key_pattern: ?[]const u8 = null,
    revision_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key_pattern = "KeyPattern",
            .revision_id = "RevisionId",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportAssetsToS3ResponseDetails = struct {
    asset_destinations: []AssetDestinationEntry,
    data_set_id: []const u8,
    encryption: ?ExportServerSideEncryption = null,
    revision_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_destinations = "AssetDestinations",
            .data_set_id = "DataSetId",
            .encryption = "Encryption",
            .revision_id = "RevisionId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetDestinationEntry = struct {
    asset_id: []const u8,
    bucket: []const u8,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_id = "AssetId",
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportAssetToSignedUrlResponseDetails = struct {
    asset_id: []const u8,
    data_set_id: []const u8,
    revision_id: []const u8,
    signed_url: ?[]const u8 = null,
    signed_url_expires_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_id = "AssetId",
            .data_set_id = "DataSetId",
            .revision_id = "RevisionId",
            .signed_url = "SignedUrl",
            .signed_url_expires_at = "SignedUrlExpiresAt",
        };
        return @field(mappings, field_name);
    }
};
