const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-10-29";
pub const sdk_id: []const u8 = "Data Pipeline";
pub const arn_namespace: ?[]const u8 = "datapipeline";
pub const endpoint_prefix: []const u8 = "datapipeline";
pub const sigv4_name: []const u8 = "datapipeline";
pub const name: []const u8 = "DataPipeline";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2012-10-29",
    sdk_id: []const u8 = "Data Pipeline",
    arn_namespace: ?[]const u8 = "datapipeline",
    endpoint_prefix: []const u8 = "datapipeline",
    sigv4_name: []const u8 = "datapipeline",
    name: []const u8 = "DataPipeline",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const activate_pipeline: struct {
    action_name: []const u8 = "ActivatePipeline",
    Request: type = struct {
        pipeline_id: []const u8,
        parameter_values: ?[]ParameterValue = null,
        start_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .parameter_values = "parameterValues",
                .start_timestamp = "startTimestamp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = activate_pipeline };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const add_tags: struct {
    action_name: []const u8 = "AddTags",
    Request: type = struct {
        pipeline_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const create_pipeline: struct {
    action_name: []const u8 = "CreatePipeline",
    Request: type = struct {
        name: []const u8,
        unique_id: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .unique_id = "uniqueId",
                .description = "description",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_pipeline };
        }
    },
    Response: type = struct {
        pipeline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const deactivate_pipeline: struct {
    action_name: []const u8 = "DeactivatePipeline",
    Request: type = struct {
        pipeline_id: []const u8,
        cancel_active: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .cancel_active = "cancelActive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deactivate_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = deactivate_pipeline };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const delete_pipeline: struct {
    action_name: []const u8 = "DeletePipeline",
    Request: type = struct {
        pipeline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_pipeline };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineNotFound,
    },
} = .{};
pub const describe_objects: struct {
    action_name: []const u8 = "DescribeObjects",
    Request: type = struct {
        pipeline_id: []const u8,
        object_ids: [][]const u8,
        evaluate_expressions: ?bool = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .object_ids = "objectIds",
                .evaluate_expressions = "evaluateExpressions",
                .marker = "marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_objects) } {
            return .{ .service_metadata = service_metadata, .action = describe_objects };
        }
    },
    Response: type = struct {
        pipeline_objects: []PipelineObject,
        marker: ?[]const u8 = null,
        has_more_results: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_objects = "pipelineObjects",
                .marker = "marker",
                .has_more_results = "hasMoreResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const describe_pipelines: struct {
    action_name: []const u8 = "DescribePipelines",
    Request: type = struct {
        pipeline_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_ids = "pipelineIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = describe_pipelines };
        }
    },
    Response: type = struct {
        pipeline_description_list: []struct {
            pipeline_id: []const u8,
            name: []const u8,
            fields: []Field,
            description: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_id = "pipelineId",
                    .name = "name",
                    .fields = "fields",
                    .description = "description",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_description_list = "pipelineDescriptionList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const evaluate_expression: struct {
    action_name: []const u8 = "EvaluateExpression",
    Request: type = struct {
        pipeline_id: []const u8,
        object_id: []const u8,
        expression: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .object_id = "objectId",
                .expression = "expression",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(evaluate_expression) } {
            return .{ .service_metadata = service_metadata, .action = evaluate_expression };
        }
    },
    Response: type = struct {
        evaluated_expression: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluated_expression = "evaluatedExpression",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
        TaskNotFound,
    },
} = .{};
pub const get_pipeline_definition: struct {
    action_name: []const u8 = "GetPipelineDefinition",
    Request: type = struct {
        pipeline_id: []const u8,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pipeline_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_pipeline_definition };
        }
    },
    Response: type = struct {
        pipeline_objects: ?[]PipelineObject = null,
        parameter_objects: ?[]ParameterObject = null,
        parameter_values: ?[]ParameterValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_objects = "pipelineObjects",
                .parameter_objects = "parameterObjects",
                .parameter_values = "parameterValues",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const list_pipelines: struct {
    action_name: []const u8 = "ListPipelines",
    Request: type = struct {
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_pipelines };
        }
    },
    Response: type = struct {
        pipeline_id_list: []struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        },
        marker: ?[]const u8 = null,
        has_more_results: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id_list = "pipelineIdList",
                .marker = "marker",
                .has_more_results = "hasMoreResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const poll_for_task: struct {
    action_name: []const u8 = "PollForTask",
    Request: type = struct {
        worker_group: []const u8,
        hostname: ?[]const u8 = null,
        instance_identity: ?struct {
            document: ?[]const u8 = null,
            signature: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document = "document",
                    .signature = "signature",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .worker_group = "workerGroup",
                .hostname = "hostname",
                .instance_identity = "instanceIdentity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(poll_for_task) } {
            return .{ .service_metadata = service_metadata, .action = poll_for_task };
        }
    },
    Response: type = struct {
        task_object: ?struct {
            task_id: ?[]const u8 = null,
            pipeline_id: ?[]const u8 = null,
            attempt_id: ?[]const u8 = null,
            objects: ?[]struct {
                key: ?[]const u8 = null,
                value: ?PipelineObject = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_id = "taskId",
                    .pipeline_id = "pipelineId",
                    .attempt_id = "attemptId",
                    .objects = "objects",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "objects", field_name))
                    return try serializeMap(self.objects, self.fieldNameFor("objects"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_object = "taskObject",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        TaskNotFound,
    },
} = .{};
pub const put_pipeline_definition: struct {
    action_name: []const u8 = "PutPipelineDefinition",
    Request: type = struct {
        pipeline_id: []const u8,
        pipeline_objects: []PipelineObject,
        parameter_objects: ?[]ParameterObject = null,
        parameter_values: ?[]ParameterValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .pipeline_objects = "pipelineObjects",
                .parameter_objects = "parameterObjects",
                .parameter_values = "parameterValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_pipeline_definition) } {
            return .{ .service_metadata = service_metadata, .action = put_pipeline_definition };
        }
    },
    Response: type = struct {
        validation_errors: ?[]ValidationError = null,
        validation_warnings: ?[]ValidationWarning = null,
        errored: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .validation_errors = "validationErrors",
                .validation_warnings = "validationWarnings",
                .errored = "errored",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const query_objects: struct {
    action_name: []const u8 = "QueryObjects",
    Request: type = struct {
        pipeline_id: []const u8,
        query: ?struct {
            selectors: ?[]struct {
                field_name: ?[]const u8 = null,
                operator: ?struct {
                    type: ?[]const u8 = null,
                    values: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type = "type",
                            .values = "values",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .field_name = "fieldName",
                        .operator = "operator",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .selectors = "selectors",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sphere: []const u8,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .query = "query",
                .sphere = "sphere",
                .marker = "marker",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query_objects) } {
            return .{ .service_metadata = service_metadata, .action = query_objects };
        }
    },
    Response: type = struct {
        ids: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        has_more_results: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
                .marker = "marker",
                .has_more_results = "hasMoreResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const remove_tags: struct {
    action_name: []const u8 = "RemoveTags",
    Request: type = struct {
        pipeline_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const report_task_progress: struct {
    action_name: []const u8 = "ReportTaskProgress",
    Request: type = struct {
        task_id: []const u8,
        fields: ?[]Field = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .fields = "fields",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(report_task_progress) } {
            return .{ .service_metadata = service_metadata, .action = report_task_progress };
        }
    },
    Response: type = struct {
        canceled: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .canceled = "canceled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
        TaskNotFound,
    },
} = .{};
pub const report_task_runner_heartbeat: struct {
    action_name: []const u8 = "ReportTaskRunnerHeartbeat",
    Request: type = struct {
        taskrunner_id: []const u8,
        worker_group: ?[]const u8 = null,
        hostname: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .taskrunner_id = "taskrunnerId",
                .worker_group = "workerGroup",
                .hostname = "hostname",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(report_task_runner_heartbeat) } {
            return .{ .service_metadata = service_metadata, .action = report_task_runner_heartbeat };
        }
    },
    Response: type = struct {
        terminate: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .terminate = "terminate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
    },
} = .{};
pub const set_status: struct {
    action_name: []const u8 = "SetStatus",
    Request: type = struct {
        pipeline_id: []const u8,
        object_ids: [][]const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .object_ids = "objectIds",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_status) } {
            return .{ .service_metadata = service_metadata, .action = set_status };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};
pub const set_task_status: struct {
    action_name: []const u8 = "SetTaskStatus",
    Request: type = struct {
        task_id: []const u8,
        task_status: []const u8,
        error_id: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        error_stack_trace: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .task_status = "taskStatus",
                .error_id = "errorId",
                .error_message = "errorMessage",
                .error_stack_trace = "errorStackTrace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_task_status) } {
            return .{ .service_metadata = service_metadata, .action = set_task_status };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
        TaskNotFound,
    },
} = .{};
pub const validate_pipeline_definition: struct {
    action_name: []const u8 = "ValidatePipelineDefinition",
    Request: type = struct {
        pipeline_id: []const u8,
        pipeline_objects: []PipelineObject,
        parameter_objects: ?[]ParameterObject = null,
        parameter_values: ?[]ParameterValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "pipelineId",
                .pipeline_objects = "pipelineObjects",
                .parameter_objects = "parameterObjects",
                .parameter_values = "parameterValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_pipeline_definition) } {
            return .{ .service_metadata = service_metadata, .action = validate_pipeline_definition };
        }
    },
    Response: type = struct {
        validation_errors: ?[]ValidationError = null,
        validation_warnings: ?[]ValidationWarning = null,
        errored: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .validation_errors = "validationErrors",
                .validation_warnings = "validationWarnings",
                .errored = "errored",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        PipelineDeleted,
        PipelineNotFound,
    },
} = .{};

pub const ValidationWarning = struct {
    id: ?[]const u8 = null,
    warnings: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .warnings = "warnings",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationError = struct {
    id: ?[]const u8 = null,
    errors: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .errors = "errors",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterValue = struct {
    id: []const u8,
    string_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .string_value = "stringValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterObject = struct {
    id: []const u8,
    attributes: []ParameterAttribute,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .attributes = "attributes",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterAttribute = struct {
    key: []const u8,
    string_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .string_value = "stringValue",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelineObject = struct {
    id: []const u8,
    name: []const u8,
    fields: []Field,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .fields = "fields",
        };
        return @field(mappings, field_name);
    }
};

pub const Field = struct {
    key: []const u8,
    string_value: ?[]const u8 = null,
    ref_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .string_value = "stringValue",
            .ref_value = "refValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};
