const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-09";
pub const sdk_id: []const u8 = "DataSync";
pub const arn_namespace: ?[]const u8 = "datasync";
pub const endpoint_prefix: []const u8 = "datasync";
pub const sigv4_name: []const u8 = "datasync";
pub const name: []const u8 = "FmrsService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-09",
    sdk_id: []const u8 = "DataSync",
    arn_namespace: ?[]const u8 = "datasync",
    endpoint_prefix: []const u8 = "datasync",
    sigv4_name: []const u8 = "datasync",
    name: []const u8 = "FmrsService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_storage_system: struct {
    action_name: []const u8 = "AddStorageSystem",
    Request: type = struct {
        server_configuration: DiscoveryServerConfiguration,
        system_type: []const u8,
        agent_arns: [][]const u8,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        tags: ?[]TagListEntry = null,
        name: ?[]const u8 = null,
        client_token: []const u8,
        credentials: Credentials,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_configuration = "ServerConfiguration",
                .system_type = "SystemType",
                .agent_arns = "AgentArns",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                .tags = "Tags",
                .name = "Name",
                .client_token = "ClientToken",
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_storage_system) } {
            return .{ .service_metadata = service_metadata, .action = add_storage_system };
        }
    },
    Response: type = struct {
        storage_system_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_system_arn = "StorageSystemArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const cancel_task_execution: struct {
    action_name: []const u8 = "CancelTaskExecution",
    Request: type = struct {
        task_execution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_task_execution) } {
            return .{ .service_metadata = service_metadata, .action = cancel_task_execution };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_agent: struct {
    action_name: []const u8 = "CreateAgent",
    Request: type = struct {
        activation_key: []const u8,
        agent_name: ?[]const u8 = null,
        tags: ?[]TagListEntry = null,
        vpc_endpoint_id: ?[]const u8 = null,
        subnet_arns: ?[][]const u8 = null,
        security_group_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activation_key = "ActivationKey",
                .agent_name = "AgentName",
                .tags = "Tags",
                .vpc_endpoint_id = "VpcEndpointId",
                .subnet_arns = "SubnetArns",
                .security_group_arns = "SecurityGroupArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_agent) } {
            return .{ .service_metadata = service_metadata, .action = create_agent };
        }
    },
    Response: type = struct {
        agent_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_azure_blob: struct {
    action_name: []const u8 = "CreateLocationAzureBlob",
    Request: type = struct {
        container_url: []const u8,
        authentication_type: []const u8,
        sas_configuration: ?AzureBlobSasConfiguration = null,
        blob_type: ?[]const u8 = null,
        access_tier: ?[]const u8 = null,
        subdirectory: ?[]const u8 = null,
        agent_arns: [][]const u8,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_url = "ContainerUrl",
                .authentication_type = "AuthenticationType",
                .sas_configuration = "SasConfiguration",
                .blob_type = "BlobType",
                .access_tier = "AccessTier",
                .subdirectory = "Subdirectory",
                .agent_arns = "AgentArns",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_azure_blob) } {
            return .{ .service_metadata = service_metadata, .action = create_location_azure_blob };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_efs: struct {
    action_name: []const u8 = "CreateLocationEfs",
    Request: type = struct {
        subdirectory: ?[]const u8 = null,
        efs_filesystem_arn: []const u8,
        ec2_config: Ec2Config,
        tags: ?[]TagListEntry = null,
        access_point_arn: ?[]const u8 = null,
        file_system_access_role_arn: ?[]const u8 = null,
        in_transit_encryption: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .efs_filesystem_arn = "EfsFilesystemArn",
                .ec2_config = "Ec2Config",
                .tags = "Tags",
                .access_point_arn = "AccessPointArn",
                .file_system_access_role_arn = "FileSystemAccessRoleArn",
                .in_transit_encryption = "InTransitEncryption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_efs) } {
            return .{ .service_metadata = service_metadata, .action = create_location_efs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_fsx_lustre: struct {
    action_name: []const u8 = "CreateLocationFsxLustre",
    Request: type = struct {
        fsx_filesystem_arn: []const u8,
        security_group_arns: [][]const u8,
        subdirectory: ?[]const u8 = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fsx_filesystem_arn = "FsxFilesystemArn",
                .security_group_arns = "SecurityGroupArns",
                .subdirectory = "Subdirectory",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_fsx_lustre) } {
            return .{ .service_metadata = service_metadata, .action = create_location_fsx_lustre };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_fsx_ontap: struct {
    action_name: []const u8 = "CreateLocationFsxOntap",
    Request: type = struct {
        protocol: FsxProtocol,
        security_group_arns: [][]const u8,
        storage_virtual_machine_arn: []const u8,
        subdirectory: ?[]const u8 = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .protocol = "Protocol",
                .security_group_arns = "SecurityGroupArns",
                .storage_virtual_machine_arn = "StorageVirtualMachineArn",
                .subdirectory = "Subdirectory",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_fsx_ontap) } {
            return .{ .service_metadata = service_metadata, .action = create_location_fsx_ontap };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_fsx_open_zfs: struct {
    action_name: []const u8 = "CreateLocationFsxOpenZfs",
    Request: type = struct {
        fsx_filesystem_arn: []const u8,
        protocol: FsxProtocol,
        security_group_arns: [][]const u8,
        subdirectory: ?[]const u8 = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fsx_filesystem_arn = "FsxFilesystemArn",
                .protocol = "Protocol",
                .security_group_arns = "SecurityGroupArns",
                .subdirectory = "Subdirectory",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_fsx_open_zfs) } {
            return .{ .service_metadata = service_metadata, .action = create_location_fsx_open_zfs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_fsx_windows: struct {
    action_name: []const u8 = "CreateLocationFsxWindows",
    Request: type = struct {
        subdirectory: ?[]const u8 = null,
        fsx_filesystem_arn: []const u8,
        security_group_arns: [][]const u8,
        tags: ?[]TagListEntry = null,
        user: []const u8,
        domain: ?[]const u8 = null,
        password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .fsx_filesystem_arn = "FsxFilesystemArn",
                .security_group_arns = "SecurityGroupArns",
                .tags = "Tags",
                .user = "User",
                .domain = "Domain",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_fsx_windows) } {
            return .{ .service_metadata = service_metadata, .action = create_location_fsx_windows };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_hdfs: struct {
    action_name: []const u8 = "CreateLocationHdfs",
    Request: type = struct {
        subdirectory: ?[]const u8 = null,
        name_nodes: []HdfsNameNode,
        block_size: ?i64 = null,
        replication_factor: ?i64 = null,
        kms_key_provider_uri: ?[]const u8 = null,
        qop_configuration: ?QopConfiguration = null,
        authentication_type: []const u8,
        simple_user: ?[]const u8 = null,
        kerberos_principal: ?[]const u8 = null,
        kerberos_keytab: ?[]const u8 = null,
        kerberos_krb5_conf: ?[]const u8 = null,
        agent_arns: [][]const u8,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .name_nodes = "NameNodes",
                .block_size = "BlockSize",
                .replication_factor = "ReplicationFactor",
                .kms_key_provider_uri = "KmsKeyProviderUri",
                .qop_configuration = "QopConfiguration",
                .authentication_type = "AuthenticationType",
                .simple_user = "SimpleUser",
                .kerberos_principal = "KerberosPrincipal",
                .kerberos_keytab = "KerberosKeytab",
                .kerberos_krb5_conf = "KerberosKrb5Conf",
                .agent_arns = "AgentArns",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_hdfs) } {
            return .{ .service_metadata = service_metadata, .action = create_location_hdfs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_nfs: struct {
    action_name: []const u8 = "CreateLocationNfs",
    Request: type = struct {
        subdirectory: []const u8,
        server_hostname: []const u8,
        on_prem_config: OnPremConfig,
        mount_options: ?NfsMountOptions = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .server_hostname = "ServerHostname",
                .on_prem_config = "OnPremConfig",
                .mount_options = "MountOptions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_nfs) } {
            return .{ .service_metadata = service_metadata, .action = create_location_nfs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_object_storage: struct {
    action_name: []const u8 = "CreateLocationObjectStorage",
    Request: type = struct {
        server_hostname: []const u8,
        server_port: ?i64 = null,
        server_protocol: ?[]const u8 = null,
        subdirectory: ?[]const u8 = null,
        bucket_name: []const u8,
        access_key: ?[]const u8 = null,
        secret_key: ?[]const u8 = null,
        agent_arns: [][]const u8,
        tags: ?[]TagListEntry = null,
        server_certificate: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_hostname = "ServerHostname",
                .server_port = "ServerPort",
                .server_protocol = "ServerProtocol",
                .subdirectory = "Subdirectory",
                .bucket_name = "BucketName",
                .access_key = "AccessKey",
                .secret_key = "SecretKey",
                .agent_arns = "AgentArns",
                .tags = "Tags",
                .server_certificate = "ServerCertificate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_object_storage) } {
            return .{ .service_metadata = service_metadata, .action = create_location_object_storage };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_s3: struct {
    action_name: []const u8 = "CreateLocationS3",
    Request: type = struct {
        subdirectory: ?[]const u8 = null,
        s3_bucket_arn: []const u8,
        s3_storage_class: ?[]const u8 = null,
        s3_config: S3Config,
        agent_arns: ?[][]const u8 = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .s3_bucket_arn = "S3BucketArn",
                .s3_storage_class = "S3StorageClass",
                .s3_config = "S3Config",
                .agent_arns = "AgentArns",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_s3) } {
            return .{ .service_metadata = service_metadata, .action = create_location_s3 };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_smb: struct {
    action_name: []const u8 = "CreateLocationSmb",
    Request: type = struct {
        subdirectory: []const u8,
        server_hostname: []const u8,
        user: []const u8,
        domain: ?[]const u8 = null,
        password: []const u8,
        agent_arns: [][]const u8,
        mount_options: ?SmbMountOptions = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .server_hostname = "ServerHostname",
                .user = "User",
                .domain = "Domain",
                .password = "Password",
                .agent_arns = "AgentArns",
                .mount_options = "MountOptions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_smb) } {
            return .{ .service_metadata = service_metadata, .action = create_location_smb };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_task: struct {
    action_name: []const u8 = "CreateTask",
    Request: type = struct {
        source_location_arn: []const u8,
        destination_location_arn: []const u8,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        options: ?Options = null,
        excludes: ?[]FilterRule = null,
        schedule: ?TaskSchedule = null,
        tags: ?[]TagListEntry = null,
        includes: ?[]FilterRule = null,
        manifest_config: ?ManifestConfig = null,
        task_report_config: ?TaskReportConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_location_arn = "SourceLocationArn",
                .destination_location_arn = "DestinationLocationArn",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                .name = "Name",
                .options = "Options",
                .excludes = "Excludes",
                .schedule = "Schedule",
                .tags = "Tags",
                .includes = "Includes",
                .manifest_config = "ManifestConfig",
                .task_report_config = "TaskReportConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_task) } {
            return .{ .service_metadata = service_metadata, .action = create_task };
        }
    },
    Response: type = struct {
        task_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const delete_agent: struct {
    action_name: []const u8 = "DeleteAgent",
    Request: type = struct {
        agent_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_agent) } {
            return .{ .service_metadata = service_metadata, .action = delete_agent };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const delete_location: struct {
    action_name: []const u8 = "DeleteLocation",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_location) } {
            return .{ .service_metadata = service_metadata, .action = delete_location };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const delete_task: struct {
    action_name: []const u8 = "DeleteTask",
    Request: type = struct {
        task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_task) } {
            return .{ .service_metadata = service_metadata, .action = delete_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_agent: struct {
    action_name: []const u8 = "DescribeAgent",
    Request: type = struct {
        agent_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_agent) } {
            return .{ .service_metadata = service_metadata, .action = describe_agent };
        }
    },
    Response: type = struct {
        agent_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_connection_time: ?i64 = null,
        creation_time: ?i64 = null,
        endpoint_type: ?[]const u8 = null,
        private_link_config: ?struct {
            vpc_endpoint_id: ?[]const u8 = null,
            private_link_endpoint: ?[]const u8 = null,
            subnet_arns: ?[][]const u8 = null,
            security_group_arns: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpc_endpoint_id = "VpcEndpointId",
                    .private_link_endpoint = "PrivateLinkEndpoint",
                    .subnet_arns = "SubnetArns",
                    .security_group_arns = "SecurityGroupArns",
                };
                return @field(mappings, field_name);
            }
        } = null,
        platform: ?Platform = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
                .name = "Name",
                .status = "Status",
                .last_connection_time = "LastConnectionTime",
                .creation_time = "CreationTime",
                .endpoint_type = "EndpointType",
                .private_link_config = "PrivateLinkConfig",
                .platform = "Platform",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_discovery_job: struct {
    action_name: []const u8 = "DescribeDiscoveryJob",
    Request: type = struct {
        discovery_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discovery_job_arn = "DiscoveryJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_discovery_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_discovery_job };
        }
    },
    Response: type = struct {
        storage_system_arn: ?[]const u8 = null,
        discovery_job_arn: ?[]const u8 = null,
        collection_duration_minutes: ?i64 = null,
        status: ?[]const u8 = null,
        job_start_time: ?i64 = null,
        job_end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_system_arn = "StorageSystemArn",
                .discovery_job_arn = "DiscoveryJobArn",
                .collection_duration_minutes = "CollectionDurationMinutes",
                .status = "Status",
                .job_start_time = "JobStartTime",
                .job_end_time = "JobEndTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_azure_blob: struct {
    action_name: []const u8 = "DescribeLocationAzureBlob",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_azure_blob) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_azure_blob };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        authentication_type: ?[]const u8 = null,
        blob_type: ?[]const u8 = null,
        access_tier: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .authentication_type = "AuthenticationType",
                .blob_type = "BlobType",
                .access_tier = "AccessTier",
                .agent_arns = "AgentArns",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_efs: struct {
    action_name: []const u8 = "DescribeLocationEfs",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_efs) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_efs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        ec2_config: ?Ec2Config = null,
        creation_time: ?i64 = null,
        access_point_arn: ?[]const u8 = null,
        file_system_access_role_arn: ?[]const u8 = null,
        in_transit_encryption: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .ec2_config = "Ec2Config",
                .creation_time = "CreationTime",
                .access_point_arn = "AccessPointArn",
                .file_system_access_role_arn = "FileSystemAccessRoleArn",
                .in_transit_encryption = "InTransitEncryption",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_fsx_lustre: struct {
    action_name: []const u8 = "DescribeLocationFsxLustre",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_fsx_lustre) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_fsx_lustre };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        security_group_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .security_group_arns = "SecurityGroupArns",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_fsx_ontap: struct {
    action_name: []const u8 = "DescribeLocationFsxOntap",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_fsx_ontap) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_fsx_ontap };
        }
    },
    Response: type = struct {
        creation_time: ?i64 = null,
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        protocol: ?FsxProtocol = null,
        security_group_arns: ?[][]const u8 = null,
        storage_virtual_machine_arn: ?[]const u8 = null,
        fsx_filesystem_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "CreationTime",
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .protocol = "Protocol",
                .security_group_arns = "SecurityGroupArns",
                .storage_virtual_machine_arn = "StorageVirtualMachineArn",
                .fsx_filesystem_arn = "FsxFilesystemArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_fsx_open_zfs: struct {
    action_name: []const u8 = "DescribeLocationFsxOpenZfs",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_fsx_open_zfs) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_fsx_open_zfs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        security_group_arns: ?[][]const u8 = null,
        protocol: ?FsxProtocol = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .security_group_arns = "SecurityGroupArns",
                .protocol = "Protocol",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_fsx_windows: struct {
    action_name: []const u8 = "DescribeLocationFsxWindows",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_fsx_windows) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_fsx_windows };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        security_group_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,
        user: ?[]const u8 = null,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .security_group_arns = "SecurityGroupArns",
                .creation_time = "CreationTime",
                .user = "User",
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_hdfs: struct {
    action_name: []const u8 = "DescribeLocationHdfs",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_hdfs) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_hdfs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        name_nodes: ?[]HdfsNameNode = null,
        block_size: ?i64 = null,
        replication_factor: ?i64 = null,
        kms_key_provider_uri: ?[]const u8 = null,
        qop_configuration: ?QopConfiguration = null,
        authentication_type: ?[]const u8 = null,
        simple_user: ?[]const u8 = null,
        kerberos_principal: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .name_nodes = "NameNodes",
                .block_size = "BlockSize",
                .replication_factor = "ReplicationFactor",
                .kms_key_provider_uri = "KmsKeyProviderUri",
                .qop_configuration = "QopConfiguration",
                .authentication_type = "AuthenticationType",
                .simple_user = "SimpleUser",
                .kerberos_principal = "KerberosPrincipal",
                .agent_arns = "AgentArns",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_nfs: struct {
    action_name: []const u8 = "DescribeLocationNfs",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_nfs) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_nfs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        on_prem_config: ?OnPremConfig = null,
        mount_options: ?NfsMountOptions = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .on_prem_config = "OnPremConfig",
                .mount_options = "MountOptions",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_object_storage: struct {
    action_name: []const u8 = "DescribeLocationObjectStorage",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_object_storage) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_object_storage };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        access_key: ?[]const u8 = null,
        server_port: ?i64 = null,
        server_protocol: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,
        server_certificate: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .access_key = "AccessKey",
                .server_port = "ServerPort",
                .server_protocol = "ServerProtocol",
                .agent_arns = "AgentArns",
                .creation_time = "CreationTime",
                .server_certificate = "ServerCertificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_s3: struct {
    action_name: []const u8 = "DescribeLocationS3",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_s3) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_s3 };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        s3_storage_class: ?[]const u8 = null,
        s3_config: ?S3Config = null,
        agent_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .s3_storage_class = "S3StorageClass",
                .s3_config = "S3Config",
                .agent_arns = "AgentArns",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_smb: struct {
    action_name: []const u8 = "DescribeLocationSmb",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_smb) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_smb };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        user: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        mount_options: ?SmbMountOptions = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .agent_arns = "AgentArns",
                .user = "User",
                .domain = "Domain",
                .mount_options = "MountOptions",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_storage_system: struct {
    action_name: []const u8 = "DescribeStorageSystem",
    Request: type = struct {
        storage_system_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_system_arn = "StorageSystemArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_storage_system) } {
            return .{ .service_metadata = service_metadata, .action = describe_storage_system };
        }
    },
    Response: type = struct {
        storage_system_arn: ?[]const u8 = null,
        server_configuration: ?DiscoveryServerConfiguration = null,
        system_type: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        connectivity_status: ?[]const u8 = null,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        secrets_manager_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_system_arn = "StorageSystemArn",
                .server_configuration = "ServerConfiguration",
                .system_type = "SystemType",
                .agent_arns = "AgentArns",
                .name = "Name",
                .error_message = "ErrorMessage",
                .connectivity_status = "ConnectivityStatus",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                .creation_time = "CreationTime",
                .secrets_manager_arn = "SecretsManagerArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_storage_system_resource_metrics: struct {
    action_name: []const u8 = "DescribeStorageSystemResourceMetrics",
    Request: type = struct {
        discovery_job_arn: []const u8,
        resource_type: []const u8,
        resource_id: []const u8,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discovery_job_arn = "DiscoveryJobArn",
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_storage_system_resource_metrics) } {
            return .{ .service_metadata = service_metadata, .action = describe_storage_system_resource_metrics };
        }
    },
    Response: type = struct {
        metrics: ?[]struct {
            timestamp: ?i64 = null,
            p95_metrics: ?struct {
                iops: ?struct {
                    read: ?f64 = null,
                    write: ?f64 = null,
                    other: ?f64 = null,
                    total: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .read = "Read",
                            .write = "Write",
                            .other = "Other",
                            .total = "Total",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                throughput: ?struct {
                    read: ?f64 = null,
                    write: ?f64 = null,
                    other: ?f64 = null,
                    total: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .read = "Read",
                            .write = "Write",
                            .other = "Other",
                            .total = "Total",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                latency: ?struct {
                    read: ?f64 = null,
                    write: ?f64 = null,
                    other: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .read = "Read",
                            .write = "Write",
                            .other = "Other",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .iops = "IOPS",
                        .throughput = "Throughput",
                        .latency = "Latency",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            capacity: ?struct {
                used: ?i64 = null,
                provisioned: ?i64 = null,
                logical_used: ?i64 = null,
                cluster_cloud_storage_used: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .used = "Used",
                        .provisioned = "Provisioned",
                        .logical_used = "LogicalUsed",
                        .cluster_cloud_storage_used = "ClusterCloudStorageUsed",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .p95_metrics = "P95Metrics",
                    .capacity = "Capacity",
                    .resource_id = "ResourceId",
                    .resource_type = "ResourceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metrics = "Metrics",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_storage_system_resources: struct {
    action_name: []const u8 = "DescribeStorageSystemResources",
    Request: type = struct {
        discovery_job_arn: []const u8,
        resource_type: []const u8,
        resource_ids: ?[][]const u8 = null,
        filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discovery_job_arn = "DiscoveryJobArn",
                .resource_type = "ResourceType",
                .resource_ids = "ResourceIds",
                .filter = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter", field_name))
                return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_storage_system_resources) } {
            return .{ .service_metadata = service_metadata, .action = describe_storage_system_resources };
        }
    },
    Response: type = struct {
        resource_details: ?struct {
            net_app_ontapsv_ms: ?[]struct {
                cluster_uuid: ?[]const u8 = null,
                resource_id: ?[]const u8 = null,
                svm_name: ?[]const u8 = null,
                cifs_share_count: ?i64 = null,
                enabled_protocols: ?[][]const u8 = null,
                total_capacity_used: ?i64 = null,
                total_capacity_provisioned: ?i64 = null,
                total_logical_capacity_used: ?i64 = null,
                max_p95_performance: ?MaxP95Performance = null,
                recommendations: ?[]Recommendation = null,
                nfs_exported_volumes: ?i64 = null,
                recommendation_status: ?[]const u8 = null,
                total_snapshot_capacity_used: ?i64 = null,
                lun_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cluster_uuid = "ClusterUuid",
                        .resource_id = "ResourceId",
                        .svm_name = "SvmName",
                        .cifs_share_count = "CifsShareCount",
                        .enabled_protocols = "EnabledProtocols",
                        .total_capacity_used = "TotalCapacityUsed",
                        .total_capacity_provisioned = "TotalCapacityProvisioned",
                        .total_logical_capacity_used = "TotalLogicalCapacityUsed",
                        .max_p95_performance = "MaxP95Performance",
                        .recommendations = "Recommendations",
                        .nfs_exported_volumes = "NfsExportedVolumes",
                        .recommendation_status = "RecommendationStatus",
                        .total_snapshot_capacity_used = "TotalSnapshotCapacityUsed",
                        .lun_count = "LunCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            net_app_ontap_volumes: ?[]struct {
                volume_name: ?[]const u8 = null,
                resource_id: ?[]const u8 = null,
                cifs_share_count: ?i64 = null,
                security_style: ?[]const u8 = null,
                svm_uuid: ?[]const u8 = null,
                svm_name: ?[]const u8 = null,
                capacity_used: ?i64 = null,
                capacity_provisioned: ?i64 = null,
                logical_capacity_used: ?i64 = null,
                nfs_exported: ?bool = null,
                snapshot_capacity_used: ?i64 = null,
                max_p95_performance: ?MaxP95Performance = null,
                recommendations: ?[]Recommendation = null,
                recommendation_status: ?[]const u8 = null,
                lun_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .volume_name = "VolumeName",
                        .resource_id = "ResourceId",
                        .cifs_share_count = "CifsShareCount",
                        .security_style = "SecurityStyle",
                        .svm_uuid = "SvmUuid",
                        .svm_name = "SvmName",
                        .capacity_used = "CapacityUsed",
                        .capacity_provisioned = "CapacityProvisioned",
                        .logical_capacity_used = "LogicalCapacityUsed",
                        .nfs_exported = "NfsExported",
                        .snapshot_capacity_used = "SnapshotCapacityUsed",
                        .max_p95_performance = "MaxP95Performance",
                        .recommendations = "Recommendations",
                        .recommendation_status = "RecommendationStatus",
                        .lun_count = "LunCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            net_app_ontap_clusters: ?[]struct {
                cifs_share_count: ?i64 = null,
                nfs_exported_volumes: ?i64 = null,
                resource_id: ?[]const u8 = null,
                cluster_name: ?[]const u8 = null,
                max_p95_performance: ?MaxP95Performance = null,
                cluster_block_storage_size: ?i64 = null,
                cluster_block_storage_used: ?i64 = null,
                cluster_block_storage_logical_used: ?i64 = null,
                recommendations: ?[]Recommendation = null,
                recommendation_status: ?[]const u8 = null,
                lun_count: ?i64 = null,
                cluster_cloud_storage_used: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cifs_share_count = "CifsShareCount",
                        .nfs_exported_volumes = "NfsExportedVolumes",
                        .resource_id = "ResourceId",
                        .cluster_name = "ClusterName",
                        .max_p95_performance = "MaxP95Performance",
                        .cluster_block_storage_size = "ClusterBlockStorageSize",
                        .cluster_block_storage_used = "ClusterBlockStorageUsed",
                        .cluster_block_storage_logical_used = "ClusterBlockStorageLogicalUsed",
                        .recommendations = "Recommendations",
                        .recommendation_status = "RecommendationStatus",
                        .lun_count = "LunCount",
                        .cluster_cloud_storage_used = "ClusterCloudStorageUsed",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .net_app_ontapsv_ms = "NetAppONTAPSVMs",
                    .net_app_ontap_volumes = "NetAppONTAPVolumes",
                    .net_app_ontap_clusters = "NetAppONTAPClusters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_details = "ResourceDetails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_task: struct {
    action_name: []const u8 = "DescribeTask",
    Request: type = struct {
        task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_task) } {
            return .{ .service_metadata = service_metadata, .action = describe_task };
        }
    },
    Response: type = struct {
        task_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        name: ?[]const u8 = null,
        current_task_execution_arn: ?[]const u8 = null,
        source_location_arn: ?[]const u8 = null,
        destination_location_arn: ?[]const u8 = null,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        source_network_interface_arns: ?[][]const u8 = null,
        destination_network_interface_arns: ?[][]const u8 = null,
        options: ?Options = null,
        excludes: ?[]FilterRule = null,
        schedule: ?TaskSchedule = null,
        error_code: ?[]const u8 = null,
        error_detail: ?[]const u8 = null,
        creation_time: ?i64 = null,
        includes: ?[]FilterRule = null,
        manifest_config: ?ManifestConfig = null,
        task_report_config: ?TaskReportConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
                .status = "Status",
                .name = "Name",
                .current_task_execution_arn = "CurrentTaskExecutionArn",
                .source_location_arn = "SourceLocationArn",
                .destination_location_arn = "DestinationLocationArn",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                .source_network_interface_arns = "SourceNetworkInterfaceArns",
                .destination_network_interface_arns = "DestinationNetworkInterfaceArns",
                .options = "Options",
                .excludes = "Excludes",
                .schedule = "Schedule",
                .error_code = "ErrorCode",
                .error_detail = "ErrorDetail",
                .creation_time = "CreationTime",
                .includes = "Includes",
                .manifest_config = "ManifestConfig",
                .task_report_config = "TaskReportConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_task_execution: struct {
    action_name: []const u8 = "DescribeTaskExecution",
    Request: type = struct {
        task_execution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_task_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_task_execution };
        }
    },
    Response: type = struct {
        task_execution_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        options: ?Options = null,
        excludes: ?[]FilterRule = null,
        includes: ?[]FilterRule = null,
        manifest_config: ?ManifestConfig = null,
        start_time: ?i64 = null,
        estimated_files_to_transfer: ?i64 = null,
        estimated_bytes_to_transfer: ?i64 = null,
        files_transferred: ?i64 = null,
        bytes_written: ?i64 = null,
        bytes_transferred: ?i64 = null,
        bytes_compressed: ?i64 = null,
        result: ?struct {
            prepare_duration: ?i64 = null,
            prepare_status: ?[]const u8 = null,
            total_duration: ?i64 = null,
            transfer_duration: ?i64 = null,
            transfer_status: ?[]const u8 = null,
            verify_duration: ?i64 = null,
            verify_status: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_detail: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .prepare_duration = "PrepareDuration",
                    .prepare_status = "PrepareStatus",
                    .total_duration = "TotalDuration",
                    .transfer_duration = "TransferDuration",
                    .transfer_status = "TransferStatus",
                    .verify_duration = "VerifyDuration",
                    .verify_status = "VerifyStatus",
                    .error_code = "ErrorCode",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        task_report_config: ?TaskReportConfig = null,
        files_deleted: ?i64 = null,
        files_skipped: ?i64 = null,
        files_verified: ?i64 = null,
        report_result: ?struct {
            status: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_detail: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                    .error_code = "ErrorCode",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        estimated_files_to_delete: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
                .status = "Status",
                .options = "Options",
                .excludes = "Excludes",
                .includes = "Includes",
                .manifest_config = "ManifestConfig",
                .start_time = "StartTime",
                .estimated_files_to_transfer = "EstimatedFilesToTransfer",
                .estimated_bytes_to_transfer = "EstimatedBytesToTransfer",
                .files_transferred = "FilesTransferred",
                .bytes_written = "BytesWritten",
                .bytes_transferred = "BytesTransferred",
                .bytes_compressed = "BytesCompressed",
                .result = "Result",
                .task_report_config = "TaskReportConfig",
                .files_deleted = "FilesDeleted",
                .files_skipped = "FilesSkipped",
                .files_verified = "FilesVerified",
                .report_result = "ReportResult",
                .estimated_files_to_delete = "EstimatedFilesToDelete",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const generate_recommendations: struct {
    action_name: []const u8 = "GenerateRecommendations",
    Request: type = struct {
        discovery_job_arn: []const u8,
        resource_ids: [][]const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discovery_job_arn = "DiscoveryJobArn",
                .resource_ids = "ResourceIds",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = generate_recommendations };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_agents: struct {
    action_name: []const u8 = "ListAgents",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_agents) } {
            return .{ .service_metadata = service_metadata, .action = list_agents };
        }
    },
    Response: type = struct {
        agents: ?[]struct {
            agent_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            platform: ?Platform = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agent_arn = "AgentArn",
                    .name = "Name",
                    .status = "Status",
                    .platform = "Platform",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agents = "Agents",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_discovery_jobs: struct {
    action_name: []const u8 = "ListDiscoveryJobs",
    Request: type = struct {
        storage_system_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_system_arn = "StorageSystemArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_discovery_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_discovery_jobs };
        }
    },
    Response: type = struct {
        discovery_jobs: ?[]struct {
            discovery_job_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .discovery_job_arn = "DiscoveryJobArn",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discovery_jobs = "DiscoveryJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_locations: struct {
    action_name: []const u8 = "ListLocations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                    .operator = "Operator",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_locations) } {
            return .{ .service_metadata = service_metadata, .action = list_locations };
        }
    },
    Response: type = struct {
        locations: ?[]struct {
            location_arn: ?[]const u8 = null,
            location_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_arn = "LocationArn",
                    .location_uri = "LocationUri",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locations = "Locations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_storage_systems: struct {
    action_name: []const u8 = "ListStorageSystems",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_storage_systems) } {
            return .{ .service_metadata = service_metadata, .action = list_storage_systems };
        }
    },
    Response: type = struct {
        storage_systems: ?[]struct {
            storage_system_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .storage_system_arn = "StorageSystemArn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_systems = "StorageSystems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]TagListEntry = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_task_executions: struct {
    action_name: []const u8 = "ListTaskExecutions",
    Request: type = struct {
        task_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_task_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_task_executions };
        }
    },
    Response: type = struct {
        task_executions: ?[]struct {
            task_execution_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_execution_arn = "TaskExecutionArn",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_executions = "TaskExecutions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_tasks: struct {
    action_name: []const u8 = "ListTasks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                    .operator = "Operator",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_tasks };
        }
    },
    Response: type = struct {
        tasks: ?[]struct {
            task_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_arn = "TaskArn",
                    .status = "Status",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "Tasks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const remove_storage_system: struct {
    action_name: []const u8 = "RemoveStorageSystem",
    Request: type = struct {
        storage_system_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_system_arn = "StorageSystemArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_storage_system) } {
            return .{ .service_metadata = service_metadata, .action = remove_storage_system };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const start_discovery_job: struct {
    action_name: []const u8 = "StartDiscoveryJob",
    Request: type = struct {
        storage_system_arn: []const u8,
        collection_duration_minutes: i64,
        client_token: []const u8,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_system_arn = "StorageSystemArn",
                .collection_duration_minutes = "CollectionDurationMinutes",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_discovery_job) } {
            return .{ .service_metadata = service_metadata, .action = start_discovery_job };
        }
    },
    Response: type = struct {
        discovery_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discovery_job_arn = "DiscoveryJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const start_task_execution: struct {
    action_name: []const u8 = "StartTaskExecution",
    Request: type = struct {
        task_arn: []const u8,
        override_options: ?Options = null,
        includes: ?[]FilterRule = null,
        excludes: ?[]FilterRule = null,
        manifest_config: ?ManifestConfig = null,
        task_report_config: ?TaskReportConfig = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
                .override_options = "OverrideOptions",
                .includes = "Includes",
                .excludes = "Excludes",
                .manifest_config = "ManifestConfig",
                .task_report_config = "TaskReportConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_task_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_task_execution };
        }
    },
    Response: type = struct {
        task_execution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const stop_discovery_job: struct {
    action_name: []const u8 = "StopDiscoveryJob",
    Request: type = struct {
        discovery_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discovery_job_arn = "DiscoveryJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_discovery_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_discovery_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []TagListEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .keys = "Keys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_agent: struct {
    action_name: []const u8 = "UpdateAgent",
    Request: type = struct {
        agent_arn: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_agent) } {
            return .{ .service_metadata = service_metadata, .action = update_agent };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_discovery_job: struct {
    action_name: []const u8 = "UpdateDiscoveryJob",
    Request: type = struct {
        discovery_job_arn: []const u8,
        collection_duration_minutes: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discovery_job_arn = "DiscoveryJobArn",
                .collection_duration_minutes = "CollectionDurationMinutes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_discovery_job) } {
            return .{ .service_metadata = service_metadata, .action = update_discovery_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_location_azure_blob: struct {
    action_name: []const u8 = "UpdateLocationAzureBlob",
    Request: type = struct {
        location_arn: []const u8,
        subdirectory: ?[]const u8 = null,
        authentication_type: ?[]const u8 = null,
        sas_configuration: ?AzureBlobSasConfiguration = null,
        blob_type: ?[]const u8 = null,
        access_tier: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .subdirectory = "Subdirectory",
                .authentication_type = "AuthenticationType",
                .sas_configuration = "SasConfiguration",
                .blob_type = "BlobType",
                .access_tier = "AccessTier",
                .agent_arns = "AgentArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_location_azure_blob) } {
            return .{ .service_metadata = service_metadata, .action = update_location_azure_blob };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_location_hdfs: struct {
    action_name: []const u8 = "UpdateLocationHdfs",
    Request: type = struct {
        location_arn: []const u8,
        subdirectory: ?[]const u8 = null,
        name_nodes: ?[]HdfsNameNode = null,
        block_size: ?i64 = null,
        replication_factor: ?i64 = null,
        kms_key_provider_uri: ?[]const u8 = null,
        qop_configuration: ?QopConfiguration = null,
        authentication_type: ?[]const u8 = null,
        simple_user: ?[]const u8 = null,
        kerberos_principal: ?[]const u8 = null,
        kerberos_keytab: ?[]const u8 = null,
        kerberos_krb5_conf: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .subdirectory = "Subdirectory",
                .name_nodes = "NameNodes",
                .block_size = "BlockSize",
                .replication_factor = "ReplicationFactor",
                .kms_key_provider_uri = "KmsKeyProviderUri",
                .qop_configuration = "QopConfiguration",
                .authentication_type = "AuthenticationType",
                .simple_user = "SimpleUser",
                .kerberos_principal = "KerberosPrincipal",
                .kerberos_keytab = "KerberosKeytab",
                .kerberos_krb5_conf = "KerberosKrb5Conf",
                .agent_arns = "AgentArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_location_hdfs) } {
            return .{ .service_metadata = service_metadata, .action = update_location_hdfs };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_location_nfs: struct {
    action_name: []const u8 = "UpdateLocationNfs",
    Request: type = struct {
        location_arn: []const u8,
        subdirectory: ?[]const u8 = null,
        on_prem_config: ?OnPremConfig = null,
        mount_options: ?NfsMountOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .subdirectory = "Subdirectory",
                .on_prem_config = "OnPremConfig",
                .mount_options = "MountOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_location_nfs) } {
            return .{ .service_metadata = service_metadata, .action = update_location_nfs };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_location_object_storage: struct {
    action_name: []const u8 = "UpdateLocationObjectStorage",
    Request: type = struct {
        location_arn: []const u8,
        server_port: ?i64 = null,
        server_protocol: ?[]const u8 = null,
        subdirectory: ?[]const u8 = null,
        access_key: ?[]const u8 = null,
        secret_key: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        server_certificate: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .server_port = "ServerPort",
                .server_protocol = "ServerProtocol",
                .subdirectory = "Subdirectory",
                .access_key = "AccessKey",
                .secret_key = "SecretKey",
                .agent_arns = "AgentArns",
                .server_certificate = "ServerCertificate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_location_object_storage) } {
            return .{ .service_metadata = service_metadata, .action = update_location_object_storage };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_location_smb: struct {
    action_name: []const u8 = "UpdateLocationSmb",
    Request: type = struct {
        location_arn: []const u8,
        subdirectory: ?[]const u8 = null,
        user: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        password: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        mount_options: ?SmbMountOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .subdirectory = "Subdirectory",
                .user = "User",
                .domain = "Domain",
                .password = "Password",
                .agent_arns = "AgentArns",
                .mount_options = "MountOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_location_smb) } {
            return .{ .service_metadata = service_metadata, .action = update_location_smb };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_storage_system: struct {
    action_name: []const u8 = "UpdateStorageSystem",
    Request: type = struct {
        storage_system_arn: []const u8,
        server_configuration: ?DiscoveryServerConfiguration = null,
        agent_arns: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        credentials: ?Credentials = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_system_arn = "StorageSystemArn",
                .server_configuration = "ServerConfiguration",
                .agent_arns = "AgentArns",
                .name = "Name",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_storage_system) } {
            return .{ .service_metadata = service_metadata, .action = update_storage_system };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_task: struct {
    action_name: []const u8 = "UpdateTask",
    Request: type = struct {
        task_arn: []const u8,
        options: ?Options = null,
        excludes: ?[]FilterRule = null,
        schedule: ?TaskSchedule = null,
        name: ?[]const u8 = null,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        includes: ?[]FilterRule = null,
        manifest_config: ?ManifestConfig = null,
        task_report_config: ?TaskReportConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
                .options = "Options",
                .excludes = "Excludes",
                .schedule = "Schedule",
                .name = "Name",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                .includes = "Includes",
                .manifest_config = "ManifestConfig",
                .task_report_config = "TaskReportConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_task) } {
            return .{ .service_metadata = service_metadata, .action = update_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_task_execution: struct {
    action_name: []const u8 = "UpdateTaskExecution",
    Request: type = struct {
        task_execution_arn: []const u8,
        options: Options,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_task_execution) } {
            return .{ .service_metadata = service_metadata, .action = update_task_execution };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};

pub const Options = struct {
    verify_mode: ?[]const u8 = null,
    overwrite_mode: ?[]const u8 = null,
    atime: ?[]const u8 = null,
    mtime: ?[]const u8 = null,
    uid: ?[]const u8 = null,
    gid: ?[]const u8 = null,
    preserve_deleted_files: ?[]const u8 = null,
    preserve_devices: ?[]const u8 = null,
    posix_permissions: ?[]const u8 = null,
    bytes_per_second: ?i64 = null,
    task_queueing: ?[]const u8 = null,
    log_level: ?[]const u8 = null,
    transfer_mode: ?[]const u8 = null,
    security_descriptor_copy_flags: ?[]const u8 = null,
    object_tags: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .verify_mode = "VerifyMode",
            .overwrite_mode = "OverwriteMode",
            .atime = "Atime",
            .mtime = "Mtime",
            .uid = "Uid",
            .gid = "Gid",
            .preserve_deleted_files = "PreserveDeletedFiles",
            .preserve_devices = "PreserveDevices",
            .posix_permissions = "PosixPermissions",
            .bytes_per_second = "BytesPerSecond",
            .task_queueing = "TaskQueueing",
            .log_level = "LogLevel",
            .transfer_mode = "TransferMode",
            .security_descriptor_copy_flags = "SecurityDescriptorCopyFlags",
            .object_tags = "ObjectTags",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskReportConfig = struct {
    destination: ?ReportDestination = null,
    output_type: ?[]const u8 = null,
    report_level: ?[]const u8 = null,
    object_version_ids: ?[]const u8 = null,
    overrides: ?ReportOverrides = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
            .output_type = "OutputType",
            .report_level = "ReportLevel",
            .object_version_ids = "ObjectVersionIds",
            .overrides = "Overrides",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportOverrides = struct {
    transferred: ?ReportOverride = null,
    verified: ?ReportOverride = null,
    deleted: ?ReportOverride = null,
    skipped: ?ReportOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transferred = "Transferred",
            .verified = "Verified",
            .deleted = "Deleted",
            .skipped = "Skipped",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportOverride = struct {
    report_level: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_level = "ReportLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportDestination = struct {
    s3: ?ReportDestinationS3 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "S3",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportDestinationS3 = struct {
    subdirectory: ?[]const u8 = null,
    s3_bucket_arn: []const u8,
    bucket_access_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subdirectory = "Subdirectory",
            .s3_bucket_arn = "S3BucketArn",
            .bucket_access_role_arn = "BucketAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ManifestConfig = struct {
    action: ?[]const u8 = null,
    format: ?[]const u8 = null,
    source: ?SourceManifestConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .format = "Format",
            .source = "Source",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceManifestConfig = struct {
    s3: S3ManifestConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "S3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ManifestConfig = struct {
    manifest_object_path: []const u8,
    bucket_access_role_arn: []const u8,
    s3_bucket_arn: []const u8,
    manifest_object_version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_object_path = "ManifestObjectPath",
            .bucket_access_role_arn = "BucketAccessRoleArn",
            .s3_bucket_arn = "S3BucketArn",
            .manifest_object_version_id = "ManifestObjectVersionId",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterRule = struct {
    filter_type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_type = "FilterType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskSchedule = struct {
    schedule_expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "ScheduleExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const Credentials = struct {
    username: []const u8,
    password: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .password = "Password",
        };
        return @field(mappings, field_name);
    }
};

pub const DiscoveryServerConfiguration = struct {
    server_hostname: []const u8,
    server_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_hostname = "ServerHostname",
            .server_port = "ServerPort",
        };
        return @field(mappings, field_name);
    }
};

pub const SmbMountOptions = struct {
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const NfsMountOptions = struct {
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const OnPremConfig = struct {
    agent_arns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .agent_arns = "AgentArns",
        };
        return @field(mappings, field_name);
    }
};

pub const QopConfiguration = struct {
    rpc_protection: ?[]const u8 = null,
    data_transfer_protection: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rpc_protection = "RpcProtection",
            .data_transfer_protection = "DataTransferProtection",
        };
        return @field(mappings, field_name);
    }
};

pub const HdfsNameNode = struct {
    hostname: []const u8,
    port: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname = "Hostname",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const AzureBlobSasConfiguration = struct {
    token: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .token = "Token",
        };
        return @field(mappings, field_name);
    }
};

pub const TagListEntry = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Platform = struct {
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const Recommendation = struct {
    storage_type: ?[]const u8 = null,
    storage_configuration: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    estimated_monthly_storage_cost: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_type = "StorageType",
            .storage_configuration = "StorageConfiguration",
            .estimated_monthly_storage_cost = "EstimatedMonthlyStorageCost",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "storage_configuration", field_name))
            return try serializeMap(self.storage_configuration, self.fieldNameFor("storage_configuration"), options, out_stream);
        return false;
    }
};

pub const MaxP95Performance = struct {
    iops_read: ?f64 = null,
    iops_write: ?f64 = null,
    iops_other: ?f64 = null,
    iops_total: ?f64 = null,
    throughput_read: ?f64 = null,
    throughput_write: ?f64 = null,
    throughput_other: ?f64 = null,
    throughput_total: ?f64 = null,
    latency_read: ?f64 = null,
    latency_write: ?f64 = null,
    latency_other: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iops_read = "IopsRead",
            .iops_write = "IopsWrite",
            .iops_other = "IopsOther",
            .iops_total = "IopsTotal",
            .throughput_read = "ThroughputRead",
            .throughput_write = "ThroughputWrite",
            .throughput_other = "ThroughputOther",
            .throughput_total = "ThroughputTotal",
            .latency_read = "LatencyRead",
            .latency_write = "LatencyWrite",
            .latency_other = "LatencyOther",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Config = struct {
    bucket_access_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_access_role_arn = "BucketAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FsxProtocol = struct {
    nfs: ?FsxProtocolNfs = null,
    smb: ?FsxProtocolSmb = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nfs = "NFS",
            .smb = "SMB",
        };
        return @field(mappings, field_name);
    }
};

pub const FsxProtocolSmb = struct {
    domain: ?[]const u8 = null,
    mount_options: ?SmbMountOptions = null,
    password: []const u8,
    user: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .mount_options = "MountOptions",
            .password = "Password",
            .user = "User",
        };
        return @field(mappings, field_name);
    }
};

pub const FsxProtocolNfs = struct {
    mount_options: ?NfsMountOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mount_options = "MountOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2Config = struct {
    subnet_arn: []const u8,
    security_group_arns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_arn = "SubnetArn",
            .security_group_arns = "SecurityGroupArns",
        };
        return @field(mappings, field_name);
    }
};
