const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "DataZone";
pub const arn_namespace: ?[]const u8 = "datazone";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "datazone";
pub const name: []const u8 = "DataZone";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "DataZone",
    arn_namespace: ?[]const u8 = "datazone",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "datazone",
    name: []const u8 = "DataZone",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_predictions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/domains/{domainIdentifier}/assets/{identifier}/accept-predictions",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptPredictions",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        revision: ?[]const u8 = null,
        accept_rule: ?struct {
            rule: ?[]const u8 = null,
            threshold: ?f32 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule = "rule",
                    .threshold = "threshold",
                };
                return @field(mappings, field_name);
            }
        } = null,
        accept_choices: ?[]struct {
            prediction_target: ?[]const u8 = null,
            prediction_choice: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .prediction_target = "predictionTarget",
                    .prediction_choice = "predictionChoice",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .revision = "revision",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .revision = "revision",
                .accept_rule = "acceptRule",
                .accept_choices = "acceptChoices",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_predictions) } {
            return .{ .service_metadata = service_metadata, .action = accept_predictions };
        }
    },
    Response: type = struct {
        domain_id: []const u8,
        asset_id: []const u8,
        revision: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .asset_id = "assetId",
                .revision = "revision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const accept_subscription_request: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/domains/{domainIdentifier}/subscription-requests/{identifier}/accept",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptSubscriptionRequest",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        decision_comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .decision_comment = "decisionComment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_subscription_request) } {
            return .{ .service_metadata = service_metadata, .action = accept_subscription_request };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        status: []const u8,
        created_at: i64,
        updated_at: i64,
        request_reason: []const u8,
        subscribed_principals: []SubscribedPrincipal,
        subscribed_listings: []SubscribedListing,
        reviewer_id: ?[]const u8 = null,
        decision_comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .status = "status",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .request_reason = "requestReason",
                .subscribed_principals = "subscribedPrincipals",
                .subscribed_listings = "subscribedListings",
                .reviewer_id = "reviewerId",
                .decision_comment = "decisionComment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_subscription: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/domains/{domainIdentifier}/subscriptions/{identifier}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelSubscription",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_subscription) } {
            return .{ .service_metadata = service_metadata, .action = cancel_subscription };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        status: []const u8,
        created_at: i64,
        updated_at: i64,
        subscribed_principal: SubscribedPrincipal,
        subscribed_listing: SubscribedListing,
        subscription_request_id: ?[]const u8 = null,
        retain_permissions: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .status = "status",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .subscribed_principal = "subscribedPrincipal",
                .subscribed_listing = "subscribedListing",
                .subscription_request_id = "subscriptionRequestId",
                .retain_permissions = "retainPermissions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/environments",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateEnvironment",
    Request: type = struct {
        project_identifier: []const u8,
        domain_identifier: []const u8,
        description: ?[]const u8 = null,
        name: []const u8,
        environment_profile_identifier: []const u8,
        user_parameters: ?[]EnvironmentParameter = null,
        glossary_terms: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_identifier = "projectIdentifier",
                .domain_identifier = "domainIdentifier",
                .description = "description",
                .name = "name",
                .environment_profile_identifier = "environmentProfileIdentifier",
                .user_parameters = "userParameters",
                .glossary_terms = "glossaryTerms",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_environment };
        }
    },
    Response: type = struct {
        project_id: []const u8,
        id: ?[]const u8 = null,
        domain_id: []const u8,
        created_by: []const u8,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        environment_profile_id: []const u8,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,
        provider: []const u8,
        provisioned_resources: ?[]Resource = null,
        status: ?[]const u8 = null,
        environment_actions: ?[]ConfigurableEnvironmentAction = null,
        glossary_terms: ?[][]const u8 = null,
        user_parameters: ?[]CustomParameter = null,
        last_deployment: ?Deployment = null,
        provisioning_properties: ?ProvisioningProperties = null,
        deployment_properties: ?DeploymentProperties = null,
        environment_blueprint_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .id = "id",
                .domain_id = "domainId",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .name = "name",
                .description = "description",
                .environment_profile_id = "environmentProfileId",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
                .provider = "provider",
                .provisioned_resources = "provisionedResources",
                .status = "status",
                .environment_actions = "environmentActions",
                .glossary_terms = "glossaryTerms",
                .user_parameters = "userParameters",
                .last_deployment = "lastDeployment",
                .provisioning_properties = "provisioningProperties",
                .deployment_properties = "deploymentProperties",
                .environment_blueprint_id = "environmentBlueprintId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_environment_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/environment-profiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateEnvironmentProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        environment_blueprint_identifier: []const u8,
        project_identifier: []const u8,
        user_parameters: ?[]EnvironmentParameter = null,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .name = "name",
                .description = "description",
                .environment_blueprint_identifier = "environmentBlueprintIdentifier",
                .project_identifier = "projectIdentifier",
                .user_parameters = "userParameters",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_environment_profile };
        }
    },
    Response: type = struct {
        id: []const u8,
        domain_id: []const u8,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,
        created_by: []const u8,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        environment_blueprint_id: []const u8,
        project_id: ?[]const u8 = null,
        user_parameters: ?[]CustomParameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .domain_id = "domainId",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .name = "name",
                .description = "description",
                .environment_blueprint_id = "environmentBlueprintId",
                .project_id = "projectId",
                .user_parameters = "userParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_group_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/group-profiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateGroupProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        group_identifier: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .group_identifier = "groupIdentifier",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_group_profile };
        }
    },
    Response: type = struct {
        domain_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .status = "status",
                .group_name = "groupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_listing_change_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/listings/change-set",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateListingChangeSet",
    Request: type = struct {
        domain_identifier: []const u8,
        entity_identifier: []const u8,
        entity_type: []const u8,
        entity_revision: ?[]const u8 = null,
        action: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .entity_identifier = "entityIdentifier",
                .entity_type = "entityType",
                .entity_revision = "entityRevision",
                .action = "action",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_listing_change_set) } {
            return .{ .service_metadata = service_metadata, .action = create_listing_change_set };
        }
    },
    Response: type = struct {
        listing_id: []const u8,
        listing_revision: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listing_id = "listingId",
                .listing_revision = "listingRevision",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_project: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/projects",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        domain_identifier: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        glossary_terms: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .name = "name",
                .description = "description",
                .glossary_terms = "glossaryTerms",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        domain_id: []const u8,
        id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        project_status: ?[]const u8 = null,
        failure_reasons: ?[]ProjectDeletionError = null,
        created_by: []const u8,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        glossary_terms: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .name = "name",
                .description = "description",
                .project_status = "projectStatus",
                .failure_reasons = "failureReasons",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .last_updated_at = "lastUpdatedAt",
                .glossary_terms = "glossaryTerms",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_project_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/projects/{projectIdentifier}/createMembership",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateProjectMembership",
    Request: type = struct {
        domain_identifier: []const u8,
        project_identifier: []const u8,
        member: Member,
        designation: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .project_identifier = "projectIdentifier",
                .member = "member",
                .designation = "designation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_project_membership };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_subscription_grant: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/subscription-grants",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSubscriptionGrant",
    Request: type = struct {
        domain_identifier: []const u8,
        environment_identifier: []const u8,
        subscription_target_identifier: []const u8,
        granted_entity: union {
            listing: ?struct {
                identifier: []const u8,
                revision: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .identifier = "identifier",
                        .revision = "revision",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .listing = "listing",
                };
                return @field(mappings, field_name);
            }
        },
        asset_target_names: ?[]struct {
            asset_id: []const u8,
            target_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .asset_id = "assetId",
                    .target_name = "targetName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .environment_identifier = "environmentIdentifier",
                .subscription_target_identifier = "subscriptionTargetIdentifier",
                .granted_entity = "grantedEntity",
                .asset_target_names = "assetTargetNames",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subscription_grant) } {
            return .{ .service_metadata = service_metadata, .action = create_subscription_grant };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        created_at: i64,
        updated_at: i64,
        subscription_target_id: []const u8,
        granted_entity: GrantedEntity,
        status: []const u8,
        assets: ?[]SubscribedAsset = null,
        subscription_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .subscription_target_id = "subscriptionTargetId",
                .granted_entity = "grantedEntity",
                .status = "status",
                .assets = "assets",
                .subscription_id = "subscriptionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_subscription_request: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/subscription-requests",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSubscriptionRequest",
    Request: type = struct {
        domain_identifier: []const u8,
        subscribed_principals: []union {
            project: ?struct {
                identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .identifier = "identifier",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project = "project",
                };
                return @field(mappings, field_name);
            }
        },
        subscribed_listings: []struct {
            identifier: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identifier = "identifier",
                };
                return @field(mappings, field_name);
            }
        },
        request_reason: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .subscribed_principals = "subscribedPrincipals",
                .subscribed_listings = "subscribedListings",
                .request_reason = "requestReason",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subscription_request) } {
            return .{ .service_metadata = service_metadata, .action = create_subscription_request };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        status: []const u8,
        created_at: i64,
        updated_at: i64,
        request_reason: []const u8,
        subscribed_principals: []SubscribedPrincipal,
        subscribed_listings: []SubscribedListing,
        reviewer_id: ?[]const u8 = null,
        decision_comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .status = "status",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .request_reason = "requestReason",
                .subscribed_principals = "subscribedPrincipals",
                .subscribed_listings = "subscribedListings",
                .reviewer_id = "reviewerId",
                .decision_comment = "decisionComment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_subscription_target: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/environments/{environmentIdentifier}/subscription-targets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSubscriptionTarget",
    Request: type = struct {
        domain_identifier: []const u8,
        environment_identifier: []const u8,
        name: []const u8,
        type: []const u8,
        subscription_target_config: []SubscriptionTargetForm,
        authorized_principals: [][]const u8,
        manage_access_role: []const u8,
        applicable_asset_types: [][]const u8,
        provider: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .environment_identifier = "environmentIdentifier",
                .name = "name",
                .type = "type",
                .subscription_target_config = "subscriptionTargetConfig",
                .authorized_principals = "authorizedPrincipals",
                .manage_access_role = "manageAccessRole",
                .applicable_asset_types = "applicableAssetTypes",
                .provider = "provider",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subscription_target) } {
            return .{ .service_metadata = service_metadata, .action = create_subscription_target };
        }
    },
    Response: type = struct {
        id: []const u8,
        authorized_principals: [][]const u8,
        domain_id: []const u8,
        project_id: []const u8,
        environment_id: []const u8,
        name: []const u8,
        type: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        created_at: i64,
        updated_at: ?i64 = null,
        manage_access_role: []const u8,
        applicable_asset_types: [][]const u8,
        subscription_target_config: []SubscriptionTargetForm,
        provider: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .authorized_principals = "authorizedPrincipals",
                .domain_id = "domainId",
                .project_id = "projectId",
                .environment_id = "environmentId",
                .name = "name",
                .type = "type",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .manage_access_role = "manageAccessRole",
                .applicable_asset_types = "applicableAssetTypes",
                .subscription_target_config = "subscriptionTargetConfig",
                .provider = "provider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_user_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/user-profiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateUserProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        user_identifier: []const u8,
        user_type: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .user_identifier = "userIdentifier",
                .user_type = "userType",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_user_profile };
        }
    },
    Response: type = struct {
        domain_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        details: ?UserProfileDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .type = "type",
                .status = "status",
                .details = "details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/domains/{domainIdentifier}/environments/{identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteEnvironment",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_environment_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/domains/{domainIdentifier}/environment-profiles/{identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteEnvironmentProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_project: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/domains/{domainIdentifier}/projects/{identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        skip_deletion_check: ?bool = null,

        pub const http_query = .{
            .skip_deletion_check = "skipDeletionCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .skip_deletion_check = "skipDeletionCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_project_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/projects/{projectIdentifier}/deleteMembership",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteProjectMembership",
    Request: type = struct {
        domain_identifier: []const u8,
        project_identifier: []const u8,
        member: Member,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .project_identifier = "projectIdentifier",
                .member = "member",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_project_membership };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_subscription_grant: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/domains/{domainIdentifier}/subscription-grants/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSubscriptionGrant",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subscription_grant) } {
            return .{ .service_metadata = service_metadata, .action = delete_subscription_grant };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        created_at: i64,
        updated_at: i64,
        subscription_target_id: []const u8,
        granted_entity: GrantedEntity,
        status: []const u8,
        assets: ?[]SubscribedAsset = null,
        subscription_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .subscription_target_id = "subscriptionTargetId",
                .granted_entity = "grantedEntity",
                .status = "status",
                .assets = "assets",
                .subscription_id = "subscriptionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_subscription_request: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/domains/{domainIdentifier}/subscription-requests/{identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSubscriptionRequest",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subscription_request) } {
            return .{ .service_metadata = service_metadata, .action = delete_subscription_request };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_subscription_target: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/domains/{domainIdentifier}/environments/{environmentIdentifier}/subscription-targets/{identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSubscriptionTarget",
    Request: type = struct {
        domain_identifier: []const u8,
        environment_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .environment_identifier = "environmentIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subscription_target) } {
            return .{ .service_metadata = service_metadata, .action = delete_subscription_target };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/environments/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironment",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_environment };
        }
    },
    Response: type = struct {
        project_id: []const u8,
        id: ?[]const u8 = null,
        domain_id: []const u8,
        created_by: []const u8,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        environment_profile_id: []const u8,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,
        provider: []const u8,
        provisioned_resources: ?[]Resource = null,
        status: ?[]const u8 = null,
        environment_actions: ?[]ConfigurableEnvironmentAction = null,
        glossary_terms: ?[][]const u8 = null,
        user_parameters: ?[]CustomParameter = null,
        last_deployment: ?Deployment = null,
        provisioning_properties: ?ProvisioningProperties = null,
        deployment_properties: ?DeploymentProperties = null,
        environment_blueprint_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .id = "id",
                .domain_id = "domainId",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .name = "name",
                .description = "description",
                .environment_profile_id = "environmentProfileId",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
                .provider = "provider",
                .provisioned_resources = "provisionedResources",
                .status = "status",
                .environment_actions = "environmentActions",
                .glossary_terms = "glossaryTerms",
                .user_parameters = "userParameters",
                .last_deployment = "lastDeployment",
                .provisioning_properties = "provisioningProperties",
                .deployment_properties = "deploymentProperties",
                .environment_blueprint_id = "environmentBlueprintId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_environment_blueprint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/environment-blueprints/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironmentBlueprint",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment_blueprint) } {
            return .{ .service_metadata = service_metadata, .action = get_environment_blueprint };
        }
    },
    Response: type = struct {
        id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        provider: []const u8,
        provisioning_properties: ProvisioningProperties,
        deployment_properties: ?DeploymentProperties = null,
        user_parameters: ?[]CustomParameter = null,
        glossary_terms: ?[][]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .provider = "provider",
                .provisioning_properties = "provisioningProperties",
                .deployment_properties = "deploymentProperties",
                .user_parameters = "userParameters",
                .glossary_terms = "glossaryTerms",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_environment_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/environment-profiles/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironmentProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_environment_profile };
        }
    },
    Response: type = struct {
        id: []const u8,
        domain_id: []const u8,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,
        created_by: []const u8,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        environment_blueprint_id: []const u8,
        project_id: ?[]const u8 = null,
        user_parameters: ?[]CustomParameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .domain_id = "domainId",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .name = "name",
                .description = "description",
                .environment_blueprint_id = "environmentBlueprintId",
                .project_id = "projectId",
                .user_parameters = "userParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_group_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/group-profiles/{groupIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroupProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        group_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .group_identifier = "groupIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_group_profile };
        }
    },
    Response: type = struct {
        domain_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .status = "status",
                .group_name = "groupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_iam_portal_login_url: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/get-portal-login-url",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIamPortalLoginUrl",
    Request: type = struct {
        domain_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_iam_portal_login_url) } {
            return .{ .service_metadata = service_metadata, .action = get_iam_portal_login_url };
        }
    },
    Response: type = struct {
        auth_code_url: ?[]const u8 = null,
        user_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auth_code_url = "authCodeUrl",
                .user_profile_id = "userProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_project: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/projects/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProject",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_project) } {
            return .{ .service_metadata = service_metadata, .action = get_project };
        }
    },
    Response: type = struct {
        domain_id: []const u8,
        id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        project_status: ?[]const u8 = null,
        failure_reasons: ?[]ProjectDeletionError = null,
        created_by: []const u8,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        glossary_terms: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .name = "name",
                .description = "description",
                .project_status = "projectStatus",
                .failure_reasons = "failureReasons",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .last_updated_at = "lastUpdatedAt",
                .glossary_terms = "glossaryTerms",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_subscription: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/subscriptions/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSubscription",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_subscription) } {
            return .{ .service_metadata = service_metadata, .action = get_subscription };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        status: []const u8,
        created_at: i64,
        updated_at: i64,
        subscribed_principal: SubscribedPrincipal,
        subscribed_listing: SubscribedListing,
        subscription_request_id: ?[]const u8 = null,
        retain_permissions: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .status = "status",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .subscribed_principal = "subscribedPrincipal",
                .subscribed_listing = "subscribedListing",
                .subscription_request_id = "subscriptionRequestId",
                .retain_permissions = "retainPermissions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_subscription_grant: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/subscription-grants/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSubscriptionGrant",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_subscription_grant) } {
            return .{ .service_metadata = service_metadata, .action = get_subscription_grant };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        created_at: i64,
        updated_at: i64,
        subscription_target_id: []const u8,
        granted_entity: GrantedEntity,
        status: []const u8,
        assets: ?[]SubscribedAsset = null,
        subscription_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .subscription_target_id = "subscriptionTargetId",
                .granted_entity = "grantedEntity",
                .status = "status",
                .assets = "assets",
                .subscription_id = "subscriptionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_subscription_request_details: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/subscription-requests/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSubscriptionRequestDetails",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_subscription_request_details) } {
            return .{ .service_metadata = service_metadata, .action = get_subscription_request_details };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        status: []const u8,
        created_at: i64,
        updated_at: i64,
        request_reason: []const u8,
        subscribed_principals: []SubscribedPrincipal,
        subscribed_listings: []SubscribedListing,
        reviewer_id: ?[]const u8 = null,
        decision_comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .status = "status",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .request_reason = "requestReason",
                .subscribed_principals = "subscribedPrincipals",
                .subscribed_listings = "subscribedListings",
                .reviewer_id = "reviewerId",
                .decision_comment = "decisionComment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_subscription_target: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/environments/{environmentIdentifier}/subscription-targets/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSubscriptionTarget",
    Request: type = struct {
        domain_identifier: []const u8,
        environment_identifier: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .environment_identifier = "environmentIdentifier",
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_subscription_target) } {
            return .{ .service_metadata = service_metadata, .action = get_subscription_target };
        }
    },
    Response: type = struct {
        id: []const u8,
        authorized_principals: [][]const u8,
        domain_id: []const u8,
        project_id: []const u8,
        environment_id: []const u8,
        name: []const u8,
        type: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        created_at: i64,
        updated_at: ?i64 = null,
        manage_access_role: []const u8,
        applicable_asset_types: [][]const u8,
        subscription_target_config: []SubscriptionTargetForm,
        provider: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .authorized_principals = "authorizedPrincipals",
                .domain_id = "domainId",
                .project_id = "projectId",
                .environment_id = "environmentId",
                .name = "name",
                .type = "type",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .manage_access_role = "manageAccessRole",
                .applicable_asset_types = "applicableAssetTypes",
                .subscription_target_config = "subscriptionTargetConfig",
                .provider = "provider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_user_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/user-profiles/{userIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUserProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        user_identifier: []const u8,
        type: ?[]const u8 = null,

        pub const http_query = .{
            .type = "type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .user_identifier = "userIdentifier",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_user_profile };
        }
    },
    Response: type = struct {
        domain_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        details: ?UserProfileDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .type = "type",
                .status = "status",
                .details = "details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_asset_revisions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/assets/{identifier}/revisions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetRevisions",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_revisions) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_revisions };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            domain_id: ?[]const u8 = null,
            id: ?[]const u8 = null,
            revision: ?[]const u8 = null,
            created_by: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "domainId",
                    .id = "id",
                    .revision = "revision",
                    .created_by = "createdBy",
                    .created_at = "createdAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_source_run_activities: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/data-source-runs/{identifier}/activities",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSourceRunActivities",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status = "status",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .status = "status",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_source_run_activities) } {
            return .{ .service_metadata = service_metadata, .action = list_data_source_run_activities };
        }
    },
    Response: type = struct {
        items: []struct {
            database: []const u8,
            data_source_run_id: []const u8,
            technical_name: []const u8,
            data_asset_status: []const u8,
            project_id: []const u8,
            data_asset_id: ?[]const u8 = null,
            technical_description: ?[]const u8 = null,
            error_message: ?struct {
                error_type: []const u8,
                error_detail: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_type = "errorType",
                        .error_detail = "errorDetail",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            created_at: i64,
            updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database = "database",
                    .data_source_run_id = "dataSourceRunId",
                    .technical_name = "technicalName",
                    .data_asset_status = "dataAssetStatus",
                    .project_id = "projectId",
                    .data_asset_id = "dataAssetId",
                    .technical_description = "technicalDescription",
                    .error_message = "errorMessage",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_environment_blueprints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/environment-blueprints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironmentBlueprints",
    Request: type = struct {
        domain_identifier: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        name: ?[]const u8 = null,
        managed: ?bool = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .name = "name",
            .managed = "managed",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .name = "name",
                .managed = "managed",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environment_blueprints) } {
            return .{ .service_metadata = service_metadata, .action = list_environment_blueprints };
        }
    },
    Response: type = struct {
        items: []struct {
            id: []const u8,
            name: []const u8,
            description: ?[]const u8 = null,
            provider: []const u8,
            provisioning_properties: ProvisioningProperties,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .provider = "provider",
                    .provisioning_properties = "provisioningProperties",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_environment_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/environment-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironmentProfiles",
    Request: type = struct {
        domain_identifier: []const u8,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,
        environment_blueprint_identifier: ?[]const u8 = null,
        project_identifier: ?[]const u8 = null,
        name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .aws_account_id = "awsAccountId",
            .aws_account_region = "awsAccountRegion",
            .environment_blueprint_identifier = "environmentBlueprintIdentifier",
            .project_identifier = "projectIdentifier",
            .name = "name",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
                .environment_blueprint_identifier = "environmentBlueprintIdentifier",
                .project_identifier = "projectIdentifier",
                .name = "name",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environment_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_environment_profiles };
        }
    },
    Response: type = struct {
        items: []struct {
            id: []const u8,
            domain_id: []const u8,
            aws_account_id: ?[]const u8 = null,
            aws_account_region: ?[]const u8 = null,
            created_by: []const u8,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            name: []const u8,
            description: ?[]const u8 = null,
            environment_blueprint_id: []const u8,
            project_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .domain_id = "domainId",
                    .aws_account_id = "awsAccountId",
                    .aws_account_region = "awsAccountRegion",
                    .created_by = "createdBy",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .name = "name",
                    .description = "description",
                    .environment_blueprint_id = "environmentBlueprintId",
                    .project_id = "projectId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/environments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironments",
    Request: type = struct {
        domain_identifier: []const u8,
        aws_account_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,
        project_identifier: []const u8,
        environment_profile_identifier: ?[]const u8 = null,
        environment_blueprint_identifier: ?[]const u8 = null,
        provider: ?[]const u8 = null,
        name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .aws_account_id = "awsAccountId",
            .status = "status",
            .aws_account_region = "awsAccountRegion",
            .project_identifier = "projectIdentifier",
            .environment_profile_identifier = "environmentProfileIdentifier",
            .environment_blueprint_identifier = "environmentBlueprintIdentifier",
            .provider = "provider",
            .name = "name",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .aws_account_id = "awsAccountId",
                .status = "status",
                .aws_account_region = "awsAccountRegion",
                .project_identifier = "projectIdentifier",
                .environment_profile_identifier = "environmentProfileIdentifier",
                .environment_blueprint_identifier = "environmentBlueprintIdentifier",
                .provider = "provider",
                .name = "name",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_environments };
        }
    },
    Response: type = struct {
        items: []struct {
            project_id: []const u8,
            id: ?[]const u8 = null,
            domain_id: []const u8,
            created_by: []const u8,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            name: []const u8,
            description: ?[]const u8 = null,
            environment_profile_id: []const u8,
            aws_account_id: ?[]const u8 = null,
            aws_account_region: ?[]const u8 = null,
            provider: []const u8,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_id = "projectId",
                    .id = "id",
                    .domain_id = "domainId",
                    .created_by = "createdBy",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .name = "name",
                    .description = "description",
                    .environment_profile_id = "environmentProfileId",
                    .aws_account_id = "awsAccountId",
                    .aws_account_region = "awsAccountRegion",
                    .provider = "provider",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_notifications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/notifications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNotifications",
    Request: type = struct {
        domain_identifier: []const u8,
        type: []const u8,
        after_timestamp: ?i64 = null,
        before_timestamp: ?i64 = null,
        subjects: ?[][]const u8 = null,
        task_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .type = "type",
            .after_timestamp = "afterTimestamp",
            .before_timestamp = "beforeTimestamp",
            .subjects = "subjects",
            .task_status = "taskStatus",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .type = "type",
                .after_timestamp = "afterTimestamp",
                .before_timestamp = "beforeTimestamp",
                .subjects = "subjects",
                .task_status = "taskStatus",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notifications) } {
            return .{ .service_metadata = service_metadata, .action = list_notifications };
        }
    },
    Response: type = struct {
        notifications: ?[]struct {
            identifier: []const u8,
            domain_identifier: []const u8,
            type: []const u8,
            topic: struct {
                subject: []const u8,
                resource: struct {
                    type: []const u8,
                    id: []const u8,
                    name: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type = "type",
                            .id = "id",
                            .name = "name",
                        };
                        return @field(mappings, field_name);
                    }
                },
                role: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .subject = "subject",
                        .resource = "resource",
                        .role = "role",
                    };
                    return @field(mappings, field_name);
                }
            },
            title: []const u8,
            message: []const u8,
            status: ?[]const u8 = null,
            action_link: []const u8,
            creation_timestamp: i64,
            last_updated_timestamp: i64,
            metadata: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identifier = "identifier",
                    .domain_identifier = "domainIdentifier",
                    .type = "type",
                    .topic = "topic",
                    .title = "title",
                    .message = "message",
                    .status = "status",
                    .action_link = "actionLink",
                    .creation_timestamp = "creationTimestamp",
                    .last_updated_timestamp = "lastUpdatedTimestamp",
                    .metadata = "metadata",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metadata", field_name))
                    return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notifications = "notifications",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_project_memberships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/projects/{projectIdentifier}/memberships",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProjectMemberships",
    Request: type = struct {
        domain_identifier: []const u8,
        project_identifier: []const u8,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .sort_by = "sortBy",
            .sort_order = "sortOrder",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .project_identifier = "projectIdentifier",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_project_memberships) } {
            return .{ .service_metadata = service_metadata, .action = list_project_memberships };
        }
    },
    Response: type = struct {
        members: []struct {
            member_details: union {
                user: ?struct {
                    user_id: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .user_id = "userId",
                        };
                        return @field(mappings, field_name);
                    }
                },
                group: ?struct {
                    group_id: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .group_id = "groupId",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .user = "user",
                        .group = "group",
                    };
                    return @field(mappings, field_name);
                }
            },
            designation: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_details = "memberDetails",
                    .designation = "designation",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "members",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_projects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        domain_identifier: []const u8,
        user_identifier: ?[]const u8 = null,
        group_identifier: ?[]const u8 = null,
        name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .user_identifier = "userIdentifier",
            .group_identifier = "groupIdentifier",
            .name = "name",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .user_identifier = "userIdentifier",
                .group_identifier = "groupIdentifier",
                .name = "name",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            domain_id: []const u8,
            id: []const u8,
            name: []const u8,
            description: ?[]const u8 = null,
            project_status: ?[]const u8 = null,
            failure_reasons: ?[]ProjectDeletionError = null,
            created_by: []const u8,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "domainId",
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .project_status = "projectStatus",
                    .failure_reasons = "failureReasons",
                    .created_by = "createdBy",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_subscription_grants: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/subscription-grants",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSubscriptionGrants",
    Request: type = struct {
        domain_identifier: []const u8,
        environment_id: ?[]const u8 = null,
        subscription_target_id: ?[]const u8 = null,
        subscribed_listing_id: ?[]const u8 = null,
        subscription_id: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .environment_id = "environmentId",
            .subscription_target_id = "subscriptionTargetId",
            .subscribed_listing_id = "subscribedListingId",
            .subscription_id = "subscriptionId",
            .sort_by = "sortBy",
            .sort_order = "sortOrder",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .environment_id = "environmentId",
                .subscription_target_id = "subscriptionTargetId",
                .subscribed_listing_id = "subscribedListingId",
                .subscription_id = "subscriptionId",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscription_grants) } {
            return .{ .service_metadata = service_metadata, .action = list_subscription_grants };
        }
    },
    Response: type = struct {
        items: []struct {
            id: []const u8,
            created_by: []const u8,
            updated_by: ?[]const u8 = null,
            domain_id: []const u8,
            created_at: i64,
            updated_at: i64,
            subscription_target_id: []const u8,
            granted_entity: GrantedEntity,
            status: []const u8,
            assets: ?[]SubscribedAsset = null,
            subscription_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .created_by = "createdBy",
                    .updated_by = "updatedBy",
                    .domain_id = "domainId",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .subscription_target_id = "subscriptionTargetId",
                    .granted_entity = "grantedEntity",
                    .status = "status",
                    .assets = "assets",
                    .subscription_id = "subscriptionId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_subscription_requests: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/subscription-requests",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSubscriptionRequests",
    Request: type = struct {
        domain_identifier: []const u8,
        status: ?[]const u8 = null,
        subscribed_listing_id: ?[]const u8 = null,
        owning_project_id: ?[]const u8 = null,
        approver_project_id: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .status = "status",
            .subscribed_listing_id = "subscribedListingId",
            .owning_project_id = "owningProjectId",
            .approver_project_id = "approverProjectId",
            .sort_by = "sortBy",
            .sort_order = "sortOrder",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .status = "status",
                .subscribed_listing_id = "subscribedListingId",
                .owning_project_id = "owningProjectId",
                .approver_project_id = "approverProjectId",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscription_requests) } {
            return .{ .service_metadata = service_metadata, .action = list_subscription_requests };
        }
    },
    Response: type = struct {
        items: []struct {
            id: []const u8,
            created_by: []const u8,
            updated_by: ?[]const u8 = null,
            domain_id: []const u8,
            status: []const u8,
            created_at: i64,
            updated_at: i64,
            request_reason: []const u8,
            subscribed_principals: []SubscribedPrincipal,
            subscribed_listings: []SubscribedListing,
            reviewer_id: ?[]const u8 = null,
            decision_comment: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .created_by = "createdBy",
                    .updated_by = "updatedBy",
                    .domain_id = "domainId",
                    .status = "status",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .request_reason = "requestReason",
                    .subscribed_principals = "subscribedPrincipals",
                    .subscribed_listings = "subscribedListings",
                    .reviewer_id = "reviewerId",
                    .decision_comment = "decisionComment",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_subscriptions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/subscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSubscriptions",
    Request: type = struct {
        domain_identifier: []const u8,
        subscription_request_identifier: ?[]const u8 = null,
        status: ?[]const u8 = null,
        subscribed_listing_id: ?[]const u8 = null,
        owning_project_id: ?[]const u8 = null,
        approver_project_id: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .subscription_request_identifier = "subscriptionRequestIdentifier",
            .status = "status",
            .subscribed_listing_id = "subscribedListingId",
            .owning_project_id = "owningProjectId",
            .approver_project_id = "approverProjectId",
            .sort_by = "sortBy",
            .sort_order = "sortOrder",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .subscription_request_identifier = "subscriptionRequestIdentifier",
                .status = "status",
                .subscribed_listing_id = "subscribedListingId",
                .owning_project_id = "owningProjectId",
                .approver_project_id = "approverProjectId",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = list_subscriptions };
        }
    },
    Response: type = struct {
        items: []struct {
            id: []const u8,
            created_by: []const u8,
            updated_by: ?[]const u8 = null,
            domain_id: []const u8,
            status: []const u8,
            created_at: i64,
            updated_at: i64,
            subscribed_principal: SubscribedPrincipal,
            subscribed_listing: SubscribedListing,
            subscription_request_id: ?[]const u8 = null,
            retain_permissions: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .created_by = "createdBy",
                    .updated_by = "updatedBy",
                    .domain_id = "domainId",
                    .status = "status",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .subscribed_principal = "subscribedPrincipal",
                    .subscribed_listing = "subscribedListing",
                    .subscription_request_id = "subscriptionRequestId",
                    .retain_permissions = "retainPermissions",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_subscription_targets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/domains/{domainIdentifier}/environments/{environmentIdentifier}/subscription-targets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSubscriptionTargets",
    Request: type = struct {
        domain_identifier: []const u8,
        environment_identifier: []const u8,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .sort_by = "sortBy",
            .sort_order = "sortOrder",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .environment_identifier = "environmentIdentifier",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscription_targets) } {
            return .{ .service_metadata = service_metadata, .action = list_subscription_targets };
        }
    },
    Response: type = struct {
        items: []struct {
            id: []const u8,
            authorized_principals: [][]const u8,
            domain_id: []const u8,
            project_id: []const u8,
            environment_id: []const u8,
            name: []const u8,
            type: []const u8,
            created_by: []const u8,
            updated_by: ?[]const u8 = null,
            created_at: i64,
            updated_at: ?i64 = null,
            manage_access_role: []const u8,
            applicable_asset_types: [][]const u8,
            subscription_target_config: []SubscriptionTargetForm,
            provider: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .authorized_principals = "authorizedPrincipals",
                    .domain_id = "domainId",
                    .project_id = "projectId",
                    .environment_id = "environmentId",
                    .name = "name",
                    .type = "type",
                    .created_by = "createdBy",
                    .updated_by = "updatedBy",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .manage_access_role = "manageAccessRole",
                    .applicable_asset_types = "applicableAssetTypes",
                    .subscription_target_config = "subscriptionTargetConfig",
                    .provider = "provider",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const reject_predictions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/domains/{domainIdentifier}/assets/{identifier}/reject-predictions",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectPredictions",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        revision: ?[]const u8 = null,
        reject_rule: ?struct {
            rule: ?[]const u8 = null,
            threshold: ?f32 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule = "rule",
                    .threshold = "threshold",
                };
                return @field(mappings, field_name);
            }
        } = null,
        reject_choices: ?[]struct {
            prediction_target: ?[]const u8 = null,
            prediction_choices: ?[]i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .prediction_target = "predictionTarget",
                    .prediction_choices = "predictionChoices",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .revision = "revision",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .revision = "revision",
                .reject_rule = "rejectRule",
                .reject_choices = "rejectChoices",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_predictions) } {
            return .{ .service_metadata = service_metadata, .action = reject_predictions };
        }
    },
    Response: type = struct {
        domain_id: []const u8,
        asset_id: []const u8,
        asset_revision: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .asset_id = "assetId",
                .asset_revision = "assetRevision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const reject_subscription_request: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/domains/{domainIdentifier}/subscription-requests/{identifier}/reject",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectSubscriptionRequest",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        decision_comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .decision_comment = "decisionComment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_subscription_request) } {
            return .{ .service_metadata = service_metadata, .action = reject_subscription_request };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        status: []const u8,
        created_at: i64,
        updated_at: i64,
        request_reason: []const u8,
        subscribed_principals: []SubscribedPrincipal,
        subscribed_listings: []SubscribedListing,
        reviewer_id: ?[]const u8 = null,
        decision_comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .status = "status",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .request_reason = "requestReason",
                .subscribed_principals = "subscribedPrincipals",
                .subscribed_listings = "subscribedListings",
                .reviewer_id = "reviewerId",
                .decision_comment = "decisionComment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const revoke_subscription: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/domains/{domainIdentifier}/subscriptions/{identifier}/revoke",
        .success_code = 200,
    };

    action_name: []const u8 = "RevokeSubscription",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        retain_permissions: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .retain_permissions = "retainPermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_subscription) } {
            return .{ .service_metadata = service_metadata, .action = revoke_subscription };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        status: []const u8,
        created_at: i64,
        updated_at: i64,
        subscribed_principal: SubscribedPrincipal,
        subscribed_listing: SubscribedListing,
        subscription_request_id: ?[]const u8 = null,
        retain_permissions: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .status = "status",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .subscribed_principal = "subscribedPrincipal",
                .subscribed_listing = "subscribedListing",
                .subscription_request_id = "subscriptionRequestId",
                .retain_permissions = "retainPermissions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const search: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/search",
        .success_code = 200,
    };

    action_name: []const u8 = "Search",
    Request: type = struct {
        domain_identifier: []const u8,
        owning_project_identifier: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        search_scope: []const u8,
        search_text: ?[]const u8 = null,
        search_in: ?[]SearchInItem = null,
        filters: ?FilterClause = null,
        sort: ?SearchSort = null,
        additional_attributes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .owning_project_identifier = "owningProjectIdentifier",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .search_scope = "searchScope",
                .search_text = "searchText",
                .search_in = "searchIn",
                .filters = "filters",
                .sort = "sort",
                .additional_attributes = "additionalAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search) } {
            return .{ .service_metadata = service_metadata, .action = search };
        }
    },
    Response: type = struct {
        items: ?[]union {
            glossary_item: ?struct {
                domain_id: []const u8,
                id: []const u8,
                name: []const u8,
                owning_project_id: []const u8,
                description: ?[]const u8 = null,
                status: []const u8,
                created_at: ?i64 = null,
                created_by: ?[]const u8 = null,
                updated_at: ?i64 = null,
                updated_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .domain_id = "domainId",
                        .id = "id",
                        .name = "name",
                        .owning_project_id = "owningProjectId",
                        .description = "description",
                        .status = "status",
                        .created_at = "createdAt",
                        .created_by = "createdBy",
                        .updated_at = "updatedAt",
                        .updated_by = "updatedBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            glossary_term_item: ?struct {
                domain_id: []const u8,
                glossary_id: []const u8,
                id: []const u8,
                name: []const u8,
                short_description: ?[]const u8 = null,
                long_description: ?[]const u8 = null,
                term_relations: ?struct {
                    isa: ?[][]const u8 = null,
                    classifies: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .isa = "isA",
                            .classifies = "classifies",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                status: []const u8,
                created_at: ?i64 = null,
                created_by: ?[]const u8 = null,
                updated_at: ?i64 = null,
                updated_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .domain_id = "domainId",
                        .glossary_id = "glossaryId",
                        .id = "id",
                        .name = "name",
                        .short_description = "shortDescription",
                        .long_description = "longDescription",
                        .term_relations = "termRelations",
                        .status = "status",
                        .created_at = "createdAt",
                        .created_by = "createdBy",
                        .updated_at = "updatedAt",
                        .updated_by = "updatedBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            asset_item: ?struct {
                domain_id: []const u8,
                identifier: []const u8,
                name: []const u8,
                type_identifier: []const u8,
                type_revision: []const u8,
                external_identifier: ?[]const u8 = null,
                description: ?[]const u8 = null,
                created_at: ?i64 = null,
                created_by: ?[]const u8 = null,
                first_revision_created_at: ?i64 = null,
                first_revision_created_by: ?[]const u8 = null,
                glossary_terms: ?[][]const u8 = null,
                owning_project_id: []const u8,
                additional_attributes: ?struct {
                    forms_output: ?[]FormOutput = null,
                    read_only_forms_output: ?[]FormOutput = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .forms_output = "formsOutput",
                            .read_only_forms_output = "readOnlyFormsOutput",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .domain_id = "domainId",
                        .identifier = "identifier",
                        .name = "name",
                        .type_identifier = "typeIdentifier",
                        .type_revision = "typeRevision",
                        .external_identifier = "externalIdentifier",
                        .description = "description",
                        .created_at = "createdAt",
                        .created_by = "createdBy",
                        .first_revision_created_at = "firstRevisionCreatedAt",
                        .first_revision_created_by = "firstRevisionCreatedBy",
                        .glossary_terms = "glossaryTerms",
                        .owning_project_id = "owningProjectId",
                        .additional_attributes = "additionalAttributes",
                    };
                    return @field(mappings, field_name);
                }
            },
            data_product_item: ?struct {
                domain_id: []const u8,
                id: []const u8,
                name: []const u8,
                owning_project_id: []const u8,
                description: ?[]const u8 = null,
                glossary_terms: ?[][]const u8 = null,
                data_product_items: ?[]struct {
                    item_id: ?[]const u8 = null,
                    domain_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .item_id = "itemId",
                            .domain_id = "domainId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                created_at: ?i64 = null,
                created_by: ?[]const u8 = null,
                updated_at: ?i64 = null,
                updated_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .domain_id = "domainId",
                        .id = "id",
                        .name = "name",
                        .owning_project_id = "owningProjectId",
                        .description = "description",
                        .glossary_terms = "glossaryTerms",
                        .data_product_items = "dataProductItems",
                        .created_at = "createdAt",
                        .created_by = "createdBy",
                        .updated_at = "updatedAt",
                        .updated_by = "updatedBy",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .glossary_item = "glossaryItem",
                    .glossary_term_item = "glossaryTermItem",
                    .asset_item = "assetItem",
                    .data_product_item = "dataProductItem",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        total_match_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
                .total_match_count = "totalMatchCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const search_group_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/search-group-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchGroupProfiles",
    Request: type = struct {
        domain_identifier: []const u8,
        group_type: []const u8,
        search_text: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .group_type = "groupType",
                .search_text = "searchText",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_group_profiles) } {
            return .{ .service_metadata = service_metadata, .action = search_group_profiles };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            domain_id: ?[]const u8 = null,
            id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            group_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "domainId",
                    .id = "id",
                    .status = "status",
                    .group_name = "groupName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const search_listings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/listings/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchListings",
    Request: type = struct {
        domain_identifier: []const u8,
        search_text: ?[]const u8 = null,
        search_in: ?[]SearchInItem = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?FilterClause = null,
        sort: ?SearchSort = null,
        additional_attributes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .search_text = "searchText",
                .search_in = "searchIn",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .filters = "filters",
                .sort = "sort",
                .additional_attributes = "additionalAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_listings) } {
            return .{ .service_metadata = service_metadata, .action = search_listings };
        }
    },
    Response: type = struct {
        items: ?[]union {
            asset_listing: ?struct {
                listing_id: ?[]const u8 = null,
                listing_revision: ?[]const u8 = null,
                name: ?[]const u8 = null,
                entity_id: ?[]const u8 = null,
                entity_revision: ?[]const u8 = null,
                entity_type: ?[]const u8 = null,
                description: ?[]const u8 = null,
                created_at: ?i64 = null,
                listing_created_by: ?[]const u8 = null,
                listing_updated_by: ?[]const u8 = null,
                glossary_terms: ?[]DetailedGlossaryTerm = null,
                owning_project_id: ?[]const u8 = null,
                additional_attributes: ?struct {
                    forms: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .forms = "forms",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .listing_id = "listingId",
                        .listing_revision = "listingRevision",
                        .name = "name",
                        .entity_id = "entityId",
                        .entity_revision = "entityRevision",
                        .entity_type = "entityType",
                        .description = "description",
                        .created_at = "createdAt",
                        .listing_created_by = "listingCreatedBy",
                        .listing_updated_by = "listingUpdatedBy",
                        .glossary_terms = "glossaryTerms",
                        .owning_project_id = "owningProjectId",
                        .additional_attributes = "additionalAttributes",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .asset_listing = "assetListing",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        total_match_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
                .total_match_count = "totalMatchCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const search_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/types-search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchTypes",
    Request: type = struct {
        domain_identifier: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        search_scope: []const u8,
        search_text: ?[]const u8 = null,
        search_in: ?[]SearchInItem = null,
        filters: ?FilterClause = null,
        sort: ?SearchSort = null,
        managed: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .search_scope = "searchScope",
                .search_text = "searchText",
                .search_in = "searchIn",
                .filters = "filters",
                .sort = "sort",
                .managed = "managed",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_types) } {
            return .{ .service_metadata = service_metadata, .action = search_types };
        }
    },
    Response: type = struct {
        items: ?[]union {
            asset_type_item: ?struct {
                domain_id: []const u8,
                name: []const u8,
                revision: []const u8,
                description: ?[]const u8 = null,
                forms_output: []struct {
                    key: ?[]const u8 = null,
                    value: ?struct {
                        type_name: []const u8,
                        type_revision: []const u8,
                        required: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .type_name = "typeName",
                                .type_revision = "typeRevision",
                                .required = "required",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                },
                owning_project_id: []const u8,
                origin_domain_id: ?[]const u8 = null,
                origin_project_id: ?[]const u8 = null,
                created_at: ?i64 = null,
                created_by: ?[]const u8 = null,
                updated_at: ?i64 = null,
                updated_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .domain_id = "domainId",
                        .name = "name",
                        .revision = "revision",
                        .description = "description",
                        .forms_output = "formsOutput",
                        .owning_project_id = "owningProjectId",
                        .origin_domain_id = "originDomainId",
                        .origin_project_id = "originProjectId",
                        .created_at = "createdAt",
                        .created_by = "createdBy",
                        .updated_at = "updatedAt",
                        .updated_by = "updatedBy",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "forms_output", field_name))
                        return try serializeMap(self.forms_output, self.fieldNameFor("forms_output"), options, out_stream);
                    return false;
                }
            },
            form_type_item: ?struct {
                domain_id: []const u8,
                name: []const u8,
                revision: []const u8,
                model: ?union {
                    smithy: ?[]const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .smithy = "smithy",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                status: ?[]const u8 = null,
                owning_project_id: ?[]const u8 = null,
                origin_domain_id: ?[]const u8 = null,
                origin_project_id: ?[]const u8 = null,
                created_at: ?i64 = null,
                created_by: ?[]const u8 = null,
                description: ?[]const u8 = null,
                imports: ?[]struct {
                    name: []const u8,
                    revision: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .revision = "revision",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .domain_id = "domainId",
                        .name = "name",
                        .revision = "revision",
                        .model = "model",
                        .status = "status",
                        .owning_project_id = "owningProjectId",
                        .origin_domain_id = "originDomainId",
                        .origin_project_id = "originProjectId",
                        .created_at = "createdAt",
                        .created_by = "createdBy",
                        .description = "description",
                        .imports = "imports",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .asset_type_item = "assetTypeItem",
                    .form_type_item = "formTypeItem",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        total_match_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
                .total_match_count = "totalMatchCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const search_user_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/domains/{domainIdentifier}/search-user-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchUserProfiles",
    Request: type = struct {
        domain_identifier: []const u8,
        user_type: []const u8,
        search_text: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .user_type = "userType",
                .search_text = "searchText",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_user_profiles) } {
            return .{ .service_metadata = service_metadata, .action = search_user_profiles };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            domain_id: ?[]const u8 = null,
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            details: ?UserProfileDetails = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "domainId",
                    .id = "id",
                    .type = "type",
                    .status = "status",
                    .details = "details",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_environment: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/domains/{domainIdentifier}/environments/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEnvironment",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        glossary_terms: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .name = "name",
                .description = "description",
                .glossary_terms = "glossaryTerms",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_environment };
        }
    },
    Response: type = struct {
        project_id: []const u8,
        id: ?[]const u8 = null,
        domain_id: []const u8,
        created_by: []const u8,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        environment_profile_id: []const u8,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,
        provider: []const u8,
        provisioned_resources: ?[]Resource = null,
        status: ?[]const u8 = null,
        environment_actions: ?[]ConfigurableEnvironmentAction = null,
        glossary_terms: ?[][]const u8 = null,
        user_parameters: ?[]CustomParameter = null,
        last_deployment: ?Deployment = null,
        provisioning_properties: ?ProvisioningProperties = null,
        deployment_properties: ?DeploymentProperties = null,
        environment_blueprint_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .id = "id",
                .domain_id = "domainId",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .name = "name",
                .description = "description",
                .environment_profile_id = "environmentProfileId",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
                .provider = "provider",
                .provisioned_resources = "provisionedResources",
                .status = "status",
                .environment_actions = "environmentActions",
                .glossary_terms = "glossaryTerms",
                .user_parameters = "userParameters",
                .last_deployment = "lastDeployment",
                .provisioning_properties = "provisioningProperties",
                .deployment_properties = "deploymentProperties",
                .environment_blueprint_id = "environmentBlueprintId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_environment_profile: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/domains/{domainIdentifier}/environment-profiles/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEnvironmentProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        user_parameters: ?[]EnvironmentParameter = null,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .name = "name",
                .description = "description",
                .user_parameters = "userParameters",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_environment_profile };
        }
    },
    Response: type = struct {
        id: []const u8,
        domain_id: []const u8,
        aws_account_id: ?[]const u8 = null,
        aws_account_region: ?[]const u8 = null,
        created_by: []const u8,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        environment_blueprint_id: []const u8,
        project_id: ?[]const u8 = null,
        user_parameters: ?[]CustomParameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .domain_id = "domainId",
                .aws_account_id = "awsAccountId",
                .aws_account_region = "awsAccountRegion",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .name = "name",
                .description = "description",
                .environment_blueprint_id = "environmentBlueprintId",
                .project_id = "projectId",
                .user_parameters = "userParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_group_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/domains/{domainIdentifier}/group-profiles/{groupIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGroupProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        group_identifier: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .group_identifier = "groupIdentifier",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_group_profile };
        }
    },
    Response: type = struct {
        domain_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .status = "status",
                .group_name = "groupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_project: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/domains/{domainIdentifier}/projects/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProject",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        glossary_terms: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .name = "name",
                .description = "description",
                .glossary_terms = "glossaryTerms",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_project) } {
            return .{ .service_metadata = service_metadata, .action = update_project };
        }
    },
    Response: type = struct {
        domain_id: []const u8,
        id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        project_status: ?[]const u8 = null,
        failure_reasons: ?[]ProjectDeletionError = null,
        created_by: []const u8,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        glossary_terms: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .name = "name",
                .description = "description",
                .project_status = "projectStatus",
                .failure_reasons = "failureReasons",
                .created_by = "createdBy",
                .created_at = "createdAt",
                .last_updated_at = "lastUpdatedAt",
                .glossary_terms = "glossaryTerms",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_subscription_grant_status: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/domains/{domainIdentifier}/subscription-grants/{identifier}/status/{assetIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSubscriptionGrantStatus",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        asset_identifier: []const u8,
        status: []const u8,
        failure_cause: ?FailureCause = null,
        target_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .asset_identifier = "assetIdentifier",
                .status = "status",
                .failure_cause = "failureCause",
                .target_name = "targetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subscription_grant_status) } {
            return .{ .service_metadata = service_metadata, .action = update_subscription_grant_status };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        created_at: i64,
        updated_at: i64,
        subscription_target_id: []const u8,
        granted_entity: GrantedEntity,
        status: []const u8,
        assets: ?[]SubscribedAsset = null,
        subscription_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .subscription_target_id = "subscriptionTargetId",
                .granted_entity = "grantedEntity",
                .status = "status",
                .assets = "assets",
                .subscription_id = "subscriptionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_subscription_request: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/domains/{domainIdentifier}/subscription-requests/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSubscriptionRequest",
    Request: type = struct {
        domain_identifier: []const u8,
        identifier: []const u8,
        request_reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .identifier = "identifier",
                .request_reason = "requestReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subscription_request) } {
            return .{ .service_metadata = service_metadata, .action = update_subscription_request };
        }
    },
    Response: type = struct {
        id: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        domain_id: []const u8,
        status: []const u8,
        created_at: i64,
        updated_at: i64,
        request_reason: []const u8,
        subscribed_principals: []SubscribedPrincipal,
        subscribed_listings: []SubscribedListing,
        reviewer_id: ?[]const u8 = null,
        decision_comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .domain_id = "domainId",
                .status = "status",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .request_reason = "requestReason",
                .subscribed_principals = "subscribedPrincipals",
                .subscribed_listings = "subscribedListings",
                .reviewer_id = "reviewerId",
                .decision_comment = "decisionComment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_subscription_target: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v2/domains/{domainIdentifier}/environments/{environmentIdentifier}/subscription-targets/{identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSubscriptionTarget",
    Request: type = struct {
        domain_identifier: []const u8,
        environment_identifier: []const u8,
        identifier: []const u8,
        name: ?[]const u8 = null,
        authorized_principals: ?[][]const u8 = null,
        applicable_asset_types: ?[][]const u8 = null,
        subscription_target_config: ?[]SubscriptionTargetForm = null,
        manage_access_role: ?[]const u8 = null,
        provider: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .environment_identifier = "environmentIdentifier",
                .identifier = "identifier",
                .name = "name",
                .authorized_principals = "authorizedPrincipals",
                .applicable_asset_types = "applicableAssetTypes",
                .subscription_target_config = "subscriptionTargetConfig",
                .manage_access_role = "manageAccessRole",
                .provider = "provider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subscription_target) } {
            return .{ .service_metadata = service_metadata, .action = update_subscription_target };
        }
    },
    Response: type = struct {
        id: []const u8,
        authorized_principals: [][]const u8,
        domain_id: []const u8,
        project_id: []const u8,
        environment_id: []const u8,
        name: []const u8,
        type: []const u8,
        created_by: []const u8,
        updated_by: ?[]const u8 = null,
        created_at: i64,
        updated_at: ?i64 = null,
        manage_access_role: []const u8,
        applicable_asset_types: [][]const u8,
        subscription_target_config: []SubscriptionTargetForm,
        provider: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .authorized_principals = "authorizedPrincipals",
                .domain_id = "domainId",
                .project_id = "projectId",
                .environment_id = "environmentId",
                .name = "name",
                .type = "type",
                .created_by = "createdBy",
                .updated_by = "updatedBy",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .manage_access_role = "manageAccessRole",
                .applicable_asset_types = "applicableAssetTypes",
                .subscription_target_config = "subscriptionTargetConfig",
                .provider = "provider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_user_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/domains/{domainIdentifier}/user-profiles/{userIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserProfile",
    Request: type = struct {
        domain_identifier: []const u8,
        user_identifier: []const u8,
        type: ?[]const u8 = null,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_identifier = "domainIdentifier",
                .user_identifier = "userIdentifier",
                .type = "type",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_user_profile };
        }
    },
    Response: type = struct {
        domain_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        details: ?UserProfileDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "domainId",
                .id = "id",
                .type = "type",
                .status = "status",
                .details = "details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const UserProfileDetails = union {
    iam: ?IamUserProfileDetails,
    sso: ?SsoUserProfileDetails,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam = "iam",
            .sso = "sso",
        };
        return @field(mappings, field_name);
    }
};

pub const SsoUserProfileDetails = struct {
    username: ?[]const u8 = null,
    first_name: ?[]const u8 = null,
    last_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "username",
            .first_name = "firstName",
            .last_name = "lastName",
        };
        return @field(mappings, field_name);
    }
};

pub const IamUserProfileDetails = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscriptionTargetForm = struct {
    form_name: []const u8,
    content: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .form_name = "formName",
            .content = "content",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscribedListing = struct {
    id: []const u8,
    revision: ?[]const u8 = null,
    name: []const u8,
    description: []const u8,
    item: SubscribedListingItem,
    owner_project_id: []const u8,
    owner_project_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .revision = "revision",
            .name = "name",
            .description = "description",
            .item = "item",
            .owner_project_id = "ownerProjectId",
            .owner_project_name = "ownerProjectName",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscribedListingItem = union {
    asset_listing: ?SubscribedAssetListing,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_listing = "assetListing",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscribedAssetListing = struct {
    entity_id: ?[]const u8 = null,
    entity_revision: ?[]const u8 = null,
    entity_type: ?[]const u8 = null,
    forms: ?[]const u8 = null,
    glossary_terms: ?[]DetailedGlossaryTerm = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_id = "entityId",
            .entity_revision = "entityRevision",
            .entity_type = "entityType",
            .forms = "forms",
            .glossary_terms = "glossaryTerms",
        };
        return @field(mappings, field_name);
    }
};

pub const DetailedGlossaryTerm = struct {
    name: ?[]const u8 = null,
    short_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .short_description = "shortDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscribedPrincipal = union {
    project: ?SubscribedProject,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .project = "project",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscribedProject = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscribedAsset = struct {
    asset_id: []const u8,
    asset_revision: []const u8,
    status: []const u8,
    target_name: ?[]const u8 = null,
    failure_cause: ?FailureCause = null,
    granted_timestamp: ?i64 = null,
    failure_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_id = "assetId",
            .asset_revision = "assetRevision",
            .status = "status",
            .target_name = "targetName",
            .failure_cause = "failureCause",
            .granted_timestamp = "grantedTimestamp",
            .failure_timestamp = "failureTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const FailureCause = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const GrantedEntity = union {
    listing: ?ListingRevision,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .listing = "listing",
        };
        return @field(mappings, field_name);
    }
};

pub const ListingRevision = struct {
    id: []const u8,
    revision: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .revision = "revision",
        };
        return @field(mappings, field_name);
    }
};

pub const ProjectDeletionError = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomParameter = struct {
    key_name: []const u8,
    description: ?[]const u8 = null,
    field_type: []const u8,
    default_value: ?[]const u8 = null,
    is_editable: ?bool = null,
    is_optional: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_name = "keyName",
            .description = "description",
            .field_type = "fieldType",
            .default_value = "defaultValue",
            .is_editable = "isEditable",
            .is_optional = "isOptional",
        };
        return @field(mappings, field_name);
    }
};

pub const EnvironmentParameter = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentProperties = struct {
    start_timeout_minutes: ?i64 = null,
    end_timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_timeout_minutes = "startTimeoutMinutes",
            .end_timeout_minutes = "endTimeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisioningProperties = union {
    cloud_formation: ?CloudFormationProperties,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_formation = "cloudFormation",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudFormationProperties = struct {
    template_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .template_url = "templateUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const Deployment = struct {
    deployment_id: ?[]const u8 = null,
    deployment_type: ?[]const u8 = null,
    deployment_status: ?[]const u8 = null,
    failure_reason: ?EnvironmentError = null,
    messages: ?[][]const u8 = null,
    is_deployment_complete: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deployment_id = "deploymentId",
            .deployment_type = "deploymentType",
            .deployment_status = "deploymentStatus",
            .failure_reason = "failureReason",
            .messages = "messages",
            .is_deployment_complete = "isDeploymentComplete",
        };
        return @field(mappings, field_name);
    }
};

pub const EnvironmentError = struct {
    code: ?[]const u8 = null,
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurableEnvironmentAction = struct {
    type: []const u8,
    auth: ?[]const u8 = null,
    parameters: []ConfigurableActionParameter,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .auth = "auth",
            .parameters = "parameters",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurableActionParameter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    provider: ?[]const u8 = null,
    name: ?[]const u8 = null,
    value: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provider = "provider",
            .name = "name",
            .value = "value",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const SearchSort = struct {
    attribute: []const u8,
    order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute = "attribute",
            .order = "order",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterClause = union {
    filter: ?Filter,
    @"and": ?[]FilterClause,
    @"or": ?[]FilterClause,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter = "filter",
            .@"and" = "and",
            .@"or" = "or",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    attribute: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute = "attribute",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SearchInItem = struct {
    attribute: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute = "attribute",
        };
        return @field(mappings, field_name);
    }
};

pub const FormOutput = struct {
    form_name: []const u8,
    type_name: ?[]const u8 = null,
    type_revision: ?[]const u8 = null,
    content: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .form_name = "formName",
            .type_name = "typeName",
            .type_revision = "typeRevision",
            .content = "content",
        };
        return @field(mappings, field_name);
    }
};

pub const Member = union {
    user_identifier: ?[]const u8,
    group_identifier: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_identifier = "userIdentifier",
            .group_identifier = "groupIdentifier",
        };
        return @field(mappings, field_name);
    }
};
