const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-04-19";
pub const sdk_id: []const u8 = "DAX";
pub const arn_namespace: ?[]const u8 = "dax";
pub const endpoint_prefix: []const u8 = "dax";
pub const sigv4_name: []const u8 = "dax";
pub const name: []const u8 = "AmazonDAXV3";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-04-19",
    sdk_id: []const u8 = "DAX",
    arn_namespace: ?[]const u8 = "dax",
    endpoint_prefix: []const u8 = "dax",
    sigv4_name: []const u8 = "dax",
    name: []const u8 = "AmazonDAXV3",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_cluster: struct {
    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        cluster_name: []const u8,
        node_type: []const u8,
        description: ?[]const u8 = null,
        replication_factor: i64,
        availability_zones: ?[][]const u8 = null,
        subnet_group_name: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        notification_topic_arn: ?[]const u8 = null,
        iam_role_arn: []const u8,
        parameter_group_name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        sse_specification: ?struct {
            enabled: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enabled = "Enabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        cluster_endpoint_encryption_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .node_type = "NodeType",
                .description = "Description",
                .replication_factor = "ReplicationFactor",
                .availability_zones = "AvailabilityZones",
                .subnet_group_name = "SubnetGroupName",
                .security_group_ids = "SecurityGroupIds",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .notification_topic_arn = "NotificationTopicArn",
                .iam_role_arn = "IamRoleArn",
                .parameter_group_name = "ParameterGroupName",
                .tags = "Tags",
                .sse_specification = "SSESpecification",
                .cluster_endpoint_encryption_type = "ClusterEndpointEncryptionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterAlreadyExists,
        ClusterQuotaForCustomerExceeded,
        InsufficientClusterCapacity,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        InvalidVPCNetworkState,
        NodeQuotaForClusterExceeded,
        NodeQuotaForCustomerExceeded,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
        ServiceQuotaExceeded,
        SubnetGroupNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_parameter_group: struct {
    action_name: []const u8 = "CreateParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = create_parameter_group };
        }
    },
    Response: type = struct {
        parameter_group: ?ParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group = "ParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        ParameterGroupAlreadyExists,
        ParameterGroupQuotaExceeded,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const create_subnet_group: struct {
    action_name: []const u8 = "CreateSubnetGroup",
    Request: type = struct {
        subnet_group_name: []const u8,
        description: ?[]const u8 = null,
        subnet_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group_name = "SubnetGroupName",
                .description = "Description",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = create_subnet_group };
        }
    },
    Response: type = struct {
        subnet_group: ?SubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group = "SubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidSubnet,
        ServiceLinkedRoleNotFound,
        SubnetGroupAlreadyExists,
        SubnetGroupQuotaExceeded,
        SubnetQuotaExceeded,
    },
} = .{};
pub const decrease_replication_factor: struct {
    action_name: []const u8 = "DecreaseReplicationFactor",
    Request: type = struct {
        cluster_name: []const u8,
        new_replication_factor: i64,
        availability_zones: ?[][]const u8 = null,
        node_ids_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .new_replication_factor = "NewReplicationFactor",
                .availability_zones = "AvailabilityZones",
                .node_ids_to_remove = "NodeIdsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decrease_replication_factor) } {
            return .{ .service_metadata = service_metadata, .action = decrease_replication_factor };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        NodeNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const delete_cluster: struct {
    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        cluster_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const delete_parameter_group: struct {
    action_name: []const u8 = "DeleteParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_parameter_group };
        }
    },
    Response: type = struct {
        deletion_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deletion_message = "DeletionMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const delete_subnet_group: struct {
    action_name: []const u8 = "DeleteSubnetGroup",
    Request: type = struct {
        subnet_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group_name = "SubnetGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_subnet_group };
        }
    },
    Response: type = struct {
        deletion_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deletion_message = "DeletionMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ServiceLinkedRoleNotFound,
        SubnetGroupInUse,
        SubnetGroupNotFound,
    },
} = .{};
pub const describe_clusters: struct {
    action_name: []const u8 = "DescribeClusters",
    Request: type = struct {
        cluster_names: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_names = "ClusterNames",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_clusters };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        clusters: ?[]Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .clusters = "Clusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_default_parameters: struct {
    action_name: []const u8 = "DescribeDefaultParameters",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_default_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_default_parameters };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        parameters: ?[]Parameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        source_name: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        duration: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_name = "SourceName",
                .source_type = "SourceType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .duration = "Duration",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        events: ?[]struct {
            source_name: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_name = "SourceName",
                    .source_type = "SourceType",
                    .message = "Message",
                    .date = "Date",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_parameter_groups: struct {
    action_name: []const u8 = "DescribeParameterGroups",
    Request: type = struct {
        parameter_group_names: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_names = "ParameterGroupNames",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_parameter_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_parameter_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        parameter_groups: ?[]ParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .parameter_groups = "ParameterGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_parameters: struct {
    action_name: []const u8 = "DescribeParameters",
    Request: type = struct {
        parameter_group_name: []const u8,
        source: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .source = "Source",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_parameters };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        parameters: ?[]Parameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_subnet_groups: struct {
    action_name: []const u8 = "DescribeSubnetGroups",
    Request: type = struct {
        subnet_group_names: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group_names = "SubnetGroupNames",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_subnet_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_subnet_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        subnet_groups: ?[]SubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .subnet_groups = "SubnetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ServiceLinkedRoleNotFound,
        SubnetGroupNotFound,
    },
} = .{};
pub const increase_replication_factor: struct {
    action_name: []const u8 = "IncreaseReplicationFactor",
    Request: type = struct {
        cluster_name: []const u8,
        new_replication_factor: i64,
        availability_zones: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .new_replication_factor = "NewReplicationFactor",
                .availability_zones = "AvailabilityZones",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(increase_replication_factor) } {
            return .{ .service_metadata = service_metadata, .action = increase_replication_factor };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InsufficientClusterCapacity,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidVPCNetworkState,
        NodeQuotaForClusterExceeded,
        NodeQuotaForCustomerExceeded,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const list_tags: struct {
    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource_name: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidARN,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const reboot_node: struct {
    action_name: []const u8 = "RebootNode",
    Request: type = struct {
        cluster_name: []const u8,
        node_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .node_id = "NodeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_node) } {
            return .{ .service_metadata = service_metadata, .action = reboot_node };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        NodeNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_name: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidARN,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_name: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidARN,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
        TagNotFound,
    },
} = .{};
pub const update_cluster: struct {
    action_name: []const u8 = "UpdateCluster",
    Request: type = struct {
        cluster_name: []const u8,
        description: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        notification_topic_arn: ?[]const u8 = null,
        notification_topic_status: ?[]const u8 = null,
        parameter_group_name: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .description = "Description",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .notification_topic_arn = "NotificationTopicArn",
                .notification_topic_status = "NotificationTopicStatus",
                .parameter_group_name = "ParameterGroupName",
                .security_group_ids = "SecurityGroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const update_parameter_group: struct {
    action_name: []const u8 = "UpdateParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,
        parameter_name_values: []struct {
            parameter_name: ?[]const u8 = null,
            parameter_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .parameter_name = "ParameterName",
                    .parameter_value = "ParameterValue",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .parameter_name_values = "ParameterNameValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = update_parameter_group };
        }
    },
    Response: type = struct {
        parameter_group: ?ParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group = "ParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const update_subnet_group: struct {
    action_name: []const u8 = "UpdateSubnetGroup",
    Request: type = struct {
        subnet_group_name: []const u8,
        description: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group_name = "SubnetGroupName",
                .description = "Description",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = update_subnet_group };
        }
    },
    Response: type = struct {
        subnet_group: ?SubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group = "SubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidSubnet,
        ServiceLinkedRoleNotFound,
        SubnetGroupNotFound,
        SubnetInUse,
        SubnetQuotaExceeded,
    },
} = .{};

pub const SubnetGroup = struct {
    subnet_group_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnets: ?[]Subnet = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_group_name = "SubnetGroupName",
            .description = "Description",
            .vpc_id = "VpcId",
            .subnets = "Subnets",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterGroup = struct {
    parameter_group_name: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_group_name = "ParameterGroupName",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const Cluster = struct {
    cluster_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    cluster_arn: ?[]const u8 = null,
    total_nodes: ?i64 = null,
    active_nodes: ?i64 = null,
    node_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    cluster_discovery_endpoint: ?Endpoint = null,
    node_ids_to_remove: ?[][]const u8 = null,
    nodes: ?[]Node = null,
    preferred_maintenance_window: ?[]const u8 = null,
    notification_configuration: ?NotificationConfiguration = null,
    subnet_group: ?[]const u8 = null,
    security_groups: ?[]SecurityGroupMembership = null,
    iam_role_arn: ?[]const u8 = null,
    parameter_group: ?ParameterGroupStatus = null,
    sse_description: ?SSEDescription = null,
    cluster_endpoint_encryption_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_name = "ClusterName",
            .description = "Description",
            .cluster_arn = "ClusterArn",
            .total_nodes = "TotalNodes",
            .active_nodes = "ActiveNodes",
            .node_type = "NodeType",
            .status = "Status",
            .cluster_discovery_endpoint = "ClusterDiscoveryEndpoint",
            .node_ids_to_remove = "NodeIdsToRemove",
            .nodes = "Nodes",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .notification_configuration = "NotificationConfiguration",
            .subnet_group = "SubnetGroup",
            .security_groups = "SecurityGroups",
            .iam_role_arn = "IamRoleArn",
            .parameter_group = "ParameterGroup",
            .sse_description = "SSEDescription",
            .cluster_endpoint_encryption_type = "ClusterEndpointEncryptionType",
        };
        return @field(mappings, field_name);
    }
};

pub const SSEDescription = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterGroupStatus = struct {
    parameter_group_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,
    node_ids_to_reboot: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_group_name = "ParameterGroupName",
            .parameter_apply_status = "ParameterApplyStatus",
            .node_ids_to_reboot = "NodeIdsToReboot",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityGroupMembership = struct {
    security_group_identifier: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_identifier = "SecurityGroupIdentifier",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationConfiguration = struct {
    topic_arn: ?[]const u8 = null,
    topic_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
            .topic_status = "TopicStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Node = struct {
    node_id: ?[]const u8 = null,
    endpoint: ?Endpoint = null,
    node_create_time: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    node_status: ?[]const u8 = null,
    parameter_group_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_id = "NodeId",
            .endpoint = "Endpoint",
            .node_create_time = "NodeCreateTime",
            .availability_zone = "AvailabilityZone",
            .node_status = "NodeStatus",
            .parameter_group_status = "ParameterGroupStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
            .url = "URL",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameter = struct {
    parameter_name: ?[]const u8 = null,
    parameter_type: ?[]const u8 = null,
    parameter_value: ?[]const u8 = null,
    node_type_specific_values: ?[]NodeTypeSpecificValue = null,
    description: ?[]const u8 = null,
    source: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    allowed_values: ?[]const u8 = null,
    is_modifiable: ?[]const u8 = null,
    change_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_type = "ParameterType",
            .parameter_value = "ParameterValue",
            .node_type_specific_values = "NodeTypeSpecificValues",
            .description = "Description",
            .source = "Source",
            .data_type = "DataType",
            .allowed_values = "AllowedValues",
            .is_modifiable = "IsModifiable",
            .change_type = "ChangeType",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeTypeSpecificValue = struct {
    node_type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_type = "NodeType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
