const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-10-26";
pub const sdk_id: []const u8 = "Detective";
pub const arn_namespace: ?[]const u8 = "detective";
pub const endpoint_prefix: []const u8 = "api.detective";
pub const sigv4_name: []const u8 = "detective";
pub const name: []const u8 = "AmazonDetective";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-10-26",
    sdk_id: []const u8 = "Detective",
    arn_namespace: ?[]const u8 = "detective",
    endpoint_prefix: []const u8 = "api.detective",
    sigv4_name: []const u8 = "detective",
    name: []const u8 = "AmazonDetective",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_invitation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/invitation",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptInvitation",
    Request: type = struct {
        graph_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_invitation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const batch_get_graph_member_datasources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/datasources/get",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetGraphMemberDatasources",
    Request: type = struct {
        graph_arn: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_graph_member_datasources) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_graph_member_datasources };
        }
    },
    Response: type = struct {
        member_datasources: ?[]MembershipDatasources = null,
        unprocessed_accounts: ?[]UnprocessedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_datasources = "MemberDatasources",
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const batch_get_membership_datasources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/membership/datasources/get",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetMembershipDatasources",
    Request: type = struct {
        graph_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arns = "GraphArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_membership_datasources) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_membership_datasources };
        }
    },
    Response: type = struct {
        membership_datasources: ?[]MembershipDatasources = null,
        unprocessed_graphs: ?[]struct {
            graph_arn: ?[]const u8 = null,
            reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .graph_arn = "GraphArn",
                    .reason = "Reason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .membership_datasources = "MembershipDatasources",
                .unprocessed_graphs = "UnprocessedGraphs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_graph: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGraph",
    Request: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_graph) } {
            return .{ .service_metadata = service_metadata, .action = create_graph };
        }
    },
    Response: type = struct {
        graph_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/members",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMembers",
    Request: type = struct {
        graph_arn: []const u8,
        message: ?[]const u8 = null,
        disable_email_notification: ?bool = null,
        accounts: []struct {
            account_id: []const u8,
            email_address: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .email_address = "EmailAddress",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .message = "Message",
                .disable_email_notification = "DisableEmailNotification",
                .accounts = "Accounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_members) } {
            return .{ .service_metadata = service_metadata, .action = create_members };
        }
    },
    Response: type = struct {
        members: ?[]MemberDetail = null,
        unprocessed_accounts: ?[]UnprocessedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "Members",
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_graph: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/removal",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGraph",
    Request: type = struct {
        graph_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_graph) } {
            return .{ .service_metadata = service_metadata, .action = delete_graph };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/members/removal",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMembers",
    Request: type = struct {
        graph_arn: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_members) } {
            return .{ .service_metadata = service_metadata, .action = delete_members };
        }
    },
    Response: type = struct {
        account_ids: ?[][]const u8 = null,
        unprocessed_accounts: ?[]UnprocessedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_organization_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/orgs/describeOrganizationConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationConfiguration",
    Request: type = struct {
        graph_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_configuration };
        }
    },
    Response: type = struct {
        auto_enable: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "AutoEnable",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const disable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/orgs/disableAdminAccount",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableOrganizationAdminAccount",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = disable_organization_admin_account };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const disassociate_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/membership/removal",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateMembership",
    Request: type = struct {
        graph_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_membership) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_membership };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const enable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/orgs/enableAdminAccount",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableOrganizationAdminAccount",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = enable_organization_admin_account };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const get_investigation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/investigations/getInvestigation",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInvestigation",
    Request: type = struct {
        graph_arn: []const u8,
        investigation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .investigation_id = "InvestigationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_investigation) } {
            return .{ .service_metadata = service_metadata, .action = get_investigation };
        }
    },
    Response: type = struct {
        graph_arn: ?[]const u8 = null,
        investigation_id: ?[]const u8 = null,
        entity_arn: ?[]const u8 = null,
        entity_type: ?[]const u8 = null,
        created_time: ?i64 = null,
        scope_start_time: ?i64 = null,
        scope_end_time: ?i64 = null,
        status: ?[]const u8 = null,
        severity: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .investigation_id = "InvestigationId",
                .entity_arn = "EntityArn",
                .entity_type = "EntityType",
                .created_time = "CreatedTime",
                .scope_start_time = "ScopeStartTime",
                .scope_end_time = "ScopeEndTime",
                .status = "Status",
                .severity = "Severity",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const get_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/members/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMembers",
    Request: type = struct {
        graph_arn: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_members) } {
            return .{ .service_metadata = service_metadata, .action = get_members };
        }
    },
    Response: type = struct {
        member_details: ?[]MemberDetail = null,
        unprocessed_accounts: ?[]UnprocessedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_details = "MemberDetails",
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_datasource_packages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/datasources/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatasourcePackages",
    Request: type = struct {
        graph_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasource_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_datasource_packages };
        }
    },
    Response: type = struct {
        datasource_packages: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                datasource_package_ingest_state: ?[]const u8 = null,
                last_ingest_state_change: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?TimestampForCollection = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .datasource_package_ingest_state = "DatasourcePackageIngestState",
                        .last_ingest_state_change = "LastIngestStateChange",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "last_ingest_state_change", field_name))
                        return try serializeMap(self.last_ingest_state_change, self.fieldNameFor("last_ingest_state_change"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datasource_packages = "DatasourcePackages",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "datasource_packages", field_name))
                return try serializeMap(self.datasource_packages, self.fieldNameFor("datasource_packages"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_graphs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graphs/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGraphs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_graphs) } {
            return .{ .service_metadata = service_metadata, .action = list_graphs };
        }
    },
    Response: type = struct {
        graph_list: ?[]struct {
            arn: ?[]const u8 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_list = "GraphList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_indicators: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/investigations/listIndicators",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIndicators",
    Request: type = struct {
        graph_arn: []const u8,
        investigation_id: []const u8,
        indicator_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .investigation_id = "InvestigationId",
                .indicator_type = "IndicatorType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_indicators) } {
            return .{ .service_metadata = service_metadata, .action = list_indicators };
        }
    },
    Response: type = struct {
        graph_arn: ?[]const u8 = null,
        investigation_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        indicators: ?[]struct {
            indicator_type: ?[]const u8 = null,
            indicator_detail: ?struct {
                tt_ps_observed_detail: ?struct {
                    tactic: ?[]const u8 = null,
                    technique: ?[]const u8 = null,
                    procedure: ?[]const u8 = null,
                    ip_address: ?[]const u8 = null,
                    api_name: ?[]const u8 = null,
                    api_success_count: ?i64 = null,
                    api_failure_count: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .tactic = "Tactic",
                            .technique = "Technique",
                            .procedure = "Procedure",
                            .ip_address = "IpAddress",
                            .api_name = "APIName",
                            .api_success_count = "APISuccessCount",
                            .api_failure_count = "APIFailureCount",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                impossible_travel_detail: ?struct {
                    starting_ip_address: ?[]const u8 = null,
                    ending_ip_address: ?[]const u8 = null,
                    starting_location: ?[]const u8 = null,
                    ending_location: ?[]const u8 = null,
                    hourly_time_delta: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .starting_ip_address = "StartingIpAddress",
                            .ending_ip_address = "EndingIpAddress",
                            .starting_location = "StartingLocation",
                            .ending_location = "EndingLocation",
                            .hourly_time_delta = "HourlyTimeDelta",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                flagged_ip_address_detail: ?struct {
                    ip_address: ?[]const u8 = null,
                    reason: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .ip_address = "IpAddress",
                            .reason = "Reason",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                new_geolocation_detail: ?struct {
                    location: ?[]const u8 = null,
                    ip_address: ?[]const u8 = null,
                    is_new_for_entire_account: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .location = "Location",
                            .ip_address = "IpAddress",
                            .is_new_for_entire_account = "IsNewForEntireAccount",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                new_aso_detail: ?struct {
                    aso: ?[]const u8 = null,
                    is_new_for_entire_account: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .aso = "Aso",
                            .is_new_for_entire_account = "IsNewForEntireAccount",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                new_user_agent_detail: ?struct {
                    user_agent: ?[]const u8 = null,
                    is_new_for_entire_account: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .user_agent = "UserAgent",
                            .is_new_for_entire_account = "IsNewForEntireAccount",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                related_finding_detail: ?struct {
                    arn: ?[]const u8 = null,
                    type: ?[]const u8 = null,
                    ip_address: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .arn = "Arn",
                            .type = "Type",
                            .ip_address = "IpAddress",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                related_finding_group_detail: ?struct {
                    id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .id = "Id",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .tt_ps_observed_detail = "TTPsObservedDetail",
                        .impossible_travel_detail = "ImpossibleTravelDetail",
                        .flagged_ip_address_detail = "FlaggedIpAddressDetail",
                        .new_geolocation_detail = "NewGeolocationDetail",
                        .new_aso_detail = "NewAsoDetail",
                        .new_user_agent_detail = "NewUserAgentDetail",
                        .related_finding_detail = "RelatedFindingDetail",
                        .related_finding_group_detail = "RelatedFindingGroupDetail",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .indicator_type = "IndicatorType",
                    .indicator_detail = "IndicatorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .investigation_id = "InvestigationId",
                .next_token = "NextToken",
                .indicators = "Indicators",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_investigations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/investigations/listInvestigations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInvestigations",
    Request: type = struct {
        graph_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter_criteria: ?struct {
            severity: ?StringFilter = null,
            status: ?StringFilter = null,
            state: ?StringFilter = null,
            entity_arn: ?StringFilter = null,
            created_time: ?struct {
                start_inclusive: i64,
                end_inclusive: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_inclusive = "StartInclusive",
                        .end_inclusive = "EndInclusive",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .severity = "Severity",
                    .status = "Status",
                    .state = "State",
                    .entity_arn = "EntityArn",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort_criteria: ?struct {
            field: ?[]const u8 = null,
            sort_order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field = "Field",
                    .sort_order = "SortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filter_criteria = "FilterCriteria",
                .sort_criteria = "SortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_investigations) } {
            return .{ .service_metadata = service_metadata, .action = list_investigations };
        }
    },
    Response: type = struct {
        investigation_details: ?[]struct {
            investigation_id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            state: ?[]const u8 = null,
            created_time: ?i64 = null,
            entity_arn: ?[]const u8 = null,
            entity_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .investigation_id = "InvestigationId",
                    .severity = "Severity",
                    .status = "Status",
                    .state = "State",
                    .created_time = "CreatedTime",
                    .entity_arn = "EntityArn",
                    .entity_type = "EntityType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .investigation_details = "InvestigationDetails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInvitations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_invitations) } {
            return .{ .service_metadata = service_metadata, .action = list_invitations };
        }
    },
    Response: type = struct {
        invitations: ?[]MemberDetail = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations = "Invitations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/members/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMembers",
    Request: type = struct {
        graph_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_members) } {
            return .{ .service_metadata = service_metadata, .action = list_members };
        }
    },
    Response: type = struct {
        member_details: ?[]MemberDetail = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_details = "MemberDetails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_organization_admin_accounts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/orgs/adminAccountslist",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationAdminAccounts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_admin_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_admin_accounts };
        }
    },
    Response: type = struct {
        administrators: ?[]struct {
            account_id: ?[]const u8 = null,
            graph_arn: ?[]const u8 = null,
            delegation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .graph_arn = "GraphArn",
                    .delegation_time = "DelegationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .administrators = "Administrators",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const reject_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitation/removal",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectInvitation",
    Request: type = struct {
        graph_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_invitation) } {
            return .{ .service_metadata = service_metadata, .action = reject_invitation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_investigation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/investigations/startInvestigation",
        .success_code = 200,
    };

    action_name: []const u8 = "StartInvestigation",
    Request: type = struct {
        graph_arn: []const u8,
        entity_arn: []const u8,
        scope_start_time: i64,
        scope_end_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .entity_arn = "EntityArn",
                .scope_start_time = "ScopeStartTime",
                .scope_end_time = "ScopeEndTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_investigation) } {
            return .{ .service_metadata = service_metadata, .action = start_investigation };
        }
    },
    Response: type = struct {
        investigation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .investigation_id = "InvestigationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const start_monitoring_member: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/member/monitoringstate",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMonitoringMember",
    Request: type = struct {
        graph_arn: []const u8,
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_monitoring_member) } {
            return .{ .service_metadata = service_metadata, .action = start_monitoring_member };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_datasource_packages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/graph/datasources/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDatasourcePackages",
    Request: type = struct {
        graph_arn: []const u8,
        datasource_packages: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .datasource_packages = "DatasourcePackages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_datasource_packages) } {
            return .{ .service_metadata = service_metadata, .action = update_datasource_packages };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const update_investigation_state: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/investigations/updateInvestigationState",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInvestigationState",
    Request: type = struct {
        graph_arn: []const u8,
        investigation_id: []const u8,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .investigation_id = "InvestigationId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_investigation_state) } {
            return .{ .service_metadata = service_metadata, .action = update_investigation_state };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const update_organization_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/orgs/updateOrganizationConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOrganizationConfiguration",
    Request: type = struct {
        graph_arn: []const u8,
        auto_enable: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_arn = "GraphArn",
                .auto_enable = "AutoEnable",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_organization_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        TooManyRequests,
        Validation,
    },
} = .{};

pub const MemberDetail = struct {
    account_id: ?[]const u8 = null,
    email_address: ?[]const u8 = null,
    graph_arn: ?[]const u8 = null,
    master_id: ?[]const u8 = null,
    administrator_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    disabled_reason: ?[]const u8 = null,
    invited_time: ?i64 = null,
    updated_time: ?i64 = null,
    volume_usage_in_bytes: ?i64 = null,
    volume_usage_updated_time: ?i64 = null,
    percent_of_graph_utilization: ?f64 = null,
    percent_of_graph_utilization_updated_time: ?i64 = null,
    invitation_type: ?[]const u8 = null,
    volume_usage_by_datasource_package: ?[]struct {
        key: ?[]const u8 = null,
        value: ?DatasourcePackageUsageInfo = null,
    } = null,
    datasource_package_ingest_states: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .email_address = "EmailAddress",
            .graph_arn = "GraphArn",
            .master_id = "MasterId",
            .administrator_id = "AdministratorId",
            .status = "Status",
            .disabled_reason = "DisabledReason",
            .invited_time = "InvitedTime",
            .updated_time = "UpdatedTime",
            .volume_usage_in_bytes = "VolumeUsageInBytes",
            .volume_usage_updated_time = "VolumeUsageUpdatedTime",
            .percent_of_graph_utilization = "PercentOfGraphUtilization",
            .percent_of_graph_utilization_updated_time = "PercentOfGraphUtilizationUpdatedTime",
            .invitation_type = "InvitationType",
            .volume_usage_by_datasource_package = "VolumeUsageByDatasourcePackage",
            .datasource_package_ingest_states = "DatasourcePackageIngestStates",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "volume_usage_by_datasource_package", field_name))
            return try serializeMap(self.volume_usage_by_datasource_package, self.fieldNameFor("volume_usage_by_datasource_package"), options, out_stream);
        if (std.mem.eql(u8, "datasource_package_ingest_states", field_name))
            return try serializeMap(self.datasource_package_ingest_states, self.fieldNameFor("datasource_package_ingest_states"), options, out_stream);
        return false;
    }
};

pub const DatasourcePackageUsageInfo = struct {
    volume_usage_in_bytes: ?i64 = null,
    volume_usage_update_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_usage_in_bytes = "VolumeUsageInBytes",
            .volume_usage_update_time = "VolumeUsageUpdateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const StringFilter = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestampForCollection = struct {
    timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp = "Timestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const UnprocessedAccount = struct {
    account_id: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};

pub const MembershipDatasources = struct {
    account_id: ?[]const u8 = null,
    graph_arn: ?[]const u8 = null,
    datasource_package_ingest_history: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TimestampForCollection = null,
        } = null,


    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "value", field_name))
            return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
        return false;
    }
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .graph_arn = "GraphArn",
            .datasource_package_ingest_history = "DatasourcePackageIngestHistory",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "datasource_package_ingest_history", field_name))
            return try serializeMap(self.datasource_package_ingest_history, self.fieldNameFor("datasource_package_ingest_history"), options, out_stream);
        return false;
    }
};
