const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-06-23";
pub const sdk_id: []const u8 = "Device Farm";
pub const arn_namespace: ?[]const u8 = "devicefarm";
pub const endpoint_prefix: []const u8 = "devicefarm";
pub const sigv4_name: []const u8 = "devicefarm";
pub const name: []const u8 = "DeviceFarm_20150623";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-06-23",
    sdk_id: []const u8 = "Device Farm",
    arn_namespace: ?[]const u8 = "devicefarm",
    endpoint_prefix: []const u8 = "devicefarm",
    sigv4_name: []const u8 = "devicefarm",
    name: []const u8 = "DeviceFarm_20150623",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_device_pool: struct {
    action_name: []const u8 = "CreateDevicePool",
    Request: type = struct {
        project_arn: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        rules: []Rule,
        max_devices: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .name = "name",
                .description = "description",
                .rules = "rules",
                .max_devices = "maxDevices",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_device_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_device_pool };
        }
    },
    Response: type = struct {
        device_pool: ?DevicePool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_pool = "devicePool",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const create_instance_profile: struct {
    action_name: []const u8 = "CreateInstanceProfile",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        package_cleanup: ?bool = null,
        exclude_app_packages_from_cleanup: ?[][]const u8 = null,
        reboot_after_use: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .package_cleanup = "packageCleanup",
                .exclude_app_packages_from_cleanup = "excludeAppPackagesFromCleanup",
                .reboot_after_use = "rebootAfterUse",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_instance_profile };
        }
    },
    Response: type = struct {
        instance_profile: ?InstanceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profile = "instanceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const create_network_profile: struct {
    action_name: []const u8 = "CreateNetworkProfile",
    Request: type = struct {
        project_arn: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        uplink_bandwidth_bits: ?i64 = null,
        downlink_bandwidth_bits: ?i64 = null,
        uplink_delay_ms: ?i64 = null,
        downlink_delay_ms: ?i64 = null,
        uplink_jitter_ms: ?i64 = null,
        downlink_jitter_ms: ?i64 = null,
        uplink_loss_percent: ?i64 = null,
        downlink_loss_percent: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .name = "name",
                .description = "description",
                .type = "type",
                .uplink_bandwidth_bits = "uplinkBandwidthBits",
                .downlink_bandwidth_bits = "downlinkBandwidthBits",
                .uplink_delay_ms = "uplinkDelayMs",
                .downlink_delay_ms = "downlinkDelayMs",
                .uplink_jitter_ms = "uplinkJitterMs",
                .downlink_jitter_ms = "downlinkJitterMs",
                .uplink_loss_percent = "uplinkLossPercent",
                .downlink_loss_percent = "downlinkLossPercent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_network_profile };
        }
    },
    Response: type = struct {
        network_profile: ?NetworkProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_profile = "networkProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const create_project: struct {
    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        name: []const u8,
        default_job_timeout_minutes: ?i64 = null,
        vpc_config: ?VpcConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .default_job_timeout_minutes = "defaultJobTimeoutMinutes",
                .vpc_config = "vpcConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        project: ?Project = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project = "project",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
        TagOperation,
    },
} = .{};
pub const create_remote_access_session: struct {
    action_name: []const u8 = "CreateRemoteAccessSession",
    Request: type = struct {
        project_arn: []const u8,
        device_arn: []const u8,
        instance_arn: ?[]const u8 = null,
        ssh_public_key: ?[]const u8 = null,
        remote_debug_enabled: ?bool = null,
        remote_record_enabled: ?bool = null,
        remote_record_app_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        client_id: ?[]const u8 = null,
        configuration: ?struct {
            billing_method: ?[]const u8 = null,
            vpce_configuration_arns: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .billing_method = "billingMethod",
                    .vpce_configuration_arns = "vpceConfigurationArns",
                };
                return @field(mappings, field_name);
            }
        } = null,
        interaction_mode: ?[]const u8 = null,
        skip_app_resign: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .device_arn = "deviceArn",
                .instance_arn = "instanceArn",
                .ssh_public_key = "sshPublicKey",
                .remote_debug_enabled = "remoteDebugEnabled",
                .remote_record_enabled = "remoteRecordEnabled",
                .remote_record_app_arn = "remoteRecordAppArn",
                .name = "name",
                .client_id = "clientId",
                .configuration = "configuration",
                .interaction_mode = "interactionMode",
                .skip_app_resign = "skipAppResign",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_remote_access_session) } {
            return .{ .service_metadata = service_metadata, .action = create_remote_access_session };
        }
    },
    Response: type = struct {
        remote_access_session: ?RemoteAccessSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remote_access_session = "remoteAccessSession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const create_test_grid_project: struct {
    action_name: []const u8 = "CreateTestGridProject",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        vpc_config: ?TestGridVpcConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .vpc_config = "vpcConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_test_grid_project) } {
            return .{ .service_metadata = service_metadata, .action = create_test_grid_project };
        }
    },
    Response: type = struct {
        test_grid_project: ?TestGridProject = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_grid_project = "testGridProject",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
        LimitExceeded,
    },
} = .{};
pub const create_test_grid_url: struct {
    action_name: []const u8 = "CreateTestGridUrl",
    Request: type = struct {
        project_arn: []const u8,
        expires_in_seconds: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .expires_in_seconds = "expiresInSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_test_grid_url) } {
            return .{ .service_metadata = service_metadata, .action = create_test_grid_url };
        }
    },
    Response: type = struct {
        url: ?[]const u8 = null,
        expires: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .url = "url",
                .expires = "expires",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
        NotFound,
    },
} = .{};
pub const create_upload: struct {
    action_name: []const u8 = "CreateUpload",
    Request: type = struct {
        project_arn: []const u8,
        name: []const u8,
        type: []const u8,
        content_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .name = "name",
                .type = "type",
                .content_type = "contentType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_upload) } {
            return .{ .service_metadata = service_metadata, .action = create_upload };
        }
    },
    Response: type = struct {
        upload: ?Upload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload = "upload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const create_vpce_configuration: struct {
    action_name: []const u8 = "CreateVPCEConfiguration",
    Request: type = struct {
        vpce_configuration_name: []const u8,
        vpce_service_name: []const u8,
        service_dns_name: []const u8,
        vpce_configuration_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpce_configuration_name = "vpceConfigurationName",
                .vpce_service_name = "vpceServiceName",
                .service_dns_name = "serviceDnsName",
                .vpce_configuration_description = "vpceConfigurationDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpce_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_vpce_configuration };
        }
    },
    Response: type = struct {
        vpce_configuration: ?VPCEConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpce_configuration = "vpceConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        ServiceAccount,
    },
} = .{};
pub const delete_device_pool: struct {
    action_name: []const u8 = "DeleteDevicePool",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_device_pool };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const delete_instance_profile: struct {
    action_name: []const u8 = "DeleteInstanceProfile",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const delete_network_profile: struct {
    action_name: []const u8 = "DeleteNetworkProfile",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const delete_project: struct {
    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const delete_remote_access_session: struct {
    action_name: []const u8 = "DeleteRemoteAccessSession",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_remote_access_session) } {
            return .{ .service_metadata = service_metadata, .action = delete_remote_access_session };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const delete_run: struct {
    action_name: []const u8 = "DeleteRun",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_run) } {
            return .{ .service_metadata = service_metadata, .action = delete_run };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const delete_test_grid_project: struct {
    action_name: []const u8 = "DeleteTestGridProject",
    Request: type = struct {
        project_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_test_grid_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_test_grid_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        CannotDelete,
        InternalService,
        NotFound,
    },
} = .{};
pub const delete_upload: struct {
    action_name: []const u8 = "DeleteUpload",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_upload) } {
            return .{ .service_metadata = service_metadata, .action = delete_upload };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const delete_vpce_configuration: struct {
    action_name: []const u8 = "DeleteVPCEConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpce_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpce_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InvalidOperation,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_account_settings: struct {
    action_name: []const u8 = "GetAccountSettings",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_account_settings };
        }
    },
    Response: type = struct {
        account_settings: ?struct {
            aws_account_number: ?[]const u8 = null,
            unmetered_devices: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            unmetered_remote_access_devices: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            max_job_timeout_minutes: ?i64 = null,
            trial_minutes: ?struct {
                total: ?f64 = null,
                remaining: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total = "total",
                        .remaining = "remaining",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            max_slots: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            default_job_timeout_minutes: ?i64 = null,
            skip_app_resign: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_account_number = "awsAccountNumber",
                    .unmetered_devices = "unmeteredDevices",
                    .unmetered_remote_access_devices = "unmeteredRemoteAccessDevices",
                    .max_job_timeout_minutes = "maxJobTimeoutMinutes",
                    .trial_minutes = "trialMinutes",
                    .max_slots = "maxSlots",
                    .default_job_timeout_minutes = "defaultJobTimeoutMinutes",
                    .skip_app_resign = "skipAppResign",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "unmetered_devices", field_name))
                    return try serializeMap(self.unmetered_devices, self.fieldNameFor("unmetered_devices"), options, out_stream);
                if (std.mem.eql(u8, "unmetered_remote_access_devices", field_name))
                    return try serializeMap(self.unmetered_remote_access_devices, self.fieldNameFor("unmetered_remote_access_devices"), options, out_stream);
                if (std.mem.eql(u8, "max_slots", field_name))
                    return try serializeMap(self.max_slots, self.fieldNameFor("max_slots"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_settings = "accountSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_device: struct {
    action_name: []const u8 = "GetDevice",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device) } {
            return .{ .service_metadata = service_metadata, .action = get_device };
        }
    },
    Response: type = struct {
        device: ?Device = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_device_instance: struct {
    action_name: []const u8 = "GetDeviceInstance",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_instance) } {
            return .{ .service_metadata = service_metadata, .action = get_device_instance };
        }
    },
    Response: type = struct {
        device_instance: ?DeviceInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_instance = "deviceInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_device_pool: struct {
    action_name: []const u8 = "GetDevicePool",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_pool) } {
            return .{ .service_metadata = service_metadata, .action = get_device_pool };
        }
    },
    Response: type = struct {
        device_pool: ?DevicePool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_pool = "devicePool",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_device_pool_compatibility: struct {
    action_name: []const u8 = "GetDevicePoolCompatibility",
    Request: type = struct {
        device_pool_arn: []const u8,
        app_arn: ?[]const u8 = null,
        test_type: ?[]const u8 = null,
        @"test": ?ScheduleRunTest = null,
        configuration: ?ScheduleRunConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_pool_arn = "devicePoolArn",
                .app_arn = "appArn",
                .test_type = "testType",
                .@"test" = "test",
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_pool_compatibility) } {
            return .{ .service_metadata = service_metadata, .action = get_device_pool_compatibility };
        }
    },
    Response: type = struct {
        compatible_devices: ?[]DevicePoolCompatibilityResult = null,
        incompatible_devices: ?[]DevicePoolCompatibilityResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compatible_devices = "compatibleDevices",
                .incompatible_devices = "incompatibleDevices",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_instance_profile: struct {
    action_name: []const u8 = "GetInstanceProfile",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_instance_profile };
        }
    },
    Response: type = struct {
        instance_profile: ?InstanceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profile = "instanceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_job: struct {
    action_name: []const u8 = "GetJob",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job) } {
            return .{ .service_metadata = service_metadata, .action = get_job };
        }
    },
    Response: type = struct {
        job: ?Job = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_network_profile: struct {
    action_name: []const u8 = "GetNetworkProfile",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_network_profile };
        }
    },
    Response: type = struct {
        network_profile: ?NetworkProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_profile = "networkProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_offering_status: struct {
    action_name: []const u8 = "GetOfferingStatus",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_offering_status) } {
            return .{ .service_metadata = service_metadata, .action = get_offering_status };
        }
    },
    Response: type = struct {
        current: ?[]struct {
            key: ?[]const u8 = null,
            value: ?OfferingStatus = null,
        } = null,
        next_period: ?[]struct {
            key: ?[]const u8 = null,
            value: ?OfferingStatus = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .current = "current",
                .next_period = "nextPeriod",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "current", field_name))
                return try serializeMap(self.current, self.fieldNameFor("current"), options, out_stream);
            if (std.mem.eql(u8, "next_period", field_name))
                return try serializeMap(self.next_period, self.fieldNameFor("next_period"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotEligible,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_project: struct {
    action_name: []const u8 = "GetProject",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_project) } {
            return .{ .service_metadata = service_metadata, .action = get_project };
        }
    },
    Response: type = struct {
        project: ?Project = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project = "project",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_remote_access_session: struct {
    action_name: []const u8 = "GetRemoteAccessSession",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_remote_access_session) } {
            return .{ .service_metadata = service_metadata, .action = get_remote_access_session };
        }
    },
    Response: type = struct {
        remote_access_session: ?RemoteAccessSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remote_access_session = "remoteAccessSession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_run: struct {
    action_name: []const u8 = "GetRun",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_run) } {
            return .{ .service_metadata = service_metadata, .action = get_run };
        }
    },
    Response: type = struct {
        run: ?Run = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run = "run",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_suite: struct {
    action_name: []const u8 = "GetSuite",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_suite) } {
            return .{ .service_metadata = service_metadata, .action = get_suite };
        }
    },
    Response: type = struct {
        suite: ?Suite = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite = "suite",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_test: struct {
    action_name: []const u8 = "GetTest",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_test) } {
            return .{ .service_metadata = service_metadata, .action = get_test };
        }
    },
    Response: type = struct {
        @"test": ?Test = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"test" = "test",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_test_grid_project: struct {
    action_name: []const u8 = "GetTestGridProject",
    Request: type = struct {
        project_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_test_grid_project) } {
            return .{ .service_metadata = service_metadata, .action = get_test_grid_project };
        }
    },
    Response: type = struct {
        test_grid_project: ?TestGridProject = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_grid_project = "testGridProject",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
        NotFound,
    },
} = .{};
pub const get_test_grid_session: struct {
    action_name: []const u8 = "GetTestGridSession",
    Request: type = struct {
        project_arn: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        session_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .session_id = "sessionId",
                .session_arn = "sessionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_test_grid_session) } {
            return .{ .service_metadata = service_metadata, .action = get_test_grid_session };
        }
    },
    Response: type = struct {
        test_grid_session: ?TestGridSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_grid_session = "testGridSession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
        NotFound,
    },
} = .{};
pub const get_upload: struct {
    action_name: []const u8 = "GetUpload",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_upload) } {
            return .{ .service_metadata = service_metadata, .action = get_upload };
        }
    },
    Response: type = struct {
        upload: ?Upload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload = "upload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const get_vpce_configuration: struct {
    action_name: []const u8 = "GetVPCEConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpce_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_vpce_configuration };
        }
    },
    Response: type = struct {
        vpce_configuration: ?VPCEConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpce_configuration = "vpceConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const install_to_remote_access_session: struct {
    action_name: []const u8 = "InstallToRemoteAccessSession",
    Request: type = struct {
        remote_access_session_arn: []const u8,
        app_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remote_access_session_arn = "remoteAccessSessionArn",
                .app_arn = "appArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(install_to_remote_access_session) } {
            return .{ .service_metadata = service_metadata, .action = install_to_remote_access_session };
        }
    },
    Response: type = struct {
        app_upload: ?Upload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_upload = "appUpload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_artifacts: struct {
    action_name: []const u8 = "ListArtifacts",
    Request: type = struct {
        arn: []const u8,
        type: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .type = "type",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_artifacts) } {
            return .{ .service_metadata = service_metadata, .action = list_artifacts };
        }
    },
    Response: type = struct {
        artifacts: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            extension: ?[]const u8 = null,
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .type = "type",
                    .extension = "extension",
                    .url = "url",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifacts = "artifacts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_device_instances: struct {
    action_name: []const u8 = "ListDeviceInstances",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_device_instances };
        }
    },
    Response: type = struct {
        device_instances: ?[]DeviceInstance = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_instances = "deviceInstances",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_device_pools: struct {
    action_name: []const u8 = "ListDevicePools",
    Request: type = struct {
        arn: []const u8,
        type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .type = "type",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_pools) } {
            return .{ .service_metadata = service_metadata, .action = list_device_pools };
        }
    },
    Response: type = struct {
        device_pools: ?[]DevicePool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_pools = "devicePools",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_devices: struct {
    action_name: []const u8 = "ListDevices",
    Request: type = struct {
        arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]DeviceFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_devices };
        }
    },
    Response: type = struct {
        devices: ?[]Device = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "devices",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_instance_profiles: struct {
    action_name: []const u8 = "ListInstanceProfiles",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instance_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_instance_profiles };
        }
    },
    Response: type = struct {
        instance_profiles: ?[]InstanceProfile = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profiles = "instanceProfiles",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_jobs: struct {
    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]Job = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_network_profiles: struct {
    action_name: []const u8 = "ListNetworkProfiles",
    Request: type = struct {
        arn: []const u8,
        type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .type = "type",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_network_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_network_profiles };
        }
    },
    Response: type = struct {
        network_profiles: ?[]NetworkProfile = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_profiles = "networkProfiles",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_offering_promotions: struct {
    action_name: []const u8 = "ListOfferingPromotions",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_offering_promotions) } {
            return .{ .service_metadata = service_metadata, .action = list_offering_promotions };
        }
    },
    Response: type = struct {
        offering_promotions: ?[]struct {
            id: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_promotions = "offeringPromotions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotEligible,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_offerings: struct {
    action_name: []const u8 = "ListOfferings",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_offerings) } {
            return .{ .service_metadata = service_metadata, .action = list_offerings };
        }
    },
    Response: type = struct {
        offerings: ?[]Offering = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offerings = "offerings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotEligible,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_offering_transactions: struct {
    action_name: []const u8 = "ListOfferingTransactions",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_offering_transactions) } {
            return .{ .service_metadata = service_metadata, .action = list_offering_transactions };
        }
    },
    Response: type = struct {
        offering_transactions: ?[]OfferingTransaction = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_transactions = "offeringTransactions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotEligible,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_projects: struct {
    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        projects: ?[]Project = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .projects = "projects",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_remote_access_sessions: struct {
    action_name: []const u8 = "ListRemoteAccessSessions",
    Request: type = struct {
        arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_remote_access_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_remote_access_sessions };
        }
    },
    Response: type = struct {
        remote_access_sessions: ?[]RemoteAccessSession = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remote_access_sessions = "remoteAccessSessions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_runs: struct {
    action_name: []const u8 = "ListRuns",
    Request: type = struct {
        arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_runs };
        }
    },
    Response: type = struct {
        runs: ?[]Run = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runs = "runs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_samples: struct {
    action_name: []const u8 = "ListSamples",
    Request: type = struct {
        arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_samples) } {
            return .{ .service_metadata = service_metadata, .action = list_samples };
        }
    },
    Response: type = struct {
        samples: ?[]struct {
            arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .type = "type",
                    .url = "url",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .samples = "samples",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_suites: struct {
    action_name: []const u8 = "ListSuites",
    Request: type = struct {
        arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_suites) } {
            return .{ .service_metadata = service_metadata, .action = list_suites };
        }
    },
    Response: type = struct {
        suites: ?[]Suite = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suites = "suites",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        NotFound,
        TagOperation,
    },
} = .{};
pub const list_test_grid_projects: struct {
    action_name: []const u8 = "ListTestGridProjects",
    Request: type = struct {
        max_result: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_result = "maxResult",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_grid_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_test_grid_projects };
        }
    },
    Response: type = struct {
        test_grid_projects: ?[]TestGridProject = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_grid_projects = "testGridProjects",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
    },
} = .{};
pub const list_test_grid_session_actions: struct {
    action_name: []const u8 = "ListTestGridSessionActions",
    Request: type = struct {
        session_arn: []const u8,
        max_result: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_arn = "sessionArn",
                .max_result = "maxResult",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_grid_session_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_test_grid_session_actions };
        }
    },
    Response: type = struct {
        actions: ?[]struct {
            action: ?[]const u8 = null,
            started: ?i64 = null,
            duration: ?i64 = null,
            status_code: ?[]const u8 = null,
            request_method: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "action",
                    .started = "started",
                    .duration = "duration",
                    .status_code = "statusCode",
                    .request_method = "requestMethod",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .actions = "actions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
        NotFound,
    },
} = .{};
pub const list_test_grid_session_artifacts: struct {
    action_name: []const u8 = "ListTestGridSessionArtifacts",
    Request: type = struct {
        session_arn: []const u8,
        type: ?[]const u8 = null,
        max_result: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_arn = "sessionArn",
                .type = "type",
                .max_result = "maxResult",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_grid_session_artifacts) } {
            return .{ .service_metadata = service_metadata, .action = list_test_grid_session_artifacts };
        }
    },
    Response: type = struct {
        artifacts: ?[]struct {
            filename: ?[]const u8 = null,
            type: ?[]const u8 = null,
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .filename = "filename",
                    .type = "type",
                    .url = "url",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifacts = "artifacts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
        NotFound,
    },
} = .{};
pub const list_test_grid_sessions: struct {
    action_name: []const u8 = "ListTestGridSessions",
    Request: type = struct {
        project_arn: []const u8,
        status: ?[]const u8 = null,
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        end_time_after: ?i64 = null,
        end_time_before: ?i64 = null,
        max_result: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .status = "status",
                .creation_time_after = "creationTimeAfter",
                .creation_time_before = "creationTimeBefore",
                .end_time_after = "endTimeAfter",
                .end_time_before = "endTimeBefore",
                .max_result = "maxResult",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_grid_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_test_grid_sessions };
        }
    },
    Response: type = struct {
        test_grid_sessions: ?[]TestGridSession = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_grid_sessions = "testGridSessions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
        NotFound,
    },
} = .{};
pub const list_tests: struct {
    action_name: []const u8 = "ListTests",
    Request: type = struct {
        arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tests) } {
            return .{ .service_metadata = service_metadata, .action = list_tests };
        }
    },
    Response: type = struct {
        tests: ?[]Test = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tests = "tests",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_unique_problems: struct {
    action_name: []const u8 = "ListUniqueProblems",
    Request: type = struct {
        arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_unique_problems) } {
            return .{ .service_metadata = service_metadata, .action = list_unique_problems };
        }
    },
    Response: type = struct {
        unique_problems: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                message: ?[]const u8 = null,
                problems: ?[]struct {
                    run: ?ProblemDetail = null,
                    job: ?ProblemDetail = null,
                    suite: ?ProblemDetail = null,
                    @"test": ?ProblemDetail = null,
                    device: ?Device = null,
                    result: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .run = "run",
                            .job = "job",
                            .suite = "suite",
                            .@"test" = "test",
                            .device = "device",
                            .result = "result",
                            .message = "message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .message = "message",
                        .problems = "problems",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unique_problems = "uniqueProblems",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "unique_problems", field_name))
                return try serializeMap(self.unique_problems, self.fieldNameFor("unique_problems"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_uploads: struct {
    action_name: []const u8 = "ListUploads",
    Request: type = struct {
        arn: []const u8,
        type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .type = "type",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_uploads) } {
            return .{ .service_metadata = service_metadata, .action = list_uploads };
        }
    },
    Response: type = struct {
        uploads: ?[]Upload = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uploads = "uploads",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const list_vpce_configurations: struct {
    action_name: []const u8 = "ListVPCEConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpce_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_vpce_configurations };
        }
    },
    Response: type = struct {
        vpce_configurations: ?[]VPCEConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpce_configurations = "vpceConfigurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        ServiceAccount,
    },
} = .{};
pub const purchase_offering: struct {
    action_name: []const u8 = "PurchaseOffering",
    Request: type = struct {
        offering_id: []const u8,
        quantity: i64,
        offering_promotion_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_id = "offeringId",
                .quantity = "quantity",
                .offering_promotion_id = "offeringPromotionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_offering };
        }
    },
    Response: type = struct {
        offering_transaction: ?OfferingTransaction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_transaction = "offeringTransaction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotEligible,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const renew_offering: struct {
    action_name: []const u8 = "RenewOffering",
    Request: type = struct {
        offering_id: []const u8,
        quantity: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_id = "offeringId",
                .quantity = "quantity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(renew_offering) } {
            return .{ .service_metadata = service_metadata, .action = renew_offering };
        }
    },
    Response: type = struct {
        offering_transaction: ?OfferingTransaction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_transaction = "offeringTransaction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotEligible,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const schedule_run: struct {
    action_name: []const u8 = "ScheduleRun",
    Request: type = struct {
        project_arn: []const u8,
        app_arn: ?[]const u8 = null,
        device_pool_arn: ?[]const u8 = null,
        device_selection_configuration: ?struct {
            filters: []DeviceFilter,
            max_devices: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .filters = "filters",
                    .max_devices = "maxDevices",
                };
                return @field(mappings, field_name);
            }
        } = null,
        name: ?[]const u8 = null,
        @"test": ScheduleRunTest,
        configuration: ?ScheduleRunConfiguration = null,
        execution_configuration: ?struct {
            job_timeout_minutes: ?i64 = null,
            accounts_cleanup: ?bool = null,
            app_packages_cleanup: ?bool = null,
            video_capture: ?bool = null,
            skip_app_resign: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_timeout_minutes = "jobTimeoutMinutes",
                    .accounts_cleanup = "accountsCleanup",
                    .app_packages_cleanup = "appPackagesCleanup",
                    .video_capture = "videoCapture",
                    .skip_app_resign = "skipAppResign",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .app_arn = "appArn",
                .device_pool_arn = "devicePoolArn",
                .device_selection_configuration = "deviceSelectionConfiguration",
                .name = "name",
                .@"test" = "test",
                .configuration = "configuration",
                .execution_configuration = "executionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(schedule_run) } {
            return .{ .service_metadata = service_metadata, .action = schedule_run };
        }
    },
    Response: type = struct {
        run: ?Run = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run = "run",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        Idempotency,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const stop_job: struct {
    action_name: []const u8 = "StopJob",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_job };
        }
    },
    Response: type = struct {
        job: ?Job = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const stop_remote_access_session: struct {
    action_name: []const u8 = "StopRemoteAccessSession",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_remote_access_session) } {
            return .{ .service_metadata = service_metadata, .action = stop_remote_access_session };
        }
    },
    Response: type = struct {
        remote_access_session: ?RemoteAccessSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .remote_access_session = "remoteAccessSession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const stop_run: struct {
    action_name: []const u8 = "StopRun",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_run) } {
            return .{ .service_metadata = service_metadata, .action = stop_run };
        }
    },
    Response: type = struct {
        run: ?Run = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run = "run",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        NotFound,
        TagOperation,
        TagPolicy,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        NotFound,
        TagOperation,
    },
} = .{};
pub const update_device_instance: struct {
    action_name: []const u8 = "UpdateDeviceInstance",
    Request: type = struct {
        arn: []const u8,
        profile_arn: ?[]const u8 = null,
        labels: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .profile_arn = "profileArn",
                .labels = "labels",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device_instance) } {
            return .{ .service_metadata = service_metadata, .action = update_device_instance };
        }
    },
    Response: type = struct {
        device_instance: ?DeviceInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_instance = "deviceInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const update_device_pool: struct {
    action_name: []const u8 = "UpdateDevicePool",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        max_devices: ?i64 = null,
        clear_max_devices: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .description = "description",
                .rules = "rules",
                .max_devices = "maxDevices",
                .clear_max_devices = "clearMaxDevices",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device_pool) } {
            return .{ .service_metadata = service_metadata, .action = update_device_pool };
        }
    },
    Response: type = struct {
        device_pool: ?DevicePool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_pool = "devicePool",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const update_instance_profile: struct {
    action_name: []const u8 = "UpdateInstanceProfile",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        package_cleanup: ?bool = null,
        exclude_app_packages_from_cleanup: ?[][]const u8 = null,
        reboot_after_use: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .description = "description",
                .package_cleanup = "packageCleanup",
                .exclude_app_packages_from_cleanup = "excludeAppPackagesFromCleanup",
                .reboot_after_use = "rebootAfterUse",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_instance_profile };
        }
    },
    Response: type = struct {
        instance_profile: ?InstanceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profile = "instanceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const update_network_profile: struct {
    action_name: []const u8 = "UpdateNetworkProfile",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        uplink_bandwidth_bits: ?i64 = null,
        downlink_bandwidth_bits: ?i64 = null,
        uplink_delay_ms: ?i64 = null,
        downlink_delay_ms: ?i64 = null,
        uplink_jitter_ms: ?i64 = null,
        downlink_jitter_ms: ?i64 = null,
        uplink_loss_percent: ?i64 = null,
        downlink_loss_percent: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .description = "description",
                .type = "type",
                .uplink_bandwidth_bits = "uplinkBandwidthBits",
                .downlink_bandwidth_bits = "downlinkBandwidthBits",
                .uplink_delay_ms = "uplinkDelayMs",
                .downlink_delay_ms = "downlinkDelayMs",
                .uplink_jitter_ms = "uplinkJitterMs",
                .downlink_jitter_ms = "downlinkJitterMs",
                .uplink_loss_percent = "uplinkLossPercent",
                .downlink_loss_percent = "downlinkLossPercent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_network_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_network_profile };
        }
    },
    Response: type = struct {
        network_profile: ?NetworkProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_profile = "networkProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const update_project: struct {
    action_name: []const u8 = "UpdateProject",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        default_job_timeout_minutes: ?i64 = null,
        vpc_config: ?VpcConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .default_job_timeout_minutes = "defaultJobTimeoutMinutes",
                .vpc_config = "vpcConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_project) } {
            return .{ .service_metadata = service_metadata, .action = update_project };
        }
    },
    Response: type = struct {
        project: ?Project = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project = "project",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const update_test_grid_project: struct {
    action_name: []const u8 = "UpdateTestGridProject",
    Request: type = struct {
        project_arn: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        vpc_config: ?TestGridVpcConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "projectArn",
                .name = "name",
                .description = "description",
                .vpc_config = "vpcConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_test_grid_project) } {
            return .{ .service_metadata = service_metadata, .action = update_test_grid_project };
        }
    },
    Response: type = struct {
        test_grid_project: ?TestGridProject = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_grid_project = "testGridProject",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InternalService,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const update_upload: struct {
    action_name: []const u8 = "UpdateUpload",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        edit_content: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .content_type = "contentType",
                .edit_content = "editContent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_upload) } {
            return .{ .service_metadata = service_metadata, .action = update_upload };
        }
    },
    Response: type = struct {
        upload: ?Upload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload = "upload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        LimitExceeded,
        NotFound,
        ServiceAccount,
    },
} = .{};
pub const update_vpce_configuration: struct {
    action_name: []const u8 = "UpdateVPCEConfiguration",
    Request: type = struct {
        arn: []const u8,
        vpce_configuration_name: ?[]const u8 = null,
        vpce_service_name: ?[]const u8 = null,
        service_dns_name: ?[]const u8 = null,
        vpce_configuration_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .vpce_configuration_name = "vpceConfigurationName",
                .vpce_service_name = "vpceServiceName",
                .service_dns_name = "serviceDnsName",
                .vpce_configuration_description = "vpceConfigurationDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpce_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_vpce_configuration };
        }
    },
    Response: type = struct {
        vpce_configuration: ?VPCEConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpce_configuration = "vpceConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Argument,
        InvalidOperation,
        NotFound,
        ServiceAccount,
    },
} = .{};

pub const VPCEConfiguration = struct {
    arn: ?[]const u8 = null,
    vpce_configuration_name: ?[]const u8 = null,
    vpce_service_name: ?[]const u8 = null,
    service_dns_name: ?[]const u8 = null,
    vpce_configuration_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .vpce_configuration_name = "vpceConfigurationName",
            .vpce_service_name = "vpceServiceName",
            .service_dns_name = "serviceDnsName",
            .vpce_configuration_description = "vpceConfigurationDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const Upload = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    created: ?i64 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    url: ?[]const u8 = null,
    metadata: ?[]const u8 = null,
    content_type: ?[]const u8 = null,
    message: ?[]const u8 = null,
    category: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .created = "created",
            .type = "type",
            .status = "status",
            .url = "url",
            .metadata = "metadata",
            .content_type = "contentType",
            .message = "message",
            .category = "category",
        };
        return @field(mappings, field_name);
    }
};

pub const TestGridProject = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    vpc_config: ?TestGridVpcConfig = null,
    created: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .vpc_config = "vpcConfig",
            .created = "created",
        };
        return @field(mappings, field_name);
    }
};

pub const TestGridVpcConfig = struct {
    security_group_ids: [][]const u8,
    subnet_ids: [][]const u8,
    vpc_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_ids = "securityGroupIds",
            .subnet_ids = "subnetIds",
            .vpc_id = "vpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const Project = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    default_job_timeout_minutes: ?i64 = null,
    created: ?i64 = null,
    vpc_config: ?VpcConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .default_job_timeout_minutes = "defaultJobTimeoutMinutes",
            .created = "created",
            .vpc_config = "vpcConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfig = struct {
    security_group_ids: [][]const u8,
    subnet_ids: [][]const u8,
    vpc_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_ids = "securityGroupIds",
            .subnet_ids = "subnetIds",
            .vpc_id = "vpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkProfile = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    uplink_bandwidth_bits: ?i64 = null,
    downlink_bandwidth_bits: ?i64 = null,
    uplink_delay_ms: ?i64 = null,
    downlink_delay_ms: ?i64 = null,
    uplink_jitter_ms: ?i64 = null,
    downlink_jitter_ms: ?i64 = null,
    uplink_loss_percent: ?i64 = null,
    downlink_loss_percent: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .type = "type",
            .uplink_bandwidth_bits = "uplinkBandwidthBits",
            .downlink_bandwidth_bits = "downlinkBandwidthBits",
            .uplink_delay_ms = "uplinkDelayMs",
            .downlink_delay_ms = "downlinkDelayMs",
            .uplink_jitter_ms = "uplinkJitterMs",
            .downlink_jitter_ms = "downlinkJitterMs",
            .uplink_loss_percent = "uplinkLossPercent",
            .downlink_loss_percent = "downlinkLossPercent",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceProfile = struct {
    arn: ?[]const u8 = null,
    package_cleanup: ?bool = null,
    exclude_app_packages_from_cleanup: ?[][]const u8 = null,
    reboot_after_use: ?bool = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .package_cleanup = "packageCleanup",
            .exclude_app_packages_from_cleanup = "excludeAppPackagesFromCleanup",
            .reboot_after_use = "rebootAfterUse",
            .name = "name",
            .description = "description",
        };
        return @field(mappings, field_name);
    }
};

pub const DevicePool = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    rules: ?[]Rule = null,
    max_devices: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .type = "type",
            .rules = "rules",
            .max_devices = "maxDevices",
        };
        return @field(mappings, field_name);
    }
};

pub const Rule = struct {
    attribute: ?[]const u8 = null,
    operator: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute = "attribute",
            .operator = "operator",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceInstance = struct {
    arn: ?[]const u8 = null,
    device_arn: ?[]const u8 = null,
    labels: ?[][]const u8 = null,
    status: ?[]const u8 = null,
    udid: ?[]const u8 = null,
    instance_profile: ?InstanceProfile = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .device_arn = "deviceArn",
            .labels = "labels",
            .status = "status",
            .udid = "udid",
            .instance_profile = "instanceProfile",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Run = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    created: ?i64 = null,
    status: ?[]const u8 = null,
    result: ?[]const u8 = null,
    started: ?i64 = null,
    stopped: ?i64 = null,
    counters: ?Counters = null,
    message: ?[]const u8 = null,
    total_jobs: ?i64 = null,
    completed_jobs: ?i64 = null,
    billing_method: ?[]const u8 = null,
    device_minutes: ?DeviceMinutes = null,
    network_profile: ?NetworkProfile = null,
    parsing_result_url: ?[]const u8 = null,
    result_code: ?[]const u8 = null,
    seed: ?i64 = null,
    app_upload: ?[]const u8 = null,
    event_count: ?i64 = null,
    job_timeout_minutes: ?i64 = null,
    device_pool_arn: ?[]const u8 = null,
    locale: ?[]const u8 = null,
    radios: ?Radios = null,
    location: ?Location = null,
    customer_artifact_paths: ?CustomerArtifactPaths = null,
    web_url: ?[]const u8 = null,
    skip_app_resign: ?bool = null,
    test_spec_arn: ?[]const u8 = null,
    device_selection_result: ?DeviceSelectionResult = null,
    vpc_config: ?VpcConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .type = "type",
            .platform = "platform",
            .created = "created",
            .status = "status",
            .result = "result",
            .started = "started",
            .stopped = "stopped",
            .counters = "counters",
            .message = "message",
            .total_jobs = "totalJobs",
            .completed_jobs = "completedJobs",
            .billing_method = "billingMethod",
            .device_minutes = "deviceMinutes",
            .network_profile = "networkProfile",
            .parsing_result_url = "parsingResultUrl",
            .result_code = "resultCode",
            .seed = "seed",
            .app_upload = "appUpload",
            .event_count = "eventCount",
            .job_timeout_minutes = "jobTimeoutMinutes",
            .device_pool_arn = "devicePoolArn",
            .locale = "locale",
            .radios = "radios",
            .location = "location",
            .customer_artifact_paths = "customerArtifactPaths",
            .web_url = "webUrl",
            .skip_app_resign = "skipAppResign",
            .test_spec_arn = "testSpecArn",
            .device_selection_result = "deviceSelectionResult",
            .vpc_config = "vpcConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceSelectionResult = struct {
    filters: ?[]DeviceFilter = null,
    matched_devices_count: ?i64 = null,
    max_devices: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filters = "filters",
            .matched_devices_count = "matchedDevicesCount",
            .max_devices = "maxDevices",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceFilter = struct {
    attribute: []const u8,
    operator: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute = "attribute",
            .operator = "operator",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerArtifactPaths = struct {
    ios_paths: ?[][]const u8 = null,
    android_paths: ?[][]const u8 = null,
    device_host_paths: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ios_paths = "iosPaths",
            .android_paths = "androidPaths",
            .device_host_paths = "deviceHostPaths",
        };
        return @field(mappings, field_name);
    }
};

pub const Location = struct {
    latitude: f64,
    longitude: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .latitude = "latitude",
            .longitude = "longitude",
        };
        return @field(mappings, field_name);
    }
};

pub const Radios = struct {
    wifi: ?bool = null,
    bluetooth: ?bool = null,
    nfc: ?bool = null,
    gps: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .wifi = "wifi",
            .bluetooth = "bluetooth",
            .nfc = "nfc",
            .gps = "gps",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceMinutes = struct {
    total: ?f64 = null,
    metered: ?f64 = null,
    unmetered: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total = "total",
            .metered = "metered",
            .unmetered = "unmetered",
        };
        return @field(mappings, field_name);
    }
};

pub const Counters = struct {
    total: ?i64 = null,
    passed: ?i64 = null,
    failed: ?i64 = null,
    warned: ?i64 = null,
    errored: ?i64 = null,
    stopped: ?i64 = null,
    skipped: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total = "total",
            .passed = "passed",
            .failed = "failed",
            .warned = "warned",
            .errored = "errored",
            .stopped = "stopped",
            .skipped = "skipped",
        };
        return @field(mappings, field_name);
    }
};

pub const RemoteAccessSession = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    created: ?i64 = null,
    status: ?[]const u8 = null,
    result: ?[]const u8 = null,
    message: ?[]const u8 = null,
    started: ?i64 = null,
    stopped: ?i64 = null,
    device: ?Device = null,
    instance_arn: ?[]const u8 = null,
    remote_debug_enabled: ?bool = null,
    remote_record_enabled: ?bool = null,
    remote_record_app_arn: ?[]const u8 = null,
    host_address: ?[]const u8 = null,
    client_id: ?[]const u8 = null,
    billing_method: ?[]const u8 = null,
    device_minutes: ?DeviceMinutes = null,
    endpoint: ?[]const u8 = null,
    device_udid: ?[]const u8 = null,
    interaction_mode: ?[]const u8 = null,
    skip_app_resign: ?bool = null,
    vpc_config: ?VpcConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .created = "created",
            .status = "status",
            .result = "result",
            .message = "message",
            .started = "started",
            .stopped = "stopped",
            .device = "device",
            .instance_arn = "instanceArn",
            .remote_debug_enabled = "remoteDebugEnabled",
            .remote_record_enabled = "remoteRecordEnabled",
            .remote_record_app_arn = "remoteRecordAppArn",
            .host_address = "hostAddress",
            .client_id = "clientId",
            .billing_method = "billingMethod",
            .device_minutes = "deviceMinutes",
            .endpoint = "endpoint",
            .device_udid = "deviceUdid",
            .interaction_mode = "interactionMode",
            .skip_app_resign = "skipAppResign",
            .vpc_config = "vpcConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const Device = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    manufacturer: ?[]const u8 = null,
    model: ?[]const u8 = null,
    model_id: ?[]const u8 = null,
    form_factor: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    os: ?[]const u8 = null,
    cpu: ?CPU = null,
    resolution: ?Resolution = null,
    heap_size: ?i64 = null,
    memory: ?i64 = null,
    image: ?[]const u8 = null,
    carrier: ?[]const u8 = null,
    radio: ?[]const u8 = null,
    remote_access_enabled: ?bool = null,
    remote_debug_enabled: ?bool = null,
    fleet_type: ?[]const u8 = null,
    fleet_name: ?[]const u8 = null,
    instances: ?[]DeviceInstance = null,
    availability: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .manufacturer = "manufacturer",
            .model = "model",
            .model_id = "modelId",
            .form_factor = "formFactor",
            .platform = "platform",
            .os = "os",
            .cpu = "cpu",
            .resolution = "resolution",
            .heap_size = "heapSize",
            .memory = "memory",
            .image = "image",
            .carrier = "carrier",
            .radio = "radio",
            .remote_access_enabled = "remoteAccessEnabled",
            .remote_debug_enabled = "remoteDebugEnabled",
            .fleet_type = "fleetType",
            .fleet_name = "fleetName",
            .instances = "instances",
            .availability = "availability",
        };
        return @field(mappings, field_name);
    }
};

pub const Resolution = struct {
    width: ?i64 = null,
    height: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .width = "width",
            .height = "height",
        };
        return @field(mappings, field_name);
    }
};

pub const CPU = struct {
    frequency: ?[]const u8 = null,
    architecture: ?[]const u8 = null,
    clock: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .frequency = "frequency",
            .architecture = "architecture",
            .clock = "clock",
        };
        return @field(mappings, field_name);
    }
};

pub const Job = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    created: ?i64 = null,
    status: ?[]const u8 = null,
    result: ?[]const u8 = null,
    started: ?i64 = null,
    stopped: ?i64 = null,
    counters: ?Counters = null,
    message: ?[]const u8 = null,
    device: ?Device = null,
    instance_arn: ?[]const u8 = null,
    device_minutes: ?DeviceMinutes = null,
    video_endpoint: ?[]const u8 = null,
    video_capture: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .type = "type",
            .created = "created",
            .status = "status",
            .result = "result",
            .started = "started",
            .stopped = "stopped",
            .counters = "counters",
            .message = "message",
            .device = "device",
            .instance_arn = "instanceArn",
            .device_minutes = "deviceMinutes",
            .video_endpoint = "videoEndpoint",
            .video_capture = "videoCapture",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleRunConfiguration = struct {
    extra_data_package_arn: ?[]const u8 = null,
    network_profile_arn: ?[]const u8 = null,
    locale: ?[]const u8 = null,
    location: ?Location = null,
    vpce_configuration_arns: ?[][]const u8 = null,
    customer_artifact_paths: ?CustomerArtifactPaths = null,
    radios: ?Radios = null,
    auxiliary_apps: ?[][]const u8 = null,
    billing_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .extra_data_package_arn = "extraDataPackageArn",
            .network_profile_arn = "networkProfileArn",
            .locale = "locale",
            .location = "location",
            .vpce_configuration_arns = "vpceConfigurationArns",
            .customer_artifact_paths = "customerArtifactPaths",
            .radios = "radios",
            .auxiliary_apps = "auxiliaryApps",
            .billing_method = "billingMethod",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleRunTest = struct {
    type: []const u8,
    test_package_arn: ?[]const u8 = null,
    test_spec_arn: ?[]const u8 = null,
    filter: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .test_package_arn = "testPackageArn",
            .test_spec_arn = "testSpecArn",
            .filter = "filter",
            .parameters = "parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const OfferingTransaction = struct {
    offering_status: ?OfferingStatus = null,
    transaction_id: ?[]const u8 = null,
    offering_promotion_id: ?[]const u8 = null,
    created_on: ?i64 = null,
    cost: ?MonetaryAmount = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .offering_status = "offeringStatus",
            .transaction_id = "transactionId",
            .offering_promotion_id = "offeringPromotionId",
            .created_on = "createdOn",
            .cost = "cost",
        };
        return @field(mappings, field_name);
    }
};

pub const MonetaryAmount = struct {
    amount: ?f64 = null,
    currency_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amount = "amount",
            .currency_code = "currencyCode",
        };
        return @field(mappings, field_name);
    }
};

pub const OfferingStatus = struct {
    type: ?[]const u8 = null,
    offering: ?Offering = null,
    quantity: ?i64 = null,
    effective_on: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .offering = "offering",
            .quantity = "quantity",
            .effective_on = "effectiveOn",
        };
        return @field(mappings, field_name);
    }
};

pub const Offering = struct {
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    recurring_charges: ?[]RecurringCharge = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .description = "description",
            .type = "type",
            .platform = "platform",
            .recurring_charges = "recurringCharges",
        };
        return @field(mappings, field_name);
    }
};

pub const RecurringCharge = struct {
    cost: ?MonetaryAmount = null,
    frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cost = "cost",
            .frequency = "frequency",
        };
        return @field(mappings, field_name);
    }
};

pub const ProblemDetail = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const Test = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    created: ?i64 = null,
    status: ?[]const u8 = null,
    result: ?[]const u8 = null,
    started: ?i64 = null,
    stopped: ?i64 = null,
    counters: ?Counters = null,
    message: ?[]const u8 = null,
    device_minutes: ?DeviceMinutes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .type = "type",
            .created = "created",
            .status = "status",
            .result = "result",
            .started = "started",
            .stopped = "stopped",
            .counters = "counters",
            .message = "message",
            .device_minutes = "deviceMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const TestGridSession = struct {
    arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created: ?i64 = null,
    ended: ?i64 = null,
    billing_minutes: ?f64 = null,
    selenium_properties: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .status = "status",
            .created = "created",
            .ended = "ended",
            .billing_minutes = "billingMinutes",
            .selenium_properties = "seleniumProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const Suite = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    created: ?i64 = null,
    status: ?[]const u8 = null,
    result: ?[]const u8 = null,
    started: ?i64 = null,
    stopped: ?i64 = null,
    counters: ?Counters = null,
    message: ?[]const u8 = null,
    device_minutes: ?DeviceMinutes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .type = "type",
            .created = "created",
            .status = "status",
            .result = "result",
            .started = "started",
            .stopped = "stopped",
            .counters = "counters",
            .message = "message",
            .device_minutes = "deviceMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const DevicePoolCompatibilityResult = struct {
    device: ?Device = null,
    compatible: ?bool = null,
    incompatibility_messages: ?[]IncompatibilityMessage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device = "device",
            .compatible = "compatible",
            .incompatibility_messages = "incompatibilityMessages",
        };
        return @field(mappings, field_name);
    }
};

pub const IncompatibilityMessage = struct {
    message: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};
