const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-12-01";
pub const sdk_id: []const u8 = "DevOps Guru";
pub const arn_namespace: ?[]const u8 = "devops-guru";
pub const endpoint_prefix: []const u8 = "devops-guru";
pub const sigv4_name: []const u8 = "devops-guru";
pub const name: []const u8 = "CapstoneControlPlaneService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-12-01",
    sdk_id: []const u8 = "DevOps Guru",
    arn_namespace: ?[]const u8 = "devops-guru",
    endpoint_prefix: []const u8 = "devops-guru",
    sigv4_name: []const u8 = "devops-guru",
    name: []const u8 = "CapstoneControlPlaneService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_notification_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "AddNotificationChannel",
    Request: type = struct {
        config: NotificationChannelConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config = "Config",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_notification_channel) } {
            return .{ .service_metadata = service_metadata, .action = add_notification_channel };
        }
    },
    Response: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_insight: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/insights/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInsight",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_insight) } {
            return .{ .service_metadata = service_metadata, .action = delete_insight };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_health: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/health",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountHealth",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_health };
        }
    },
    Response: type = struct {
        open_reactive_insights: i64,
        open_proactive_insights: i64,
        metrics_analyzed: i64,
        resource_hours: i64,
        analyzed_resource_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .open_reactive_insights = "OpenReactiveInsights",
                .open_proactive_insights = "OpenProactiveInsights",
                .metrics_analyzed = "MetricsAnalyzed",
                .resource_hours = "ResourceHours",
                .analyzed_resource_count = "AnalyzedResourceCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_overview: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/overview",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountOverview",
    Request: type = struct {
        from_time: i64,
        to_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_time = "FromTime",
                .to_time = "ToTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_overview) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_overview };
        }
    },
    Response: type = struct {
        reactive_insights: i64,
        proactive_insights: i64,
        mean_time_to_recover_in_milliseconds: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reactive_insights = "ReactiveInsights",
                .proactive_insights = "ProactiveInsights",
                .mean_time_to_recover_in_milliseconds = "MeanTimeToRecoverInMilliseconds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_anomaly: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/anomalies/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnomaly",
    Request: type = struct {
        id: []const u8,
        account_id: ?[]const u8 = null,

        pub const http_query = .{
            .account_id = "AccountId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_anomaly) } {
            return .{ .service_metadata = service_metadata, .action = describe_anomaly };
        }
    },
    Response: type = struct {
        proactive_anomaly: ?struct {
            id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            update_time: ?i64 = null,
            anomaly_time_range: ?AnomalyTimeRange = null,
            anomaly_reported_time_range: ?AnomalyReportedTimeRange = null,
            prediction_time_range: ?PredictionTimeRange = null,
            source_details: ?AnomalySourceDetails = null,
            associated_insight_id: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            limit: ?f64 = null,
            source_metadata: ?AnomalySourceMetadata = null,
            anomaly_resources: ?[]AnomalyResource = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .severity = "Severity",
                    .status = "Status",
                    .update_time = "UpdateTime",
                    .anomaly_time_range = "AnomalyTimeRange",
                    .anomaly_reported_time_range = "AnomalyReportedTimeRange",
                    .prediction_time_range = "PredictionTimeRange",
                    .source_details = "SourceDetails",
                    .associated_insight_id = "AssociatedInsightId",
                    .resource_collection = "ResourceCollection",
                    .limit = "Limit",
                    .source_metadata = "SourceMetadata",
                    .anomaly_resources = "AnomalyResources",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        reactive_anomaly: ?struct {
            id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            anomaly_time_range: ?AnomalyTimeRange = null,
            anomaly_reported_time_range: ?AnomalyReportedTimeRange = null,
            source_details: ?AnomalySourceDetails = null,
            associated_insight_id: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            causal_anomaly_id: ?[]const u8 = null,
            anomaly_resources: ?[]AnomalyResource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .severity = "Severity",
                    .status = "Status",
                    .anomaly_time_range = "AnomalyTimeRange",
                    .anomaly_reported_time_range = "AnomalyReportedTimeRange",
                    .source_details = "SourceDetails",
                    .associated_insight_id = "AssociatedInsightId",
                    .resource_collection = "ResourceCollection",
                    .type = "Type",
                    .name = "Name",
                    .description = "Description",
                    .causal_anomaly_id = "CausalAnomalyId",
                    .anomaly_resources = "AnomalyResources",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_anomaly = "ProactiveAnomaly",
                .reactive_anomaly = "ReactiveAnomaly",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_event_sources_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/event-sources",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeEventSourcesConfig",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_sources_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_sources_config };
        }
    },
    Response: type = struct {
        event_sources: ?EventSourcesConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_sources = "EventSources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_feedback: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFeedback",
    Request: type = struct {
        insight_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_feedback) } {
            return .{ .service_metadata = service_metadata, .action = describe_feedback };
        }
    },
    Response: type = struct {
        insight_feedback: ?InsightFeedback = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_feedback = "InsightFeedback",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_insight: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInsight",
    Request: type = struct {
        id: []const u8,
        account_id: ?[]const u8 = null,

        pub const http_query = .{
            .account_id = "AccountId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_insight) } {
            return .{ .service_metadata = service_metadata, .action = describe_insight };
        }
    },
    Response: type = struct {
        proactive_insight: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            insight_time_range: ?InsightTimeRange = null,
            prediction_time_range: ?PredictionTimeRange = null,
            resource_collection: ?ResourceCollection = null,
            ssm_ops_item_id: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .severity = "Severity",
                    .status = "Status",
                    .insight_time_range = "InsightTimeRange",
                    .prediction_time_range = "PredictionTimeRange",
                    .resource_collection = "ResourceCollection",
                    .ssm_ops_item_id = "SsmOpsItemId",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        reactive_insight: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            insight_time_range: ?InsightTimeRange = null,
            resource_collection: ?ResourceCollection = null,
            ssm_ops_item_id: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .severity = "Severity",
                    .status = "Status",
                    .insight_time_range = "InsightTimeRange",
                    .resource_collection = "ResourceCollection",
                    .ssm_ops_item_id = "SsmOpsItemId",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_insight = "ProactiveInsight",
                .reactive_insight = "ReactiveInsight",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_organization_health: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/health",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationHealth",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        organizational_unit_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
                .organizational_unit_ids = "OrganizationalUnitIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_health };
        }
    },
    Response: type = struct {
        open_reactive_insights: i64,
        open_proactive_insights: i64,
        metrics_analyzed: i64,
        resource_hours: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .open_reactive_insights = "OpenReactiveInsights",
                .open_proactive_insights = "OpenProactiveInsights",
                .metrics_analyzed = "MetricsAnalyzed",
                .resource_hours = "ResourceHours",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_organization_overview: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/overview",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationOverview",
    Request: type = struct {
        from_time: i64,
        to_time: ?i64 = null,
        account_ids: ?[][]const u8 = null,
        organizational_unit_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_time = "FromTime",
                .to_time = "ToTime",
                .account_ids = "AccountIds",
                .organizational_unit_ids = "OrganizationalUnitIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_overview) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_overview };
        }
    },
    Response: type = struct {
        reactive_insights: i64,
        proactive_insights: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reactive_insights = "ReactiveInsights",
                .proactive_insights = "ProactiveInsights",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_organization_resource_collection_health: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/health/resource-collection",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationResourceCollectionHealth",
    Request: type = struct {
        organization_resource_collection_type: []const u8,
        account_ids: ?[][]const u8 = null,
        organizational_unit_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_resource_collection_type = "OrganizationResourceCollectionType",
                .account_ids = "AccountIds",
                .organizational_unit_ids = "OrganizationalUnitIds",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_resource_collection_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_resource_collection_health };
        }
    },
    Response: type = struct {
        cloud_formation: ?[]CloudFormationHealth = null,
        service: ?[]ServiceHealth = null,
        account: ?[]struct {
            account_id: ?[]const u8 = null,
            insight: ?struct {
                open_proactive_insights: ?i64 = null,
                open_reactive_insights: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .open_proactive_insights = "OpenProactiveInsights",
                        .open_reactive_insights = "OpenReactiveInsights",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .insight = "Insight",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        tags: ?[]TagHealth = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_formation = "CloudFormation",
                .service = "Service",
                .account = "Account",
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_resource_collection_health: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/health/resource-collection/{ResourceCollectionType}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeResourceCollectionHealth",
    Request: type = struct {
        resource_collection_type: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection_type = "ResourceCollectionType",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_collection_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_collection_health };
        }
    },
    Response: type = struct {
        cloud_formation: ?[]CloudFormationHealth = null,
        service: ?[]ServiceHealth = null,
        next_token: ?[]const u8 = null,
        tags: ?[]TagHealth = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_formation = "CloudFormation",
                .service = "Service",
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_service_integration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/service-integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeServiceIntegration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_service_integration) } {
            return .{ .service_metadata = service_metadata, .action = describe_service_integration };
        }
    },
    Response: type = struct {
        service_integration: ?struct {
            ops_center: ?struct {
                opt_in_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .opt_in_status = "OptInStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            logs_anomaly_detection: ?struct {
                opt_in_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .opt_in_status = "OptInStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            kms_server_side_encryption: ?struct {
                kms_key_id: ?[]const u8 = null,
                opt_in_status: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .kms_key_id = "KMSKeyId",
                        .opt_in_status = "OptInStatus",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ops_center = "OpsCenter",
                    .logs_anomaly_detection = "LogsAnomalyDetection",
                    .kms_server_side_encryption = "KMSServerSideEncryption",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_integration = "ServiceIntegration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_cost_estimation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cost-estimation",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCostEstimation",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cost_estimation) } {
            return .{ .service_metadata = service_metadata, .action = get_cost_estimation };
        }
    },
    Response: type = struct {
        resource_collection: ?CostEstimationResourceCollectionFilter = null,
        status: ?[]const u8 = null,
        costs: ?[]struct {
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            count: ?i64 = null,
            unit_cost: ?f64 = null,
            cost: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .state = "State",
                    .count = "Count",
                    .unit_cost = "UnitCost",
                    .cost = "Cost",
                };
                return @field(mappings, field_name);
            }
        } = null,
        time_range: ?struct {
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total_cost: ?f64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection = "ResourceCollection",
                .status = "Status",
                .costs = "Costs",
                .time_range = "TimeRange",
                .total_cost = "TotalCost",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_collection: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resource-collections/{ResourceCollectionType}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceCollection",
    Request: type = struct {
        resource_collection_type: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection_type = "ResourceCollectionType",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_collection) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_collection };
        }
    },
    Response: type = struct {
        resource_collection: ?struct {
            cloud_formation: ?struct {
                stack_names: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .stack_names = "StackNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]struct {
                app_boundary_key: []const u8,
                tag_values: [][]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .app_boundary_key = "AppBoundaryKey",
                        .tag_values = "TagValues",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cloud_formation = "CloudFormation",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection = "ResourceCollection",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_anomalies_for_insight: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/anomalies/insight/{InsightId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnomaliesForInsight",
    Request: type = struct {
        insight_id: []const u8,
        start_time_range: ?StartTimeRange = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_id: ?[]const u8 = null,
        filters: ?struct {
            service_collection: ?ServiceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_collection = "ServiceCollection",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .start_time_range = "StartTimeRange",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .account_id = "AccountId",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_anomalies_for_insight) } {
            return .{ .service_metadata = service_metadata, .action = list_anomalies_for_insight };
        }
    },
    Response: type = struct {
        proactive_anomalies: ?[]struct {
            id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            update_time: ?i64 = null,
            anomaly_time_range: ?AnomalyTimeRange = null,
            anomaly_reported_time_range: ?AnomalyReportedTimeRange = null,
            prediction_time_range: ?PredictionTimeRange = null,
            source_details: ?AnomalySourceDetails = null,
            associated_insight_id: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            limit: ?f64 = null,
            source_metadata: ?AnomalySourceMetadata = null,
            anomaly_resources: ?[]AnomalyResource = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .severity = "Severity",
                    .status = "Status",
                    .update_time = "UpdateTime",
                    .anomaly_time_range = "AnomalyTimeRange",
                    .anomaly_reported_time_range = "AnomalyReportedTimeRange",
                    .prediction_time_range = "PredictionTimeRange",
                    .source_details = "SourceDetails",
                    .associated_insight_id = "AssociatedInsightId",
                    .resource_collection = "ResourceCollection",
                    .limit = "Limit",
                    .source_metadata = "SourceMetadata",
                    .anomaly_resources = "AnomalyResources",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        reactive_anomalies: ?[]struct {
            id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            anomaly_time_range: ?AnomalyTimeRange = null,
            anomaly_reported_time_range: ?AnomalyReportedTimeRange = null,
            source_details: ?AnomalySourceDetails = null,
            associated_insight_id: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            causal_anomaly_id: ?[]const u8 = null,
            anomaly_resources: ?[]AnomalyResource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .severity = "Severity",
                    .status = "Status",
                    .anomaly_time_range = "AnomalyTimeRange",
                    .anomaly_reported_time_range = "AnomalyReportedTimeRange",
                    .source_details = "SourceDetails",
                    .associated_insight_id = "AssociatedInsightId",
                    .resource_collection = "ResourceCollection",
                    .type = "Type",
                    .name = "Name",
                    .description = "Description",
                    .causal_anomaly_id = "CausalAnomalyId",
                    .anomaly_resources = "AnomalyResources",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_anomalies = "ProactiveAnomalies",
                .reactive_anomalies = "ReactiveAnomalies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_anomalous_log_groups: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-log-anomalies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnomalousLogGroups",
    Request: type = struct {
        insight_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_anomalous_log_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_anomalous_log_groups };
        }
    },
    Response: type = struct {
        insight_id: []const u8,
        anomalous_log_groups: []struct {
            log_group_name: ?[]const u8 = null,
            impact_start_time: ?i64 = null,
            impact_end_time: ?i64 = null,
            number_of_log_lines_scanned: ?i64 = null,
            log_anomaly_showcases: ?[]struct {
                log_anomaly_classes: ?[]struct {
                    log_stream_name: ?[]const u8 = null,
                    log_anomaly_type: ?[]const u8 = null,
                    log_anomaly_token: ?[]const u8 = null,
                    log_event_id: ?[]const u8 = null,
                    explanation: ?[]const u8 = null,
                    number_of_log_lines_occurrences: ?i64 = null,
                    log_event_timestamp: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .log_stream_name = "LogStreamName",
                            .log_anomaly_type = "LogAnomalyType",
                            .log_anomaly_token = "LogAnomalyToken",
                            .log_event_id = "LogEventId",
                            .explanation = "Explanation",
                            .number_of_log_lines_occurrences = "NumberOfLogLinesOccurrences",
                            .log_event_timestamp = "LogEventTimestamp",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .log_anomaly_classes = "LogAnomalyClasses",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .log_group_name = "LogGroupName",
                    .impact_start_time = "ImpactStartTime",
                    .impact_end_time = "ImpactEndTime",
                    .number_of_log_lines_scanned = "NumberOfLogLinesScanned",
                    .log_anomaly_showcases = "LogAnomalyShowcases",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .anomalous_log_groups = "AnomalousLogGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/events",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEvents",
    Request: type = struct {
        filters: struct {
            insight_id: ?[]const u8 = null,
            event_time_range: ?struct {
                from_time: i64,
                to_time: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .from_time = "FromTime",
                        .to_time = "ToTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            event_class: ?[]const u8 = null,
            event_source: ?[]const u8 = null,
            data_source: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .insight_id = "InsightId",
                    .event_time_range = "EventTimeRange",
                    .event_class = "EventClass",
                    .event_source = "EventSource",
                    .data_source = "DataSource",
                    .resource_collection = "ResourceCollection",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_events) } {
            return .{ .service_metadata = service_metadata, .action = list_events };
        }
    },
    Response: type = struct {
        events: []struct {
            resource_collection: ?ResourceCollection = null,
            id: ?[]const u8 = null,
            time: ?i64 = null,
            event_source: ?[]const u8 = null,
            name: ?[]const u8 = null,
            data_source: ?[]const u8 = null,
            event_class: ?[]const u8 = null,
            resources: ?[]struct {
                type: ?[]const u8 = null,
                name: ?[]const u8 = null,
                arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .name = "Name",
                        .arn = "Arn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_collection = "ResourceCollection",
                    .id = "Id",
                    .time = "Time",
                    .event_source = "EventSource",
                    .name = "Name",
                    .data_source = "DataSource",
                    .event_class = "EventClass",
                    .resources = "Resources",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "Events",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/insights",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInsights",
    Request: type = struct {
        status_filter: ListInsightsStatusFilter,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_filter = "StatusFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_insights) } {
            return .{ .service_metadata = service_metadata, .action = list_insights };
        }
    },
    Response: type = struct {
        proactive_insights: ?[]ProactiveInsightSummary = null,
        reactive_insights: ?[]ReactiveInsightSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_insights = "ProactiveInsights",
                .reactive_insights = "ReactiveInsights",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_monitored_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/monitoredResources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMonitoredResources",
    Request: type = struct {
        filters: ?struct {
            resource_permission: []const u8,
            resource_type_filters: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_permission = "ResourcePermission",
                    .resource_type_filters = "ResourceTypeFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_monitored_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_monitored_resources };
        }
    },
    Response: type = struct {
        monitored_resource_identifiers: []struct {
            monitored_resource_name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            resource_permission: ?[]const u8 = null,
            last_updated: ?i64 = null,
            resource_collection: ?ResourceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .monitored_resource_name = "MonitoredResourceName",
                    .type = "Type",
                    .resource_permission = "ResourcePermission",
                    .last_updated = "LastUpdated",
                    .resource_collection = "ResourceCollection",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitored_resource_identifiers = "MonitoredResourceIdentifiers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_notification_channels: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNotificationChannels",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notification_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_notification_channels };
        }
    },
    Response: type = struct {
        channels: ?[]struct {
            id: ?[]const u8 = null,
            config: ?NotificationChannelConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .config = "Config",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_organization_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/insights",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationInsights",
    Request: type = struct {
        status_filter: ListInsightsStatusFilter,
        max_results: ?i64 = null,
        account_ids: ?[][]const u8 = null,
        organizational_unit_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_filter = "StatusFilter",
                .max_results = "MaxResults",
                .account_ids = "AccountIds",
                .organizational_unit_ids = "OrganizationalUnitIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_insights) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_insights };
        }
    },
    Response: type = struct {
        proactive_insights: ?[]struct {
            id: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            organizational_unit_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            insight_time_range: ?InsightTimeRange = null,
            prediction_time_range: ?PredictionTimeRange = null,
            resource_collection: ?ResourceCollection = null,
            service_collection: ?ServiceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .account_id = "AccountId",
                    .organizational_unit_id = "OrganizationalUnitId",
                    .name = "Name",
                    .severity = "Severity",
                    .status = "Status",
                    .insight_time_range = "InsightTimeRange",
                    .prediction_time_range = "PredictionTimeRange",
                    .resource_collection = "ResourceCollection",
                    .service_collection = "ServiceCollection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        reactive_insights: ?[]struct {
            id: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            organizational_unit_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            insight_time_range: ?InsightTimeRange = null,
            resource_collection: ?ResourceCollection = null,
            service_collection: ?ServiceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .account_id = "AccountId",
                    .organizational_unit_id = "OrganizationalUnitId",
                    .name = "Name",
                    .severity = "Severity",
                    .status = "Status",
                    .insight_time_range = "InsightTimeRange",
                    .resource_collection = "ResourceCollection",
                    .service_collection = "ServiceCollection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_insights = "ProactiveInsights",
                .reactive_insights = "ReactiveInsights",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendations",
    Request: type = struct {
        insight_id: []const u8,
        next_token: ?[]const u8 = null,
        locale: ?[]const u8 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .next_token = "NextToken",
                .locale = "Locale",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendations };
        }
    },
    Response: type = struct {
        recommendations: ?[]struct {
            description: ?[]const u8 = null,
            link: ?[]const u8 = null,
            name: ?[]const u8 = null,
            reason: ?[]const u8 = null,
            related_events: ?[]struct {
                name: ?[]const u8 = null,
                resources: ?[]struct {
                    name: ?[]const u8 = null,
                    type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .type = "Type",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .resources = "Resources",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            related_anomalies: ?[]struct {
                resources: ?[]struct {
                    name: ?[]const u8 = null,
                    type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .type = "Type",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                source_details: ?[]struct {
                    cloud_watch_metrics: ?[]struct {
                        metric_name: ?[]const u8 = null,
                        namespace: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .metric_name = "MetricName",
                                .namespace = "Namespace",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cloud_watch_metrics = "CloudWatchMetrics",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                anomaly_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resources = "Resources",
                        .source_details = "SourceDetails",
                        .anomaly_id = "AnomalyId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            category: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .link = "Link",
                    .name = "Name",
                    .reason = "Reason",
                    .related_events = "RelatedEvents",
                    .related_anomalies = "RelatedAnomalies",
                    .category = "Category",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendations = "Recommendations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_feedback: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFeedback",
    Request: type = struct {
        insight_feedback: ?InsightFeedback = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_feedback = "InsightFeedback",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_feedback) } {
            return .{ .service_metadata = service_metadata, .action = put_feedback };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const remove_notification_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveNotificationChannel",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_notification_channel) } {
            return .{ .service_metadata = service_metadata, .action = remove_notification_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const search_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/insights/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchInsights",
    Request: type = struct {
        start_time_range: StartTimeRange,
        filters: ?struct {
            severities: ?[][]const u8 = null,
            statuses: ?[][]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            service_collection: ?ServiceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .severities = "Severities",
                    .statuses = "Statuses",
                    .resource_collection = "ResourceCollection",
                    .service_collection = "ServiceCollection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time_range = "StartTimeRange",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_insights) } {
            return .{ .service_metadata = service_metadata, .action = search_insights };
        }
    },
    Response: type = struct {
        proactive_insights: ?[]ProactiveInsightSummary = null,
        reactive_insights: ?[]ReactiveInsightSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_insights = "ProactiveInsights",
                .reactive_insights = "ReactiveInsights",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const search_organization_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/insights/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchOrganizationInsights",
    Request: type = struct {
        account_ids: [][]const u8,
        start_time_range: StartTimeRange,
        filters: ?struct {
            severities: ?[][]const u8 = null,
            statuses: ?[][]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            service_collection: ?ServiceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .severities = "Severities",
                    .statuses = "Statuses",
                    .resource_collection = "ResourceCollection",
                    .service_collection = "ServiceCollection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
                .start_time_range = "StartTimeRange",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_organization_insights) } {
            return .{ .service_metadata = service_metadata, .action = search_organization_insights };
        }
    },
    Response: type = struct {
        proactive_insights: ?[]ProactiveInsightSummary = null,
        reactive_insights: ?[]ReactiveInsightSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_insights = "ProactiveInsights",
                .reactive_insights = "ReactiveInsights",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const start_cost_estimation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cost-estimation",
        .success_code = 200,
    };

    action_name: []const u8 = "StartCostEstimation",
    Request: type = struct {
        resource_collection: CostEstimationResourceCollectionFilter,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection = "ResourceCollection",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_cost_estimation) } {
            return .{ .service_metadata = service_metadata, .action = start_cost_estimation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_event_sources_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/event-sources",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEventSourcesConfig",
    Request: type = struct {
        event_sources: ?EventSourcesConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_sources = "EventSources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_event_sources_config) } {
            return .{ .service_metadata = service_metadata, .action = update_event_sources_config };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_collection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/resource-collections",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourceCollection",
    Request: type = struct {
        action: []const u8,
        resource_collection: struct {
            cloud_formation: ?struct {
                stack_names: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .stack_names = "StackNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]struct {
                app_boundary_key: []const u8,
                tag_values: [][]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .app_boundary_key = "AppBoundaryKey",
                        .tag_values = "TagValues",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cloud_formation = "CloudFormation",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "Action",
                .resource_collection = "ResourceCollection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_collection) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_collection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_service_integration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/service-integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateServiceIntegration",
    Request: type = struct {
        service_integration: struct {
            ops_center: ?struct {
                opt_in_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .opt_in_status = "OptInStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            logs_anomaly_detection: ?struct {
                opt_in_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .opt_in_status = "OptInStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            kms_server_side_encryption: ?struct {
                kms_key_id: ?[]const u8 = null,
                opt_in_status: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .kms_key_id = "KMSKeyId",
                        .opt_in_status = "OptInStatus",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ops_center = "OpsCenter",
                    .logs_anomaly_detection = "LogsAnomalyDetection",
                    .kms_server_side_encryption = "KMSServerSideEncryption",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_integration = "ServiceIntegration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service_integration) } {
            return .{ .service_metadata = service_metadata, .action = update_service_integration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const EventSourcesConfig = struct {
    amazon_code_guru_profiler: ?AmazonCodeGuruProfilerIntegration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_code_guru_profiler = "AmazonCodeGuruProfiler",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonCodeGuruProfilerIntegration = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const CostEstimationResourceCollectionFilter = struct {
    cloud_formation: ?CloudFormationCostEstimationResourceCollectionFilter = null,
    tags: ?[]TagCostEstimationResourceCollectionFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_formation = "CloudFormation",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const TagCostEstimationResourceCollectionFilter = struct {
    app_boundary_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_boundary_key = "AppBoundaryKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudFormationCostEstimationResourceCollectionFilter = struct {
    stack_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stack_names = "StackNames",
        };
        return @field(mappings, field_name);
    }
};

pub const ReactiveInsightSummary = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    severity: ?[]const u8 = null,
    status: ?[]const u8 = null,
    insight_time_range: ?InsightTimeRange = null,
    resource_collection: ?ResourceCollection = null,
    service_collection: ?ServiceCollection = null,
    associated_resource_arns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .severity = "Severity",
            .status = "Status",
            .insight_time_range = "InsightTimeRange",
            .resource_collection = "ResourceCollection",
            .service_collection = "ServiceCollection",
            .associated_resource_arns = "AssociatedResourceArns",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceCollection = struct {
    service_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_names = "ServiceNames",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceCollection = struct {
    cloud_formation: ?CloudFormationCollection = null,
    tags: ?[]TagCollection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_formation = "CloudFormation",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const TagCollection = struct {
    app_boundary_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_boundary_key = "AppBoundaryKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudFormationCollection = struct {
    stack_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stack_names = "StackNames",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightTimeRange = struct {
    start_time: i64,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ProactiveInsightSummary = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    severity: ?[]const u8 = null,
    status: ?[]const u8 = null,
    insight_time_range: ?InsightTimeRange = null,
    prediction_time_range: ?PredictionTimeRange = null,
    resource_collection: ?ResourceCollection = null,
    service_collection: ?ServiceCollection = null,
    associated_resource_arns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .severity = "Severity",
            .status = "Status",
            .insight_time_range = "InsightTimeRange",
            .prediction_time_range = "PredictionTimeRange",
            .resource_collection = "ResourceCollection",
            .service_collection = "ServiceCollection",
            .associated_resource_arns = "AssociatedResourceArns",
        };
        return @field(mappings, field_name);
    }
};

pub const PredictionTimeRange = struct {
    start_time: i64,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const StartTimeRange = struct {
    from_time: ?i64 = null,
    to_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_time = "FromTime",
            .to_time = "ToTime",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightFeedback = struct {
    id: ?[]const u8 = null,
    feedback: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .feedback = "Feedback",
        };
        return @field(mappings, field_name);
    }
};

pub const ListInsightsStatusFilter = struct {
    ongoing: ?ListInsightsOngoingStatusFilter = null,
    closed: ?ListInsightsClosedStatusFilter = null,
    any: ?ListInsightsAnyStatusFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ongoing = "Ongoing",
            .closed = "Closed",
            .any = "Any",
        };
        return @field(mappings, field_name);
    }
};

pub const ListInsightsAnyStatusFilter = struct {
    type: []const u8,
    start_time_range: StartTimeRange,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .start_time_range = "StartTimeRange",
        };
        return @field(mappings, field_name);
    }
};

pub const ListInsightsClosedStatusFilter = struct {
    type: []const u8,
    end_time_range: EndTimeRange,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .end_time_range = "EndTimeRange",
        };
        return @field(mappings, field_name);
    }
};

pub const EndTimeRange = struct {
    from_time: ?i64 = null,
    to_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_time = "FromTime",
            .to_time = "ToTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ListInsightsOngoingStatusFilter = struct {
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationChannelConfig = struct {
    sns: SnsChannelConfig,
    filters: ?NotificationFilterConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns = "Sns",
            .filters = "Filters",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationFilterConfig = struct {
    severities: ?[][]const u8 = null,
    message_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .severities = "Severities",
            .message_types = "MessageTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsChannelConfig = struct {
    topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalyResource = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalySourceDetails = struct {
    cloud_watch_metrics: ?[]CloudWatchMetricsDetail = null,
    performance_insights_metrics: ?[]PerformanceInsightsMetricsDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_metrics = "CloudWatchMetrics",
            .performance_insights_metrics = "PerformanceInsightsMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceInsightsMetricsDetail = struct {
    metric_display_name: ?[]const u8 = null,
    unit: ?[]const u8 = null,
    metric_query: ?PerformanceInsightsMetricQuery = null,
    reference_data: ?[]PerformanceInsightsReferenceData = null,
    stats_at_anomaly: ?[]PerformanceInsightsStat = null,
    stats_at_baseline: ?[]PerformanceInsightsStat = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_display_name = "MetricDisplayName",
            .unit = "Unit",
            .metric_query = "MetricQuery",
            .reference_data = "ReferenceData",
            .stats_at_anomaly = "StatsAtAnomaly",
            .stats_at_baseline = "StatsAtBaseline",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceInsightsStat = struct {
    type: ?[]const u8 = null,
    value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceInsightsReferenceData = struct {
    name: ?[]const u8 = null,
    comparison_values: ?PerformanceInsightsReferenceComparisonValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .comparison_values = "ComparisonValues",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceInsightsReferenceComparisonValues = struct {
    reference_scalar: ?PerformanceInsightsReferenceScalar = null,
    reference_metric: ?PerformanceInsightsReferenceMetric = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reference_scalar = "ReferenceScalar",
            .reference_metric = "ReferenceMetric",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceInsightsReferenceMetric = struct {
    metric_query: ?PerformanceInsightsMetricQuery = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_query = "MetricQuery",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceInsightsMetricQuery = struct {
    metric: ?[]const u8 = null,
    group_by: ?PerformanceInsightsMetricDimensionGroup = null,
    filter: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric = "Metric",
            .group_by = "GroupBy",
            .filter = "Filter",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "filter", field_name))
            return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
        return false;
    }
};

pub const PerformanceInsightsMetricDimensionGroup = struct {
    group: ?[]const u8 = null,
    dimensions: ?[][]const u8 = null,
    limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group = "Group",
            .dimensions = "Dimensions",
            .limit = "Limit",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceInsightsReferenceScalar = struct {
    value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchMetricsDetail = struct {
    metric_name: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    dimensions: ?[]CloudWatchMetricsDimension = null,
    stat: ?[]const u8 = null,
    unit: ?[]const u8 = null,
    period: ?i64 = null,
    metric_data_summary: ?CloudWatchMetricsDataSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .namespace = "Namespace",
            .dimensions = "Dimensions",
            .stat = "Stat",
            .unit = "Unit",
            .period = "Period",
            .metric_data_summary = "MetricDataSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchMetricsDataSummary = struct {
    timestamp_metric_value_pair_list: ?[]TimestampMetricValuePair = null,
    status_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp_metric_value_pair_list = "TimestampMetricValuePairList",
            .status_code = "StatusCode",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestampMetricValuePair = struct {
    timestamp: ?i64 = null,
    metric_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp = "Timestamp",
            .metric_value = "MetricValue",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchMetricsDimension = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalyReportedTimeRange = struct {
    open_time: i64,
    close_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .open_time = "OpenTime",
            .close_time = "CloseTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalyTimeRange = struct {
    start_time: i64,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalySourceMetadata = struct {
    source: ?[]const u8 = null,
    source_resource_name: ?[]const u8 = null,
    source_resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
            .source_resource_name = "SourceResourceName",
            .source_resource_type = "SourceResourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const TagHealth = struct {
    app_boundary_key: ?[]const u8 = null,
    tag_value: ?[]const u8 = null,
    insight: ?InsightHealth = null,
    analyzed_resource_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_boundary_key = "AppBoundaryKey",
            .tag_value = "TagValue",
            .insight = "Insight",
            .analyzed_resource_count = "AnalyzedResourceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightHealth = struct {
    open_proactive_insights: ?i64 = null,
    open_reactive_insights: ?i64 = null,
    mean_time_to_recover_in_milliseconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .open_proactive_insights = "OpenProactiveInsights",
            .open_reactive_insights = "OpenReactiveInsights",
            .mean_time_to_recover_in_milliseconds = "MeanTimeToRecoverInMilliseconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceHealth = struct {
    service_name: ?[]const u8 = null,
    insight: ?ServiceInsightHealth = null,
    analyzed_resource_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_name = "ServiceName",
            .insight = "Insight",
            .analyzed_resource_count = "AnalyzedResourceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceInsightHealth = struct {
    open_proactive_insights: ?i64 = null,
    open_reactive_insights: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .open_proactive_insights = "OpenProactiveInsights",
            .open_reactive_insights = "OpenReactiveInsights",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudFormationHealth = struct {
    stack_name: ?[]const u8 = null,
    insight: ?InsightHealth = null,
    analyzed_resource_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stack_name = "StackName",
            .insight = "Insight",
            .analyzed_resource_count = "AnalyzedResourceCount",
        };
        return @field(mappings, field_name);
    }
};
