const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-10-25";
pub const sdk_id: []const u8 = "Direct Connect";
pub const arn_namespace: ?[]const u8 = "directconnect";
pub const endpoint_prefix: []const u8 = "directconnect";
pub const sigv4_name: []const u8 = "directconnect";
pub const name: []const u8 = "OvertureService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2012-10-25",
    sdk_id: []const u8 = "Direct Connect",
    arn_namespace: ?[]const u8 = "directconnect",
    endpoint_prefix: []const u8 = "directconnect",
    sigv4_name: []const u8 = "directconnect",
    name: []const u8 = "OvertureService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const accept_direct_connect_gateway_association_proposal: struct {
    action_name: []const u8 = "AcceptDirectConnectGatewayAssociationProposal",
    Request: type = struct {
        direct_connect_gateway_id: []const u8,
        proposal_id: []const u8,
        associated_gateway_owner_account: []const u8,
        override_allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_id = "directConnectGatewayId",
                .proposal_id = "proposalId",
                .associated_gateway_owner_account = "associatedGatewayOwnerAccount",
                .override_allowed_prefixes_to_direct_connect_gateway = "overrideAllowedPrefixesToDirectConnectGateway",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_direct_connect_gateway_association_proposal) } {
            return .{ .service_metadata = service_metadata, .action = accept_direct_connect_gateway_association_proposal };
        }
    },
    Response: type = struct {
        direct_connect_gateway_association: ?DirectConnectGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_association = "directConnectGatewayAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const allocate_connection_on_interconnect: struct {
    action_name: []const u8 = "AllocateConnectionOnInterconnect",
    Request: type = struct {
        bandwidth: []const u8,
        connection_name: []const u8,
        owner_account: []const u8,
        interconnect_id: []const u8,
        vlan: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bandwidth = "bandwidth",
                .connection_name = "connectionName",
                .owner_account = "ownerAccount",
                .interconnect_id = "interconnectId",
                .vlan = "vlan",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allocate_connection_on_interconnect) } {
            return .{ .service_metadata = service_metadata, .action = allocate_connection_on_interconnect };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        connection_name: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        vlan: ?i64 = null,
        partner_name: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        port_encryption_status: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .connection_state = "connectionState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .vlan = "vlan",
                .partner_name = "partnerName",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .port_encryption_status = "portEncryptionStatus",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const allocate_hosted_connection: struct {
    action_name: []const u8 = "AllocateHostedConnection",
    Request: type = struct {
        connection_id: []const u8,
        owner_account: []const u8,
        bandwidth: []const u8,
        connection_name: []const u8,
        vlan: i64,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .owner_account = "ownerAccount",
                .bandwidth = "bandwidth",
                .connection_name = "connectionName",
                .vlan = "vlan",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allocate_hosted_connection) } {
            return .{ .service_metadata = service_metadata, .action = allocate_hosted_connection };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        connection_name: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        vlan: ?i64 = null,
        partner_name: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        port_encryption_status: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .connection_state = "connectionState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .vlan = "vlan",
                .partner_name = "partnerName",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .port_encryption_status = "portEncryptionStatus",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const allocate_private_virtual_interface: struct {
    action_name: []const u8 = "AllocatePrivateVirtualInterface",
    Request: type = struct {
        connection_id: []const u8,
        owner_account: []const u8,
        new_private_virtual_interface_allocation: struct {
            virtual_interface_name: []const u8,
            vlan: i64,
            asn: i64,
            mtu: ?i64 = null,
            auth_key: ?[]const u8 = null,
            amazon_address: ?[]const u8 = null,
            address_family: ?[]const u8 = null,
            customer_address: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .virtual_interface_name = "virtualInterfaceName",
                    .vlan = "vlan",
                    .asn = "asn",
                    .mtu = "mtu",
                    .auth_key = "authKey",
                    .amazon_address = "amazonAddress",
                    .address_family = "addressFamily",
                    .customer_address = "customerAddress",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .owner_account = "ownerAccount",
                .new_private_virtual_interface_allocation = "newPrivateVirtualInterfaceAllocation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allocate_private_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = allocate_private_virtual_interface };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        virtual_interface_type: ?[]const u8 = null,
        virtual_interface_name: ?[]const u8 = null,
        vlan: ?i64 = null,
        asn: ?i64 = null,
        amazon_side_asn: ?i64 = null,
        auth_key: ?[]const u8 = null,
        amazon_address: ?[]const u8 = null,
        customer_address: ?[]const u8 = null,
        address_family: ?[]const u8 = null,
        virtual_interface_state: ?[]const u8 = null,
        customer_router_config: ?[]const u8 = null,
        mtu: ?i64 = null,
        jumbo_frame_capable: ?bool = null,
        virtual_gateway_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,
        route_filter_prefixes: ?[]RouteFilterPrefix = null,
        bgp_peers: ?[]BGPPeer = null,
        region: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        site_link_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .virtual_interface_id = "virtualInterfaceId",
                .location = "location",
                .connection_id = "connectionId",
                .virtual_interface_type = "virtualInterfaceType",
                .virtual_interface_name = "virtualInterfaceName",
                .vlan = "vlan",
                .asn = "asn",
                .amazon_side_asn = "amazonSideAsn",
                .auth_key = "authKey",
                .amazon_address = "amazonAddress",
                .customer_address = "customerAddress",
                .address_family = "addressFamily",
                .virtual_interface_state = "virtualInterfaceState",
                .customer_router_config = "customerRouterConfig",
                .mtu = "mtu",
                .jumbo_frame_capable = "jumboFrameCapable",
                .virtual_gateway_id = "virtualGatewayId",
                .direct_connect_gateway_id = "directConnectGatewayId",
                .route_filter_prefixes = "routeFilterPrefixes",
                .bgp_peers = "bgpPeers",
                .region = "region",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .tags = "tags",
                .site_link_enabled = "siteLinkEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const allocate_public_virtual_interface: struct {
    action_name: []const u8 = "AllocatePublicVirtualInterface",
    Request: type = struct {
        connection_id: []const u8,
        owner_account: []const u8,
        new_public_virtual_interface_allocation: struct {
            virtual_interface_name: []const u8,
            vlan: i64,
            asn: i64,
            auth_key: ?[]const u8 = null,
            amazon_address: ?[]const u8 = null,
            customer_address: ?[]const u8 = null,
            address_family: ?[]const u8 = null,
            route_filter_prefixes: ?[]RouteFilterPrefix = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .virtual_interface_name = "virtualInterfaceName",
                    .vlan = "vlan",
                    .asn = "asn",
                    .auth_key = "authKey",
                    .amazon_address = "amazonAddress",
                    .customer_address = "customerAddress",
                    .address_family = "addressFamily",
                    .route_filter_prefixes = "routeFilterPrefixes",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .owner_account = "ownerAccount",
                .new_public_virtual_interface_allocation = "newPublicVirtualInterfaceAllocation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allocate_public_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = allocate_public_virtual_interface };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        virtual_interface_type: ?[]const u8 = null,
        virtual_interface_name: ?[]const u8 = null,
        vlan: ?i64 = null,
        asn: ?i64 = null,
        amazon_side_asn: ?i64 = null,
        auth_key: ?[]const u8 = null,
        amazon_address: ?[]const u8 = null,
        customer_address: ?[]const u8 = null,
        address_family: ?[]const u8 = null,
        virtual_interface_state: ?[]const u8 = null,
        customer_router_config: ?[]const u8 = null,
        mtu: ?i64 = null,
        jumbo_frame_capable: ?bool = null,
        virtual_gateway_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,
        route_filter_prefixes: ?[]RouteFilterPrefix = null,
        bgp_peers: ?[]BGPPeer = null,
        region: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        site_link_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .virtual_interface_id = "virtualInterfaceId",
                .location = "location",
                .connection_id = "connectionId",
                .virtual_interface_type = "virtualInterfaceType",
                .virtual_interface_name = "virtualInterfaceName",
                .vlan = "vlan",
                .asn = "asn",
                .amazon_side_asn = "amazonSideAsn",
                .auth_key = "authKey",
                .amazon_address = "amazonAddress",
                .customer_address = "customerAddress",
                .address_family = "addressFamily",
                .virtual_interface_state = "virtualInterfaceState",
                .customer_router_config = "customerRouterConfig",
                .mtu = "mtu",
                .jumbo_frame_capable = "jumboFrameCapable",
                .virtual_gateway_id = "virtualGatewayId",
                .direct_connect_gateway_id = "directConnectGatewayId",
                .route_filter_prefixes = "routeFilterPrefixes",
                .bgp_peers = "bgpPeers",
                .region = "region",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .tags = "tags",
                .site_link_enabled = "siteLinkEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const allocate_transit_virtual_interface: struct {
    action_name: []const u8 = "AllocateTransitVirtualInterface",
    Request: type = struct {
        connection_id: []const u8,
        owner_account: []const u8,
        new_transit_virtual_interface_allocation: struct {
            virtual_interface_name: ?[]const u8 = null,
            vlan: ?i64 = null,
            asn: ?i64 = null,
            mtu: ?i64 = null,
            auth_key: ?[]const u8 = null,
            amazon_address: ?[]const u8 = null,
            customer_address: ?[]const u8 = null,
            address_family: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .virtual_interface_name = "virtualInterfaceName",
                    .vlan = "vlan",
                    .asn = "asn",
                    .mtu = "mtu",
                    .auth_key = "authKey",
                    .amazon_address = "amazonAddress",
                    .customer_address = "customerAddress",
                    .address_family = "addressFamily",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .owner_account = "ownerAccount",
                .new_transit_virtual_interface_allocation = "newTransitVirtualInterfaceAllocation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allocate_transit_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = allocate_transit_virtual_interface };
        }
    },
    Response: type = struct {
        virtual_interface: ?VirtualInterface = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface = "virtualInterface",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const associate_connection_with_lag: struct {
    action_name: []const u8 = "AssociateConnectionWithLag",
    Request: type = struct {
        connection_id: []const u8,
        lag_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .lag_id = "lagId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_connection_with_lag) } {
            return .{ .service_metadata = service_metadata, .action = associate_connection_with_lag };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        connection_name: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        vlan: ?i64 = null,
        partner_name: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        port_encryption_status: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .connection_state = "connectionState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .vlan = "vlan",
                .partner_name = "partnerName",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .port_encryption_status = "portEncryptionStatus",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const associate_hosted_connection: struct {
    action_name: []const u8 = "AssociateHostedConnection",
    Request: type = struct {
        connection_id: []const u8,
        parent_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .parent_connection_id = "parentConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_hosted_connection) } {
            return .{ .service_metadata = service_metadata, .action = associate_hosted_connection };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        connection_name: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        vlan: ?i64 = null,
        partner_name: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        port_encryption_status: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .connection_state = "connectionState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .vlan = "vlan",
                .partner_name = "partnerName",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .port_encryption_status = "portEncryptionStatus",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const associate_mac_sec_key: struct {
    action_name: []const u8 = "AssociateMacSecKey",
    Request: type = struct {
        connection_id: []const u8,
        secret_arn: ?[]const u8 = null,
        ckn: ?[]const u8 = null,
        cak: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .secret_arn = "secretARN",
                .ckn = "ckn",
                .cak = "cak",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_mac_sec_key) } {
            return .{ .service_metadata = service_metadata, .action = associate_mac_sec_key };
        }
    },
    Response: type = struct {
        connection_id: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const associate_virtual_interface: struct {
    action_name: []const u8 = "AssociateVirtualInterface",
    Request: type = struct {
        virtual_interface_id: []const u8,
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
                .connection_id = "connectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = associate_virtual_interface };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        virtual_interface_type: ?[]const u8 = null,
        virtual_interface_name: ?[]const u8 = null,
        vlan: ?i64 = null,
        asn: ?i64 = null,
        amazon_side_asn: ?i64 = null,
        auth_key: ?[]const u8 = null,
        amazon_address: ?[]const u8 = null,
        customer_address: ?[]const u8 = null,
        address_family: ?[]const u8 = null,
        virtual_interface_state: ?[]const u8 = null,
        customer_router_config: ?[]const u8 = null,
        mtu: ?i64 = null,
        jumbo_frame_capable: ?bool = null,
        virtual_gateway_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,
        route_filter_prefixes: ?[]RouteFilterPrefix = null,
        bgp_peers: ?[]BGPPeer = null,
        region: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        site_link_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .virtual_interface_id = "virtualInterfaceId",
                .location = "location",
                .connection_id = "connectionId",
                .virtual_interface_type = "virtualInterfaceType",
                .virtual_interface_name = "virtualInterfaceName",
                .vlan = "vlan",
                .asn = "asn",
                .amazon_side_asn = "amazonSideAsn",
                .auth_key = "authKey",
                .amazon_address = "amazonAddress",
                .customer_address = "customerAddress",
                .address_family = "addressFamily",
                .virtual_interface_state = "virtualInterfaceState",
                .customer_router_config = "customerRouterConfig",
                .mtu = "mtu",
                .jumbo_frame_capable = "jumboFrameCapable",
                .virtual_gateway_id = "virtualGatewayId",
                .direct_connect_gateway_id = "directConnectGatewayId",
                .route_filter_prefixes = "routeFilterPrefixes",
                .bgp_peers = "bgpPeers",
                .region = "region",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .tags = "tags",
                .site_link_enabled = "siteLinkEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const confirm_connection: struct {
    action_name: []const u8 = "ConfirmConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_connection) } {
            return .{ .service_metadata = service_metadata, .action = confirm_connection };
        }
    },
    Response: type = struct {
        connection_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_state = "connectionState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const confirm_customer_agreement: struct {
    action_name: []const u8 = "ConfirmCustomerAgreement",
    Request: type = struct {
        agreement_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_name = "agreementName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_customer_agreement) } {
            return .{ .service_metadata = service_metadata, .action = confirm_customer_agreement };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const confirm_private_virtual_interface: struct {
    action_name: []const u8 = "ConfirmPrivateVirtualInterface",
    Request: type = struct {
        virtual_interface_id: []const u8,
        virtual_gateway_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
                .virtual_gateway_id = "virtualGatewayId",
                .direct_connect_gateway_id = "directConnectGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_private_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = confirm_private_virtual_interface };
        }
    },
    Response: type = struct {
        virtual_interface_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_state = "virtualInterfaceState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const confirm_public_virtual_interface: struct {
    action_name: []const u8 = "ConfirmPublicVirtualInterface",
    Request: type = struct {
        virtual_interface_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_public_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = confirm_public_virtual_interface };
        }
    },
    Response: type = struct {
        virtual_interface_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_state = "virtualInterfaceState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const confirm_transit_virtual_interface: struct {
    action_name: []const u8 = "ConfirmTransitVirtualInterface",
    Request: type = struct {
        virtual_interface_id: []const u8,
        direct_connect_gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
                .direct_connect_gateway_id = "directConnectGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_transit_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = confirm_transit_virtual_interface };
        }
    },
    Response: type = struct {
        virtual_interface_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_state = "virtualInterfaceState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const create_bgp_peer: struct {
    action_name: []const u8 = "CreateBGPPeer",
    Request: type = struct {
        virtual_interface_id: ?[]const u8 = null,
        new_bgp_peer: ?struct {
            asn: ?i64 = null,
            auth_key: ?[]const u8 = null,
            address_family: ?[]const u8 = null,
            amazon_address: ?[]const u8 = null,
            customer_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .asn = "asn",
                    .auth_key = "authKey",
                    .address_family = "addressFamily",
                    .amazon_address = "amazonAddress",
                    .customer_address = "customerAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
                .new_bgp_peer = "newBGPPeer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bgp_peer) } {
            return .{ .service_metadata = service_metadata, .action = create_bgp_peer };
        }
    },
    Response: type = struct {
        virtual_interface: ?VirtualInterface = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface = "virtualInterface",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const create_connection: struct {
    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        location: []const u8,
        bandwidth: []const u8,
        connection_name: []const u8,
        lag_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        request_mac_sec: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "location",
                .bandwidth = "bandwidth",
                .connection_name = "connectionName",
                .lag_id = "lagId",
                .tags = "tags",
                .provider_name = "providerName",
                .request_mac_sec = "requestMACSec",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        connection_name: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        vlan: ?i64 = null,
        partner_name: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        port_encryption_status: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .connection_state = "connectionState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .vlan = "vlan",
                .partner_name = "partnerName",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .port_encryption_status = "portEncryptionStatus",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const create_direct_connect_gateway: struct {
    action_name: []const u8 = "CreateDirectConnectGateway",
    Request: type = struct {
        direct_connect_gateway_name: []const u8,
        amazon_side_asn: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_name = "directConnectGatewayName",
                .amazon_side_asn = "amazonSideAsn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_direct_connect_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_direct_connect_gateway };
        }
    },
    Response: type = struct {
        direct_connect_gateway: ?DirectConnectGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway = "directConnectGateway",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const create_direct_connect_gateway_association: struct {
    action_name: []const u8 = "CreateDirectConnectGatewayAssociation",
    Request: type = struct {
        direct_connect_gateway_id: []const u8,
        gateway_id: ?[]const u8 = null,
        add_allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,
        virtual_gateway_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_id = "directConnectGatewayId",
                .gateway_id = "gatewayId",
                .add_allowed_prefixes_to_direct_connect_gateway = "addAllowedPrefixesToDirectConnectGateway",
                .virtual_gateway_id = "virtualGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_direct_connect_gateway_association) } {
            return .{ .service_metadata = service_metadata, .action = create_direct_connect_gateway_association };
        }
    },
    Response: type = struct {
        direct_connect_gateway_association: ?DirectConnectGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_association = "directConnectGatewayAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const create_direct_connect_gateway_association_proposal: struct {
    action_name: []const u8 = "CreateDirectConnectGatewayAssociationProposal",
    Request: type = struct {
        direct_connect_gateway_id: []const u8,
        direct_connect_gateway_owner_account: []const u8,
        gateway_id: []const u8,
        add_allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,
        remove_allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_id = "directConnectGatewayId",
                .direct_connect_gateway_owner_account = "directConnectGatewayOwnerAccount",
                .gateway_id = "gatewayId",
                .add_allowed_prefixes_to_direct_connect_gateway = "addAllowedPrefixesToDirectConnectGateway",
                .remove_allowed_prefixes_to_direct_connect_gateway = "removeAllowedPrefixesToDirectConnectGateway",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_direct_connect_gateway_association_proposal) } {
            return .{ .service_metadata = service_metadata, .action = create_direct_connect_gateway_association_proposal };
        }
    },
    Response: type = struct {
        direct_connect_gateway_association_proposal: ?DirectConnectGatewayAssociationProposal = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_association_proposal = "directConnectGatewayAssociationProposal",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const create_interconnect: struct {
    action_name: []const u8 = "CreateInterconnect",
    Request: type = struct {
        interconnect_name: []const u8,
        bandwidth: []const u8,
        location: []const u8,
        lag_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interconnect_name = "interconnectName",
                .bandwidth = "bandwidth",
                .location = "location",
                .lag_id = "lagId",
                .tags = "tags",
                .provider_name = "providerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_interconnect) } {
            return .{ .service_metadata = service_metadata, .action = create_interconnect };
        }
    },
    Response: type = struct {
        interconnect_id: ?[]const u8 = null,
        interconnect_name: ?[]const u8 = null,
        interconnect_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interconnect_id = "interconnectId",
                .interconnect_name = "interconnectName",
                .interconnect_state = "interconnectState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const create_lag: struct {
    action_name: []const u8 = "CreateLag",
    Request: type = struct {
        number_of_connections: i64,
        location: []const u8,
        connections_bandwidth: []const u8,
        lag_name: []const u8,
        connection_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        child_connection_tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        request_mac_sec: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .number_of_connections = "numberOfConnections",
                .location = "location",
                .connections_bandwidth = "connectionsBandwidth",
                .lag_name = "lagName",
                .connection_id = "connectionId",
                .tags = "tags",
                .child_connection_tags = "childConnectionTags",
                .provider_name = "providerName",
                .request_mac_sec = "requestMACSec",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lag) } {
            return .{ .service_metadata = service_metadata, .action = create_lag };
        }
    },
    Response: type = struct {
        connections_bandwidth: ?[]const u8 = null,
        number_of_connections: ?i64 = null,
        lag_id: ?[]const u8 = null,
        owner_account: ?[]const u8 = null,
        lag_name: ?[]const u8 = null,
        lag_state: ?[]const u8 = null,
        location: ?[]const u8 = null,
        region: ?[]const u8 = null,
        minimum_links: ?i64 = null,
        aws_device: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        connections: ?[]Connection = null,
        allows_hosted_connections: ?bool = null,
        jumbo_frame_capable: ?bool = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections_bandwidth = "connectionsBandwidth",
                .number_of_connections = "numberOfConnections",
                .lag_id = "lagId",
                .owner_account = "ownerAccount",
                .lag_name = "lagName",
                .lag_state = "lagState",
                .location = "location",
                .region = "region",
                .minimum_links = "minimumLinks",
                .aws_device = "awsDevice",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .connections = "connections",
                .allows_hosted_connections = "allowsHostedConnections",
                .jumbo_frame_capable = "jumboFrameCapable",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const create_private_virtual_interface: struct {
    action_name: []const u8 = "CreatePrivateVirtualInterface",
    Request: type = struct {
        connection_id: []const u8,
        new_private_virtual_interface: struct {
            virtual_interface_name: []const u8,
            vlan: i64,
            asn: i64,
            mtu: ?i64 = null,
            auth_key: ?[]const u8 = null,
            amazon_address: ?[]const u8 = null,
            customer_address: ?[]const u8 = null,
            address_family: ?[]const u8 = null,
            virtual_gateway_id: ?[]const u8 = null,
            direct_connect_gateway_id: ?[]const u8 = null,
            tags: ?[]Tag = null,
            enable_site_link: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .virtual_interface_name = "virtualInterfaceName",
                    .vlan = "vlan",
                    .asn = "asn",
                    .mtu = "mtu",
                    .auth_key = "authKey",
                    .amazon_address = "amazonAddress",
                    .customer_address = "customerAddress",
                    .address_family = "addressFamily",
                    .virtual_gateway_id = "virtualGatewayId",
                    .direct_connect_gateway_id = "directConnectGatewayId",
                    .tags = "tags",
                    .enable_site_link = "enableSiteLink",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .new_private_virtual_interface = "newPrivateVirtualInterface",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_private_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = create_private_virtual_interface };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        virtual_interface_type: ?[]const u8 = null,
        virtual_interface_name: ?[]const u8 = null,
        vlan: ?i64 = null,
        asn: ?i64 = null,
        amazon_side_asn: ?i64 = null,
        auth_key: ?[]const u8 = null,
        amazon_address: ?[]const u8 = null,
        customer_address: ?[]const u8 = null,
        address_family: ?[]const u8 = null,
        virtual_interface_state: ?[]const u8 = null,
        customer_router_config: ?[]const u8 = null,
        mtu: ?i64 = null,
        jumbo_frame_capable: ?bool = null,
        virtual_gateway_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,
        route_filter_prefixes: ?[]RouteFilterPrefix = null,
        bgp_peers: ?[]BGPPeer = null,
        region: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        site_link_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .virtual_interface_id = "virtualInterfaceId",
                .location = "location",
                .connection_id = "connectionId",
                .virtual_interface_type = "virtualInterfaceType",
                .virtual_interface_name = "virtualInterfaceName",
                .vlan = "vlan",
                .asn = "asn",
                .amazon_side_asn = "amazonSideAsn",
                .auth_key = "authKey",
                .amazon_address = "amazonAddress",
                .customer_address = "customerAddress",
                .address_family = "addressFamily",
                .virtual_interface_state = "virtualInterfaceState",
                .customer_router_config = "customerRouterConfig",
                .mtu = "mtu",
                .jumbo_frame_capable = "jumboFrameCapable",
                .virtual_gateway_id = "virtualGatewayId",
                .direct_connect_gateway_id = "directConnectGatewayId",
                .route_filter_prefixes = "routeFilterPrefixes",
                .bgp_peers = "bgpPeers",
                .region = "region",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .tags = "tags",
                .site_link_enabled = "siteLinkEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const create_public_virtual_interface: struct {
    action_name: []const u8 = "CreatePublicVirtualInterface",
    Request: type = struct {
        connection_id: []const u8,
        new_public_virtual_interface: struct {
            virtual_interface_name: []const u8,
            vlan: i64,
            asn: i64,
            auth_key: ?[]const u8 = null,
            amazon_address: ?[]const u8 = null,
            customer_address: ?[]const u8 = null,
            address_family: ?[]const u8 = null,
            route_filter_prefixes: ?[]RouteFilterPrefix = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .virtual_interface_name = "virtualInterfaceName",
                    .vlan = "vlan",
                    .asn = "asn",
                    .auth_key = "authKey",
                    .amazon_address = "amazonAddress",
                    .customer_address = "customerAddress",
                    .address_family = "addressFamily",
                    .route_filter_prefixes = "routeFilterPrefixes",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .new_public_virtual_interface = "newPublicVirtualInterface",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_public_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = create_public_virtual_interface };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        virtual_interface_type: ?[]const u8 = null,
        virtual_interface_name: ?[]const u8 = null,
        vlan: ?i64 = null,
        asn: ?i64 = null,
        amazon_side_asn: ?i64 = null,
        auth_key: ?[]const u8 = null,
        amazon_address: ?[]const u8 = null,
        customer_address: ?[]const u8 = null,
        address_family: ?[]const u8 = null,
        virtual_interface_state: ?[]const u8 = null,
        customer_router_config: ?[]const u8 = null,
        mtu: ?i64 = null,
        jumbo_frame_capable: ?bool = null,
        virtual_gateway_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,
        route_filter_prefixes: ?[]RouteFilterPrefix = null,
        bgp_peers: ?[]BGPPeer = null,
        region: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        site_link_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .virtual_interface_id = "virtualInterfaceId",
                .location = "location",
                .connection_id = "connectionId",
                .virtual_interface_type = "virtualInterfaceType",
                .virtual_interface_name = "virtualInterfaceName",
                .vlan = "vlan",
                .asn = "asn",
                .amazon_side_asn = "amazonSideAsn",
                .auth_key = "authKey",
                .amazon_address = "amazonAddress",
                .customer_address = "customerAddress",
                .address_family = "addressFamily",
                .virtual_interface_state = "virtualInterfaceState",
                .customer_router_config = "customerRouterConfig",
                .mtu = "mtu",
                .jumbo_frame_capable = "jumboFrameCapable",
                .virtual_gateway_id = "virtualGatewayId",
                .direct_connect_gateway_id = "directConnectGatewayId",
                .route_filter_prefixes = "routeFilterPrefixes",
                .bgp_peers = "bgpPeers",
                .region = "region",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .tags = "tags",
                .site_link_enabled = "siteLinkEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const create_transit_virtual_interface: struct {
    action_name: []const u8 = "CreateTransitVirtualInterface",
    Request: type = struct {
        connection_id: []const u8,
        new_transit_virtual_interface: struct {
            virtual_interface_name: ?[]const u8 = null,
            vlan: ?i64 = null,
            asn: ?i64 = null,
            mtu: ?i64 = null,
            auth_key: ?[]const u8 = null,
            amazon_address: ?[]const u8 = null,
            customer_address: ?[]const u8 = null,
            address_family: ?[]const u8 = null,
            direct_connect_gateway_id: ?[]const u8 = null,
            tags: ?[]Tag = null,
            enable_site_link: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .virtual_interface_name = "virtualInterfaceName",
                    .vlan = "vlan",
                    .asn = "asn",
                    .mtu = "mtu",
                    .auth_key = "authKey",
                    .amazon_address = "amazonAddress",
                    .customer_address = "customerAddress",
                    .address_family = "addressFamily",
                    .direct_connect_gateway_id = "directConnectGatewayId",
                    .tags = "tags",
                    .enable_site_link = "enableSiteLink",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .new_transit_virtual_interface = "newTransitVirtualInterface",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_virtual_interface };
        }
    },
    Response: type = struct {
        virtual_interface: ?VirtualInterface = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface = "virtualInterface",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const delete_bgp_peer: struct {
    action_name: []const u8 = "DeleteBGPPeer",
    Request: type = struct {
        virtual_interface_id: ?[]const u8 = null,
        asn: ?i64 = null,
        customer_address: ?[]const u8 = null,
        bgp_peer_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
                .asn = "asn",
                .customer_address = "customerAddress",
                .bgp_peer_id = "bgpPeerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bgp_peer) } {
            return .{ .service_metadata = service_metadata, .action = delete_bgp_peer };
        }
    },
    Response: type = struct {
        virtual_interface: ?VirtualInterface = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface = "virtualInterface",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        connection_name: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        vlan: ?i64 = null,
        partner_name: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        port_encryption_status: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .connection_state = "connectionState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .vlan = "vlan",
                .partner_name = "partnerName",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .port_encryption_status = "portEncryptionStatus",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const delete_direct_connect_gateway: struct {
    action_name: []const u8 = "DeleteDirectConnectGateway",
    Request: type = struct {
        direct_connect_gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_id = "directConnectGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_direct_connect_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_direct_connect_gateway };
        }
    },
    Response: type = struct {
        direct_connect_gateway: ?DirectConnectGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway = "directConnectGateway",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const delete_direct_connect_gateway_association: struct {
    action_name: []const u8 = "DeleteDirectConnectGatewayAssociation",
    Request: type = struct {
        association_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,
        virtual_gateway_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .direct_connect_gateway_id = "directConnectGatewayId",
                .virtual_gateway_id = "virtualGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_direct_connect_gateway_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_direct_connect_gateway_association };
        }
    },
    Response: type = struct {
        direct_connect_gateway_association: ?DirectConnectGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_association = "directConnectGatewayAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const delete_direct_connect_gateway_association_proposal: struct {
    action_name: []const u8 = "DeleteDirectConnectGatewayAssociationProposal",
    Request: type = struct {
        proposal_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proposal_id = "proposalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_direct_connect_gateway_association_proposal) } {
            return .{ .service_metadata = service_metadata, .action = delete_direct_connect_gateway_association_proposal };
        }
    },
    Response: type = struct {
        direct_connect_gateway_association_proposal: ?DirectConnectGatewayAssociationProposal = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_association_proposal = "directConnectGatewayAssociationProposal",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const delete_interconnect: struct {
    action_name: []const u8 = "DeleteInterconnect",
    Request: type = struct {
        interconnect_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interconnect_id = "interconnectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_interconnect) } {
            return .{ .service_metadata = service_metadata, .action = delete_interconnect };
        }
    },
    Response: type = struct {
        interconnect_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interconnect_state = "interconnectState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const delete_lag: struct {
    action_name: []const u8 = "DeleteLag",
    Request: type = struct {
        lag_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lag_id = "lagId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lag) } {
            return .{ .service_metadata = service_metadata, .action = delete_lag };
        }
    },
    Response: type = struct {
        connections_bandwidth: ?[]const u8 = null,
        number_of_connections: ?i64 = null,
        lag_id: ?[]const u8 = null,
        owner_account: ?[]const u8 = null,
        lag_name: ?[]const u8 = null,
        lag_state: ?[]const u8 = null,
        location: ?[]const u8 = null,
        region: ?[]const u8 = null,
        minimum_links: ?i64 = null,
        aws_device: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        connections: ?[]Connection = null,
        allows_hosted_connections: ?bool = null,
        jumbo_frame_capable: ?bool = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections_bandwidth = "connectionsBandwidth",
                .number_of_connections = "numberOfConnections",
                .lag_id = "lagId",
                .owner_account = "ownerAccount",
                .lag_name = "lagName",
                .lag_state = "lagState",
                .location = "location",
                .region = "region",
                .minimum_links = "minimumLinks",
                .aws_device = "awsDevice",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .connections = "connections",
                .allows_hosted_connections = "allowsHostedConnections",
                .jumbo_frame_capable = "jumboFrameCapable",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const delete_virtual_interface: struct {
    action_name: []const u8 = "DeleteVirtualInterface",
    Request: type = struct {
        virtual_interface_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_virtual_interface) } {
            return .{ .service_metadata = service_metadata, .action = delete_virtual_interface };
        }
    },
    Response: type = struct {
        virtual_interface_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_state = "virtualInterfaceState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_connection_loa: struct {
    action_name: []const u8 = "DescribeConnectionLoa",
    Request: type = struct {
        connection_id: []const u8,
        provider_name: ?[]const u8 = null,
        loa_content_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .provider_name = "providerName",
                .loa_content_type = "loaContentType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connection_loa) } {
            return .{ .service_metadata = service_metadata, .action = describe_connection_loa };
        }
    },
    Response: type = struct {
        loa: ?Loa = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .loa = "loa",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_connections: struct {
    action_name: []const u8 = "DescribeConnections",
    Request: type = struct {
        connection_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_connections };
        }
    },
    Response: type = struct {
        connections: ?[]Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "connections",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_connections_on_interconnect: struct {
    action_name: []const u8 = "DescribeConnectionsOnInterconnect",
    Request: type = struct {
        interconnect_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interconnect_id = "interconnectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connections_on_interconnect) } {
            return .{ .service_metadata = service_metadata, .action = describe_connections_on_interconnect };
        }
    },
    Response: type = struct {
        connections: ?[]Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "connections",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_customer_metadata: struct {
    action_name: []const u8 = "DescribeCustomerMetadata",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_customer_metadata) } {
            return .{ .service_metadata = service_metadata, .action = describe_customer_metadata };
        }
    },
    Response: type = struct {
        agreements: ?[]struct {
            agreement_name: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agreement_name = "agreementName",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        nni_partner_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreements = "agreements",
                .nni_partner_type = "nniPartnerType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_direct_connect_gateway_association_proposals: struct {
    action_name: []const u8 = "DescribeDirectConnectGatewayAssociationProposals",
    Request: type = struct {
        direct_connect_gateway_id: ?[]const u8 = null,
        proposal_id: ?[]const u8 = null,
        associated_gateway_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_id = "directConnectGatewayId",
                .proposal_id = "proposalId",
                .associated_gateway_id = "associatedGatewayId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_direct_connect_gateway_association_proposals) } {
            return .{ .service_metadata = service_metadata, .action = describe_direct_connect_gateway_association_proposals };
        }
    },
    Response: type = struct {
        direct_connect_gateway_association_proposals: ?[]DirectConnectGatewayAssociationProposal = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_association_proposals = "directConnectGatewayAssociationProposals",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_direct_connect_gateway_associations: struct {
    action_name: []const u8 = "DescribeDirectConnectGatewayAssociations",
    Request: type = struct {
        association_id: ?[]const u8 = null,
        associated_gateway_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        virtual_gateway_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .associated_gateway_id = "associatedGatewayId",
                .direct_connect_gateway_id = "directConnectGatewayId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .virtual_gateway_id = "virtualGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_direct_connect_gateway_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_direct_connect_gateway_associations };
        }
    },
    Response: type = struct {
        direct_connect_gateway_associations: ?[]DirectConnectGatewayAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_associations = "directConnectGatewayAssociations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_direct_connect_gateway_attachments: struct {
    action_name: []const u8 = "DescribeDirectConnectGatewayAttachments",
    Request: type = struct {
        direct_connect_gateway_id: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_id = "directConnectGatewayId",
                .virtual_interface_id = "virtualInterfaceId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_direct_connect_gateway_attachments) } {
            return .{ .service_metadata = service_metadata, .action = describe_direct_connect_gateway_attachments };
        }
    },
    Response: type = struct {
        direct_connect_gateway_attachments: ?[]struct {
            direct_connect_gateway_id: ?[]const u8 = null,
            virtual_interface_id: ?[]const u8 = null,
            virtual_interface_region: ?[]const u8 = null,
            virtual_interface_owner_account: ?[]const u8 = null,
            attachment_state: ?[]const u8 = null,
            attachment_type: ?[]const u8 = null,
            state_change_error: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .direct_connect_gateway_id = "directConnectGatewayId",
                    .virtual_interface_id = "virtualInterfaceId",
                    .virtual_interface_region = "virtualInterfaceRegion",
                    .virtual_interface_owner_account = "virtualInterfaceOwnerAccount",
                    .attachment_state = "attachmentState",
                    .attachment_type = "attachmentType",
                    .state_change_error = "stateChangeError",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_attachments = "directConnectGatewayAttachments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_direct_connect_gateways: struct {
    action_name: []const u8 = "DescribeDirectConnectGateways",
    Request: type = struct {
        direct_connect_gateway_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_id = "directConnectGatewayId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_direct_connect_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_direct_connect_gateways };
        }
    },
    Response: type = struct {
        direct_connect_gateways: ?[]DirectConnectGateway = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateways = "directConnectGateways",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_hosted_connections: struct {
    action_name: []const u8 = "DescribeHostedConnections",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hosted_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_hosted_connections };
        }
    },
    Response: type = struct {
        connections: ?[]Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "connections",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_interconnect_loa: struct {
    action_name: []const u8 = "DescribeInterconnectLoa",
    Request: type = struct {
        interconnect_id: []const u8,
        provider_name: ?[]const u8 = null,
        loa_content_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interconnect_id = "interconnectId",
                .provider_name = "providerName",
                .loa_content_type = "loaContentType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_interconnect_loa) } {
            return .{ .service_metadata = service_metadata, .action = describe_interconnect_loa };
        }
    },
    Response: type = struct {
        loa: ?Loa = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .loa = "loa",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_interconnects: struct {
    action_name: []const u8 = "DescribeInterconnects",
    Request: type = struct {
        interconnect_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interconnect_id = "interconnectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_interconnects) } {
            return .{ .service_metadata = service_metadata, .action = describe_interconnects };
        }
    },
    Response: type = struct {
        interconnects: ?[]Interconnect = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interconnects = "interconnects",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_lags: struct {
    action_name: []const u8 = "DescribeLags",
    Request: type = struct {
        lag_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lag_id = "lagId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_lags) } {
            return .{ .service_metadata = service_metadata, .action = describe_lags };
        }
    },
    Response: type = struct {
        lags: ?[]Lag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lags = "lags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_loa: struct {
    action_name: []const u8 = "DescribeLoa",
    Request: type = struct {
        connection_id: []const u8,
        provider_name: ?[]const u8 = null,
        loa_content_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .provider_name = "providerName",
                .loa_content_type = "loaContentType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_loa) } {
            return .{ .service_metadata = service_metadata, .action = describe_loa };
        }
    },
    Response: type = struct {
        loa_content: ?[]const u8 = null,
        loa_content_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .loa_content = "loaContent",
                .loa_content_type = "loaContentType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_locations: struct {
    action_name: []const u8 = "DescribeLocations",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_locations) } {
            return .{ .service_metadata = service_metadata, .action = describe_locations };
        }
    },
    Response: type = struct {
        locations: ?[]struct {
            location_code: ?[]const u8 = null,
            location_name: ?[]const u8 = null,
            region: ?[]const u8 = null,
            available_port_speeds: ?[][]const u8 = null,
            available_providers: ?[][]const u8 = null,
            available_mac_sec_port_speeds: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_code = "locationCode",
                    .location_name = "locationName",
                    .region = "region",
                    .available_port_speeds = "availablePortSpeeds",
                    .available_providers = "availableProviders",
                    .available_mac_sec_port_speeds = "availableMacSecPortSpeeds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locations = "locations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_router_configuration: struct {
    action_name: []const u8 = "DescribeRouterConfiguration",
    Request: type = struct {
        virtual_interface_id: []const u8,
        router_type_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
                .router_type_identifier = "routerTypeIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_router_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_router_configuration };
        }
    },
    Response: type = struct {
        customer_router_config: ?[]const u8 = null,
        router: ?struct {
            vendor: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            software: ?[]const u8 = null,
            xslt_template_name: ?[]const u8 = null,
            xslt_template_name_for_mac_sec: ?[]const u8 = null,
            router_type_identifier: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vendor = "vendor",
                    .platform = "platform",
                    .software = "software",
                    .xslt_template_name = "xsltTemplateName",
                    .xslt_template_name_for_mac_sec = "xsltTemplateNameForMacSec",
                    .router_type_identifier = "routerTypeIdentifier",
                };
                return @field(mappings, field_name);
            }
        } = null,
        virtual_interface_id: ?[]const u8 = null,
        virtual_interface_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_router_config = "customerRouterConfig",
                .router = "router",
                .virtual_interface_id = "virtualInterfaceId",
                .virtual_interface_name = "virtualInterfaceName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_tags: struct {
    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        resource_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "resourceArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        resource_tags: ?[]struct {
            resource_arn: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "resourceArn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_tags = "resourceTags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_virtual_gateways: struct {
    action_name: []const u8 = "DescribeVirtualGateways",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_virtual_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_virtual_gateways };
        }
    },
    Response: type = struct {
        virtual_gateways: ?[]struct {
            virtual_gateway_id: ?[]const u8 = null,
            virtual_gateway_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .virtual_gateway_id = "virtualGatewayId",
                    .virtual_gateway_state = "virtualGatewayState",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_gateways = "virtualGateways",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const describe_virtual_interfaces: struct {
    action_name: []const u8 = "DescribeVirtualInterfaces",
    Request: type = struct {
        connection_id: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .virtual_interface_id = "virtualInterfaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_virtual_interfaces) } {
            return .{ .service_metadata = service_metadata, .action = describe_virtual_interfaces };
        }
    },
    Response: type = struct {
        virtual_interfaces: ?[]VirtualInterface = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interfaces = "virtualInterfaces",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const disassociate_connection_from_lag: struct {
    action_name: []const u8 = "DisassociateConnectionFromLag",
    Request: type = struct {
        connection_id: []const u8,
        lag_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .lag_id = "lagId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_connection_from_lag) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_connection_from_lag };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        connection_name: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        vlan: ?i64 = null,
        partner_name: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        port_encryption_status: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .connection_state = "connectionState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .vlan = "vlan",
                .partner_name = "partnerName",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .port_encryption_status = "portEncryptionStatus",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const disassociate_mac_sec_key: struct {
    action_name: []const u8 = "DisassociateMacSecKey",
    Request: type = struct {
        connection_id: []const u8,
        secret_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .secret_arn = "secretARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_mac_sec_key) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_mac_sec_key };
        }
    },
    Response: type = struct {
        connection_id: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const list_virtual_interface_test_history: struct {
    action_name: []const u8 = "ListVirtualInterfaceTestHistory",
    Request: type = struct {
        test_id: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,
        bgp_peers: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_id = "testId",
                .virtual_interface_id = "virtualInterfaceId",
                .bgp_peers = "bgpPeers",
                .status = "status",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_virtual_interface_test_history) } {
            return .{ .service_metadata = service_metadata, .action = list_virtual_interface_test_history };
        }
    },
    Response: type = struct {
        virtual_interface_test_history: ?[]VirtualInterfaceTestHistory = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_test_history = "virtualInterfaceTestHistory",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const start_bgp_failover_test: struct {
    action_name: []const u8 = "StartBgpFailoverTest",
    Request: type = struct {
        virtual_interface_id: []const u8,
        bgp_peers: ?[][]const u8 = null,
        test_duration_in_minutes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
                .bgp_peers = "bgpPeers",
                .test_duration_in_minutes = "testDurationInMinutes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_bgp_failover_test) } {
            return .{ .service_metadata = service_metadata, .action = start_bgp_failover_test };
        }
    },
    Response: type = struct {
        virtual_interface_test: ?VirtualInterfaceTestHistory = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_test = "virtualInterfaceTest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const stop_bgp_failover_test: struct {
    action_name: []const u8 = "StopBgpFailoverTest",
    Request: type = struct {
        virtual_interface_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_bgp_failover_test) } {
            return .{ .service_metadata = service_metadata, .action = stop_bgp_failover_test };
        }
    },
    Response: type = struct {
        virtual_interface_test: ?VirtualInterfaceTestHistory = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_test = "virtualInterfaceTest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const update_connection: struct {
    action_name: []const u8 = "UpdateConnection",
    Request: type = struct {
        connection_id: []const u8,
        connection_name: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .encryption_mode = "encryptionMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connection) } {
            return .{ .service_metadata = service_metadata, .action = update_connection };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        connection_name: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        region: ?[]const u8 = null,
        location: ?[]const u8 = null,
        bandwidth: ?[]const u8 = null,
        vlan: ?i64 = null,
        partner_name: ?[]const u8 = null,
        loa_issue_time: ?i64 = null,
        lag_id: ?[]const u8 = null,
        aws_device: ?[]const u8 = null,
        jumbo_frame_capable: ?bool = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        port_encryption_status: ?[]const u8 = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .connection_id = "connectionId",
                .connection_name = "connectionName",
                .connection_state = "connectionState",
                .region = "region",
                .location = "location",
                .bandwidth = "bandwidth",
                .vlan = "vlan",
                .partner_name = "partnerName",
                .loa_issue_time = "loaIssueTime",
                .lag_id = "lagId",
                .aws_device = "awsDevice",
                .jumbo_frame_capable = "jumboFrameCapable",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .port_encryption_status = "portEncryptionStatus",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const update_direct_connect_gateway: struct {
    action_name: []const u8 = "UpdateDirectConnectGateway",
    Request: type = struct {
        direct_connect_gateway_id: []const u8,
        new_direct_connect_gateway_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_id = "directConnectGatewayId",
                .new_direct_connect_gateway_name = "newDirectConnectGatewayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_direct_connect_gateway) } {
            return .{ .service_metadata = service_metadata, .action = update_direct_connect_gateway };
        }
    },
    Response: type = struct {
        direct_connect_gateway: ?DirectConnectGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway = "directConnectGateway",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const update_direct_connect_gateway_association: struct {
    action_name: []const u8 = "UpdateDirectConnectGatewayAssociation",
    Request: type = struct {
        association_id: ?[]const u8 = null,
        add_allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,
        remove_allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .add_allowed_prefixes_to_direct_connect_gateway = "addAllowedPrefixesToDirectConnectGateway",
                .remove_allowed_prefixes_to_direct_connect_gateway = "removeAllowedPrefixesToDirectConnectGateway",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_direct_connect_gateway_association) } {
            return .{ .service_metadata = service_metadata, .action = update_direct_connect_gateway_association };
        }
    },
    Response: type = struct {
        direct_connect_gateway_association: ?DirectConnectGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .direct_connect_gateway_association = "directConnectGatewayAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const update_lag: struct {
    action_name: []const u8 = "UpdateLag",
    Request: type = struct {
        lag_id: []const u8,
        lag_name: ?[]const u8 = null,
        minimum_links: ?i64 = null,
        encryption_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lag_id = "lagId",
                .lag_name = "lagName",
                .minimum_links = "minimumLinks",
                .encryption_mode = "encryptionMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_lag) } {
            return .{ .service_metadata = service_metadata, .action = update_lag };
        }
    },
    Response: type = struct {
        connections_bandwidth: ?[]const u8 = null,
        number_of_connections: ?i64 = null,
        lag_id: ?[]const u8 = null,
        owner_account: ?[]const u8 = null,
        lag_name: ?[]const u8 = null,
        lag_state: ?[]const u8 = null,
        location: ?[]const u8 = null,
        region: ?[]const u8 = null,
        minimum_links: ?i64 = null,
        aws_device: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        connections: ?[]Connection = null,
        allows_hosted_connections: ?bool = null,
        jumbo_frame_capable: ?bool = null,
        has_logical_redundancy: ?[]const u8 = null,
        tags: ?[]Tag = null,
        provider_name: ?[]const u8 = null,
        mac_sec_capable: ?bool = null,
        encryption_mode: ?[]const u8 = null,
        mac_sec_keys: ?[]MacSecKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections_bandwidth = "connectionsBandwidth",
                .number_of_connections = "numberOfConnections",
                .lag_id = "lagId",
                .owner_account = "ownerAccount",
                .lag_name = "lagName",
                .lag_state = "lagState",
                .location = "location",
                .region = "region",
                .minimum_links = "minimumLinks",
                .aws_device = "awsDevice",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .connections = "connections",
                .allows_hosted_connections = "allowsHostedConnections",
                .jumbo_frame_capable = "jumboFrameCapable",
                .has_logical_redundancy = "hasLogicalRedundancy",
                .tags = "tags",
                .provider_name = "providerName",
                .mac_sec_capable = "macSecCapable",
                .encryption_mode = "encryptionMode",
                .mac_sec_keys = "macSecKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};
pub const update_virtual_interface_attributes: struct {
    action_name: []const u8 = "UpdateVirtualInterfaceAttributes",
    Request: type = struct {
        virtual_interface_id: []const u8,
        mtu: ?i64 = null,
        enable_site_link: ?bool = null,
        virtual_interface_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_interface_id = "virtualInterfaceId",
                .mtu = "mtu",
                .enable_site_link = "enableSiteLink",
                .virtual_interface_name = "virtualInterfaceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_virtual_interface_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_virtual_interface_attributes };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        virtual_interface_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        virtual_interface_type: ?[]const u8 = null,
        virtual_interface_name: ?[]const u8 = null,
        vlan: ?i64 = null,
        asn: ?i64 = null,
        amazon_side_asn: ?i64 = null,
        auth_key: ?[]const u8 = null,
        amazon_address: ?[]const u8 = null,
        customer_address: ?[]const u8 = null,
        address_family: ?[]const u8 = null,
        virtual_interface_state: ?[]const u8 = null,
        customer_router_config: ?[]const u8 = null,
        mtu: ?i64 = null,
        jumbo_frame_capable: ?bool = null,
        virtual_gateway_id: ?[]const u8 = null,
        direct_connect_gateway_id: ?[]const u8 = null,
        route_filter_prefixes: ?[]RouteFilterPrefix = null,
        bgp_peers: ?[]BGPPeer = null,
        region: ?[]const u8 = null,
        aws_device_v2: ?[]const u8 = null,
        aws_logical_device_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        site_link_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "ownerAccount",
                .virtual_interface_id = "virtualInterfaceId",
                .location = "location",
                .connection_id = "connectionId",
                .virtual_interface_type = "virtualInterfaceType",
                .virtual_interface_name = "virtualInterfaceName",
                .vlan = "vlan",
                .asn = "asn",
                .amazon_side_asn = "amazonSideAsn",
                .auth_key = "authKey",
                .amazon_address = "amazonAddress",
                .customer_address = "customerAddress",
                .address_family = "addressFamily",
                .virtual_interface_state = "virtualInterfaceState",
                .customer_router_config = "customerRouterConfig",
                .mtu = "mtu",
                .jumbo_frame_capable = "jumboFrameCapable",
                .virtual_gateway_id = "virtualGatewayId",
                .direct_connect_gateway_id = "directConnectGatewayId",
                .route_filter_prefixes = "routeFilterPrefixes",
                .bgp_peers = "bgpPeers",
                .region = "region",
                .aws_device_v2 = "awsDeviceV2",
                .aws_logical_device_id = "awsLogicalDeviceId",
                .tags = "tags",
                .site_link_enabled = "siteLinkEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectConnectClient,
        DirectConnectServer,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const BGPPeer = struct {
    bgp_peer_id: ?[]const u8 = null,
    asn: ?i64 = null,
    auth_key: ?[]const u8 = null,
    address_family: ?[]const u8 = null,
    amazon_address: ?[]const u8 = null,
    customer_address: ?[]const u8 = null,
    bgp_peer_state: ?[]const u8 = null,
    bgp_status: ?[]const u8 = null,
    aws_device_v2: ?[]const u8 = null,
    aws_logical_device_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bgp_peer_id = "bgpPeerId",
            .asn = "asn",
            .auth_key = "authKey",
            .address_family = "addressFamily",
            .amazon_address = "amazonAddress",
            .customer_address = "customerAddress",
            .bgp_peer_state = "bgpPeerState",
            .bgp_status = "bgpStatus",
            .aws_device_v2 = "awsDeviceV2",
            .aws_logical_device_id = "awsLogicalDeviceId",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteFilterPrefix = struct {
    cidr: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
        };
        return @field(mappings, field_name);
    }
};

pub const MacSecKey = struct {
    secret_arn: ?[]const u8 = null,
    ckn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    start_on: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .secret_arn = "secretARN",
            .ckn = "ckn",
            .state = "state",
            .start_on = "startOn",
        };
        return @field(mappings, field_name);
    }
};

pub const Connection = struct {
    owner_account: ?[]const u8 = null,
    connection_id: ?[]const u8 = null,
    connection_name: ?[]const u8 = null,
    connection_state: ?[]const u8 = null,
    region: ?[]const u8 = null,
    location: ?[]const u8 = null,
    bandwidth: ?[]const u8 = null,
    vlan: ?i64 = null,
    partner_name: ?[]const u8 = null,
    loa_issue_time: ?i64 = null,
    lag_id: ?[]const u8 = null,
    aws_device: ?[]const u8 = null,
    jumbo_frame_capable: ?bool = null,
    aws_device_v2: ?[]const u8 = null,
    aws_logical_device_id: ?[]const u8 = null,
    has_logical_redundancy: ?[]const u8 = null,
    tags: ?[]Tag = null,
    provider_name: ?[]const u8 = null,
    mac_sec_capable: ?bool = null,
    port_encryption_status: ?[]const u8 = null,
    encryption_mode: ?[]const u8 = null,
    mac_sec_keys: ?[]MacSecKey = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_account = "ownerAccount",
            .connection_id = "connectionId",
            .connection_name = "connectionName",
            .connection_state = "connectionState",
            .region = "region",
            .location = "location",
            .bandwidth = "bandwidth",
            .vlan = "vlan",
            .partner_name = "partnerName",
            .loa_issue_time = "loaIssueTime",
            .lag_id = "lagId",
            .aws_device = "awsDevice",
            .jumbo_frame_capable = "jumboFrameCapable",
            .aws_device_v2 = "awsDeviceV2",
            .aws_logical_device_id = "awsLogicalDeviceId",
            .has_logical_redundancy = "hasLogicalRedundancy",
            .tags = "tags",
            .provider_name = "providerName",
            .mac_sec_capable = "macSecCapable",
            .port_encryption_status = "portEncryptionStatus",
            .encryption_mode = "encryptionMode",
            .mac_sec_keys = "macSecKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const DirectConnectGatewayAssociation = struct {
    direct_connect_gateway_id: ?[]const u8 = null,
    direct_connect_gateway_owner_account: ?[]const u8 = null,
    association_state: ?[]const u8 = null,
    state_change_error: ?[]const u8 = null,
    associated_gateway: ?AssociatedGateway = null,
    association_id: ?[]const u8 = null,
    allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,
    virtual_gateway_id: ?[]const u8 = null,
    virtual_gateway_region: ?[]const u8 = null,
    virtual_gateway_owner_account: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .direct_connect_gateway_id = "directConnectGatewayId",
            .direct_connect_gateway_owner_account = "directConnectGatewayOwnerAccount",
            .association_state = "associationState",
            .state_change_error = "stateChangeError",
            .associated_gateway = "associatedGateway",
            .association_id = "associationId",
            .allowed_prefixes_to_direct_connect_gateway = "allowedPrefixesToDirectConnectGateway",
            .virtual_gateway_id = "virtualGatewayId",
            .virtual_gateway_region = "virtualGatewayRegion",
            .virtual_gateway_owner_account = "virtualGatewayOwnerAccount",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociatedGateway = struct {
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    owner_account: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .type = "type",
            .owner_account = "ownerAccount",
            .region = "region",
        };
        return @field(mappings, field_name);
    }
};

pub const DirectConnectGateway = struct {
    direct_connect_gateway_id: ?[]const u8 = null,
    direct_connect_gateway_name: ?[]const u8 = null,
    amazon_side_asn: ?i64 = null,
    owner_account: ?[]const u8 = null,
    direct_connect_gateway_state: ?[]const u8 = null,
    state_change_error: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .direct_connect_gateway_id = "directConnectGatewayId",
            .direct_connect_gateway_name = "directConnectGatewayName",
            .amazon_side_asn = "amazonSideAsn",
            .owner_account = "ownerAccount",
            .direct_connect_gateway_state = "directConnectGatewayState",
            .state_change_error = "stateChangeError",
        };
        return @field(mappings, field_name);
    }
};

pub const VirtualInterfaceTestHistory = struct {
    test_id: ?[]const u8 = null,
    virtual_interface_id: ?[]const u8 = null,
    bgp_peers: ?[][]const u8 = null,
    status: ?[]const u8 = null,
    owner_account: ?[]const u8 = null,
    test_duration_in_minutes: ?i64 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .test_id = "testId",
            .virtual_interface_id = "virtualInterfaceId",
            .bgp_peers = "bgpPeers",
            .status = "status",
            .owner_account = "ownerAccount",
            .test_duration_in_minutes = "testDurationInMinutes",
            .start_time = "startTime",
            .end_time = "endTime",
        };
        return @field(mappings, field_name);
    }
};

pub const VirtualInterface = struct {
    owner_account: ?[]const u8 = null,
    virtual_interface_id: ?[]const u8 = null,
    location: ?[]const u8 = null,
    connection_id: ?[]const u8 = null,
    virtual_interface_type: ?[]const u8 = null,
    virtual_interface_name: ?[]const u8 = null,
    vlan: ?i64 = null,
    asn: ?i64 = null,
    amazon_side_asn: ?i64 = null,
    auth_key: ?[]const u8 = null,
    amazon_address: ?[]const u8 = null,
    customer_address: ?[]const u8 = null,
    address_family: ?[]const u8 = null,
    virtual_interface_state: ?[]const u8 = null,
    customer_router_config: ?[]const u8 = null,
    mtu: ?i64 = null,
    jumbo_frame_capable: ?bool = null,
    virtual_gateway_id: ?[]const u8 = null,
    direct_connect_gateway_id: ?[]const u8 = null,
    route_filter_prefixes: ?[]RouteFilterPrefix = null,
    bgp_peers: ?[]BGPPeer = null,
    region: ?[]const u8 = null,
    aws_device_v2: ?[]const u8 = null,
    aws_logical_device_id: ?[]const u8 = null,
    tags: ?[]Tag = null,
    site_link_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_account = "ownerAccount",
            .virtual_interface_id = "virtualInterfaceId",
            .location = "location",
            .connection_id = "connectionId",
            .virtual_interface_type = "virtualInterfaceType",
            .virtual_interface_name = "virtualInterfaceName",
            .vlan = "vlan",
            .asn = "asn",
            .amazon_side_asn = "amazonSideAsn",
            .auth_key = "authKey",
            .amazon_address = "amazonAddress",
            .customer_address = "customerAddress",
            .address_family = "addressFamily",
            .virtual_interface_state = "virtualInterfaceState",
            .customer_router_config = "customerRouterConfig",
            .mtu = "mtu",
            .jumbo_frame_capable = "jumboFrameCapable",
            .virtual_gateway_id = "virtualGatewayId",
            .direct_connect_gateway_id = "directConnectGatewayId",
            .route_filter_prefixes = "routeFilterPrefixes",
            .bgp_peers = "bgpPeers",
            .region = "region",
            .aws_device_v2 = "awsDeviceV2",
            .aws_logical_device_id = "awsLogicalDeviceId",
            .tags = "tags",
            .site_link_enabled = "siteLinkEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Lag = struct {
    connections_bandwidth: ?[]const u8 = null,
    number_of_connections: ?i64 = null,
    lag_id: ?[]const u8 = null,
    owner_account: ?[]const u8 = null,
    lag_name: ?[]const u8 = null,
    lag_state: ?[]const u8 = null,
    location: ?[]const u8 = null,
    region: ?[]const u8 = null,
    minimum_links: ?i64 = null,
    aws_device: ?[]const u8 = null,
    aws_device_v2: ?[]const u8 = null,
    aws_logical_device_id: ?[]const u8 = null,
    connections: ?[]Connection = null,
    allows_hosted_connections: ?bool = null,
    jumbo_frame_capable: ?bool = null,
    has_logical_redundancy: ?[]const u8 = null,
    tags: ?[]Tag = null,
    provider_name: ?[]const u8 = null,
    mac_sec_capable: ?bool = null,
    encryption_mode: ?[]const u8 = null,
    mac_sec_keys: ?[]MacSecKey = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connections_bandwidth = "connectionsBandwidth",
            .number_of_connections = "numberOfConnections",
            .lag_id = "lagId",
            .owner_account = "ownerAccount",
            .lag_name = "lagName",
            .lag_state = "lagState",
            .location = "location",
            .region = "region",
            .minimum_links = "minimumLinks",
            .aws_device = "awsDevice",
            .aws_device_v2 = "awsDeviceV2",
            .aws_logical_device_id = "awsLogicalDeviceId",
            .connections = "connections",
            .allows_hosted_connections = "allowsHostedConnections",
            .jumbo_frame_capable = "jumboFrameCapable",
            .has_logical_redundancy = "hasLogicalRedundancy",
            .tags = "tags",
            .provider_name = "providerName",
            .mac_sec_capable = "macSecCapable",
            .encryption_mode = "encryptionMode",
            .mac_sec_keys = "macSecKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const Interconnect = struct {
    interconnect_id: ?[]const u8 = null,
    interconnect_name: ?[]const u8 = null,
    interconnect_state: ?[]const u8 = null,
    region: ?[]const u8 = null,
    location: ?[]const u8 = null,
    bandwidth: ?[]const u8 = null,
    loa_issue_time: ?i64 = null,
    lag_id: ?[]const u8 = null,
    aws_device: ?[]const u8 = null,
    jumbo_frame_capable: ?bool = null,
    aws_device_v2: ?[]const u8 = null,
    aws_logical_device_id: ?[]const u8 = null,
    has_logical_redundancy: ?[]const u8 = null,
    tags: ?[]Tag = null,
    provider_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interconnect_id = "interconnectId",
            .interconnect_name = "interconnectName",
            .interconnect_state = "interconnectState",
            .region = "region",
            .location = "location",
            .bandwidth = "bandwidth",
            .loa_issue_time = "loaIssueTime",
            .lag_id = "lagId",
            .aws_device = "awsDevice",
            .jumbo_frame_capable = "jumboFrameCapable",
            .aws_device_v2 = "awsDeviceV2",
            .aws_logical_device_id = "awsLogicalDeviceId",
            .has_logical_redundancy = "hasLogicalRedundancy",
            .tags = "tags",
            .provider_name = "providerName",
        };
        return @field(mappings, field_name);
    }
};

pub const Loa = struct {
    loa_content: ?[]const u8 = null,
    loa_content_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .loa_content = "loaContent",
            .loa_content_type = "loaContentType",
        };
        return @field(mappings, field_name);
    }
};

pub const DirectConnectGatewayAssociationProposal = struct {
    proposal_id: ?[]const u8 = null,
    direct_connect_gateway_id: ?[]const u8 = null,
    direct_connect_gateway_owner_account: ?[]const u8 = null,
    proposal_state: ?[]const u8 = null,
    associated_gateway: ?AssociatedGateway = null,
    existing_allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,
    requested_allowed_prefixes_to_direct_connect_gateway: ?[]RouteFilterPrefix = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .proposal_id = "proposalId",
            .direct_connect_gateway_id = "directConnectGatewayId",
            .direct_connect_gateway_owner_account = "directConnectGatewayOwnerAccount",
            .proposal_state = "proposalState",
            .associated_gateway = "associatedGateway",
            .existing_allowed_prefixes_to_direct_connect_gateway = "existingAllowedPrefixesToDirectConnectGateway",
            .requested_allowed_prefixes_to_direct_connect_gateway = "requestedAllowedPrefixesToDirectConnectGateway",
        };
        return @field(mappings, field_name);
    }
};
