const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-04-16";
pub const sdk_id: []const u8 = "Directory Service";
pub const arn_namespace: ?[]const u8 = "ds";
pub const endpoint_prefix: []const u8 = "ds";
pub const sigv4_name: []const u8 = "ds";
pub const name: []const u8 = "DirectoryService_20150416";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-04-16",
    sdk_id: []const u8 = "Directory Service",
    arn_namespace: ?[]const u8 = "ds",
    endpoint_prefix: []const u8 = "ds",
    sigv4_name: []const u8 = "ds",
    name: []const u8 = "DirectoryService_20150416",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const accept_shared_directory: struct {
    action_name: []const u8 = "AcceptSharedDirectory",
    Request: type = struct {
        shared_directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shared_directory_id = "SharedDirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_shared_directory) } {
            return .{ .service_metadata = service_metadata, .action = accept_shared_directory };
        }
    },
    Response: type = struct {
        shared_directory: ?SharedDirectory = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shared_directory = "SharedDirectory",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryAlreadyShared,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const add_ip_routes: struct {
    action_name: []const u8 = "AddIpRoutes",
    Request: type = struct {
        directory_id: []const u8,
        ip_routes: []struct {
            cidr_ip: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cidr_ip = "CidrIp",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        },
        update_security_group_for_directory_controllers: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .ip_routes = "IpRoutes",
                .update_security_group_for_directory_controllers = "UpdateSecurityGroupForDirectoryControllers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_ip_routes) } {
            return .{ .service_metadata = service_metadata, .action = add_ip_routes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        EntityAlreadyExists,
        EntityDoesNotExist,
        InvalidParameter,
        IpRouteLimitExceeded,
        Service,
    },
} = .{};
pub const add_region: struct {
    action_name: []const u8 = "AddRegion",
    Request: type = struct {
        directory_id: []const u8,
        region_name: []const u8,
        vpc_settings: DirectoryVpcSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .region_name = "RegionName",
                .vpc_settings = "VPCSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_region) } {
            return .{ .service_metadata = service_metadata, .action = add_region };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryAlreadyInRegion,
        DirectoryDoesNotExist,
        DirectoryUnavailable,
        EntityDoesNotExist,
        InvalidParameter,
        RegionLimitExceeded,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        TagLimitExceeded,
    },
} = .{};
pub const cancel_schema_extension: struct {
    action_name: []const u8 = "CancelSchemaExtension",
    Request: type = struct {
        directory_id: []const u8,
        schema_extension_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .schema_extension_id = "SchemaExtensionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_schema_extension) } {
            return .{ .service_metadata = service_metadata, .action = cancel_schema_extension };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        Service,
    },
} = .{};
pub const connect_directory: struct {
    action_name: []const u8 = "ConnectDirectory",
    Request: type = struct {
        name: []const u8,
        short_name: ?[]const u8 = null,
        password: []const u8,
        description: ?[]const u8 = null,
        size: []const u8,
        connect_settings: struct {
            vpc_id: []const u8,
            subnet_ids: [][]const u8,
            customer_dns_ips: [][]const u8,
            customer_user_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpc_id = "VpcId",
                    .subnet_ids = "SubnetIds",
                    .customer_dns_ips = "CustomerDnsIps",
                    .customer_user_name = "CustomerUserName",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .short_name = "ShortName",
                .password = "Password",
                .description = "Description",
                .size = "Size",
                .connect_settings = "ConnectSettings",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(connect_directory) } {
            return .{ .service_metadata = service_metadata, .action = connect_directory };
        }
    },
    Response: type = struct {
        directory_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryLimitExceeded,
        InvalidParameter,
        Service,
    },
} = .{};
pub const create_alias: struct {
    action_name: []const u8 = "CreateAlias",
    Request: type = struct {
        directory_id: []const u8,
        alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_alias };
        }
    },
    Response: type = struct {
        directory_id: ?[]const u8 = null,
        alias: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityAlreadyExists,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const create_computer: struct {
    action_name: []const u8 = "CreateComputer",
    Request: type = struct {
        directory_id: []const u8,
        computer_name: []const u8,
        password: []const u8,
        organizational_unit_distinguished_name: ?[]const u8 = null,
        computer_attributes: ?[]Attribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .computer_name = "ComputerName",
                .password = "Password",
                .organizational_unit_distinguished_name = "OrganizationalUnitDistinguishedName",
                .computer_attributes = "ComputerAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_computer) } {
            return .{ .service_metadata = service_metadata, .action = create_computer };
        }
    },
    Response: type = struct {
        computer: ?struct {
            computer_id: ?[]const u8 = null,
            computer_name: ?[]const u8 = null,
            computer_attributes: ?[]Attribute = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .computer_id = "ComputerId",
                    .computer_name = "ComputerName",
                    .computer_attributes = "ComputerAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .computer = "Computer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthenticationFailed,
        Client,
        DirectoryUnavailable,
        EntityAlreadyExists,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const create_conditional_forwarder: struct {
    action_name: []const u8 = "CreateConditionalForwarder",
    Request: type = struct {
        directory_id: []const u8,
        remote_domain_name: []const u8,
        dns_ip_addrs: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .remote_domain_name = "RemoteDomainName",
                .dns_ip_addrs = "DnsIpAddrs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_conditional_forwarder) } {
            return .{ .service_metadata = service_metadata, .action = create_conditional_forwarder };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        EntityAlreadyExists,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const create_directory: struct {
    action_name: []const u8 = "CreateDirectory",
    Request: type = struct {
        name: []const u8,
        short_name: ?[]const u8 = null,
        password: []const u8,
        description: ?[]const u8 = null,
        size: []const u8,
        vpc_settings: ?DirectoryVpcSettings = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .short_name = "ShortName",
                .password = "Password",
                .description = "Description",
                .size = "Size",
                .vpc_settings = "VpcSettings",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_directory) } {
            return .{ .service_metadata = service_metadata, .action = create_directory };
        }
    },
    Response: type = struct {
        directory_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryLimitExceeded,
        InvalidParameter,
        Service,
    },
} = .{};
pub const create_log_subscription: struct {
    action_name: []const u8 = "CreateLogSubscription",
    Request: type = struct {
        directory_id: []const u8,
        log_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .log_group_name = "LogGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_log_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_log_subscription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityAlreadyExists,
        EntityDoesNotExist,
        InsufficientPermissions,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const create_microsoft_ad: struct {
    action_name: []const u8 = "CreateMicrosoftAD",
    Request: type = struct {
        name: []const u8,
        short_name: ?[]const u8 = null,
        password: []const u8,
        description: ?[]const u8 = null,
        vpc_settings: DirectoryVpcSettings,
        edition: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .short_name = "ShortName",
                .password = "Password",
                .description = "Description",
                .vpc_settings = "VpcSettings",
                .edition = "Edition",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_microsoft_ad) } {
            return .{ .service_metadata = service_metadata, .action = create_microsoft_ad };
        }
    },
    Response: type = struct {
        directory_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryLimitExceeded,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const create_snapshot: struct {
    action_name: []const u8 = "CreateSnapshot",
    Request: type = struct {
        directory_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        SnapshotLimitExceeded,
    },
} = .{};
pub const create_trust: struct {
    action_name: []const u8 = "CreateTrust",
    Request: type = struct {
        directory_id: []const u8,
        remote_domain_name: []const u8,
        trust_password: []const u8,
        trust_direction: []const u8,
        trust_type: ?[]const u8 = null,
        conditional_forwarder_ip_addrs: ?[][]const u8 = null,
        selective_auth: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .remote_domain_name = "RemoteDomainName",
                .trust_password = "TrustPassword",
                .trust_direction = "TrustDirection",
                .trust_type = "TrustType",
                .conditional_forwarder_ip_addrs = "ConditionalForwarderIpAddrs",
                .selective_auth = "SelectiveAuth",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trust) } {
            return .{ .service_metadata = service_metadata, .action = create_trust };
        }
    },
    Response: type = struct {
        trust_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_id = "TrustId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityAlreadyExists,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const delete_conditional_forwarder: struct {
    action_name: []const u8 = "DeleteConditionalForwarder",
    Request: type = struct {
        directory_id: []const u8,
        remote_domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .remote_domain_name = "RemoteDomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_conditional_forwarder) } {
            return .{ .service_metadata = service_metadata, .action = delete_conditional_forwarder };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const delete_directory: struct {
    action_name: []const u8 = "DeleteDirectory",
    Request: type = struct {
        directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_directory) } {
            return .{ .service_metadata = service_metadata, .action = delete_directory };
        }
    },
    Response: type = struct {
        directory_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        Service,
    },
} = .{};
pub const delete_log_subscription: struct {
    action_name: []const u8 = "DeleteLogSubscription",
    Request: type = struct {
        directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_log_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_log_subscription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const delete_snapshot: struct {
    action_name: []const u8 = "DeleteSnapshot",
    Request: type = struct {
        snapshot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_snapshot };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const delete_trust: struct {
    action_name: []const u8 = "DeleteTrust",
    Request: type = struct {
        trust_id: []const u8,
        delete_associated_conditional_forwarder: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_id = "TrustId",
                .delete_associated_conditional_forwarder = "DeleteAssociatedConditionalForwarder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trust) } {
            return .{ .service_metadata = service_metadata, .action = delete_trust };
        }
    },
    Response: type = struct {
        trust_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_id = "TrustId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const deregister_certificate: struct {
    action_name: []const u8 = "DeregisterCertificate",
    Request: type = struct {
        directory_id: []const u8,
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .certificate_id = "CertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_certificate) } {
            return .{ .service_metadata = service_metadata, .action = deregister_certificate };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateDoesNotExist,
        CertificateInUse,
        Client,
        DirectoryDoesNotExist,
        DirectoryUnavailable,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const deregister_event_topic: struct {
    action_name: []const u8 = "DeregisterEventTopic",
    Request: type = struct {
        directory_id: []const u8,
        topic_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .topic_name = "TopicName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_event_topic) } {
            return .{ .service_metadata = service_metadata, .action = deregister_event_topic };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const describe_certificate: struct {
    action_name: []const u8 = "DescribeCertificate",
    Request: type = struct {
        directory_id: []const u8,
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .certificate_id = "CertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificate) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificate };
        }
    },
    Response: type = struct {
        certificate: ?struct {
            certificate_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            state_reason: ?[]const u8 = null,
            common_name: ?[]const u8 = null,
            registered_date_time: ?i64 = null,
            expiry_date_time: ?i64 = null,
            type: ?[]const u8 = null,
            client_cert_auth_settings: ?ClientCertAuthSettings = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_id = "CertificateId",
                    .state = "State",
                    .state_reason = "StateReason",
                    .common_name = "CommonName",
                    .registered_date_time = "RegisteredDateTime",
                    .expiry_date_time = "ExpiryDateTime",
                    .type = "Type",
                    .client_cert_auth_settings = "ClientCertAuthSettings",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateDoesNotExist,
        Client,
        DirectoryDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_client_authentication_settings: struct {
    action_name: []const u8 = "DescribeClientAuthenticationSettings",
    Request: type = struct {
        directory_id: []const u8,
        type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .type = "Type",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_authentication_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_authentication_settings };
        }
    },
    Response: type = struct {
        client_authentication_settings_info: ?[]struct {
            type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .status = "Status",
                    .last_updated_date_time = "LastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_authentication_settings_info = "ClientAuthenticationSettingsInfo",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_conditional_forwarders: struct {
    action_name: []const u8 = "DescribeConditionalForwarders",
    Request: type = struct {
        directory_id: []const u8,
        remote_domain_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .remote_domain_names = "RemoteDomainNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_conditional_forwarders) } {
            return .{ .service_metadata = service_metadata, .action = describe_conditional_forwarders };
        }
    },
    Response: type = struct {
        conditional_forwarders: ?[]struct {
            remote_domain_name: ?[]const u8 = null,
            dns_ip_addrs: ?[][]const u8 = null,
            replication_scope: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .remote_domain_name = "RemoteDomainName",
                    .dns_ip_addrs = "DnsIpAddrs",
                    .replication_scope = "ReplicationScope",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conditional_forwarders = "ConditionalForwarders",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_directories: struct {
    action_name: []const u8 = "DescribeDirectories",
    Request: type = struct {
        directory_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_ids = "DirectoryIds",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_directories) } {
            return .{ .service_metadata = service_metadata, .action = describe_directories };
        }
    },
    Response: type = struct {
        directory_descriptions: ?[]struct {
            directory_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            short_name: ?[]const u8 = null,
            size: ?[]const u8 = null,
            edition: ?[]const u8 = null,
            alias: ?[]const u8 = null,
            access_url: ?[]const u8 = null,
            description: ?[]const u8 = null,
            dns_ip_addrs: ?[][]const u8 = null,
            stage: ?[]const u8 = null,
            share_status: ?[]const u8 = null,
            share_method: ?[]const u8 = null,
            share_notes: ?[]const u8 = null,
            launch_time: ?i64 = null,
            stage_last_updated_date_time: ?i64 = null,
            type: ?[]const u8 = null,
            vpc_settings: ?DirectoryVpcSettingsDescription = null,
            connect_settings: ?struct {
                vpc_id: ?[]const u8 = null,
                subnet_ids: ?[][]const u8 = null,
                customer_user_name: ?[]const u8 = null,
                security_group_id: ?[]const u8 = null,
                availability_zones: ?[][]const u8 = null,
                connect_ips: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .vpc_id = "VpcId",
                        .subnet_ids = "SubnetIds",
                        .customer_user_name = "CustomerUserName",
                        .security_group_id = "SecurityGroupId",
                        .availability_zones = "AvailabilityZones",
                        .connect_ips = "ConnectIps",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            radius_settings: ?RadiusSettings = null,
            radius_status: ?[]const u8 = null,
            stage_reason: ?[]const u8 = null,
            sso_enabled: ?bool = null,
            desired_number_of_domain_controllers: ?i64 = null,
            owner_directory_description: ?struct {
                directory_id: ?[]const u8 = null,
                account_id: ?[]const u8 = null,
                dns_ip_addrs: ?[][]const u8 = null,
                vpc_settings: ?DirectoryVpcSettingsDescription = null,
                radius_settings: ?RadiusSettings = null,
                radius_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .directory_id = "DirectoryId",
                        .account_id = "AccountId",
                        .dns_ip_addrs = "DnsIpAddrs",
                        .vpc_settings = "VpcSettings",
                        .radius_settings = "RadiusSettings",
                        .radius_status = "RadiusStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            regions_info: ?struct {
                primary_region: ?[]const u8 = null,
                additional_regions: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .primary_region = "PrimaryRegion",
                        .additional_regions = "AdditionalRegions",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            os_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .name = "Name",
                    .short_name = "ShortName",
                    .size = "Size",
                    .edition = "Edition",
                    .alias = "Alias",
                    .access_url = "AccessUrl",
                    .description = "Description",
                    .dns_ip_addrs = "DnsIpAddrs",
                    .stage = "Stage",
                    .share_status = "ShareStatus",
                    .share_method = "ShareMethod",
                    .share_notes = "ShareNotes",
                    .launch_time = "LaunchTime",
                    .stage_last_updated_date_time = "StageLastUpdatedDateTime",
                    .type = "Type",
                    .vpc_settings = "VpcSettings",
                    .connect_settings = "ConnectSettings",
                    .radius_settings = "RadiusSettings",
                    .radius_status = "RadiusStatus",
                    .stage_reason = "StageReason",
                    .sso_enabled = "SsoEnabled",
                    .desired_number_of_domain_controllers = "DesiredNumberOfDomainControllers",
                    .owner_directory_description = "OwnerDirectoryDescription",
                    .regions_info = "RegionsInfo",
                    .os_version = "OsVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_descriptions = "DirectoryDescriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
    },
} = .{};
pub const describe_domain_controllers: struct {
    action_name: []const u8 = "DescribeDomainControllers",
    Request: type = struct {
        directory_id: []const u8,
        domain_controller_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .domain_controller_ids = "DomainControllerIds",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_controllers) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_controllers };
        }
    },
    Response: type = struct {
        domain_controllers: ?[]struct {
            directory_id: ?[]const u8 = null,
            domain_controller_id: ?[]const u8 = null,
            dns_ip_addr: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            subnet_id: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            launch_time: ?i64 = null,
            status_last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .domain_controller_id = "DomainControllerId",
                    .dns_ip_addr = "DnsIpAddr",
                    .vpc_id = "VpcId",
                    .subnet_id = "SubnetId",
                    .availability_zone = "AvailabilityZone",
                    .status = "Status",
                    .status_reason = "StatusReason",
                    .launch_time = "LaunchTime",
                    .status_last_updated_date_time = "StatusLastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_controllers = "DomainControllers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_event_topics: struct {
    action_name: []const u8 = "DescribeEventTopics",
    Request: type = struct {
        directory_id: ?[]const u8 = null,
        topic_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .topic_names = "TopicNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_topics) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_topics };
        }
    },
    Response: type = struct {
        event_topics: ?[]struct {
            directory_id: ?[]const u8 = null,
            topic_name: ?[]const u8 = null,
            topic_arn: ?[]const u8 = null,
            created_date_time: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .topic_name = "TopicName",
                    .topic_arn = "TopicArn",
                    .created_date_time = "CreatedDateTime",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_topics = "EventTopics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const describe_ldaps_settings: struct {
    action_name: []const u8 = "DescribeLDAPSSettings",
    Request: type = struct {
        directory_id: []const u8,
        type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .type = "Type",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ldaps_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_ldaps_settings };
        }
    },
    Response: type = struct {
        ldaps_settings_info: ?[]struct {
            ldaps_status: ?[]const u8 = null,
            ldaps_status_reason: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ldaps_status = "LDAPSStatus",
                    .ldaps_status_reason = "LDAPSStatusReason",
                    .last_updated_date_time = "LastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ldaps_settings_info = "LDAPSSettingsInfo",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_regions: struct {
    action_name: []const u8 = "DescribeRegions",
    Request: type = struct {
        directory_id: []const u8,
        region_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .region_name = "RegionName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_regions) } {
            return .{ .service_metadata = service_metadata, .action = describe_regions };
        }
    },
    Response: type = struct {
        regions_description: ?[]struct {
            directory_id: ?[]const u8 = null,
            region_name: ?[]const u8 = null,
            region_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            vpc_settings: ?DirectoryVpcSettings = null,
            desired_number_of_domain_controllers: ?i64 = null,
            launch_time: ?i64 = null,
            status_last_updated_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .region_name = "RegionName",
                    .region_type = "RegionType",
                    .status = "Status",
                    .vpc_settings = "VpcSettings",
                    .desired_number_of_domain_controllers = "DesiredNumberOfDomainControllers",
                    .launch_time = "LaunchTime",
                    .status_last_updated_date_time = "StatusLastUpdatedDateTime",
                    .last_updated_date_time = "LastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regions_description = "RegionsDescription",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_settings: struct {
    action_name: []const u8 = "DescribeSettings",
    Request: type = struct {
        directory_id: []const u8,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .status = "Status",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_settings };
        }
    },
    Response: type = struct {
        directory_id: ?[]const u8 = null,
        setting_entries: ?[]struct {
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            allowed_values: ?[]const u8 = null,
            applied_value: ?[]const u8 = null,
            requested_value: ?[]const u8 = null,
            request_status: ?[]const u8 = null,
            request_detailed_status: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            request_status_message: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,
            last_requested_date_time: ?i64 = null,
            data_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .name = "Name",
                    .allowed_values = "AllowedValues",
                    .applied_value = "AppliedValue",
                    .requested_value = "RequestedValue",
                    .request_status = "RequestStatus",
                    .request_detailed_status = "RequestDetailedStatus",
                    .request_status_message = "RequestStatusMessage",
                    .last_updated_date_time = "LastUpdatedDateTime",
                    .last_requested_date_time = "LastRequestedDateTime",
                    .data_type = "DataType",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "request_detailed_status", field_name))
                    return try serializeMap(self.request_detailed_status, self.fieldNameFor("request_detailed_status"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .setting_entries = "SettingEntries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_shared_directories: struct {
    action_name: []const u8 = "DescribeSharedDirectories",
    Request: type = struct {
        owner_directory_id: []const u8,
        shared_directory_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_directory_id = "OwnerDirectoryId",
                .shared_directory_ids = "SharedDirectoryIds",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_shared_directories) } {
            return .{ .service_metadata = service_metadata, .action = describe_shared_directories };
        }
    },
    Response: type = struct {
        shared_directories: ?[]SharedDirectory = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shared_directories = "SharedDirectories",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_snapshots: struct {
    action_name: []const u8 = "DescribeSnapshots",
    Request: type = struct {
        directory_id: ?[]const u8 = null,
        snapshot_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .snapshot_ids = "SnapshotIds",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshots };
        }
    },
    Response: type = struct {
        snapshots: ?[]struct {
            directory_id: ?[]const u8 = null,
            snapshot_id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            start_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .snapshot_id = "SnapshotId",
                    .type = "Type",
                    .name = "Name",
                    .status = "Status",
                    .start_time = "StartTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshots = "Snapshots",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
    },
} = .{};
pub const describe_trusts: struct {
    action_name: []const u8 = "DescribeTrusts",
    Request: type = struct {
        directory_id: ?[]const u8 = null,
        trust_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .trust_ids = "TrustIds",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trusts) } {
            return .{ .service_metadata = service_metadata, .action = describe_trusts };
        }
    },
    Response: type = struct {
        trusts: ?[]struct {
            directory_id: ?[]const u8 = null,
            trust_id: ?[]const u8 = null,
            remote_domain_name: ?[]const u8 = null,
            trust_type: ?[]const u8 = null,
            trust_direction: ?[]const u8 = null,
            trust_state: ?[]const u8 = null,
            created_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            state_last_updated_date_time: ?i64 = null,
            trust_state_reason: ?[]const u8 = null,
            selective_auth: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .trust_id = "TrustId",
                    .remote_domain_name = "RemoteDomainName",
                    .trust_type = "TrustType",
                    .trust_direction = "TrustDirection",
                    .trust_state = "TrustState",
                    .created_date_time = "CreatedDateTime",
                    .last_updated_date_time = "LastUpdatedDateTime",
                    .state_last_updated_date_time = "StateLastUpdatedDateTime",
                    .trust_state_reason = "TrustStateReason",
                    .selective_auth = "SelectiveAuth",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trusts = "Trusts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const describe_update_directory: struct {
    action_name: []const u8 = "DescribeUpdateDirectory",
    Request: type = struct {
        directory_id: []const u8,
        update_type: []const u8,
        region_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .update_type = "UpdateType",
                .region_name = "RegionName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_update_directory) } {
            return .{ .service_metadata = service_metadata, .action = describe_update_directory };
        }
    },
    Response: type = struct {
        update_activities: ?[]struct {
            region: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            initiated_by: ?[]const u8 = null,
            new_value: ?UpdateValue = null,
            previous_value: ?UpdateValue = null,
            start_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "Region",
                    .status = "Status",
                    .status_reason = "StatusReason",
                    .initiated_by = "InitiatedBy",
                    .new_value = "NewValue",
                    .previous_value = "PreviousValue",
                    .start_time = "StartTime",
                    .last_updated_date_time = "LastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_activities = "UpdateActivities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
    },
} = .{};
pub const disable_client_authentication: struct {
    action_name: []const u8 = "DisableClientAuthentication",
    Request: type = struct {
        directory_id: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_client_authentication) } {
            return .{ .service_metadata = service_metadata, .action = disable_client_authentication };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryDoesNotExist,
        InvalidClientAuthStatus,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const disable_ldaps: struct {
    action_name: []const u8 = "DisableLDAPS",
    Request: type = struct {
        directory_id: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_ldaps) } {
            return .{ .service_metadata = service_metadata, .action = disable_ldaps };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryDoesNotExist,
        DirectoryUnavailable,
        InvalidLDAPSStatus,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const disable_radius: struct {
    action_name: []const u8 = "DisableRadius",
    Request: type = struct {
        directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_radius) } {
            return .{ .service_metadata = service_metadata, .action = disable_radius };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        Service,
    },
} = .{};
pub const disable_sso: struct {
    action_name: []const u8 = "DisableSso",
    Request: type = struct {
        directory_id: []const u8,
        user_name: ?[]const u8 = null,
        password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .user_name = "UserName",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_sso) } {
            return .{ .service_metadata = service_metadata, .action = disable_sso };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthenticationFailed,
        Client,
        EntityDoesNotExist,
        InsufficientPermissions,
        Service,
    },
} = .{};
pub const enable_client_authentication: struct {
    action_name: []const u8 = "EnableClientAuthentication",
    Request: type = struct {
        directory_id: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_client_authentication) } {
            return .{ .service_metadata = service_metadata, .action = enable_client_authentication };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryDoesNotExist,
        InvalidClientAuthStatus,
        NoAvailableCertificate,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const enable_ldaps: struct {
    action_name: []const u8 = "EnableLDAPS",
    Request: type = struct {
        directory_id: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_ldaps) } {
            return .{ .service_metadata = service_metadata, .action = enable_ldaps };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryDoesNotExist,
        DirectoryUnavailable,
        InvalidLDAPSStatus,
        InvalidParameter,
        NoAvailableCertificate,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const enable_radius: struct {
    action_name: []const u8 = "EnableRadius",
    Request: type = struct {
        directory_id: []const u8,
        radius_settings: RadiusSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .radius_settings = "RadiusSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_radius) } {
            return .{ .service_metadata = service_metadata, .action = enable_radius };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityAlreadyExists,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const enable_sso: struct {
    action_name: []const u8 = "EnableSso",
    Request: type = struct {
        directory_id: []const u8,
        user_name: ?[]const u8 = null,
        password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .user_name = "UserName",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_sso) } {
            return .{ .service_metadata = service_metadata, .action = enable_sso };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthenticationFailed,
        Client,
        EntityDoesNotExist,
        InsufficientPermissions,
        Service,
    },
} = .{};
pub const get_directory_limits: struct {
    action_name: []const u8 = "GetDirectoryLimits",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_directory_limits) } {
            return .{ .service_metadata = service_metadata, .action = get_directory_limits };
        }
    },
    Response: type = struct {
        directory_limits: ?struct {
            cloud_only_directories_limit: ?i64 = null,
            cloud_only_directories_current_count: ?i64 = null,
            cloud_only_directories_limit_reached: ?bool = null,
            cloud_only_microsoft_ad_limit: ?i64 = null,
            cloud_only_microsoft_ad_current_count: ?i64 = null,
            cloud_only_microsoft_ad_limit_reached: ?bool = null,
            connected_directories_limit: ?i64 = null,
            connected_directories_current_count: ?i64 = null,
            connected_directories_limit_reached: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cloud_only_directories_limit = "CloudOnlyDirectoriesLimit",
                    .cloud_only_directories_current_count = "CloudOnlyDirectoriesCurrentCount",
                    .cloud_only_directories_limit_reached = "CloudOnlyDirectoriesLimitReached",
                    .cloud_only_microsoft_ad_limit = "CloudOnlyMicrosoftADLimit",
                    .cloud_only_microsoft_ad_current_count = "CloudOnlyMicrosoftADCurrentCount",
                    .cloud_only_microsoft_ad_limit_reached = "CloudOnlyMicrosoftADLimitReached",
                    .connected_directories_limit = "ConnectedDirectoriesLimit",
                    .connected_directories_current_count = "ConnectedDirectoriesCurrentCount",
                    .connected_directories_limit_reached = "ConnectedDirectoriesLimitReached",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_limits = "DirectoryLimits",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        Service,
    },
} = .{};
pub const get_snapshot_limits: struct {
    action_name: []const u8 = "GetSnapshotLimits",
    Request: type = struct {
        directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_snapshot_limits) } {
            return .{ .service_metadata = service_metadata, .action = get_snapshot_limits };
        }
    },
    Response: type = struct {
        snapshot_limits: ?struct {
            manual_snapshots_limit: ?i64 = null,
            manual_snapshots_current_count: ?i64 = null,
            manual_snapshots_limit_reached: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .manual_snapshots_limit = "ManualSnapshotsLimit",
                    .manual_snapshots_current_count = "ManualSnapshotsCurrentCount",
                    .manual_snapshots_limit_reached = "ManualSnapshotsLimitReached",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_limits = "SnapshotLimits",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        Service,
    },
} = .{};
pub const list_certificates: struct {
    action_name: []const u8 = "ListCertificates",
    Request: type = struct {
        directory_id: []const u8,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_certificates) } {
            return .{ .service_metadata = service_metadata, .action = list_certificates };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        certificates_info: ?[]struct {
            certificate_id: ?[]const u8 = null,
            common_name: ?[]const u8 = null,
            state: ?[]const u8 = null,
            expiry_date_time: ?i64 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_id = "CertificateId",
                    .common_name = "CommonName",
                    .state = "State",
                    .expiry_date_time = "ExpiryDateTime",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .certificates_info = "CertificatesInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const list_ip_routes: struct {
    action_name: []const u8 = "ListIpRoutes",
    Request: type = struct {
        directory_id: []const u8,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ip_routes) } {
            return .{ .service_metadata = service_metadata, .action = list_ip_routes };
        }
    },
    Response: type = struct {
        ip_routes_info: ?[]struct {
            directory_id: ?[]const u8 = null,
            cidr_ip: ?[]const u8 = null,
            ip_route_status_msg: ?[]const u8 = null,
            added_date_time: ?i64 = null,
            ip_route_status_reason: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .cidr_ip = "CidrIp",
                    .ip_route_status_msg = "IpRouteStatusMsg",
                    .added_date_time = "AddedDateTime",
                    .ip_route_status_reason = "IpRouteStatusReason",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_routes_info = "IpRoutesInfo",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
    },
} = .{};
pub const list_log_subscriptions: struct {
    action_name: []const u8 = "ListLogSubscriptions",
    Request: type = struct {
        directory_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_log_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = list_log_subscriptions };
        }
    },
    Response: type = struct {
        log_subscriptions: ?[]struct {
            directory_id: ?[]const u8 = null,
            log_group_name: ?[]const u8 = null,
            subscription_created_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .log_group_name = "LogGroupName",
                    .subscription_created_date_time = "SubscriptionCreatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_subscriptions = "LogSubscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        Service,
    },
} = .{};
pub const list_schema_extensions: struct {
    action_name: []const u8 = "ListSchemaExtensions",
    Request: type = struct {
        directory_id: []const u8,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schema_extensions) } {
            return .{ .service_metadata = service_metadata, .action = list_schema_extensions };
        }
    },
    Response: type = struct {
        schema_extensions_info: ?[]struct {
            directory_id: ?[]const u8 = null,
            schema_extension_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            schema_extension_status: ?[]const u8 = null,
            schema_extension_status_reason: ?[]const u8 = null,
            start_date_time: ?i64 = null,
            end_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .schema_extension_id = "SchemaExtensionId",
                    .description = "Description",
                    .schema_extension_status = "SchemaExtensionStatus",
                    .schema_extension_status_reason = "SchemaExtensionStatusReason",
                    .start_date_time = "StartDateTime",
                    .end_date_time = "EndDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_extensions_info = "SchemaExtensionsInfo",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        Service,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_id: []const u8,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidNextToken,
        InvalidParameter,
        Service,
    },
} = .{};
pub const register_certificate: struct {
    action_name: []const u8 = "RegisterCertificate",
    Request: type = struct {
        directory_id: []const u8,
        certificate_data: []const u8,
        type: ?[]const u8 = null,
        client_cert_auth_settings: ?ClientCertAuthSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .certificate_data = "CertificateData",
                .type = "Type",
                .client_cert_auth_settings = "ClientCertAuthSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_certificate) } {
            return .{ .service_metadata = service_metadata, .action = register_certificate };
        }
    },
    Response: type = struct {
        certificate_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "CertificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateAlreadyExists,
        CertificateLimitExceeded,
        Client,
        DirectoryDoesNotExist,
        DirectoryUnavailable,
        InvalidCertificate,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const register_event_topic: struct {
    action_name: []const u8 = "RegisterEventTopic",
    Request: type = struct {
        directory_id: []const u8,
        topic_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .topic_name = "TopicName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_event_topic) } {
            return .{ .service_metadata = service_metadata, .action = register_event_topic };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const reject_shared_directory: struct {
    action_name: []const u8 = "RejectSharedDirectory",
    Request: type = struct {
        shared_directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shared_directory_id = "SharedDirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_shared_directory) } {
            return .{ .service_metadata = service_metadata, .action = reject_shared_directory };
        }
    },
    Response: type = struct {
        shared_directory_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shared_directory_id = "SharedDirectoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryAlreadyShared,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const remove_ip_routes: struct {
    action_name: []const u8 = "RemoveIpRoutes",
    Request: type = struct {
        directory_id: []const u8,
        cidr_ips: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .cidr_ips = "CidrIps",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_ip_routes) } {
            return .{ .service_metadata = service_metadata, .action = remove_ip_routes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const remove_region: struct {
    action_name: []const u8 = "RemoveRegion",
    Request: type = struct {
        directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_region) } {
            return .{ .service_metadata = service_metadata, .action = remove_region };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryDoesNotExist,
        DirectoryUnavailable,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const reset_user_password: struct {
    action_name: []const u8 = "ResetUserPassword",
    Request: type = struct {
        directory_id: []const u8,
        user_name: []const u8,
        new_password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .user_name = "UserName",
                .new_password = "NewPassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_user_password) } {
            return .{ .service_metadata = service_metadata, .action = reset_user_password };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        EntityDoesNotExist,
        InvalidPassword,
        Service,
        UnsupportedOperation,
        UserDoesNotExist,
    },
} = .{};
pub const restore_from_snapshot: struct {
    action_name: []const u8 = "RestoreFromSnapshot",
    Request: type = struct {
        snapshot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_from_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = restore_from_snapshot };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const share_directory: struct {
    action_name: []const u8 = "ShareDirectory",
    Request: type = struct {
        directory_id: []const u8,
        share_notes: ?[]const u8 = null,
        share_target: struct {
            id: []const u8,
            type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        },
        share_method: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .share_notes = "ShareNotes",
                .share_target = "ShareTarget",
                .share_method = "ShareMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(share_directory) } {
            return .{ .service_metadata = service_metadata, .action = share_directory };
        }
    },
    Response: type = struct {
        shared_directory_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shared_directory_id = "SharedDirectoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryAlreadyShared,
        EntityDoesNotExist,
        InvalidParameter,
        InvalidTarget,
        Organizations,
        Service,
        ShareLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const start_schema_extension: struct {
    action_name: []const u8 = "StartSchemaExtension",
    Request: type = struct {
        directory_id: []const u8,
        create_snapshot_before_schema_extension: bool,
        ldif_content: []const u8,
        description: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .create_snapshot_before_schema_extension = "CreateSnapshotBeforeSchemaExtension",
                .ldif_content = "LdifContent",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_schema_extension) } {
            return .{ .service_metadata = service_metadata, .action = start_schema_extension };
        }
    },
    Response: type = struct {
        schema_extension_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_extension_id = "SchemaExtensionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        SnapshotLimitExceeded,
    },
} = .{};
pub const unshare_directory: struct {
    action_name: []const u8 = "UnshareDirectory",
    Request: type = struct {
        directory_id: []const u8,
        unshare_target: struct {
            id: []const u8,
            type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .unshare_target = "UnshareTarget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unshare_directory) } {
            return .{ .service_metadata = service_metadata, .action = unshare_directory };
        }
    },
    Response: type = struct {
        shared_directory_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shared_directory_id = "SharedDirectoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryNotShared,
        EntityDoesNotExist,
        InvalidTarget,
        Service,
    },
} = .{};
pub const update_conditional_forwarder: struct {
    action_name: []const u8 = "UpdateConditionalForwarder",
    Request: type = struct {
        directory_id: []const u8,
        remote_domain_name: []const u8,
        dns_ip_addrs: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .remote_domain_name = "RemoteDomainName",
                .dns_ip_addrs = "DnsIpAddrs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_conditional_forwarder) } {
            return .{ .service_metadata = service_metadata, .action = update_conditional_forwarder };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const update_directory_setup: struct {
    action_name: []const u8 = "UpdateDirectorySetup",
    Request: type = struct {
        directory_id: []const u8,
        update_type: []const u8,
        os_update_settings: ?OSUpdateSettings = null,
        create_snapshot_before_update: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .update_type = "UpdateType",
                .os_update_settings = "OSUpdateSettings",
                .create_snapshot_before_update = "CreateSnapshotBeforeUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_directory_setup) } {
            return .{ .service_metadata = service_metadata, .action = update_directory_setup };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        DirectoryDoesNotExist,
        DirectoryInDesiredState,
        DirectoryUnavailable,
        InvalidParameter,
        Service,
        SnapshotLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const update_number_of_domain_controllers: struct {
    action_name: []const u8 = "UpdateNumberOfDomainControllers",
    Request: type = struct {
        directory_id: []const u8,
        desired_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .desired_number = "DesiredNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_number_of_domain_controllers) } {
            return .{ .service_metadata = service_metadata, .action = update_number_of_domain_controllers };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryUnavailable,
        DomainControllerLimitExceeded,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};
pub const update_radius: struct {
    action_name: []const u8 = "UpdateRadius",
    Request: type = struct {
        directory_id: []const u8,
        radius_settings: RadiusSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .radius_settings = "RadiusSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_radius) } {
            return .{ .service_metadata = service_metadata, .action = update_radius };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const update_settings: struct {
    action_name: []const u8 = "UpdateSettings",
    Request: type = struct {
        directory_id: []const u8,
        settings: []struct {
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .settings = "Settings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_settings };
        }
    },
    Response: type = struct {
        directory_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        DirectoryDoesNotExist,
        DirectoryUnavailable,
        IncompatibleSettings,
        InvalidParameter,
        Service,
        UnsupportedOperation,
        UnsupportedSettings,
    },
} = .{};
pub const update_trust: struct {
    action_name: []const u8 = "UpdateTrust",
    Request: type = struct {
        trust_id: []const u8,
        selective_auth: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_id = "TrustId",
                .selective_auth = "SelectiveAuth",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_trust) } {
            return .{ .service_metadata = service_metadata, .action = update_trust };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        trust_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .trust_id = "TrustId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
    },
} = .{};
pub const verify_trust: struct {
    action_name: []const u8 = "VerifyTrust",
    Request: type = struct {
        trust_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_id = "TrustId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_trust) } {
            return .{ .service_metadata = service_metadata, .action = verify_trust };
        }
    },
    Response: type = struct {
        trust_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_id = "TrustId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        EntityDoesNotExist,
        InvalidParameter,
        Service,
        UnsupportedOperation,
    },
} = .{};

pub const RadiusSettings = struct {
    radius_servers: ?[][]const u8 = null,
    radius_port: ?i64 = null,
    radius_timeout: ?i64 = null,
    radius_retries: ?i64 = null,
    shared_secret: ?[]const u8 = null,
    authentication_protocol: ?[]const u8 = null,
    display_label: ?[]const u8 = null,
    use_same_username: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .radius_servers = "RadiusServers",
            .radius_port = "RadiusPort",
            .radius_timeout = "RadiusTimeout",
            .radius_retries = "RadiusRetries",
            .shared_secret = "SharedSecret",
            .authentication_protocol = "AuthenticationProtocol",
            .display_label = "DisplayLabel",
            .use_same_username = "UseSameUsername",
        };
        return @field(mappings, field_name);
    }
};

pub const OSUpdateSettings = struct {
    os_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .os_version = "OSVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientCertAuthSettings = struct {
    ocsp_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ocsp_url = "OCSPUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateValue = struct {
    os_update_settings: ?OSUpdateSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .os_update_settings = "OSUpdateSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const SharedDirectory = struct {
    owner_account_id: ?[]const u8 = null,
    owner_directory_id: ?[]const u8 = null,
    share_method: ?[]const u8 = null,
    shared_account_id: ?[]const u8 = null,
    shared_directory_id: ?[]const u8 = null,
    share_status: ?[]const u8 = null,
    share_notes: ?[]const u8 = null,
    created_date_time: ?i64 = null,
    last_updated_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_account_id = "OwnerAccountId",
            .owner_directory_id = "OwnerDirectoryId",
            .share_method = "ShareMethod",
            .shared_account_id = "SharedAccountId",
            .shared_directory_id = "SharedDirectoryId",
            .share_status = "ShareStatus",
            .share_notes = "ShareNotes",
            .created_date_time = "CreatedDateTime",
            .last_updated_date_time = "LastUpdatedDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DirectoryVpcSettings = struct {
    vpc_id: []const u8,
    subnet_ids: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
            .subnet_ids = "SubnetIds",
        };
        return @field(mappings, field_name);
    }
};

pub const DirectoryVpcSettingsDescription = struct {
    vpc_id: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    security_group_id: ?[]const u8 = null,
    availability_zones: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
            .subnet_ids = "SubnetIds",
            .security_group_id = "SecurityGroupId",
            .availability_zones = "AvailabilityZones",
        };
        return @field(mappings, field_name);
    }
};

pub const Attribute = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
