const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-01-12";
pub const sdk_id: []const u8 = "DLM";
pub const arn_namespace: ?[]const u8 = "dlm";
pub const endpoint_prefix: []const u8 = "dlm";
pub const sigv4_name: []const u8 = "dlm";
pub const name: []const u8 = "dlm_20180112";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-01-12",
    sdk_id: []const u8 = "DLM",
    arn_namespace: ?[]const u8 = "dlm",
    endpoint_prefix: []const u8 = "dlm",
    sigv4_name: []const u8 = "dlm",
    name: []const u8 = "dlm_20180112",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_lifecycle_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policies",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLifecyclePolicy",
    Request: type = struct {
        execution_role_arn: []const u8,
        description: []const u8,
        state: []const u8,
        policy_details: ?PolicyDetails = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        default_policy: ?[]const u8 = null,
        create_interval: ?i64 = null,
        retain_interval: ?i64 = null,
        copy_tags: ?bool = null,
        extend_deletion: ?bool = null,
        cross_region_copy_targets: ?[]CrossRegionCopyTarget = null,
        exclusions: ?Exclusions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_role_arn = "ExecutionRoleArn",
                .description = "Description",
                .state = "State",
                .policy_details = "PolicyDetails",
                .tags = "Tags",
                .default_policy = "DefaultPolicy",
                .create_interval = "CreateInterval",
                .retain_interval = "RetainInterval",
                .copy_tags = "CopyTags",
                .extend_deletion = "ExtendDeletion",
                .cross_region_copy_targets = "CrossRegionCopyTargets",
                .exclusions = "Exclusions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_lifecycle_policy };
        }
    },
    Response: type = struct {
        policy_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        LimitExceeded,
    },
} = .{};
pub const delete_lifecycle_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/policies/{PolicyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLifecyclePolicy",
    Request: type = struct {
        policy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_lifecycle_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_lifecycle_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policies",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLifecyclePolicies",
    Request: type = struct {
        policy_ids: ?[][]const u8 = null,
        state: ?[]const u8 = null,
        resource_types: ?[][]const u8 = null,
        target_tags: ?[][]const u8 = null,
        tags_to_add: ?[][]const u8 = null,
        default_policy_type: ?[]const u8 = null,

        pub const http_query = .{
            .policy_ids = "policyIds",
            .state = "state",
            .resource_types = "resourceTypes",
            .target_tags = "targetTags",
            .tags_to_add = "tagsToAdd",
            .default_policy_type = "defaultPolicyType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_ids = "PolicyIds",
                .state = "State",
                .resource_types = "ResourceTypes",
                .target_tags = "TargetTags",
                .tags_to_add = "TagsToAdd",
                .default_policy_type = "DefaultPolicyType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lifecycle_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_lifecycle_policies };
        }
    },
    Response: type = struct {
        policies: ?[]struct {
            policy_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            policy_type: ?[]const u8 = null,
            default_policy: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_id = "PolicyId",
                    .description = "Description",
                    .state = "State",
                    .tags = "Tags",
                    .policy_type = "PolicyType",
                    .default_policy = "DefaultPolicy",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "Policies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_lifecycle_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policies/{PolicyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLifecyclePolicy",
    Request: type = struct {
        policy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_lifecycle_policy };
        }
    },
    Response: type = struct {
        policy: ?struct {
            policy_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            state: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            execution_role_arn: ?[]const u8 = null,
            date_created: ?i64 = null,
            date_modified: ?i64 = null,
            policy_details: ?PolicyDetails = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            policy_arn: ?[]const u8 = null,
            default_policy: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_id = "PolicyId",
                    .description = "Description",
                    .state = "State",
                    .status_message = "StatusMessage",
                    .execution_role_arn = "ExecutionRoleArn",
                    .date_created = "DateCreated",
                    .date_modified = "DateModified",
                    .policy_details = "PolicyDetails",
                    .tags = "Tags",
                    .policy_arn = "PolicyArn",
                    .default_policy = "DefaultPolicy",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_lifecycle_policy: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/policies/{PolicyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLifecyclePolicy",
    Request: type = struct {
        policy_id: []const u8,
        execution_role_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        description: ?[]const u8 = null,
        policy_details: ?PolicyDetails = null,
        create_interval: ?i64 = null,
        retain_interval: ?i64 = null,
        copy_tags: ?bool = null,
        extend_deletion: ?bool = null,
        cross_region_copy_targets: ?[]CrossRegionCopyTarget = null,
        exclusions: ?Exclusions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
                .execution_role_arn = "ExecutionRoleArn",
                .state = "State",
                .description = "Description",
                .policy_details = "PolicyDetails",
                .create_interval = "CreateInterval",
                .retain_interval = "RetainInterval",
                .copy_tags = "CopyTags",
                .extend_deletion = "ExtendDeletion",
                .cross_region_copy_targets = "CrossRegionCopyTargets",
                .exclusions = "Exclusions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_lifecycle_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};

pub const Exclusions = struct {
    exclude_boot_volumes: ?bool = null,
    exclude_volume_types: ?[][]const u8 = null,
    exclude_tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .exclude_boot_volumes = "ExcludeBootVolumes",
            .exclude_volume_types = "ExcludeVolumeTypes",
            .exclude_tags = "ExcludeTags",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const CrossRegionCopyTarget = struct {
    target_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_region = "TargetRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyDetails = struct {
    policy_type: ?[]const u8 = null,
    resource_types: ?[][]const u8 = null,
    resource_locations: ?[][]const u8 = null,
    target_tags: ?[]Tag = null,
    schedules: ?[]Schedule = null,
    parameters: ?Parameters = null,
    event_source: ?EventSource = null,
    actions: ?[]Action = null,
    policy_language: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    create_interval: ?i64 = null,
    retain_interval: ?i64 = null,
    copy_tags: ?bool = null,
    cross_region_copy_targets: ?[]CrossRegionCopyTarget = null,
    extend_deletion: ?bool = null,
    exclusions: ?Exclusions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_type = "PolicyType",
            .resource_types = "ResourceTypes",
            .resource_locations = "ResourceLocations",
            .target_tags = "TargetTags",
            .schedules = "Schedules",
            .parameters = "Parameters",
            .event_source = "EventSource",
            .actions = "Actions",
            .policy_language = "PolicyLanguage",
            .resource_type = "ResourceType",
            .create_interval = "CreateInterval",
            .retain_interval = "RetainInterval",
            .copy_tags = "CopyTags",
            .cross_region_copy_targets = "CrossRegionCopyTargets",
            .extend_deletion = "ExtendDeletion",
            .exclusions = "Exclusions",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    name: []const u8,
    cross_region_copy: []CrossRegionCopyAction,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .cross_region_copy = "CrossRegionCopy",
        };
        return @field(mappings, field_name);
    }
};

pub const CrossRegionCopyAction = struct {
    target: []const u8,
    encryption_configuration: EncryptionConfiguration,
    retain_rule: ?CrossRegionCopyRetainRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target = "Target",
            .encryption_configuration = "EncryptionConfiguration",
            .retain_rule = "RetainRule",
        };
        return @field(mappings, field_name);
    }
};

pub const CrossRegionCopyRetainRule = struct {
    interval: ?i64 = null,
    interval_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interval = "Interval",
            .interval_unit = "IntervalUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    encrypted: bool,
    cmk_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encrypted = "Encrypted",
            .cmk_arn = "CmkArn",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSource = struct {
    type: []const u8,
    parameters: ?EventParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }
};

pub const EventParameters = struct {
    event_type: []const u8,
    snapshot_owner: [][]const u8,
    description_regex: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_type = "EventType",
            .snapshot_owner = "SnapshotOwner",
            .description_regex = "DescriptionRegex",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameters = struct {
    exclude_boot_volume: ?bool = null,
    no_reboot: ?bool = null,
    exclude_data_volume_tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .exclude_boot_volume = "ExcludeBootVolume",
            .no_reboot = "NoReboot",
            .exclude_data_volume_tags = "ExcludeDataVolumeTags",
        };
        return @field(mappings, field_name);
    }
};

pub const Schedule = struct {
    name: ?[]const u8 = null,
    copy_tags: ?bool = null,
    tags_to_add: ?[]Tag = null,
    variable_tags: ?[]Tag = null,
    create_rule: ?CreateRule = null,
    retain_rule: ?RetainRule = null,
    fast_restore_rule: ?FastRestoreRule = null,
    cross_region_copy_rules: ?[]CrossRegionCopyRule = null,
    share_rules: ?[]ShareRule = null,
    deprecate_rule: ?DeprecateRule = null,
    archive_rule: ?ArchiveRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .copy_tags = "CopyTags",
            .tags_to_add = "TagsToAdd",
            .variable_tags = "VariableTags",
            .create_rule = "CreateRule",
            .retain_rule = "RetainRule",
            .fast_restore_rule = "FastRestoreRule",
            .cross_region_copy_rules = "CrossRegionCopyRules",
            .share_rules = "ShareRules",
            .deprecate_rule = "DeprecateRule",
            .archive_rule = "ArchiveRule",
        };
        return @field(mappings, field_name);
    }
};

pub const ArchiveRule = struct {
    retain_rule: ArchiveRetainRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retain_rule = "RetainRule",
        };
        return @field(mappings, field_name);
    }
};

pub const ArchiveRetainRule = struct {
    retention_archive_tier: RetentionArchiveTier,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retention_archive_tier = "RetentionArchiveTier",
        };
        return @field(mappings, field_name);
    }
};

pub const RetentionArchiveTier = struct {
    count: ?i64 = null,
    interval: ?i64 = null,
    interval_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .interval = "Interval",
            .interval_unit = "IntervalUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const DeprecateRule = struct {
    count: ?i64 = null,
    interval: ?i64 = null,
    interval_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .interval = "Interval",
            .interval_unit = "IntervalUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const ShareRule = struct {
    target_accounts: [][]const u8,
    unshare_interval: ?i64 = null,
    unshare_interval_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_accounts = "TargetAccounts",
            .unshare_interval = "UnshareInterval",
            .unshare_interval_unit = "UnshareIntervalUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const CrossRegionCopyRule = struct {
    target_region: ?[]const u8 = null,
    target: ?[]const u8 = null,
    encrypted: bool,
    cmk_arn: ?[]const u8 = null,
    copy_tags: ?bool = null,
    retain_rule: ?CrossRegionCopyRetainRule = null,
    deprecate_rule: ?CrossRegionCopyDeprecateRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_region = "TargetRegion",
            .target = "Target",
            .encrypted = "Encrypted",
            .cmk_arn = "CmkArn",
            .copy_tags = "CopyTags",
            .retain_rule = "RetainRule",
            .deprecate_rule = "DeprecateRule",
        };
        return @field(mappings, field_name);
    }
};

pub const CrossRegionCopyDeprecateRule = struct {
    interval: ?i64 = null,
    interval_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interval = "Interval",
            .interval_unit = "IntervalUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const FastRestoreRule = struct {
    count: ?i64 = null,
    interval: ?i64 = null,
    interval_unit: ?[]const u8 = null,
    availability_zones: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .interval = "Interval",
            .interval_unit = "IntervalUnit",
            .availability_zones = "AvailabilityZones",
        };
        return @field(mappings, field_name);
    }
};

pub const RetainRule = struct {
    count: ?i64 = null,
    interval: ?i64 = null,
    interval_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .interval = "Interval",
            .interval_unit = "IntervalUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateRule = struct {
    location: ?[]const u8 = null,
    interval: ?i64 = null,
    interval_unit: ?[]const u8 = null,
    times: ?[][]const u8 = null,
    cron_expression: ?[]const u8 = null,
    scripts: ?[]Script = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .location = "Location",
            .interval = "Interval",
            .interval_unit = "IntervalUnit",
            .times = "Times",
            .cron_expression = "CronExpression",
            .scripts = "Scripts",
        };
        return @field(mappings, field_name);
    }
};

pub const Script = struct {
    stages: ?[][]const u8 = null,
    execution_handler_service: ?[]const u8 = null,
    execution_handler: []const u8,
    execute_operation_on_script_failure: ?bool = null,
    execution_timeout: ?i64 = null,
    maximum_retry_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stages = "Stages",
            .execution_handler_service = "ExecutionHandlerService",
            .execution_handler = "ExecutionHandler",
            .execute_operation_on_script_failure = "ExecuteOperationOnScriptFailure",
            .execution_timeout = "ExecutionTimeout",
            .maximum_retry_count = "MaximumRetryCount",
        };
        return @field(mappings, field_name);
    }
};
