const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-10-31";
pub const sdk_id: []const u8 = "DocDB";
pub const arn_namespace: ?[]const u8 = "rds";
pub const endpoint_prefix: []const u8 = "rds";
pub const sigv4_name: []const u8 = "rds";
pub const name: []const u8 = "AmazonRDSv19";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2014-10-31",
    sdk_id: []const u8 = "DocDB",
    arn_namespace: ?[]const u8 = "rds",
    endpoint_prefix: []const u8 = "rds",
    sigv4_name: []const u8 = "rds",
    name: []const u8 = "AmazonRDSv19",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const add_source_identifier_to_subscription: struct {
    action_name: []const u8 = "AddSourceIdentifierToSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        source_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .source_identifier = "SourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_source_identifier_to_subscription) } {
            return .{ .service_metadata = service_metadata, .action = add_source_identifier_to_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        SourceNotFound,
        SubscriptionNotFound,
    },
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_name: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        DBSnapshotNotFound,
    },
} = .{};
pub const apply_pending_maintenance_action: struct {
    action_name: []const u8 = "ApplyPendingMaintenanceAction",
    Request: type = struct {
        resource_identifier: []const u8,
        apply_action: []const u8,
        opt_in_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .apply_action = "ApplyAction",
                .opt_in_type = "OptInType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_pending_maintenance_action) } {
            return .{ .service_metadata = service_metadata, .action = apply_pending_maintenance_action };
        }
    },
    Response: type = struct {
        resource_pending_maintenance_actions: ?ResourcePendingMaintenanceActions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_pending_maintenance_actions = "ResourcePendingMaintenanceActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDBClusterState,
        InvalidDBInstanceState,
        ResourceNotFound,
    },
} = .{};
pub const copy_db_cluster_parameter_group: struct {
    action_name: []const u8 = "CopyDBClusterParameterGroup",
    Request: type = struct {
        source_db_cluster_parameter_group_identifier: []const u8,
        target_db_cluster_parameter_group_identifier: []const u8,
        target_db_cluster_parameter_group_description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_cluster_parameter_group_identifier = "SourceDBClusterParameterGroupIdentifier",
                .target_db_cluster_parameter_group_identifier = "TargetDBClusterParameterGroupIdentifier",
                .target_db_cluster_parameter_group_description = "TargetDBClusterParameterGroupDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = copy_db_cluster_parameter_group };
        }
    },
    Response: type = struct {
        db_cluster_parameter_group: ?DBClusterParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group = "DBClusterParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupAlreadyExists,
        DBParameterGroupNotFound,
        DBParameterGroupQuotaExceeded,
    },
} = .{};
pub const copy_db_cluster_snapshot: struct {
    action_name: []const u8 = "CopyDBClusterSnapshot",
    Request: type = struct {
        source_db_cluster_snapshot_identifier: []const u8,
        target_db_cluster_snapshot_identifier: []const u8,
        kms_key_id: ?[]const u8 = null,
        pre_signed_url: ?[]const u8 = null,
        copy_tags: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_db_cluster_snapshot_identifier = "SourceDBClusterSnapshotIdentifier",
                .target_db_cluster_snapshot_identifier = "TargetDBClusterSnapshotIdentifier",
                .kms_key_id = "KmsKeyId",
                .pre_signed_url = "PreSignedUrl",
                .copy_tags = "CopyTags",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_db_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = copy_db_cluster_snapshot };
        }
    },
    Response: type = struct {
        db_cluster_snapshot: ?DBClusterSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot = "DBClusterSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotAlreadyExists,
        DBClusterSnapshotNotFound,
        InvalidDBClusterSnapshotState,
        InvalidDBClusterState,
        KMSKeyNotAccessible,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const create_db_cluster: struct {
    action_name: []const u8 = "CreateDBCluster",
    Request: type = struct {
        availability_zones: ?[][]const u8 = null,
        backup_retention_period: ?i64 = null,
        db_cluster_identifier: []const u8,
        db_cluster_parameter_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        db_subnet_group_name: ?[]const u8 = null,
        engine: []const u8,
        engine_version: ?[]const u8 = null,
        port: ?i64 = null,
        master_username: ?[]const u8 = null,
        master_user_password: ?[]const u8 = null,
        preferred_backup_window: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        tags: ?[]Tag = null,
        storage_encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        pre_signed_url: ?[]const u8 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        deletion_protection: ?bool = null,
        global_cluster_identifier: ?[]const u8 = null,
        storage_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZones",
                .backup_retention_period = "BackupRetentionPeriod",
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .db_subnet_group_name = "DBSubnetGroupName",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .port = "Port",
                .master_username = "MasterUsername",
                .master_user_password = "MasterUserPassword",
                .preferred_backup_window = "PreferredBackupWindow",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .tags = "Tags",
                .storage_encrypted = "StorageEncrypted",
                .kms_key_id = "KmsKeyId",
                .pre_signed_url = "PreSignedUrl",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .deletion_protection = "DeletionProtection",
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .storage_type = "StorageType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterNotFound,
        DBClusterParameterGroupNotFound,
        DBClusterQuotaExceeded,
        DBInstanceNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        GlobalClusterNotFound,
        InsufficientStorageClusterCapacity,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        InvalidDBSubnetGroupState,
        InvalidGlobalClusterState,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        StorageQuotaExceeded,
    },
} = .{};
pub const create_db_cluster_parameter_group: struct {
    action_name: []const u8 = "CreateDBClusterParameterGroup",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,
        db_parameter_group_family: []const u8,
        description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .db_parameter_group_family = "DBParameterGroupFamily",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = create_db_cluster_parameter_group };
        }
    },
    Response: type = struct {
        db_cluster_parameter_group: ?DBClusterParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group = "DBClusterParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupAlreadyExists,
        DBParameterGroupQuotaExceeded,
    },
} = .{};
pub const create_db_cluster_snapshot: struct {
    action_name: []const u8 = "CreateDBClusterSnapshot",
    Request: type = struct {
        db_cluster_snapshot_identifier: []const u8,
        db_cluster_identifier: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
                .db_cluster_identifier = "DBClusterIdentifier",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_db_cluster_snapshot };
        }
    },
    Response: type = struct {
        db_cluster_snapshot: ?DBClusterSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot = "DBClusterSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBClusterSnapshotAlreadyExists,
        InvalidDBClusterSnapshotState,
        InvalidDBClusterState,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const create_db_instance: struct {
    action_name: []const u8 = "CreateDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        db_instance_class: []const u8,
        engine: []const u8,
        availability_zone: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        tags: ?[]Tag = null,
        db_cluster_identifier: []const u8,
        copy_tags_to_snapshot: ?bool = null,
        promotion_tier: ?i64 = null,
        enable_performance_insights: ?bool = null,
        performance_insights_kms_key_id: ?[]const u8 = null,
        ca_certificate_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .db_instance_class = "DBInstanceClass",
                .engine = "Engine",
                .availability_zone = "AvailabilityZone",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .tags = "Tags",
                .db_cluster_identifier = "DBClusterIdentifier",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .promotion_tier = "PromotionTier",
                .enable_performance_insights = "EnablePerformanceInsights",
                .performance_insights_kms_key_id = "PerformanceInsightsKMSKeyId",
                .ca_certificate_identifier = "CACertificateIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        DBClusterNotFound,
        DBInstanceAlreadyExists,
        DBParameterGroupNotFound,
        DBSecurityGroupNotFound,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        InstanceQuotaExceeded,
        InsufficientDBInstanceCapacity,
        InvalidDBClusterState,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        StorageQuotaExceeded,
        StorageTypeNotSupported,
    },
} = .{};
pub const create_db_subnet_group: struct {
    action_name: []const u8 = "CreateDBSubnetGroup",
    Request: type = struct {
        db_subnet_group_name: []const u8,
        db_subnet_group_description: []const u8,
        subnet_ids: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group_name = "DBSubnetGroupName",
                .db_subnet_group_description = "DBSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_db_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = create_db_subnet_group };
        }
    },
    Response: type = struct {
        db_subnet_group: ?DBSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group = "DBSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSubnetGroupAlreadyExists,
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupQuotaExceeded,
        DBSubnetQuotaExceeded,
        InvalidSubnet,
    },
} = .{};
pub const create_event_subscription: struct {
    action_name: []const u8 = "CreateEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: []const u8,
        source_type: ?[]const u8 = null,
        event_categories: ?[][]const u8 = null,
        source_ids: ?[][]const u8 = null,
        enabled: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .event_categories = "EventCategories",
                .source_ids = "SourceIds",
                .enabled = "Enabled",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventSubscriptionQuotaExceeded,
        SNSInvalidTopic,
        SNSNoAuthorization,
        SNSTopicArnNotFound,
        SourceNotFound,
        SubscriptionAlreadyExist,
        SubscriptionCategoryNotFound,
    },
} = .{};
pub const create_global_cluster: struct {
    action_name: []const u8 = "CreateGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: []const u8,
        source_db_cluster_identifier: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        database_name: ?[]const u8 = null,
        storage_encrypted: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .source_db_cluster_identifier = "SourceDBClusterIdentifier",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .deletion_protection = "DeletionProtection",
                .database_name = "DatabaseName",
                .storage_encrypted = "StorageEncrypted",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        GlobalClusterAlreadyExists,
        GlobalClusterQuotaExceeded,
        InvalidDBClusterState,
    },
} = .{};
pub const delete_db_cluster: struct {
    action_name: []const u8 = "DeleteDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        skip_final_snapshot: ?bool = null,
        final_db_snapshot_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .skip_final_snapshot = "SkipFinalSnapshot",
                .final_db_snapshot_identifier = "FinalDBSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBClusterSnapshotAlreadyExists,
        InvalidDBClusterSnapshotState,
        InvalidDBClusterState,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const delete_db_cluster_parameter_group: struct {
    action_name: []const u8 = "DeleteDBClusterParameterGroup",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_cluster_parameter_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const delete_db_cluster_snapshot: struct {
    action_name: []const u8 = "DeleteDBClusterSnapshot",
    Request: type = struct {
        db_cluster_snapshot_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_cluster_snapshot };
        }
    },
    Response: type = struct {
        db_cluster_snapshot: ?DBClusterSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot = "DBClusterSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
        InvalidDBClusterSnapshotState,
    },
} = .{};
pub const delete_db_instance: struct {
    action_name: []const u8 = "DeleteDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        DBSnapshotAlreadyExists,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const delete_db_subnet_group: struct {
    action_name: []const u8 = "DeleteDBSubnetGroup",
    Request: type = struct {
        db_subnet_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group_name = "DBSubnetGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_db_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_db_subnet_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBSubnetGroupNotFound,
        InvalidDBSubnetGroupState,
        InvalidDBSubnetState,
    },
} = .{};
pub const delete_event_subscription: struct {
    action_name: []const u8 = "DeleteEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEventSubscriptionState,
        SubscriptionNotFound,
    },
} = .{};
pub const delete_global_cluster: struct {
    action_name: []const u8 = "DeleteGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalClusterNotFound,
        InvalidGlobalClusterState,
    },
} = .{};
pub const describe_certificates: struct {
    action_name: []const u8 = "DescribeCertificates",
    Request: type = struct {
        certificate_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_identifier = "CertificateIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificates) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificates };
        }
    },
    Response: type = struct {
        certificates: ?[]struct {
            certificate_identifier: ?[]const u8 = null,
            certificate_type: ?[]const u8 = null,
            thumbprint: ?[]const u8 = null,
            valid_from: ?i64 = null,
            valid_till: ?i64 = null,
            certificate_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_identifier = "CertificateIdentifier",
                    .certificate_type = "CertificateType",
                    .thumbprint = "Thumbprint",
                    .valid_from = "ValidFrom",
                    .valid_till = "ValidTill",
                    .certificate_arn = "CertificateArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificates = "Certificates",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateNotFound,
    },
} = .{};
pub const describe_db_cluster_parameter_groups: struct {
    action_name: []const u8 = "DescribeDBClusterParameterGroups",
    Request: type = struct {
        db_cluster_parameter_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_parameter_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_parameter_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_cluster_parameter_groups: ?[]DBClusterParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_cluster_parameter_groups = "DBClusterParameterGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
    },
} = .{};
pub const describe_db_cluster_parameters: struct {
    action_name: []const u8 = "DescribeDBClusterParameters",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,
        source: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .source = "Source",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_parameters };
        }
    },
    Response: type = struct {
        parameters: ?[]Parameter = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "Parameters",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
    },
} = .{};
pub const describe_db_clusters: struct {
    action_name: []const u8 = "DescribeDBClusters",
    Request: type = struct {
        db_cluster_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_clusters };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_clusters: ?[]DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_clusters = "DBClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
    },
} = .{};
pub const describe_db_cluster_snapshot_attributes: struct {
    action_name: []const u8 = "DescribeDBClusterSnapshotAttributes",
    Request: type = struct {
        db_cluster_snapshot_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_snapshot_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_snapshot_attributes };
        }
    },
    Response: type = struct {
        db_cluster_snapshot_attributes_result: ?DBClusterSnapshotAttributesResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_attributes_result = "DBClusterSnapshotAttributesResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
    },
} = .{};
pub const describe_db_cluster_snapshots: struct {
    action_name: []const u8 = "DescribeDBClusterSnapshots",
    Request: type = struct {
        db_cluster_identifier: ?[]const u8 = null,
        db_cluster_snapshot_identifier: ?[]const u8 = null,
        snapshot_type: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        include_shared: ?bool = null,
        include_public: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
                .snapshot_type = "SnapshotType",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .include_shared = "IncludeShared",
                .include_public = "IncludePublic",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_cluster_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_cluster_snapshots };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_cluster_snapshots: ?[]DBClusterSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_cluster_snapshots = "DBClusterSnapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
    },
} = .{};
pub const describe_db_engine_versions: struct {
    action_name: []const u8 = "DescribeDBEngineVersions",
    Request: type = struct {
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        db_parameter_group_family: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        default_only: ?bool = null,
        list_supported_character_sets: ?bool = null,
        list_supported_timezones: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .db_parameter_group_family = "DBParameterGroupFamily",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .default_only = "DefaultOnly",
                .list_supported_character_sets = "ListSupportedCharacterSets",
                .list_supported_timezones = "ListSupportedTimezones",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_engine_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_engine_versions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_engine_versions: ?[]struct {
            engine: ?[]const u8 = null,
            engine_version: ?[]const u8 = null,
            db_parameter_group_family: ?[]const u8 = null,
            db_engine_description: ?[]const u8 = null,
            db_engine_version_description: ?[]const u8 = null,
            valid_upgrade_target: ?[]struct {
                engine: ?[]const u8 = null,
                engine_version: ?[]const u8 = null,
                description: ?[]const u8 = null,
                auto_upgrade: ?bool = null,
                is_major_version_upgrade: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .engine = "Engine",
                        .engine_version = "EngineVersion",
                        .description = "Description",
                        .auto_upgrade = "AutoUpgrade",
                        .is_major_version_upgrade = "IsMajorVersionUpgrade",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            exportable_log_types: ?[][]const u8 = null,
            supports_log_exports_to_cloudwatch_logs: ?bool = null,
            supported_ca_certificate_identifiers: ?[][]const u8 = null,
            supports_certificate_rotation_without_restart: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine = "Engine",
                    .engine_version = "EngineVersion",
                    .db_parameter_group_family = "DBParameterGroupFamily",
                    .db_engine_description = "DBEngineDescription",
                    .db_engine_version_description = "DBEngineVersionDescription",
                    .valid_upgrade_target = "ValidUpgradeTarget",
                    .exportable_log_types = "ExportableLogTypes",
                    .supports_log_exports_to_cloudwatch_logs = "SupportsLogExportsToCloudwatchLogs",
                    .supported_ca_certificate_identifiers = "SupportedCACertificateIdentifiers",
                    .supports_certificate_rotation_without_restart = "SupportsCertificateRotationWithoutRestart",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_engine_versions = "DBEngineVersions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_db_instances: struct {
    action_name: []const u8 = "DescribeDBInstances",
    Request: type = struct {
        db_instance_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_instances };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_instances: ?[]DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_instances = "DBInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
    },
} = .{};
pub const describe_db_subnet_groups: struct {
    action_name: []const u8 = "DescribeDBSubnetGroups",
    Request: type = struct {
        db_subnet_group_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group_name = "DBSubnetGroupName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_db_subnet_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_db_subnet_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        db_subnet_groups: ?[]DBSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .db_subnet_groups = "DBSubnetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSubnetGroupNotFound,
    },
} = .{};
pub const describe_engine_default_cluster_parameters: struct {
    action_name: []const u8 = "DescribeEngineDefaultClusterParameters",
    Request: type = struct {
        db_parameter_group_family: []const u8,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_parameter_group_family = "DBParameterGroupFamily",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_engine_default_cluster_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_engine_default_cluster_parameters };
        }
    },
    Response: type = struct {
        engine_defaults: ?struct {
            db_parameter_group_family: ?[]const u8 = null,
            marker: ?[]const u8 = null,
            parameters: ?[]Parameter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .db_parameter_group_family = "DBParameterGroupFamily",
                    .marker = "Marker",
                    .parameters = "Parameters",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_defaults = "EngineDefaults",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_categories: struct {
    action_name: []const u8 = "DescribeEventCategories",
    Request: type = struct {
        source_type: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_type = "SourceType",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_categories) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_categories };
        }
    },
    Response: type = struct {
        event_categories_map_list: ?[]struct {
            source_type: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_type = "SourceType",
                    .event_categories = "EventCategories",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_categories_map_list = "EventCategoriesMapList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        source_identifier: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        duration: ?i64 = null,
        event_categories: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_identifier = "SourceIdentifier",
                .source_type = "SourceType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .duration = "Duration",
                .event_categories = "EventCategories",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        events: ?[]struct {
            source_identifier: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,
            date: ?i64 = null,
            source_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_identifier = "SourceIdentifier",
                    .source_type = "SourceType",
                    .message = "Message",
                    .event_categories = "EventCategories",
                    .date = "Date",
                    .source_arn = "SourceArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_subscriptions: struct {
    action_name: []const u8 = "DescribeEventSubscriptions",
    Request: type = struct {
        subscription_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_subscriptions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        event_subscriptions_list: ?[]EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .event_subscriptions_list = "EventSubscriptionsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        SubscriptionNotFound,
    },
} = .{};
pub const describe_global_clusters: struct {
    action_name: []const u8 = "DescribeGlobalClusters",
    Request: type = struct {
        global_cluster_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_global_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_global_clusters };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        global_clusters: ?[]GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .global_clusters = "GlobalClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalClusterNotFound,
    },
} = .{};
pub const describe_orderable_db_instance_options: struct {
    action_name: []const u8 = "DescribeOrderableDBInstanceOptions",
    Request: type = struct {
        engine: []const u8,
        engine_version: ?[]const u8 = null,
        db_instance_class: ?[]const u8 = null,
        license_model: ?[]const u8 = null,
        vpc: ?bool = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .db_instance_class = "DBInstanceClass",
                .license_model = "LicenseModel",
                .vpc = "Vpc",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_orderable_db_instance_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_orderable_db_instance_options };
        }
    },
    Response: type = struct {
        orderable_db_instance_options: ?[]struct {
            engine: ?[]const u8 = null,
            engine_version: ?[]const u8 = null,
            db_instance_class: ?[]const u8 = null,
            license_model: ?[]const u8 = null,
            availability_zones: ?[]AvailabilityZone = null,
            vpc: ?bool = null,
            storage_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine = "Engine",
                    .engine_version = "EngineVersion",
                    .db_instance_class = "DBInstanceClass",
                    .license_model = "LicenseModel",
                    .availability_zones = "AvailabilityZones",
                    .vpc = "Vpc",
                    .storage_type = "StorageType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .orderable_db_instance_options = "OrderableDBInstanceOptions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_pending_maintenance_actions: struct {
    action_name: []const u8 = "DescribePendingMaintenanceActions",
    Request: type = struct {
        resource_identifier: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pending_maintenance_actions) } {
            return .{ .service_metadata = service_metadata, .action = describe_pending_maintenance_actions };
        }
    },
    Response: type = struct {
        pending_maintenance_actions: ?[]ResourcePendingMaintenanceActions = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pending_maintenance_actions = "PendingMaintenanceActions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const failover_db_cluster: struct {
    action_name: []const u8 = "FailoverDBCluster",
    Request: type = struct {
        db_cluster_identifier: ?[]const u8 = null,
        target_db_instance_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .target_db_instance_identifier = "TargetDBInstanceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(failover_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = failover_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_name: []const u8,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        DBSnapshotNotFound,
    },
} = .{};
pub const modify_db_cluster: struct {
    action_name: []const u8 = "ModifyDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        new_db_cluster_identifier: ?[]const u8 = null,
        apply_immediately: ?bool = null,
        backup_retention_period: ?i64 = null,
        db_cluster_parameter_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        port: ?i64 = null,
        master_user_password: ?[]const u8 = null,
        preferred_backup_window: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        cloudwatch_logs_export_configuration: ?struct {
            enable_log_types: ?[][]const u8 = null,
            disable_log_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enable_log_types = "EnableLogTypes",
                    .disable_log_types = "DisableLogTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        engine_version: ?[]const u8 = null,
        allow_major_version_upgrade: ?bool = null,
        deletion_protection: ?bool = null,
        storage_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .new_db_cluster_identifier = "NewDBClusterIdentifier",
                .apply_immediately = "ApplyImmediately",
                .backup_retention_period = "BackupRetentionPeriod",
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .port = "Port",
                .master_user_password = "MasterUserPassword",
                .preferred_backup_window = "PreferredBackupWindow",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .cloudwatch_logs_export_configuration = "CloudwatchLogsExportConfiguration",
                .engine_version = "EngineVersion",
                .allow_major_version_upgrade = "AllowMajorVersionUpgrade",
                .deletion_protection = "DeletionProtection",
                .storage_type = "StorageType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterNotFound,
        DBClusterParameterGroupNotFound,
        DBSubnetGroupNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
        InvalidDBSecurityGroupState,
        InvalidDBSubnetGroupState,
        InvalidSubnet,
        InvalidVPCNetworkState,
        StorageQuotaExceeded,
    },
} = .{};
pub const modify_db_cluster_parameter_group: struct {
    action_name: []const u8 = "ModifyDBClusterParameterGroup",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,
        parameters: []Parameter,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_cluster_parameter_group };
        }
    },
    Response: type = struct {
        db_cluster_parameter_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const modify_db_cluster_snapshot_attribute: struct {
    action_name: []const u8 = "ModifyDBClusterSnapshotAttribute",
    Request: type = struct {
        db_cluster_snapshot_identifier: []const u8,
        attribute_name: []const u8,
        values_to_add: ?[][]const u8 = null,
        values_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
                .attribute_name = "AttributeName",
                .values_to_add = "ValuesToAdd",
                .values_to_remove = "ValuesToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_cluster_snapshot_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_cluster_snapshot_attribute };
        }
    },
    Response: type = struct {
        db_cluster_snapshot_attributes_result: ?DBClusterSnapshotAttributesResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_snapshot_attributes_result = "DBClusterSnapshotAttributesResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterSnapshotNotFound,
        InvalidDBClusterSnapshotState,
        SharedSnapshotQuotaExceeded,
    },
} = .{};
pub const modify_db_instance: struct {
    action_name: []const u8 = "ModifyDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        db_instance_class: ?[]const u8 = null,
        apply_immediately: ?bool = null,
        preferred_maintenance_window: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        new_db_instance_identifier: ?[]const u8 = null,
        ca_certificate_identifier: ?[]const u8 = null,
        copy_tags_to_snapshot: ?bool = null,
        promotion_tier: ?i64 = null,
        enable_performance_insights: ?bool = null,
        performance_insights_kms_key_id: ?[]const u8 = null,
        certificate_rotation_restart: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .db_instance_class = "DBInstanceClass",
                .apply_immediately = "ApplyImmediately",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .new_db_instance_identifier = "NewDBInstanceIdentifier",
                .ca_certificate_identifier = "CACertificateIdentifier",
                .copy_tags_to_snapshot = "CopyTagsToSnapshot",
                .promotion_tier = "PromotionTier",
                .enable_performance_insights = "EnablePerformanceInsights",
                .performance_insights_kms_key_id = "PerformanceInsightsKMSKeyId",
                .certificate_rotation_restart = "CertificateRotationRestart",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        CertificateNotFound,
        DBInstanceAlreadyExists,
        DBInstanceNotFound,
        DBParameterGroupNotFound,
        DBSecurityGroupNotFound,
        DBUpgradeDependencyFailure,
        InsufficientDBInstanceCapacity,
        InvalidDBInstanceState,
        InvalidDBSecurityGroupState,
        InvalidVPCNetworkState,
        StorageQuotaExceeded,
        StorageTypeNotSupported,
    },
} = .{};
pub const modify_db_subnet_group: struct {
    action_name: []const u8 = "ModifyDBSubnetGroup",
    Request: type = struct {
        db_subnet_group_name: []const u8,
        db_subnet_group_description: ?[]const u8 = null,
        subnet_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group_name = "DBSubnetGroupName",
                .db_subnet_group_description = "DBSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_db_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_db_subnet_group };
        }
    },
    Response: type = struct {
        db_subnet_group: ?DBSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_subnet_group = "DBSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBSubnetGroupDoesNotCoverEnoughAZs,
        DBSubnetGroupNotFound,
        DBSubnetQuotaExceeded,
        InvalidSubnet,
        SubnetAlreadyInUse,
    },
} = .{};
pub const modify_event_subscription: struct {
    action_name: []const u8 = "ModifyEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        event_categories: ?[][]const u8 = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .event_categories = "EventCategories",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = modify_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventSubscriptionQuotaExceeded,
        SNSInvalidTopic,
        SNSNoAuthorization,
        SNSTopicArnNotFound,
        SubscriptionCategoryNotFound,
        SubscriptionNotFound,
    },
} = .{};
pub const modify_global_cluster: struct {
    action_name: []const u8 = "ModifyGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: []const u8,
        new_global_cluster_identifier: ?[]const u8 = null,
        deletion_protection: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .new_global_cluster_identifier = "NewGlobalClusterIdentifier",
                .deletion_protection = "DeletionProtection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = modify_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalClusterNotFound,
        InvalidGlobalClusterState,
    },
} = .{};
pub const reboot_db_instance: struct {
    action_name: []const u8 = "RebootDBInstance",
    Request: type = struct {
        db_instance_identifier: []const u8,
        force_failover: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance_identifier = "DBInstanceIdentifier",
                .force_failover = "ForceFailover",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_db_instance) } {
            return .{ .service_metadata = service_metadata, .action = reboot_db_instance };
        }
    },
    Response: type = struct {
        db_instance: ?DBInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_instance = "DBInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBInstanceNotFound,
        InvalidDBInstanceState,
    },
} = .{};
pub const remove_from_global_cluster: struct {
    action_name: []const u8 = "RemoveFromGlobalCluster",
    Request: type = struct {
        global_cluster_identifier: []const u8,
        db_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster_identifier = "GlobalClusterIdentifier",
                .db_cluster_identifier = "DbClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_from_global_cluster) } {
            return .{ .service_metadata = service_metadata, .action = remove_from_global_cluster };
        }
    },
    Response: type = struct {
        global_cluster: ?GlobalCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_cluster = "GlobalCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        GlobalClusterNotFound,
        InvalidGlobalClusterState,
    },
} = .{};
pub const remove_source_identifier_from_subscription: struct {
    action_name: []const u8 = "RemoveSourceIdentifierFromSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        source_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .source_identifier = "SourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_source_identifier_from_subscription) } {
            return .{ .service_metadata = service_metadata, .action = remove_source_identifier_from_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        SourceNotFound,
        SubscriptionNotFound,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_name: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DBClusterNotFound,
        DBInstanceNotFound,
        DBSnapshotNotFound,
    },
} = .{};
pub const reset_db_cluster_parameter_group: struct {
    action_name: []const u8 = "ResetDBClusterParameterGroup",
    Request: type = struct {
        db_cluster_parameter_group_name: []const u8,
        reset_all_parameters: ?bool = null,
        parameters: ?[]Parameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .reset_all_parameters = "ResetAllParameters",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_db_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = reset_db_cluster_parameter_group };
        }
    },
    Response: type = struct {
        db_cluster_parameter_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBParameterGroupNotFound,
        InvalidDBParameterGroupState,
    },
} = .{};
pub const restore_db_cluster_from_snapshot: struct {
    action_name: []const u8 = "RestoreDBClusterFromSnapshot",
    Request: type = struct {
        availability_zones: ?[][]const u8 = null,
        db_cluster_identifier: []const u8,
        snapshot_identifier: []const u8,
        engine: []const u8,
        engine_version: ?[]const u8 = null,
        port: ?i64 = null,
        db_subnet_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        deletion_protection: ?bool = null,
        db_cluster_parameter_group_name: ?[]const u8 = null,
        storage_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZones",
                .db_cluster_identifier = "DBClusterIdentifier",
                .snapshot_identifier = "SnapshotIdentifier",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .port = "Port",
                .db_subnet_group_name = "DBSubnetGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .deletion_protection = "DeletionProtection",
                .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
                .storage_type = "StorageType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_db_cluster_from_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = restore_db_cluster_from_snapshot };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterQuotaExceeded,
        DBClusterSnapshotNotFound,
        DBSnapshotNotFound,
        DBSubnetGroupNotFound,
        InsufficientDBClusterCapacity,
        InsufficientStorageClusterCapacity,
        InvalidDBClusterSnapshotState,
        InvalidDBSnapshotState,
        InvalidRestore,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        StorageQuotaExceeded,
    },
} = .{};
pub const restore_db_cluster_to_point_in_time: struct {
    action_name: []const u8 = "RestoreDBClusterToPointInTime",
    Request: type = struct {
        db_cluster_identifier: []const u8,
        restore_type: ?[]const u8 = null,
        source_db_cluster_identifier: []const u8,
        restore_to_time: ?i64 = null,
        use_latest_restorable_time: ?bool = null,
        port: ?i64 = null,
        db_subnet_group_name: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        enable_cloudwatch_logs_exports: ?[][]const u8 = null,
        deletion_protection: ?bool = null,
        storage_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
                .restore_type = "RestoreType",
                .source_db_cluster_identifier = "SourceDBClusterIdentifier",
                .restore_to_time = "RestoreToTime",
                .use_latest_restorable_time = "UseLatestRestorableTime",
                .port = "Port",
                .db_subnet_group_name = "DBSubnetGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .enable_cloudwatch_logs_exports = "EnableCloudwatchLogsExports",
                .deletion_protection = "DeletionProtection",
                .storage_type = "StorageType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_db_cluster_to_point_in_time) } {
            return .{ .service_metadata = service_metadata, .action = restore_db_cluster_to_point_in_time };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterAlreadyExists,
        DBClusterNotFound,
        DBClusterQuotaExceeded,
        DBClusterSnapshotNotFound,
        DBSubnetGroupNotFound,
        InsufficientDBClusterCapacity,
        InsufficientStorageClusterCapacity,
        InvalidDBClusterSnapshotState,
        InvalidDBClusterState,
        InvalidDBSnapshotState,
        InvalidRestore,
        InvalidSubnet,
        InvalidVPCNetworkState,
        KMSKeyNotAccessible,
        StorageQuotaExceeded,
    },
} = .{};
pub const start_db_cluster: struct {
    action_name: []const u8 = "StartDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = start_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
    },
} = .{};
pub const stop_db_cluster: struct {
    action_name: []const u8 = "StopDBCluster",
    Request: type = struct {
        db_cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_identifier = "DBClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_db_cluster) } {
            return .{ .service_metadata = service_metadata, .action = stop_db_cluster };
        }
    },
    Response: type = struct {
        db_cluster: ?DBCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster = "DBCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DBClusterNotFound,
        InvalidDBClusterState,
        InvalidDBInstanceState,
    },
} = .{};

pub const DBCluster = struct {
    availability_zones: ?[][]const u8 = null,
    backup_retention_period: ?i64 = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_cluster_parameter_group: ?[]const u8 = null,
    db_subnet_group: ?[]const u8 = null,
    status: ?[]const u8 = null,
    percent_progress: ?[]const u8 = null,
    earliest_restorable_time: ?i64 = null,
    endpoint: ?[]const u8 = null,
    reader_endpoint: ?[]const u8 = null,
    multi_az: ?bool = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    latest_restorable_time: ?i64 = null,
    port: ?i64 = null,
    master_username: ?[]const u8 = null,
    preferred_backup_window: ?[]const u8 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    replication_source_identifier: ?[]const u8 = null,
    read_replica_identifiers: ?[][]const u8 = null,
    db_cluster_members: ?[]DBClusterMember = null,
    vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
    hosted_zone_id: ?[]const u8 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_cluster_resource_id: ?[]const u8 = null,
    db_cluster_arn: ?[]const u8 = null,
    associated_roles: ?[]DBClusterRole = null,
    clone_group_id: ?[]const u8 = null,
    cluster_create_time: ?i64 = null,
    enabled_cloudwatch_logs_exports: ?[][]const u8 = null,
    deletion_protection: ?bool = null,
    storage_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .backup_retention_period = "BackupRetentionPeriod",
            .db_cluster_identifier = "DBClusterIdentifier",
            .db_cluster_parameter_group = "DBClusterParameterGroup",
            .db_subnet_group = "DBSubnetGroup",
            .status = "Status",
            .percent_progress = "PercentProgress",
            .earliest_restorable_time = "EarliestRestorableTime",
            .endpoint = "Endpoint",
            .reader_endpoint = "ReaderEndpoint",
            .multi_az = "MultiAZ",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .latest_restorable_time = "LatestRestorableTime",
            .port = "Port",
            .master_username = "MasterUsername",
            .preferred_backup_window = "PreferredBackupWindow",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .replication_source_identifier = "ReplicationSourceIdentifier",
            .read_replica_identifiers = "ReadReplicaIdentifiers",
            .db_cluster_members = "DBClusterMembers",
            .vpc_security_groups = "VpcSecurityGroups",
            .hosted_zone_id = "HostedZoneId",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .db_cluster_resource_id = "DbClusterResourceId",
            .db_cluster_arn = "DBClusterArn",
            .associated_roles = "AssociatedRoles",
            .clone_group_id = "CloneGroupId",
            .cluster_create_time = "ClusterCreateTime",
            .enabled_cloudwatch_logs_exports = "EnabledCloudwatchLogsExports",
            .deletion_protection = "DeletionProtection",
            .storage_type = "StorageType",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterRole = struct {
    role_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcSecurityGroupMembership = struct {
    vpc_security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_security_group_id = "VpcSecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterMember = struct {
    db_instance_identifier: ?[]const u8 = null,
    is_cluster_writer: ?bool = null,
    db_cluster_parameter_group_status: ?[]const u8 = null,
    promotion_tier: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_identifier = "DBInstanceIdentifier",
            .is_cluster_writer = "IsClusterWriter",
            .db_cluster_parameter_group_status = "DBClusterParameterGroupStatus",
            .promotion_tier = "PromotionTier",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameter = struct {
    parameter_name: ?[]const u8 = null,
    parameter_value: ?[]const u8 = null,
    description: ?[]const u8 = null,
    source: ?[]const u8 = null,
    apply_type: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    allowed_values: ?[]const u8 = null,
    is_modifiable: ?bool = null,
    minimum_engine_version: ?[]const u8 = null,
    apply_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_value = "ParameterValue",
            .description = "Description",
            .source = "Source",
            .apply_type = "ApplyType",
            .data_type = "DataType",
            .allowed_values = "AllowedValues",
            .is_modifiable = "IsModifiable",
            .minimum_engine_version = "MinimumEngineVersion",
            .apply_method = "ApplyMethod",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSubscription = struct {
    customer_aws_id: ?[]const u8 = null,
    cust_subscription_id: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    subscription_creation_time: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    source_ids_list: ?[][]const u8 = null,
    event_categories_list: ?[][]const u8 = null,
    enabled: ?bool = null,
    event_subscription_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_aws_id = "CustomerAwsId",
            .cust_subscription_id = "CustSubscriptionId",
            .sns_topic_arn = "SnsTopicArn",
            .status = "Status",
            .subscription_creation_time = "SubscriptionCreationTime",
            .source_type = "SourceType",
            .source_ids_list = "SourceIdsList",
            .event_categories_list = "EventCategoriesList",
            .enabled = "Enabled",
            .event_subscription_arn = "EventSubscriptionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalCluster = struct {
    global_cluster_identifier: ?[]const u8 = null,
    global_cluster_resource_id: ?[]const u8 = null,
    global_cluster_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    storage_encrypted: ?bool = null,
    deletion_protection: ?bool = null,
    global_cluster_members: ?[]GlobalClusterMember = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_cluster_identifier = "GlobalClusterIdentifier",
            .global_cluster_resource_id = "GlobalClusterResourceId",
            .global_cluster_arn = "GlobalClusterArn",
            .status = "Status",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .database_name = "DatabaseName",
            .storage_encrypted = "StorageEncrypted",
            .deletion_protection = "DeletionProtection",
            .global_cluster_members = "GlobalClusterMembers",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalClusterMember = struct {
    db_cluster_arn: ?[]const u8 = null,
    readers: ?[][]const u8 = null,
    is_writer: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_arn = "DBClusterArn",
            .readers = "Readers",
            .is_writer = "IsWriter",
        };
        return @field(mappings, field_name);
    }
};

pub const DBInstance = struct {
    db_instance_identifier: ?[]const u8 = null,
    db_instance_class: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    db_instance_status: ?[]const u8 = null,
    endpoint: ?Endpoint = null,
    instance_create_time: ?i64 = null,
    preferred_backup_window: ?[]const u8 = null,
    backup_retention_period: ?i64 = null,
    vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
    availability_zone: ?[]const u8 = null,
    db_subnet_group: ?DBSubnetGroup = null,
    preferred_maintenance_window: ?[]const u8 = null,
    pending_modified_values: ?PendingModifiedValues = null,
    latest_restorable_time: ?i64 = null,
    engine_version: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    publicly_accessible: ?bool = null,
    status_infos: ?[]DBInstanceStatusInfo = null,
    db_cluster_identifier: ?[]const u8 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    dbi_resource_id: ?[]const u8 = null,
    ca_certificate_identifier: ?[]const u8 = null,
    copy_tags_to_snapshot: ?bool = null,
    promotion_tier: ?i64 = null,
    db_instance_arn: ?[]const u8 = null,
    enabled_cloudwatch_logs_exports: ?[][]const u8 = null,
    certificate_details: ?CertificateDetails = null,
    performance_insights_enabled: ?bool = null,
    performance_insights_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_identifier = "DBInstanceIdentifier",
            .db_instance_class = "DBInstanceClass",
            .engine = "Engine",
            .db_instance_status = "DBInstanceStatus",
            .endpoint = "Endpoint",
            .instance_create_time = "InstanceCreateTime",
            .preferred_backup_window = "PreferredBackupWindow",
            .backup_retention_period = "BackupRetentionPeriod",
            .vpc_security_groups = "VpcSecurityGroups",
            .availability_zone = "AvailabilityZone",
            .db_subnet_group = "DBSubnetGroup",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .pending_modified_values = "PendingModifiedValues",
            .latest_restorable_time = "LatestRestorableTime",
            .engine_version = "EngineVersion",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .publicly_accessible = "PubliclyAccessible",
            .status_infos = "StatusInfos",
            .db_cluster_identifier = "DBClusterIdentifier",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .dbi_resource_id = "DbiResourceId",
            .ca_certificate_identifier = "CACertificateIdentifier",
            .copy_tags_to_snapshot = "CopyTagsToSnapshot",
            .promotion_tier = "PromotionTier",
            .db_instance_arn = "DBInstanceArn",
            .enabled_cloudwatch_logs_exports = "EnabledCloudwatchLogsExports",
            .certificate_details = "CertificateDetails",
            .performance_insights_enabled = "PerformanceInsightsEnabled",
            .performance_insights_kms_key_id = "PerformanceInsightsKMSKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateDetails = struct {
    ca_identifier: ?[]const u8 = null,
    valid_till: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ca_identifier = "CAIdentifier",
            .valid_till = "ValidTill",
        };
        return @field(mappings, field_name);
    }
};

pub const DBInstanceStatusInfo = struct {
    status_type: ?[]const u8 = null,
    normal: ?bool = null,
    status: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_type = "StatusType",
            .normal = "Normal",
            .status = "Status",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingModifiedValues = struct {
    db_instance_class: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    master_user_password: ?[]const u8 = null,
    port: ?i64 = null,
    backup_retention_period: ?i64 = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    iops: ?i64 = null,
    db_instance_identifier: ?[]const u8 = null,
    storage_type: ?[]const u8 = null,
    ca_certificate_identifier: ?[]const u8 = null,
    db_subnet_group_name: ?[]const u8 = null,
    pending_cloudwatch_logs_exports: ?PendingCloudwatchLogsExports = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_class = "DBInstanceClass",
            .allocated_storage = "AllocatedStorage",
            .master_user_password = "MasterUserPassword",
            .port = "Port",
            .backup_retention_period = "BackupRetentionPeriod",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .iops = "Iops",
            .db_instance_identifier = "DBInstanceIdentifier",
            .storage_type = "StorageType",
            .ca_certificate_identifier = "CACertificateIdentifier",
            .db_subnet_group_name = "DBSubnetGroupName",
            .pending_cloudwatch_logs_exports = "PendingCloudwatchLogsExports",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingCloudwatchLogsExports = struct {
    log_types_to_enable: ?[][]const u8 = null,
    log_types_to_disable: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_types_to_enable = "LogTypesToEnable",
            .log_types_to_disable = "LogTypesToDisable",
        };
        return @field(mappings, field_name);
    }
};

pub const DBSubnetGroup = struct {
    db_subnet_group_name: ?[]const u8 = null,
    db_subnet_group_description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_group_status: ?[]const u8 = null,
    subnets: ?[]Subnet = null,
    db_subnet_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_subnet_group_name = "DBSubnetGroupName",
            .db_subnet_group_description = "DBSubnetGroupDescription",
            .vpc_id = "VpcId",
            .subnet_group_status = "SubnetGroupStatus",
            .subnets = "Subnets",
            .db_subnet_group_arn = "DBSubnetGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?AvailabilityZone = null,
    subnet_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
            .subnet_status = "SubnetStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,
    hosted_zone_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
            .hosted_zone_id = "HostedZoneId",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterSnapshotAttributesResult = struct {
    db_cluster_snapshot_identifier: ?[]const u8 = null,
    db_cluster_snapshot_attributes: ?[]DBClusterSnapshotAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
            .db_cluster_snapshot_attributes = "DBClusterSnapshotAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterSnapshotAttribute = struct {
    attribute_name: ?[]const u8 = null,
    attribute_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_values = "AttributeValues",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePendingMaintenanceActions = struct {
    resource_identifier: ?[]const u8 = null,
    pending_maintenance_action_details: ?[]PendingMaintenanceAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_identifier = "ResourceIdentifier",
            .pending_maintenance_action_details = "PendingMaintenanceActionDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingMaintenanceAction = struct {
    action: ?[]const u8 = null,
    auto_applied_after_date: ?i64 = null,
    forced_apply_date: ?i64 = null,
    opt_in_status: ?[]const u8 = null,
    current_apply_date: ?i64 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .auto_applied_after_date = "AutoAppliedAfterDate",
            .forced_apply_date = "ForcedApplyDate",
            .opt_in_status = "OptInStatus",
            .current_apply_date = "CurrentApplyDate",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterSnapshot = struct {
    availability_zones: ?[][]const u8 = null,
    db_cluster_snapshot_identifier: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    snapshot_create_time: ?i64 = null,
    engine: ?[]const u8 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    vpc_id: ?[]const u8 = null,
    cluster_create_time: ?i64 = null,
    master_username: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    percent_progress: ?i64 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_cluster_snapshot_arn: ?[]const u8 = null,
    source_db_cluster_snapshot_arn: ?[]const u8 = null,
    storage_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .db_cluster_snapshot_identifier = "DBClusterSnapshotIdentifier",
            .db_cluster_identifier = "DBClusterIdentifier",
            .snapshot_create_time = "SnapshotCreateTime",
            .engine = "Engine",
            .status = "Status",
            .port = "Port",
            .vpc_id = "VpcId",
            .cluster_create_time = "ClusterCreateTime",
            .master_username = "MasterUsername",
            .engine_version = "EngineVersion",
            .snapshot_type = "SnapshotType",
            .percent_progress = "PercentProgress",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .db_cluster_snapshot_arn = "DBClusterSnapshotArn",
            .source_db_cluster_snapshot_arn = "SourceDBClusterSnapshotArn",
            .storage_type = "StorageType",
        };
        return @field(mappings, field_name);
    }
};

pub const DBClusterParameterGroup = struct {
    db_cluster_parameter_group_name: ?[]const u8 = null,
    db_parameter_group_family: ?[]const u8 = null,
    description: ?[]const u8 = null,
    db_cluster_parameter_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_parameter_group_name = "DBClusterParameterGroupName",
            .db_parameter_group_family = "DBParameterGroupFamily",
            .description = "Description",
            .db_cluster_parameter_group_arn = "DBClusterParameterGroupArn",
        };
        return @field(mappings, field_name);
    }
};
