const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-11-28";
pub const sdk_id: []const u8 = "DocDB Elastic";
pub const arn_namespace: ?[]const u8 = "docdb-elastic";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "docdb-elastic";
pub const name: []const u8 = "ChimeraDbLionfishServiceLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-11-28",
    sdk_id: []const u8 = "DocDB Elastic",
    arn_namespace: ?[]const u8 = "docdb-elastic",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "docdb-elastic",
    name: []const u8 = "ChimeraDbLionfishServiceLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_cluster: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cluster",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        cluster_name: []const u8,
        auth_type: []const u8,
        admin_user_name: []const u8,
        admin_user_password: []const u8,
        shard_capacity: i64,
        shard_count: i64,
        vpc_security_group_ids: ?[][]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .auth_type = "authType",
                .admin_user_name = "adminUserName",
                .admin_user_password = "adminUserPassword",
                .shard_capacity = "shardCapacity",
                .shard_count = "shardCount",
                .vpc_security_group_ids = "vpcSecurityGroupIds",
                .subnet_ids = "subnetIds",
                .kms_key_id = "kmsKeyId",
                .client_token = "clientToken",
                .preferred_maintenance_window = "preferredMaintenanceWindow",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster: Cluster,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_cluster_snapshot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cluster-snapshot",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateClusterSnapshot",
    Request: type = struct {
        cluster_arn: []const u8,
        snapshot_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .snapshot_name = "snapshotName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ClusterSnapshot,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_cluster: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/cluster/{clusterArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        cluster_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {
        cluster: Cluster,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_cluster_snapshot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/cluster-snapshot/{snapshotArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteClusterSnapshot",
    Request: type = struct {
        snapshot_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_arn = "snapshotArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ClusterSnapshot,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_cluster: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cluster/{clusterArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCluster",
    Request: type = struct {
        cluster_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cluster) } {
            return .{ .service_metadata = service_metadata, .action = get_cluster };
        }
    },
    Response: type = struct {
        cluster: Cluster,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_cluster_snapshot: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cluster-snapshot/{snapshotArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetClusterSnapshot",
    Request: type = struct {
        snapshot_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_arn = "snapshotArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = get_cluster_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ClusterSnapshot,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_clusters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters",
        .success_code = 200,
    };

    action_name: []const u8 = "ListClusters",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_clusters };
        }
    },
    Response: type = struct {
        clusters: ?[]struct {
            cluster_name: []const u8,
            cluster_arn: []const u8,
            status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_name = "clusterName",
                    .cluster_arn = "clusterArn",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .clusters = "clusters",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_cluster_snapshots: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cluster-snapshots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListClusterSnapshots",
    Request: type = struct {
        cluster_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .cluster_arn = "clusterArn",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cluster_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = list_cluster_snapshots };
        }
    },
    Response: type = struct {
        snapshots: ?[]struct {
            snapshot_name: []const u8,
            snapshot_arn: []const u8,
            cluster_arn: []const u8,
            status: []const u8,
            snapshot_creation_time: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .snapshot_name = "snapshotName",
                    .snapshot_arn = "snapshotArn",
                    .cluster_arn = "clusterArn",
                    .status = "status",
                    .snapshot_creation_time = "snapshotCreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshots = "snapshots",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const restore_cluster_from_snapshot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cluster-snapshot/{snapshotArn}/restore",
        .success_code = 200,
    };

    action_name: []const u8 = "RestoreClusterFromSnapshot",
    Request: type = struct {
        cluster_name: []const u8,
        snapshot_arn: []const u8,
        vpc_security_group_ids: ?[][]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .snapshot_arn = "snapshotArn",
                .vpc_security_group_ids = "vpcSecurityGroupIds",
                .subnet_ids = "subnetIds",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_cluster_from_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = restore_cluster_from_snapshot };
        }
    },
    Response: type = struct {
        cluster: Cluster,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_cluster: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cluster/{clusterArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCluster",
    Request: type = struct {
        cluster_arn: []const u8,
        auth_type: ?[]const u8 = null,
        shard_capacity: ?i64 = null,
        shard_count: ?i64 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        admin_user_password: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .auth_type = "authType",
                .shard_capacity = "shardCapacity",
                .shard_count = "shardCount",
                .vpc_security_group_ids = "vpcSecurityGroupIds",
                .subnet_ids = "subnetIds",
                .admin_user_password = "adminUserPassword",
                .client_token = "clientToken",
                .preferred_maintenance_window = "preferredMaintenanceWindow",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster };
        }
    },
    Response: type = struct {
        cluster: Cluster,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Cluster = struct {
    cluster_name: []const u8,
    cluster_arn: []const u8,
    status: []const u8,
    cluster_endpoint: []const u8,
    create_time: []const u8,
    admin_user_name: []const u8,
    auth_type: []const u8,
    shard_capacity: i64,
    shard_count: i64,
    vpc_security_group_ids: [][]const u8,
    subnet_ids: [][]const u8,
    preferred_maintenance_window: []const u8,
    kms_key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_name = "clusterName",
            .cluster_arn = "clusterArn",
            .status = "status",
            .cluster_endpoint = "clusterEndpoint",
            .create_time = "createTime",
            .admin_user_name = "adminUserName",
            .auth_type = "authType",
            .shard_capacity = "shardCapacity",
            .shard_count = "shardCount",
            .vpc_security_group_ids = "vpcSecurityGroupIds",
            .subnet_ids = "subnetIds",
            .preferred_maintenance_window = "preferredMaintenanceWindow",
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterSnapshot = struct {
    subnet_ids: [][]const u8,
    snapshot_name: []const u8,
    snapshot_arn: []const u8,
    snapshot_creation_time: []const u8,
    cluster_arn: []const u8,
    cluster_creation_time: []const u8,
    status: []const u8,
    vpc_security_group_ids: [][]const u8,
    admin_user_name: []const u8,
    kms_key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "subnetIds",
            .snapshot_name = "snapshotName",
            .snapshot_arn = "snapshotArn",
            .snapshot_creation_time = "snapshotCreationTime",
            .cluster_arn = "clusterArn",
            .cluster_creation_time = "clusterCreationTime",
            .status = "status",
            .vpc_security_group_ids = "vpcSecurityGroupIds",
            .admin_user_name = "adminUserName",
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }
};
