const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-02-26";
pub const sdk_id: []const u8 = "drs";
pub const arn_namespace: ?[]const u8 = "drs";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "drs";
pub const name: []const u8 = "ElasticDisasterRecoveryService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-02-26",
    sdk_id: []const u8 = "drs",
    arn_namespace: ?[]const u8 = "drs",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "drs",
    name: []const u8 = "ElasticDisasterRecoveryService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_extended_source_server: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateExtendedSourceServer",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateExtendedSourceServer",
    Request: type = struct {
        source_server_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_server_arn = "sourceServerArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_extended_source_server) } {
            return .{ .service_metadata = service_metadata, .action = create_extended_source_server };
        }
    },
    Response: type = struct {
        source_server: ?struct {
            source_server_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            recovery_instance_id: ?[]const u8 = null,
            last_launch_result: ?[]const u8 = null,
            data_replication_info: ?struct {
                lag_duration: ?[]const u8 = null,
                eta_date_time: ?[]const u8 = null,
                replicated_disks: ?[]struct {
                    device_name: ?[]const u8 = null,
                    total_storage_bytes: ?i64 = null,
                    replicated_storage_bytes: ?i64 = null,
                    rescanned_storage_bytes: ?i64 = null,
                    backlogged_storage_bytes: ?i64 = null,
                    volume_status: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .device_name = "deviceName",
                            .total_storage_bytes = "totalStorageBytes",
                            .replicated_storage_bytes = "replicatedStorageBytes",
                            .rescanned_storage_bytes = "rescannedStorageBytes",
                            .backlogged_storage_bytes = "backloggedStorageBytes",
                            .volume_status = "volumeStatus",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                data_replication_state: ?[]const u8 = null,
                data_replication_initiation: ?struct {
                    start_date_time: ?[]const u8 = null,
                    next_attempt_date_time: ?[]const u8 = null,
                    steps: ?[]struct {
                        name: ?[]const u8 = null,
                        status: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "name",
                                .status = "status",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .start_date_time = "startDateTime",
                            .next_attempt_date_time = "nextAttemptDateTime",
                            .steps = "steps",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                data_replication_error: ?struct {
                    @"error": ?[]const u8 = null,
                    raw_error: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .@"error" = "error",
                            .raw_error = "rawError",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                staging_availability_zone: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .lag_duration = "lagDuration",
                        .eta_date_time = "etaDateTime",
                        .replicated_disks = "replicatedDisks",
                        .data_replication_state = "dataReplicationState",
                        .data_replication_initiation = "dataReplicationInitiation",
                        .data_replication_error = "dataReplicationError",
                        .staging_availability_zone = "stagingAvailabilityZone",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            life_cycle: ?struct {
                added_to_service_date_time: ?[]const u8 = null,
                first_byte_date_time: ?[]const u8 = null,
                elapsed_replication_duration: ?[]const u8 = null,
                last_seen_by_service_date_time: ?[]const u8 = null,
                last_launch: ?struct {
                    initiated: ?struct {
                        api_call_date_time: ?[]const u8 = null,
                        job_id: ?[]const u8 = null,
                        type: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .api_call_date_time = "apiCallDateTime",
                                .job_id = "jobID",
                                .type = "type",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    status: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .initiated = "initiated",
                            .status = "status",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .added_to_service_date_time = "addedToServiceDateTime",
                        .first_byte_date_time = "firstByteDateTime",
                        .elapsed_replication_duration = "elapsedReplicationDuration",
                        .last_seen_by_service_date_time = "lastSeenByServiceDateTime",
                        .last_launch = "lastLaunch",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            source_properties: ?struct {
                last_updated_date_time: ?[]const u8 = null,
                recommended_instance_type: ?[]const u8 = null,
                identification_hints: ?struct {
                    fqdn: ?[]const u8 = null,
                    hostname: ?[]const u8 = null,
                    vm_ware_uuid: ?[]const u8 = null,
                    aws_instance_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .fqdn = "fqdn",
                            .hostname = "hostname",
                            .vm_ware_uuid = "vmWareUuid",
                            .aws_instance_id = "awsInstanceID",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                network_interfaces: ?[]struct {
                    mac_address: ?[]const u8 = null,
                    ips: ?[][]const u8 = null,
                    is_primary: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .mac_address = "macAddress",
                            .ips = "ips",
                            .is_primary = "isPrimary",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                disks: ?[]struct {
                    device_name: ?[]const u8 = null,
                    bytes: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .device_name = "deviceName",
                            .bytes = "bytes",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                cpus: ?[]struct {
                    cores: ?i64 = null,
                    model_name: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cores = "cores",
                            .model_name = "modelName",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ram_bytes: ?i64 = null,
                os: ?struct {
                    full_string: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .full_string = "fullString",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                supports_nitro_instances: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .last_updated_date_time = "lastUpdatedDateTime",
                        .recommended_instance_type = "recommendedInstanceType",
                        .identification_hints = "identificationHints",
                        .network_interfaces = "networkInterfaces",
                        .disks = "disks",
                        .cpus = "cpus",
                        .ram_bytes = "ramBytes",
                        .os = "os",
                        .supports_nitro_instances = "supportsNitroInstances",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            staging_area: ?struct {
                status: ?[]const u8 = null,
                staging_account_id: ?[]const u8 = null,
                staging_source_server_arn: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "status",
                        .staging_account_id = "stagingAccountID",
                        .staging_source_server_arn = "stagingSourceServerArn",
                        .error_message = "errorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            source_cloud_properties: ?struct {
                origin_account_id: ?[]const u8 = null,
                origin_region: ?[]const u8 = null,
                origin_availability_zone: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .origin_account_id = "originAccountID",
                        .origin_region = "originRegion",
                        .origin_availability_zone = "originAvailabilityZone",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            replication_direction: ?[]const u8 = null,
            reversed_direction_source_server_arn: ?[]const u8 = null,
            source_network_id: ?[]const u8 = null,
            agent_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_server_id = "sourceServerID",
                    .arn = "arn",
                    .tags = "tags",
                    .recovery_instance_id = "recoveryInstanceId",
                    .last_launch_result = "lastLaunchResult",
                    .data_replication_info = "dataReplicationInfo",
                    .life_cycle = "lifeCycle",
                    .source_properties = "sourceProperties",
                    .staging_area = "stagingArea",
                    .source_cloud_properties = "sourceCloudProperties",
                    .replication_direction = "replicationDirection",
                    .reversed_direction_source_server_arn = "reversedDirectionSourceServerArn",
                    .source_network_id = "sourceNetworkID",
                    .agent_version = "agentVersion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_server = "sourceServer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        UninitializedAccount,
        Validation,
    },
} = .{};
pub const delete_launch_action: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteLaunchAction",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteLaunchAction",
    Request: type = struct {
        resource_id: []const u8,
        action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "resourceId",
                .action_id = "actionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_launch_action) } {
            return .{ .service_metadata = service_metadata, .action = delete_launch_action };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        UninitializedAccount,
        Validation,
    },
} = .{};
pub const initialize_service: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/InitializeService",
        .success_code = 204,
    };

    action_name: []const u8 = "InitializeService",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initialize_service) } {
            return .{ .service_metadata = service_metadata, .action = initialize_service };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_extensible_source_servers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListExtensibleSourceServers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListExtensibleSourceServers",
    Request: type = struct {
        staging_account_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .staging_account_id = "stagingAccountID",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_extensible_source_servers) } {
            return .{ .service_metadata = service_metadata, .action = list_extensible_source_servers };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            hostname: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hostname = "hostname",
                    .arn = "arn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        UninitializedAccount,
        Validation,
    },
} = .{};
pub const list_launch_actions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListLaunchActions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLaunchActions",
    Request: type = struct {
        resource_id: []const u8,
        filters: ?struct {
            action_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_ids = "actionIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "resourceId",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_launch_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_launch_actions };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            action_id: ?[]const u8 = null,
            action_code: ?[]const u8 = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            active: ?bool = null,
            order: ?i64 = null,
            action_version: ?[]const u8 = null,
            optional: ?bool = null,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?LaunchActionParameter = null,
            } = null,
            description: ?[]const u8 = null,
            category: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_id = "actionId",
                    .action_code = "actionCode",
                    .type = "type",
                    .name = "name",
                    .active = "active",
                    .order = "order",
                    .action_version = "actionVersion",
                    .optional = "optional",
                    .parameters = "parameters",
                    .description = "description",
                    .category = "category",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        UninitializedAccount,
    },
} = .{};
pub const list_staging_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ListStagingAccounts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStagingAccounts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_staging_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_staging_accounts };
        }
    },
    Response: type = struct {
        accounts: ?[]struct {
            account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountID",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "accounts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        UninitializedAccount,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_launch_action: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutLaunchAction",
        .success_code = 200,
    };

    action_name: []const u8 = "PutLaunchAction",
    Request: type = struct {
        resource_id: []const u8,
        action_code: []const u8,
        order: i64,
        action_id: []const u8,
        optional: bool,
        active: bool,
        name: []const u8,
        action_version: []const u8,
        category: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LaunchActionParameter = null,
        } = null,
        description: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "resourceId",
                .action_code = "actionCode",
                .order = "order",
                .action_id = "actionId",
                .optional = "optional",
                .active = "active",
                .name = "name",
                .action_version = "actionVersion",
                .category = "category",
                .parameters = "parameters",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_launch_action) } {
            return .{ .service_metadata = service_metadata, .action = put_launch_action };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,
        action_id: ?[]const u8 = null,
        action_code: ?[]const u8 = null,
        type: ?[]const u8 = null,
        name: ?[]const u8 = null,
        active: ?bool = null,
        order: ?i64 = null,
        action_version: ?[]const u8 = null,
        optional: ?bool = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LaunchActionParameter = null,
        } = null,
        description: ?[]const u8 = null,
        category: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "resourceId",
                .action_id = "actionId",
                .action_code = "actionCode",
                .type = "type",
                .name = "name",
                .active = "active",
                .order = "order",
                .action_version = "actionVersion",
                .optional = "optional",
                .parameters = "parameters",
                .description = "description",
                .category = "category",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        UninitializedAccount,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const LaunchActionParameter = struct {
    value: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};
