const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-08-10";
pub const sdk_id: []const u8 = "DynamoDB";
pub const arn_namespace: ?[]const u8 = "dynamodb";
pub const endpoint_prefix: []const u8 = "dynamodb";
pub const sigv4_name: []const u8 = "dynamodb";
pub const name: []const u8 = "DynamoDB_20120810";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2012-08-10",
    sdk_id: []const u8 = "DynamoDB",
    arn_namespace: ?[]const u8 = "dynamodb",
    endpoint_prefix: []const u8 = "dynamodb",
    sigv4_name: []const u8 = "dynamodb",
    name: []const u8 = "DynamoDB_20120810",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const batch_execute_statement: struct {
    action_name: []const u8 = "BatchExecuteStatement",
    Request: type = struct {
        statements: []struct {
            statement: []const u8,
            parameters: ?[]AttributeValue = null,
            consistent_read: ?bool = null,
            return_values_on_condition_check_failure: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .statement = "Statement",
                    .parameters = "Parameters",
                    .consistent_read = "ConsistentRead",
                    .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
                };
                return @field(mappings, field_name);
            }
        },
        return_consumed_capacity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statements = "Statements",
                .return_consumed_capacity = "ReturnConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_execute_statement) } {
            return .{ .service_metadata = service_metadata, .action = batch_execute_statement };
        }
    },
    Response: type = struct {
        responses: ?[]struct {
            @"error": ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,
                item: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "Code",
                        .message = "Message",
                        .item = "Item",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "item", field_name))
                        return try serializeMap(self.item, self.fieldNameFor("item"), options, out_stream);
                    return false;
                }
            } = null,
            table_name: ?[]const u8 = null,
            item: ?[]struct {
                key: ?[]const u8 = null,
                value: ?AttributeValue = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .@"error" = "Error",
                    .table_name = "TableName",
                    .item = "Item",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "item", field_name))
                    return try serializeMap(self.item, self.fieldNameFor("item"), options, out_stream);
                return false;
            }
        } = null,
        consumed_capacity: ?[]ConsumedCapacity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .responses = "Responses",
                .consumed_capacity = "ConsumedCapacity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        RequestLimitExceeded,
    },
} = .{};
pub const batch_get_item: struct {
    action_name: []const u8 = "BatchGetItem",
    Request: type = struct {
        request_items: []struct {
            key: ?[]const u8 = null,
            value: ?KeysAndAttributes = null,
        },
        return_consumed_capacity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_items = "RequestItems",
                .return_consumed_capacity = "ReturnConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_items", field_name))
                return try serializeMap(self.request_items, self.fieldNameFor("request_items"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_item) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_item };
        }
    },
    Response: type = struct {
        responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?AttributeValue = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        unprocessed_keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?KeysAndAttributes = null,
        } = null,
        consumed_capacity: ?[]ConsumedCapacity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .responses = "Responses",
                .unprocessed_keys = "UnprocessedKeys",
                .consumed_capacity = "ConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "responses", field_name))
                return try serializeMap(self.responses, self.fieldNameFor("responses"), options, out_stream);
            if (std.mem.eql(u8, "unprocessed_keys", field_name))
                return try serializeMap(self.unprocessed_keys, self.fieldNameFor("unprocessed_keys"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const batch_write_item: struct {
    action_name: []const u8 = "BatchWriteItem",
    Request: type = struct {
        request_items: []struct {
            key: ?[]const u8 = null,
            value: ?[]WriteRequest = null,
        },
        return_consumed_capacity: ?[]const u8 = null,
        return_item_collection_metrics: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_items = "RequestItems",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .return_item_collection_metrics = "ReturnItemCollectionMetrics",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_items", field_name))
                return try serializeMap(self.request_items, self.fieldNameFor("request_items"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_write_item) } {
            return .{ .service_metadata = service_metadata, .action = batch_write_item };
        }
    },
    Response: type = struct {
        unprocessed_items: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]WriteRequest = null,
        } = null,
        item_collection_metrics: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ItemCollectionMetrics = null,
        } = null,
        consumed_capacity: ?[]ConsumedCapacity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_items = "UnprocessedItems",
                .item_collection_metrics = "ItemCollectionMetrics",
                .consumed_capacity = "ConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "unprocessed_items", field_name))
                return try serializeMap(self.unprocessed_items, self.fieldNameFor("unprocessed_items"), options, out_stream);
            if (std.mem.eql(u8, "item_collection_metrics", field_name))
                return try serializeMap(self.item_collection_metrics, self.fieldNameFor("item_collection_metrics"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ItemCollectionSizeLimitExceeded,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_backup: struct {
    action_name: []const u8 = "CreateBackup",
    Request: type = struct {
        table_name: []const u8,
        backup_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .backup_name = "BackupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backup) } {
            return .{ .service_metadata = service_metadata, .action = create_backup };
        }
    },
    Response: type = struct {
        backup_details: ?BackupDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_details = "BackupDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupInUse,
        ContinuousBackupsUnavailable,
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        TableInUse,
        TableNotFound,
    },
} = .{};
pub const create_global_table: struct {
    action_name: []const u8 = "CreateGlobalTable",
    Request: type = struct {
        global_table_name: []const u8,
        replication_group: []Replica,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_name = "GlobalTableName",
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_global_table) } {
            return .{ .service_metadata = service_metadata, .action = create_global_table };
        }
    },
    Response: type = struct {
        global_table_description: ?GlobalTableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_description = "GlobalTableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalTableAlreadyExists,
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        TableNotFound,
    },
} = .{};
pub const create_table: struct {
    action_name: []const u8 = "CreateTable",
    Request: type = struct {
        attribute_definitions: []AttributeDefinition,
        table_name: []const u8,
        key_schema: []KeySchemaElement,
        local_secondary_indexes: ?[]LocalSecondaryIndex = null,
        global_secondary_indexes: ?[]GlobalSecondaryIndex = null,
        billing_mode: ?[]const u8 = null,
        provisioned_throughput: ?ProvisionedThroughput = null,
        stream_specification: ?StreamSpecification = null,
        sse_specification: ?SSESpecification = null,
        tags: ?[]Tag = null,
        table_class: ?[]const u8 = null,
        deletion_protection_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_definitions = "AttributeDefinitions",
                .table_name = "TableName",
                .key_schema = "KeySchema",
                .local_secondary_indexes = "LocalSecondaryIndexes",
                .global_secondary_indexes = "GlobalSecondaryIndexes",
                .billing_mode = "BillingMode",
                .provisioned_throughput = "ProvisionedThroughput",
                .stream_specification = "StreamSpecification",
                .sse_specification = "SSESpecification",
                .tags = "Tags",
                .table_class = "TableClass",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_table) } {
            return .{ .service_metadata = service_metadata, .action = create_table };
        }
    },
    Response: type = struct {
        table_description: ?TableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_description = "TableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
    },
} = .{};
pub const delete_backup: struct {
    action_name: []const u8 = "DeleteBackup",
    Request: type = struct {
        backup_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_arn = "BackupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup };
        }
    },
    Response: type = struct {
        backup_description: ?BackupDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_description = "BackupDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupInUse,
        BackupNotFound,
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
    },
} = .{};
pub const delete_item: struct {
    action_name: []const u8 = "DeleteItem",
    Request: type = struct {
        table_name: []const u8,
        key: []struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        },
        expected: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ExpectedAttributeValue = null,
        } = null,
        conditional_operator: ?[]const u8 = null,
        return_values: ?[]const u8 = null,
        return_consumed_capacity: ?[]const u8 = null,
        return_item_collection_metrics: ?[]const u8 = null,
        condition_expression: ?[]const u8 = null,
        expression_attribute_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        expression_attribute_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        return_values_on_condition_check_failure: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .key = "Key",
                .expected = "Expected",
                .conditional_operator = "ConditionalOperator",
                .return_values = "ReturnValues",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .return_item_collection_metrics = "ReturnItemCollectionMetrics",
                .condition_expression = "ConditionExpression",
                .expression_attribute_names = "ExpressionAttributeNames",
                .expression_attribute_values = "ExpressionAttributeValues",
                .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "key", field_name))
                return try serializeMap(self.key, self.fieldNameFor("key"), options, out_stream);
            if (std.mem.eql(u8, "expected", field_name))
                return try serializeMap(self.expected, self.fieldNameFor("expected"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_names", field_name))
                return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_values", field_name))
                return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_item) } {
            return .{ .service_metadata = service_metadata, .action = delete_item };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        consumed_capacity: ?ConsumedCapacity = null,
        item_collection_metrics: ?ItemCollectionMetrics = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .consumed_capacity = "ConsumedCapacity",
                .item_collection_metrics = "ItemCollectionMetrics",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConditionalCheckFailed,
        InternalServerError,
        InvalidEndpoint,
        ItemCollectionSizeLimitExceeded,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
        TransactionConflict,
    },
} = .{};
pub const delete_table: struct {
    action_name: []const u8 = "DeleteTable",
    Request: type = struct {
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_table };
        }
    },
    Response: type = struct {
        table_description: ?TableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_description = "TableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const describe_backup: struct {
    action_name: []const u8 = "DescribeBackup",
    Request: type = struct {
        backup_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_arn = "BackupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_backup) } {
            return .{ .service_metadata = service_metadata, .action = describe_backup };
        }
    },
    Response: type = struct {
        backup_description: ?BackupDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_description = "BackupDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupNotFound,
        InternalServerError,
        InvalidEndpoint,
    },
} = .{};
pub const describe_continuous_backups: struct {
    action_name: []const u8 = "DescribeContinuousBackups",
    Request: type = struct {
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_continuous_backups) } {
            return .{ .service_metadata = service_metadata, .action = describe_continuous_backups };
        }
    },
    Response: type = struct {
        continuous_backups_description: ?ContinuousBackupsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .continuous_backups_description = "ContinuousBackupsDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        TableNotFound,
    },
} = .{};
pub const describe_contributor_insights: struct {
    action_name: []const u8 = "DescribeContributorInsights",
    Request: type = struct {
        table_name: []const u8,
        index_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .index_name = "IndexName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_contributor_insights) } {
            return .{ .service_metadata = service_metadata, .action = describe_contributor_insights };
        }
    },
    Response: type = struct {
        table_name: ?[]const u8 = null,
        index_name: ?[]const u8 = null,
        contributor_insights_rule_list: ?[][]const u8 = null,
        contributor_insights_status: ?[]const u8 = null,
        last_update_date_time: ?i64 = null,
        failure_exception: ?struct {
            exception_name: ?[]const u8 = null,
            exception_description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .exception_name = "ExceptionName",
                    .exception_description = "ExceptionDescription",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .index_name = "IndexName",
                .contributor_insights_rule_list = "ContributorInsightsRuleList",
                .contributor_insights_status = "ContributorInsightsStatus",
                .last_update_date_time = "LastUpdateDateTime",
                .failure_exception = "FailureException",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceNotFound,
    },
} = .{};
pub const describe_endpoints: struct {
    action_name: []const u8 = "DescribeEndpoints",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoints };
        }
    },
    Response: type = struct {
        endpoints: []struct {
            address: []const u8,
            cache_period_in_minutes: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .address = "Address",
                    .cache_period_in_minutes = "CachePeriodInMinutes",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_export: struct {
    action_name: []const u8 = "DescribeExport",
    Request: type = struct {
        export_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_arn = "ExportArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_export) } {
            return .{ .service_metadata = service_metadata, .action = describe_export };
        }
    },
    Response: type = struct {
        export_description: ?ExportDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_description = "ExportDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExportNotFound,
        InternalServerError,
        LimitExceeded,
    },
} = .{};
pub const describe_global_table: struct {
    action_name: []const u8 = "DescribeGlobalTable",
    Request: type = struct {
        global_table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_name = "GlobalTableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_global_table) } {
            return .{ .service_metadata = service_metadata, .action = describe_global_table };
        }
    },
    Response: type = struct {
        global_table_description: ?GlobalTableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_description = "GlobalTableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalTableNotFound,
        InternalServerError,
        InvalidEndpoint,
    },
} = .{};
pub const describe_global_table_settings: struct {
    action_name: []const u8 = "DescribeGlobalTableSettings",
    Request: type = struct {
        global_table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_name = "GlobalTableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_global_table_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_global_table_settings };
        }
    },
    Response: type = struct {
        global_table_name: ?[]const u8 = null,
        replica_settings: ?[]ReplicaSettingsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_name = "GlobalTableName",
                .replica_settings = "ReplicaSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalTableNotFound,
        InternalServerError,
        InvalidEndpoint,
    },
} = .{};
pub const describe_import: struct {
    action_name: []const u8 = "DescribeImport",
    Request: type = struct {
        import_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_arn = "ImportArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_import) } {
            return .{ .service_metadata = service_metadata, .action = describe_import };
        }
    },
    Response: type = struct {
        import_table_description: ImportTableDescription,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_table_description = "ImportTableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImportNotFound,
    },
} = .{};
pub const describe_kinesis_streaming_destination: struct {
    action_name: []const u8 = "DescribeKinesisStreamingDestination",
    Request: type = struct {
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_kinesis_streaming_destination) } {
            return .{ .service_metadata = service_metadata, .action = describe_kinesis_streaming_destination };
        }
    },
    Response: type = struct {
        table_name: ?[]const u8 = null,
        kinesis_data_stream_destinations: ?[]struct {
            stream_arn: ?[]const u8 = null,
            destination_status: ?[]const u8 = null,
            destination_status_description: ?[]const u8 = null,
            approximate_creation_date_time_precision: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stream_arn = "StreamArn",
                    .destination_status = "DestinationStatus",
                    .destination_status_description = "DestinationStatusDescription",
                    .approximate_creation_date_time_precision = "ApproximateCreationDateTimePrecision",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .kinesis_data_stream_destinations = "KinesisDataStreamDestinations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ResourceNotFound,
    },
} = .{};
pub const describe_limits: struct {
    action_name: []const u8 = "DescribeLimits",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_limits };
        }
    },
    Response: type = struct {
        account_max_read_capacity_units: ?i64 = null,
        account_max_write_capacity_units: ?i64 = null,
        table_max_read_capacity_units: ?i64 = null,
        table_max_write_capacity_units: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_max_read_capacity_units = "AccountMaxReadCapacityUnits",
                .account_max_write_capacity_units = "AccountMaxWriteCapacityUnits",
                .table_max_read_capacity_units = "TableMaxReadCapacityUnits",
                .table_max_write_capacity_units = "TableMaxWriteCapacityUnits",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
    },
} = .{};
pub const describe_table: struct {
    action_name: []const u8 = "DescribeTable",
    Request: type = struct {
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_table) } {
            return .{ .service_metadata = service_metadata, .action = describe_table };
        }
    },
    Response: type = struct {
        table: ?TableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table = "Table",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ResourceNotFound,
    },
} = .{};
pub const describe_table_replica_auto_scaling: struct {
    action_name: []const u8 = "DescribeTableReplicaAutoScaling",
    Request: type = struct {
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_table_replica_auto_scaling) } {
            return .{ .service_metadata = service_metadata, .action = describe_table_replica_auto_scaling };
        }
    },
    Response: type = struct {
        table_auto_scaling_description: ?TableAutoScalingDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_auto_scaling_description = "TableAutoScalingDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceNotFound,
    },
} = .{};
pub const describe_time_to_live: struct {
    action_name: []const u8 = "DescribeTimeToLive",
    Request: type = struct {
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_time_to_live) } {
            return .{ .service_metadata = service_metadata, .action = describe_time_to_live };
        }
    },
    Response: type = struct {
        time_to_live_description: ?TimeToLiveDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_to_live_description = "TimeToLiveDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ResourceNotFound,
    },
} = .{};
pub const disable_kinesis_streaming_destination: struct {
    action_name: []const u8 = "DisableKinesisStreamingDestination",
    Request: type = struct {
        table_name: []const u8,
        stream_arn: []const u8,
        enable_kinesis_streaming_configuration: ?EnableKinesisStreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .stream_arn = "StreamArn",
                .enable_kinesis_streaming_configuration = "EnableKinesisStreamingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_kinesis_streaming_destination) } {
            return .{ .service_metadata = service_metadata, .action = disable_kinesis_streaming_destination };
        }
    },
    Response: type = struct {
        table_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        destination_status: ?[]const u8 = null,
        enable_kinesis_streaming_configuration: ?EnableKinesisStreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .stream_arn = "StreamArn",
                .destination_status = "DestinationStatus",
                .enable_kinesis_streaming_configuration = "EnableKinesisStreamingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const enable_kinesis_streaming_destination: struct {
    action_name: []const u8 = "EnableKinesisStreamingDestination",
    Request: type = struct {
        table_name: []const u8,
        stream_arn: []const u8,
        enable_kinesis_streaming_configuration: ?EnableKinesisStreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .stream_arn = "StreamArn",
                .enable_kinesis_streaming_configuration = "EnableKinesisStreamingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_kinesis_streaming_destination) } {
            return .{ .service_metadata = service_metadata, .action = enable_kinesis_streaming_destination };
        }
    },
    Response: type = struct {
        table_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        destination_status: ?[]const u8 = null,
        enable_kinesis_streaming_configuration: ?EnableKinesisStreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .stream_arn = "StreamArn",
                .destination_status = "DestinationStatus",
                .enable_kinesis_streaming_configuration = "EnableKinesisStreamingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const execute_statement: struct {
    action_name: []const u8 = "ExecuteStatement",
    Request: type = struct {
        statement: []const u8,
        parameters: ?[]AttributeValue = null,
        consistent_read: ?bool = null,
        next_token: ?[]const u8 = null,
        return_consumed_capacity: ?[]const u8 = null,
        limit: ?i64 = null,
        return_values_on_condition_check_failure: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement = "Statement",
                .parameters = "Parameters",
                .consistent_read = "ConsistentRead",
                .next_token = "NextToken",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .limit = "Limit",
                .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_statement) } {
            return .{ .service_metadata = service_metadata, .action = execute_statement };
        }
    },
    Response: type = struct {
        items: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        next_token: ?[]const u8 = null,
        consumed_capacity: ?ConsumedCapacity = null,
        last_evaluated_key: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
                .consumed_capacity = "ConsumedCapacity",
                .last_evaluated_key = "LastEvaluatedKey",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "items", field_name))
                return try serializeMap(self.items, self.fieldNameFor("items"), options, out_stream);
            if (std.mem.eql(u8, "last_evaluated_key", field_name))
                return try serializeMap(self.last_evaluated_key, self.fieldNameFor("last_evaluated_key"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConditionalCheckFailed,
        DuplicateItem,
        InternalServerError,
        ItemCollectionSizeLimitExceeded,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
        TransactionConflict,
    },
} = .{};
pub const execute_transaction: struct {
    action_name: []const u8 = "ExecuteTransaction",
    Request: type = struct {
        transact_statements: []struct {
            statement: []const u8,
            parameters: ?[]AttributeValue = null,
            return_values_on_condition_check_failure: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .statement = "Statement",
                    .parameters = "Parameters",
                    .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
                };
                return @field(mappings, field_name);
            }
        },
        client_request_token: ?[]const u8 = null,
        return_consumed_capacity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transact_statements = "TransactStatements",
                .client_request_token = "ClientRequestToken",
                .return_consumed_capacity = "ReturnConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_transaction) } {
            return .{ .service_metadata = service_metadata, .action = execute_transaction };
        }
    },
    Response: type = struct {
        responses: ?[]ItemResponse = null,
        consumed_capacity: ?[]ConsumedCapacity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .responses = "Responses",
                .consumed_capacity = "ConsumedCapacity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServerError,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
        TransactionCanceled,
        TransactionInProgress,
    },
} = .{};
pub const export_table_to_point_in_time: struct {
    action_name: []const u8 = "ExportTableToPointInTime",
    Request: type = struct {
        table_arn: []const u8,
        export_time: ?i64 = null,
        client_token: ?[]const u8 = null,
        s3_bucket: []const u8,
        s3_bucket_owner: ?[]const u8 = null,
        s3_prefix: ?[]const u8 = null,
        s3_sse_algorithm: ?[]const u8 = null,
        s3_sse_kms_key_id: ?[]const u8 = null,
        export_format: ?[]const u8 = null,
        export_type: ?[]const u8 = null,
        incremental_export_specification: ?IncrementalExportSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_arn = "TableArn",
                .export_time = "ExportTime",
                .client_token = "ClientToken",
                .s3_bucket = "S3Bucket",
                .s3_bucket_owner = "S3BucketOwner",
                .s3_prefix = "S3Prefix",
                .s3_sse_algorithm = "S3SseAlgorithm",
                .s3_sse_kms_key_id = "S3SseKmsKeyId",
                .export_format = "ExportFormat",
                .export_type = "ExportType",
                .incremental_export_specification = "IncrementalExportSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_table_to_point_in_time) } {
            return .{ .service_metadata = service_metadata, .action = export_table_to_point_in_time };
        }
    },
    Response: type = struct {
        export_description: ?ExportDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_description = "ExportDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExportConflict,
        InternalServerError,
        InvalidExportTime,
        LimitExceeded,
        PointInTimeRecoveryUnavailable,
        TableNotFound,
    },
} = .{};
pub const get_item: struct {
    action_name: []const u8 = "GetItem",
    Request: type = struct {
        table_name: []const u8,
        key: []struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        },
        attributes_to_get: ?[][]const u8 = null,
        consistent_read: ?bool = null,
        return_consumed_capacity: ?[]const u8 = null,
        projection_expression: ?[]const u8 = null,
        expression_attribute_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .key = "Key",
                .attributes_to_get = "AttributesToGet",
                .consistent_read = "ConsistentRead",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .projection_expression = "ProjectionExpression",
                .expression_attribute_names = "ExpressionAttributeNames",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "key", field_name))
                return try serializeMap(self.key, self.fieldNameFor("key"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_names", field_name))
                return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_item) } {
            return .{ .service_metadata = service_metadata, .action = get_item };
        }
    },
    Response: type = struct {
        item: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        consumed_capacity: ?ConsumedCapacity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .item = "Item",
                .consumed_capacity = "ConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "item", field_name))
                return try serializeMap(self.item, self.fieldNameFor("item"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const import_table: struct {
    action_name: []const u8 = "ImportTable",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        s3_bucket_source: S3BucketSource,
        input_format: []const u8,
        input_format_options: ?InputFormatOptions = null,
        input_compression_type: ?[]const u8 = null,
        table_creation_parameters: TableCreationParameters,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .s3_bucket_source = "S3BucketSource",
                .input_format = "InputFormat",
                .input_format_options = "InputFormatOptions",
                .input_compression_type = "InputCompressionType",
                .table_creation_parameters = "TableCreationParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_table) } {
            return .{ .service_metadata = service_metadata, .action = import_table };
        }
    },
    Response: type = struct {
        import_table_description: ImportTableDescription,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_table_description = "ImportTableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImportConflict,
        LimitExceeded,
        ResourceInUse,
    },
} = .{};
pub const list_backups: struct {
    action_name: []const u8 = "ListBackups",
    Request: type = struct {
        table_name: ?[]const u8 = null,
        limit: ?i64 = null,
        time_range_lower_bound: ?i64 = null,
        time_range_upper_bound: ?i64 = null,
        exclusive_start_backup_arn: ?[]const u8 = null,
        backup_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .limit = "Limit",
                .time_range_lower_bound = "TimeRangeLowerBound",
                .time_range_upper_bound = "TimeRangeUpperBound",
                .exclusive_start_backup_arn = "ExclusiveStartBackupArn",
                .backup_type = "BackupType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backups) } {
            return .{ .service_metadata = service_metadata, .action = list_backups };
        }
    },
    Response: type = struct {
        backup_summaries: ?[]struct {
            table_name: ?[]const u8 = null,
            table_id: ?[]const u8 = null,
            table_arn: ?[]const u8 = null,
            backup_arn: ?[]const u8 = null,
            backup_name: ?[]const u8 = null,
            backup_creation_date_time: ?i64 = null,
            backup_expiry_date_time: ?i64 = null,
            backup_status: ?[]const u8 = null,
            backup_type: ?[]const u8 = null,
            backup_size_bytes: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_name = "TableName",
                    .table_id = "TableId",
                    .table_arn = "TableArn",
                    .backup_arn = "BackupArn",
                    .backup_name = "BackupName",
                    .backup_creation_date_time = "BackupCreationDateTime",
                    .backup_expiry_date_time = "BackupExpiryDateTime",
                    .backup_status = "BackupStatus",
                    .backup_type = "BackupType",
                    .backup_size_bytes = "BackupSizeBytes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_evaluated_backup_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_summaries = "BackupSummaries",
                .last_evaluated_backup_arn = "LastEvaluatedBackupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
    },
} = .{};
pub const list_contributor_insights: struct {
    action_name: []const u8 = "ListContributorInsights",
    Request: type = struct {
        table_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contributor_insights) } {
            return .{ .service_metadata = service_metadata, .action = list_contributor_insights };
        }
    },
    Response: type = struct {
        contributor_insights_summaries: ?[]struct {
            table_name: ?[]const u8 = null,
            index_name: ?[]const u8 = null,
            contributor_insights_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_name = "TableName",
                    .index_name = "IndexName",
                    .contributor_insights_status = "ContributorInsightsStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contributor_insights_summaries = "ContributorInsightsSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceNotFound,
    },
} = .{};
pub const list_exports: struct {
    action_name: []const u8 = "ListExports",
    Request: type = struct {
        table_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_arn = "TableArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_exports) } {
            return .{ .service_metadata = service_metadata, .action = list_exports };
        }
    },
    Response: type = struct {
        export_summaries: ?[]struct {
            export_arn: ?[]const u8 = null,
            export_status: ?[]const u8 = null,
            export_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .export_arn = "ExportArn",
                    .export_status = "ExportStatus",
                    .export_type = "ExportType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_summaries = "ExportSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        LimitExceeded,
    },
} = .{};
pub const list_global_tables: struct {
    action_name: []const u8 = "ListGlobalTables",
    Request: type = struct {
        exclusive_start_global_table_name: ?[]const u8 = null,
        limit: ?i64 = null,
        region_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exclusive_start_global_table_name = "ExclusiveStartGlobalTableName",
                .limit = "Limit",
                .region_name = "RegionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_global_tables) } {
            return .{ .service_metadata = service_metadata, .action = list_global_tables };
        }
    },
    Response: type = struct {
        global_tables: ?[]struct {
            global_table_name: ?[]const u8 = null,
            replication_group: ?[]Replica = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .global_table_name = "GlobalTableName",
                    .replication_group = "ReplicationGroup",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_evaluated_global_table_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_tables = "GlobalTables",
                .last_evaluated_global_table_name = "LastEvaluatedGlobalTableName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
    },
} = .{};
pub const list_imports: struct {
    action_name: []const u8 = "ListImports",
    Request: type = struct {
        table_arn: ?[]const u8 = null,
        page_size: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_arn = "TableArn",
                .page_size = "PageSize",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_imports) } {
            return .{ .service_metadata = service_metadata, .action = list_imports };
        }
    },
    Response: type = struct {
        import_summary_list: ?[]struct {
            import_arn: ?[]const u8 = null,
            import_status: ?[]const u8 = null,
            table_arn: ?[]const u8 = null,
            s3_bucket_source: ?S3BucketSource = null,
            cloud_watch_log_group_arn: ?[]const u8 = null,
            input_format: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .import_arn = "ImportArn",
                    .import_status = "ImportStatus",
                    .table_arn = "TableArn",
                    .s3_bucket_source = "S3BucketSource",
                    .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                    .input_format = "InputFormat",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_summary_list = "ImportSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const list_tables: struct {
    action_name: []const u8 = "ListTables",
    Request: type = struct {
        exclusive_start_table_name: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exclusive_start_table_name = "ExclusiveStartTableName",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tables) } {
            return .{ .service_metadata = service_metadata, .action = list_tables };
        }
    },
    Response: type = struct {
        table_names: ?[][]const u8 = null,
        last_evaluated_table_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_names = "TableNames",
                .last_evaluated_table_name = "LastEvaluatedTableName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
    },
} = .{};
pub const list_tags_of_resource: struct {
    action_name: []const u8 = "ListTagsOfResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_of_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_of_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ResourceNotFound,
    },
} = .{};
pub const put_item: struct {
    action_name: []const u8 = "PutItem",
    Request: type = struct {
        table_name: []const u8,
        item: []struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        },
        expected: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ExpectedAttributeValue = null,
        } = null,
        return_values: ?[]const u8 = null,
        return_consumed_capacity: ?[]const u8 = null,
        return_item_collection_metrics: ?[]const u8 = null,
        conditional_operator: ?[]const u8 = null,
        condition_expression: ?[]const u8 = null,
        expression_attribute_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        expression_attribute_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        return_values_on_condition_check_failure: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .item = "Item",
                .expected = "Expected",
                .return_values = "ReturnValues",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .return_item_collection_metrics = "ReturnItemCollectionMetrics",
                .conditional_operator = "ConditionalOperator",
                .condition_expression = "ConditionExpression",
                .expression_attribute_names = "ExpressionAttributeNames",
                .expression_attribute_values = "ExpressionAttributeValues",
                .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "item", field_name))
                return try serializeMap(self.item, self.fieldNameFor("item"), options, out_stream);
            if (std.mem.eql(u8, "expected", field_name))
                return try serializeMap(self.expected, self.fieldNameFor("expected"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_names", field_name))
                return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_values", field_name))
                return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_item) } {
            return .{ .service_metadata = service_metadata, .action = put_item };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        consumed_capacity: ?ConsumedCapacity = null,
        item_collection_metrics: ?ItemCollectionMetrics = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .consumed_capacity = "ConsumedCapacity",
                .item_collection_metrics = "ItemCollectionMetrics",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConditionalCheckFailed,
        InternalServerError,
        InvalidEndpoint,
        ItemCollectionSizeLimitExceeded,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
        TransactionConflict,
    },
} = .{};
pub const query: struct {
    action_name: []const u8 = "Query",
    Request: type = struct {
        table_name: []const u8,
        index_name: ?[]const u8 = null,
        select: ?[]const u8 = null,
        attributes_to_get: ?[][]const u8 = null,
        limit: ?i64 = null,
        consistent_read: ?bool = null,
        key_conditions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Condition = null,
        } = null,
        query_filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Condition = null,
        } = null,
        conditional_operator: ?[]const u8 = null,
        scan_index_forward: ?bool = null,
        exclusive_start_key: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        return_consumed_capacity: ?[]const u8 = null,
        projection_expression: ?[]const u8 = null,
        filter_expression: ?[]const u8 = null,
        key_condition_expression: ?[]const u8 = null,
        expression_attribute_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        expression_attribute_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .index_name = "IndexName",
                .select = "Select",
                .attributes_to_get = "AttributesToGet",
                .limit = "Limit",
                .consistent_read = "ConsistentRead",
                .key_conditions = "KeyConditions",
                .query_filter = "QueryFilter",
                .conditional_operator = "ConditionalOperator",
                .scan_index_forward = "ScanIndexForward",
                .exclusive_start_key = "ExclusiveStartKey",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .projection_expression = "ProjectionExpression",
                .filter_expression = "FilterExpression",
                .key_condition_expression = "KeyConditionExpression",
                .expression_attribute_names = "ExpressionAttributeNames",
                .expression_attribute_values = "ExpressionAttributeValues",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "key_conditions", field_name))
                return try serializeMap(self.key_conditions, self.fieldNameFor("key_conditions"), options, out_stream);
            if (std.mem.eql(u8, "query_filter", field_name))
                return try serializeMap(self.query_filter, self.fieldNameFor("query_filter"), options, out_stream);
            if (std.mem.eql(u8, "exclusive_start_key", field_name))
                return try serializeMap(self.exclusive_start_key, self.fieldNameFor("exclusive_start_key"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_names", field_name))
                return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_values", field_name))
                return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query) } {
            return .{ .service_metadata = service_metadata, .action = query };
        }
    },
    Response: type = struct {
        items: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        count: ?i64 = null,
        scanned_count: ?i64 = null,
        last_evaluated_key: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        consumed_capacity: ?ConsumedCapacity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .count = "Count",
                .scanned_count = "ScannedCount",
                .last_evaluated_key = "LastEvaluatedKey",
                .consumed_capacity = "ConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "items", field_name))
                return try serializeMap(self.items, self.fieldNameFor("items"), options, out_stream);
            if (std.mem.eql(u8, "last_evaluated_key", field_name))
                return try serializeMap(self.last_evaluated_key, self.fieldNameFor("last_evaluated_key"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const restore_table_from_backup: struct {
    action_name: []const u8 = "RestoreTableFromBackup",
    Request: type = struct {
        target_table_name: []const u8,
        backup_arn: []const u8,
        billing_mode_override: ?[]const u8 = null,
        global_secondary_index_override: ?[]GlobalSecondaryIndex = null,
        local_secondary_index_override: ?[]LocalSecondaryIndex = null,
        provisioned_throughput_override: ?ProvisionedThroughput = null,
        sse_specification_override: ?SSESpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_table_name = "TargetTableName",
                .backup_arn = "BackupArn",
                .billing_mode_override = "BillingModeOverride",
                .global_secondary_index_override = "GlobalSecondaryIndexOverride",
                .local_secondary_index_override = "LocalSecondaryIndexOverride",
                .provisioned_throughput_override = "ProvisionedThroughputOverride",
                .sse_specification_override = "SSESpecificationOverride",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_table_from_backup) } {
            return .{ .service_metadata = service_metadata, .action = restore_table_from_backup };
        }
    },
    Response: type = struct {
        table_description: ?TableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_description = "TableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupInUse,
        BackupNotFound,
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        TableAlreadyExists,
        TableInUse,
    },
} = .{};
pub const restore_table_to_point_in_time: struct {
    action_name: []const u8 = "RestoreTableToPointInTime",
    Request: type = struct {
        source_table_arn: ?[]const u8 = null,
        source_table_name: ?[]const u8 = null,
        target_table_name: []const u8,
        use_latest_restorable_time: ?bool = null,
        restore_date_time: ?i64 = null,
        billing_mode_override: ?[]const u8 = null,
        global_secondary_index_override: ?[]GlobalSecondaryIndex = null,
        local_secondary_index_override: ?[]LocalSecondaryIndex = null,
        provisioned_throughput_override: ?ProvisionedThroughput = null,
        sse_specification_override: ?SSESpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_table_arn = "SourceTableArn",
                .source_table_name = "SourceTableName",
                .target_table_name = "TargetTableName",
                .use_latest_restorable_time = "UseLatestRestorableTime",
                .restore_date_time = "RestoreDateTime",
                .billing_mode_override = "BillingModeOverride",
                .global_secondary_index_override = "GlobalSecondaryIndexOverride",
                .local_secondary_index_override = "LocalSecondaryIndexOverride",
                .provisioned_throughput_override = "ProvisionedThroughputOverride",
                .sse_specification_override = "SSESpecificationOverride",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_table_to_point_in_time) } {
            return .{ .service_metadata = service_metadata, .action = restore_table_to_point_in_time };
        }
    },
    Response: type = struct {
        table_description: ?TableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_description = "TableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        InvalidRestoreTime,
        LimitExceeded,
        PointInTimeRecoveryUnavailable,
        TableAlreadyExists,
        TableInUse,
        TableNotFound,
    },
} = .{};
pub const scan: struct {
    action_name: []const u8 = "Scan",
    Request: type = struct {
        table_name: []const u8,
        index_name: ?[]const u8 = null,
        attributes_to_get: ?[][]const u8 = null,
        limit: ?i64 = null,
        select: ?[]const u8 = null,
        scan_filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Condition = null,
        } = null,
        conditional_operator: ?[]const u8 = null,
        exclusive_start_key: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        return_consumed_capacity: ?[]const u8 = null,
        total_segments: ?i64 = null,
        segment: ?i64 = null,
        projection_expression: ?[]const u8 = null,
        filter_expression: ?[]const u8 = null,
        expression_attribute_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        expression_attribute_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        consistent_read: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .index_name = "IndexName",
                .attributes_to_get = "AttributesToGet",
                .limit = "Limit",
                .select = "Select",
                .scan_filter = "ScanFilter",
                .conditional_operator = "ConditionalOperator",
                .exclusive_start_key = "ExclusiveStartKey",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .total_segments = "TotalSegments",
                .segment = "Segment",
                .projection_expression = "ProjectionExpression",
                .filter_expression = "FilterExpression",
                .expression_attribute_names = "ExpressionAttributeNames",
                .expression_attribute_values = "ExpressionAttributeValues",
                .consistent_read = "ConsistentRead",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "scan_filter", field_name))
                return try serializeMap(self.scan_filter, self.fieldNameFor("scan_filter"), options, out_stream);
            if (std.mem.eql(u8, "exclusive_start_key", field_name))
                return try serializeMap(self.exclusive_start_key, self.fieldNameFor("exclusive_start_key"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_names", field_name))
                return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_values", field_name))
                return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(scan) } {
            return .{ .service_metadata = service_metadata, .action = scan };
        }
    },
    Response: type = struct {
        items: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        count: ?i64 = null,
        scanned_count: ?i64 = null,
        last_evaluated_key: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        consumed_capacity: ?ConsumedCapacity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .count = "Count",
                .scanned_count = "ScannedCount",
                .last_evaluated_key = "LastEvaluatedKey",
                .consumed_capacity = "ConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "items", field_name))
                return try serializeMap(self.items, self.fieldNameFor("items"), options, out_stream);
            if (std.mem.eql(u8, "last_evaluated_key", field_name))
                return try serializeMap(self.last_evaluated_key, self.fieldNameFor("last_evaluated_key"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const transact_get_items: struct {
    action_name: []const u8 = "TransactGetItems",
    Request: type = struct {
        transact_items: []struct {
            get: struct {
                key: []struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                },
                table_name: []const u8,
                projection_expression: ?[]const u8 = null,
                expression_attribute_names: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .table_name = "TableName",
                        .projection_expression = "ProjectionExpression",
                        .expression_attribute_names = "ExpressionAttributeNames",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "key", field_name))
                        return try serializeMap(self.key, self.fieldNameFor("key"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_names", field_name))
                        return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
                    return false;
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .get = "Get",
                };
                return @field(mappings, field_name);
            }
        },
        return_consumed_capacity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transact_items = "TransactItems",
                .return_consumed_capacity = "ReturnConsumedCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(transact_get_items) } {
            return .{ .service_metadata = service_metadata, .action = transact_get_items };
        }
    },
    Response: type = struct {
        consumed_capacity: ?[]ConsumedCapacity = null,
        responses: ?[]ItemResponse = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .consumed_capacity = "ConsumedCapacity",
                .responses = "Responses",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
        TransactionCanceled,
    },
} = .{};
pub const transact_write_items: struct {
    action_name: []const u8 = "TransactWriteItems",
    Request: type = struct {
        transact_items: []struct {
            condition_check: ?struct {
                key: []struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                },
                table_name: []const u8,
                condition_expression: []const u8,
                expression_attribute_names: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                expression_attribute_values: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                } = null,
                return_values_on_condition_check_failure: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .table_name = "TableName",
                        .condition_expression = "ConditionExpression",
                        .expression_attribute_names = "ExpressionAttributeNames",
                        .expression_attribute_values = "ExpressionAttributeValues",
                        .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "key", field_name))
                        return try serializeMap(self.key, self.fieldNameFor("key"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_names", field_name))
                        return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_values", field_name))
                        return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
                    return false;
                }
            } = null,
            put: ?struct {
                item: []struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                },
                table_name: []const u8,
                condition_expression: ?[]const u8 = null,
                expression_attribute_names: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                expression_attribute_values: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                } = null,
                return_values_on_condition_check_failure: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .item = "Item",
                        .table_name = "TableName",
                        .condition_expression = "ConditionExpression",
                        .expression_attribute_names = "ExpressionAttributeNames",
                        .expression_attribute_values = "ExpressionAttributeValues",
                        .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "item", field_name))
                        return try serializeMap(self.item, self.fieldNameFor("item"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_names", field_name))
                        return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_values", field_name))
                        return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
                    return false;
                }
            } = null,
            delete: ?struct {
                key: []struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                },
                table_name: []const u8,
                condition_expression: ?[]const u8 = null,
                expression_attribute_names: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                expression_attribute_values: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                } = null,
                return_values_on_condition_check_failure: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .table_name = "TableName",
                        .condition_expression = "ConditionExpression",
                        .expression_attribute_names = "ExpressionAttributeNames",
                        .expression_attribute_values = "ExpressionAttributeValues",
                        .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "key", field_name))
                        return try serializeMap(self.key, self.fieldNameFor("key"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_names", field_name))
                        return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_values", field_name))
                        return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
                    return false;
                }
            } = null,
            update: ?struct {
                key: []struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                },
                update_expression: []const u8,
                table_name: []const u8,
                condition_expression: ?[]const u8 = null,
                expression_attribute_names: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                expression_attribute_values: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                } = null,
                return_values_on_condition_check_failure: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .update_expression = "UpdateExpression",
                        .table_name = "TableName",
                        .condition_expression = "ConditionExpression",
                        .expression_attribute_names = "ExpressionAttributeNames",
                        .expression_attribute_values = "ExpressionAttributeValues",
                        .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "key", field_name))
                        return try serializeMap(self.key, self.fieldNameFor("key"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_names", field_name))
                        return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
                    if (std.mem.eql(u8, "expression_attribute_values", field_name))
                        return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .condition_check = "ConditionCheck",
                    .put = "Put",
                    .delete = "Delete",
                    .update = "Update",
                };
                return @field(mappings, field_name);
            }
        },
        return_consumed_capacity: ?[]const u8 = null,
        return_item_collection_metrics: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transact_items = "TransactItems",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .return_item_collection_metrics = "ReturnItemCollectionMetrics",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(transact_write_items) } {
            return .{ .service_metadata = service_metadata, .action = transact_write_items };
        }
    },
    Response: type = struct {
        consumed_capacity: ?[]ConsumedCapacity = null,
        item_collection_metrics: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ItemCollectionMetrics = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .consumed_capacity = "ConsumedCapacity",
                .item_collection_metrics = "ItemCollectionMetrics",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "item_collection_metrics", field_name))
                return try serializeMap(self.item_collection_metrics, self.fieldNameFor("item_collection_metrics"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidEndpoint,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
        TransactionCanceled,
        TransactionInProgress,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_continuous_backups: struct {
    action_name: []const u8 = "UpdateContinuousBackups",
    Request: type = struct {
        table_name: []const u8,
        point_in_time_recovery_specification: struct {
            point_in_time_recovery_enabled: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .point_in_time_recovery_enabled = "PointInTimeRecoveryEnabled",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .point_in_time_recovery_specification = "PointInTimeRecoverySpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_continuous_backups) } {
            return .{ .service_metadata = service_metadata, .action = update_continuous_backups };
        }
    },
    Response: type = struct {
        continuous_backups_description: ?ContinuousBackupsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .continuous_backups_description = "ContinuousBackupsDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContinuousBackupsUnavailable,
        InternalServerError,
        InvalidEndpoint,
        TableNotFound,
    },
} = .{};
pub const update_contributor_insights: struct {
    action_name: []const u8 = "UpdateContributorInsights",
    Request: type = struct {
        table_name: []const u8,
        index_name: ?[]const u8 = null,
        contributor_insights_action: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .index_name = "IndexName",
                .contributor_insights_action = "ContributorInsightsAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contributor_insights) } {
            return .{ .service_metadata = service_metadata, .action = update_contributor_insights };
        }
    },
    Response: type = struct {
        table_name: ?[]const u8 = null,
        index_name: ?[]const u8 = null,
        contributor_insights_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .index_name = "IndexName",
                .contributor_insights_status = "ContributorInsightsStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceNotFound,
    },
} = .{};
pub const update_global_table: struct {
    action_name: []const u8 = "UpdateGlobalTable",
    Request: type = struct {
        global_table_name: []const u8,
        replica_updates: []struct {
            create: ?struct {
                region_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .region_name = "RegionName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            delete: ?struct {
                region_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .region_name = "RegionName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .create = "Create",
                    .delete = "Delete",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_name = "GlobalTableName",
                .replica_updates = "ReplicaUpdates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_global_table) } {
            return .{ .service_metadata = service_metadata, .action = update_global_table };
        }
    },
    Response: type = struct {
        global_table_description: ?GlobalTableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_description = "GlobalTableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalTableNotFound,
        InternalServerError,
        InvalidEndpoint,
        ReplicaAlreadyExists,
        ReplicaNotFound,
        TableNotFound,
    },
} = .{};
pub const update_global_table_settings: struct {
    action_name: []const u8 = "UpdateGlobalTableSettings",
    Request: type = struct {
        global_table_name: []const u8,
        global_table_billing_mode: ?[]const u8 = null,
        global_table_provisioned_write_capacity_units: ?i64 = null,
        global_table_provisioned_write_capacity_auto_scaling_settings_update: ?AutoScalingSettingsUpdate = null,
        global_table_global_secondary_index_settings_update: ?[]struct {
            index_name: []const u8,
            provisioned_write_capacity_units: ?i64 = null,
            provisioned_write_capacity_auto_scaling_settings_update: ?AutoScalingSettingsUpdate = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .index_name = "IndexName",
                    .provisioned_write_capacity_units = "ProvisionedWriteCapacityUnits",
                    .provisioned_write_capacity_auto_scaling_settings_update = "ProvisionedWriteCapacityAutoScalingSettingsUpdate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        replica_settings_update: ?[]struct {
            region_name: []const u8,
            replica_provisioned_read_capacity_units: ?i64 = null,
            replica_provisioned_read_capacity_auto_scaling_settings_update: ?AutoScalingSettingsUpdate = null,
            replica_global_secondary_index_settings_update: ?[]struct {
                index_name: []const u8,
                provisioned_read_capacity_units: ?i64 = null,
                provisioned_read_capacity_auto_scaling_settings_update: ?AutoScalingSettingsUpdate = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index_name = "IndexName",
                        .provisioned_read_capacity_units = "ProvisionedReadCapacityUnits",
                        .provisioned_read_capacity_auto_scaling_settings_update = "ProvisionedReadCapacityAutoScalingSettingsUpdate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            replica_table_class: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region_name = "RegionName",
                    .replica_provisioned_read_capacity_units = "ReplicaProvisionedReadCapacityUnits",
                    .replica_provisioned_read_capacity_auto_scaling_settings_update = "ReplicaProvisionedReadCapacityAutoScalingSettingsUpdate",
                    .replica_global_secondary_index_settings_update = "ReplicaGlobalSecondaryIndexSettingsUpdate",
                    .replica_table_class = "ReplicaTableClass",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_name = "GlobalTableName",
                .global_table_billing_mode = "GlobalTableBillingMode",
                .global_table_provisioned_write_capacity_units = "GlobalTableProvisionedWriteCapacityUnits",
                .global_table_provisioned_write_capacity_auto_scaling_settings_update = "GlobalTableProvisionedWriteCapacityAutoScalingSettingsUpdate",
                .global_table_global_secondary_index_settings_update = "GlobalTableGlobalSecondaryIndexSettingsUpdate",
                .replica_settings_update = "ReplicaSettingsUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_global_table_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_global_table_settings };
        }
    },
    Response: type = struct {
        global_table_name: ?[]const u8 = null,
        replica_settings: ?[]ReplicaSettingsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_table_name = "GlobalTableName",
                .replica_settings = "ReplicaSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalTableNotFound,
        IndexNotFound,
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ReplicaNotFound,
        ResourceInUse,
    },
} = .{};
pub const update_item: struct {
    action_name: []const u8 = "UpdateItem",
    Request: type = struct {
        table_name: []const u8,
        key: []struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        },
        attribute_updates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                value: ?AttributeValue = null,
                action: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .value = "Value",
                        .action = "Action",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        expected: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ExpectedAttributeValue = null,
        } = null,
        conditional_operator: ?[]const u8 = null,
        return_values: ?[]const u8 = null,
        return_consumed_capacity: ?[]const u8 = null,
        return_item_collection_metrics: ?[]const u8 = null,
        update_expression: ?[]const u8 = null,
        condition_expression: ?[]const u8 = null,
        expression_attribute_names: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        expression_attribute_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        return_values_on_condition_check_failure: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .key = "Key",
                .attribute_updates = "AttributeUpdates",
                .expected = "Expected",
                .conditional_operator = "ConditionalOperator",
                .return_values = "ReturnValues",
                .return_consumed_capacity = "ReturnConsumedCapacity",
                .return_item_collection_metrics = "ReturnItemCollectionMetrics",
                .update_expression = "UpdateExpression",
                .condition_expression = "ConditionExpression",
                .expression_attribute_names = "ExpressionAttributeNames",
                .expression_attribute_values = "ExpressionAttributeValues",
                .return_values_on_condition_check_failure = "ReturnValuesOnConditionCheckFailure",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "key", field_name))
                return try serializeMap(self.key, self.fieldNameFor("key"), options, out_stream);
            if (std.mem.eql(u8, "attribute_updates", field_name))
                return try serializeMap(self.attribute_updates, self.fieldNameFor("attribute_updates"), options, out_stream);
            if (std.mem.eql(u8, "expected", field_name))
                return try serializeMap(self.expected, self.fieldNameFor("expected"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_names", field_name))
                return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
            if (std.mem.eql(u8, "expression_attribute_values", field_name))
                return try serializeMap(self.expression_attribute_values, self.fieldNameFor("expression_attribute_values"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_item) } {
            return .{ .service_metadata = service_metadata, .action = update_item };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AttributeValue = null,
        } = null,
        consumed_capacity: ?ConsumedCapacity = null,
        item_collection_metrics: ?ItemCollectionMetrics = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .consumed_capacity = "ConsumedCapacity",
                .item_collection_metrics = "ItemCollectionMetrics",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConditionalCheckFailed,
        InternalServerError,
        InvalidEndpoint,
        ItemCollectionSizeLimitExceeded,
        ProvisionedThroughputExceeded,
        RequestLimitExceeded,
        ResourceNotFound,
        TransactionConflict,
    },
} = .{};
pub const update_kinesis_streaming_destination: struct {
    action_name: []const u8 = "UpdateKinesisStreamingDestination",
    Request: type = struct {
        table_name: []const u8,
        stream_arn: []const u8,
        update_kinesis_streaming_configuration: ?UpdateKinesisStreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .stream_arn = "StreamArn",
                .update_kinesis_streaming_configuration = "UpdateKinesisStreamingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kinesis_streaming_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_kinesis_streaming_destination };
        }
    },
    Response: type = struct {
        table_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        destination_status: ?[]const u8 = null,
        update_kinesis_streaming_configuration: ?UpdateKinesisStreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .stream_arn = "StreamArn",
                .destination_status = "DestinationStatus",
                .update_kinesis_streaming_configuration = "UpdateKinesisStreamingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_table: struct {
    action_name: []const u8 = "UpdateTable",
    Request: type = struct {
        attribute_definitions: ?[]AttributeDefinition = null,
        table_name: []const u8,
        billing_mode: ?[]const u8 = null,
        provisioned_throughput: ?ProvisionedThroughput = null,
        global_secondary_index_updates: ?[]struct {
            update: ?struct {
                index_name: []const u8,
                provisioned_throughput: ProvisionedThroughput,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index_name = "IndexName",
                        .provisioned_throughput = "ProvisionedThroughput",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            create: ?struct {
                index_name: []const u8,
                key_schema: []KeySchemaElement,
                projection: Projection,
                provisioned_throughput: ?ProvisionedThroughput = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index_name = "IndexName",
                        .key_schema = "KeySchema",
                        .projection = "Projection",
                        .provisioned_throughput = "ProvisionedThroughput",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            delete: ?struct {
                index_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index_name = "IndexName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .update = "Update",
                    .create = "Create",
                    .delete = "Delete",
                };
                return @field(mappings, field_name);
            }
        } = null,
        stream_specification: ?StreamSpecification = null,
        sse_specification: ?SSESpecification = null,
        replica_updates: ?[]struct {
            create: ?struct {
                region_name: []const u8,
                kms_master_key_id: ?[]const u8 = null,
                provisioned_throughput_override: ?ProvisionedThroughputOverride = null,
                global_secondary_indexes: ?[]ReplicaGlobalSecondaryIndex = null,
                table_class_override: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .region_name = "RegionName",
                        .kms_master_key_id = "KMSMasterKeyId",
                        .provisioned_throughput_override = "ProvisionedThroughputOverride",
                        .global_secondary_indexes = "GlobalSecondaryIndexes",
                        .table_class_override = "TableClassOverride",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            update: ?struct {
                region_name: []const u8,
                kms_master_key_id: ?[]const u8 = null,
                provisioned_throughput_override: ?ProvisionedThroughputOverride = null,
                global_secondary_indexes: ?[]ReplicaGlobalSecondaryIndex = null,
                table_class_override: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .region_name = "RegionName",
                        .kms_master_key_id = "KMSMasterKeyId",
                        .provisioned_throughput_override = "ProvisionedThroughputOverride",
                        .global_secondary_indexes = "GlobalSecondaryIndexes",
                        .table_class_override = "TableClassOverride",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            delete: ?struct {
                region_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .region_name = "RegionName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .create = "Create",
                    .update = "Update",
                    .delete = "Delete",
                };
                return @field(mappings, field_name);
            }
        } = null,
        table_class: ?[]const u8 = null,
        deletion_protection_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_definitions = "AttributeDefinitions",
                .table_name = "TableName",
                .billing_mode = "BillingMode",
                .provisioned_throughput = "ProvisionedThroughput",
                .global_secondary_index_updates = "GlobalSecondaryIndexUpdates",
                .stream_specification = "StreamSpecification",
                .sse_specification = "SSESpecification",
                .replica_updates = "ReplicaUpdates",
                .table_class = "TableClass",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table) } {
            return .{ .service_metadata = service_metadata, .action = update_table };
        }
    },
    Response: type = struct {
        table_description: ?TableDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_description = "TableDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_table_replica_auto_scaling: struct {
    action_name: []const u8 = "UpdateTableReplicaAutoScaling",
    Request: type = struct {
        global_secondary_index_updates: ?[]struct {
            index_name: ?[]const u8 = null,
            provisioned_write_capacity_auto_scaling_update: ?AutoScalingSettingsUpdate = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .index_name = "IndexName",
                    .provisioned_write_capacity_auto_scaling_update = "ProvisionedWriteCapacityAutoScalingUpdate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        table_name: []const u8,
        provisioned_write_capacity_auto_scaling_update: ?AutoScalingSettingsUpdate = null,
        replica_updates: ?[]struct {
            region_name: []const u8,
            replica_global_secondary_index_updates: ?[]struct {
                index_name: ?[]const u8 = null,
                provisioned_read_capacity_auto_scaling_update: ?AutoScalingSettingsUpdate = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index_name = "IndexName",
                        .provisioned_read_capacity_auto_scaling_update = "ProvisionedReadCapacityAutoScalingUpdate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            replica_provisioned_read_capacity_auto_scaling_update: ?AutoScalingSettingsUpdate = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region_name = "RegionName",
                    .replica_global_secondary_index_updates = "ReplicaGlobalSecondaryIndexUpdates",
                    .replica_provisioned_read_capacity_auto_scaling_update = "ReplicaProvisionedReadCapacityAutoScalingUpdate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_secondary_index_updates = "GlobalSecondaryIndexUpdates",
                .table_name = "TableName",
                .provisioned_write_capacity_auto_scaling_update = "ProvisionedWriteCapacityAutoScalingUpdate",
                .replica_updates = "ReplicaUpdates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table_replica_auto_scaling) } {
            return .{ .service_metadata = service_metadata, .action = update_table_replica_auto_scaling };
        }
    },
    Response: type = struct {
        table_auto_scaling_description: ?TableAutoScalingDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_auto_scaling_description = "TableAutoScalingDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_time_to_live: struct {
    action_name: []const u8 = "UpdateTimeToLive",
    Request: type = struct {
        table_name: []const u8,
        time_to_live_specification: TimeToLiveSpecification,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .time_to_live_specification = "TimeToLiveSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_time_to_live) } {
            return .{ .service_metadata = service_metadata, .action = update_time_to_live };
        }
    },
    Response: type = struct {
        time_to_live_specification: ?TimeToLiveSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_to_live_specification = "TimeToLiveSpecification",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidEndpoint,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};

pub const TimeToLiveSpecification = struct {
    enabled: bool,
    attribute_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .attribute_name = "AttributeName",
        };
        return @field(mappings, field_name);
    }
};

pub const TableAutoScalingDescription = struct {
    table_name: ?[]const u8 = null,
    table_status: ?[]const u8 = null,
    replicas: ?[]ReplicaAutoScalingDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "TableName",
            .table_status = "TableStatus",
            .replicas = "Replicas",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaAutoScalingDescription = struct {
    region_name: ?[]const u8 = null,
    global_secondary_indexes: ?[]ReplicaGlobalSecondaryIndexAutoScalingDescription = null,
    replica_provisioned_read_capacity_auto_scaling_settings: ?AutoScalingSettingsDescription = null,
    replica_provisioned_write_capacity_auto_scaling_settings: ?AutoScalingSettingsDescription = null,
    replica_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region_name = "RegionName",
            .global_secondary_indexes = "GlobalSecondaryIndexes",
            .replica_provisioned_read_capacity_auto_scaling_settings = "ReplicaProvisionedReadCapacityAutoScalingSettings",
            .replica_provisioned_write_capacity_auto_scaling_settings = "ReplicaProvisionedWriteCapacityAutoScalingSettings",
            .replica_status = "ReplicaStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingSettingsDescription = struct {
    minimum_units: ?i64 = null,
    maximum_units: ?i64 = null,
    auto_scaling_disabled: ?bool = null,
    auto_scaling_role_arn: ?[]const u8 = null,
    scaling_policies: ?[]AutoScalingPolicyDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_units = "MinimumUnits",
            .maximum_units = "MaximumUnits",
            .auto_scaling_disabled = "AutoScalingDisabled",
            .auto_scaling_role_arn = "AutoScalingRoleArn",
            .scaling_policies = "ScalingPolicies",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingPolicyDescription = struct {
    policy_name: ?[]const u8 = null,
    target_tracking_scaling_policy_configuration: ?AutoScalingTargetTrackingScalingPolicyConfigurationDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
            .target_tracking_scaling_policy_configuration = "TargetTrackingScalingPolicyConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingTargetTrackingScalingPolicyConfigurationDescription = struct {
    disable_scale_in: ?bool = null,
    scale_in_cooldown: ?i64 = null,
    scale_out_cooldown: ?i64 = null,
    target_value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disable_scale_in = "DisableScaleIn",
            .scale_in_cooldown = "ScaleInCooldown",
            .scale_out_cooldown = "ScaleOutCooldown",
            .target_value = "TargetValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaGlobalSecondaryIndexAutoScalingDescription = struct {
    index_name: ?[]const u8 = null,
    index_status: ?[]const u8 = null,
    provisioned_read_capacity_auto_scaling_settings: ?AutoScalingSettingsDescription = null,
    provisioned_write_capacity_auto_scaling_settings: ?AutoScalingSettingsDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .index_status = "IndexStatus",
            .provisioned_read_capacity_auto_scaling_settings = "ProvisionedReadCapacityAutoScalingSettings",
            .provisioned_write_capacity_auto_scaling_settings = "ProvisionedWriteCapacityAutoScalingSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingSettingsUpdate = struct {
    minimum_units: ?i64 = null,
    maximum_units: ?i64 = null,
    auto_scaling_disabled: ?bool = null,
    auto_scaling_role_arn: ?[]const u8 = null,
    scaling_policy_update: ?AutoScalingPolicyUpdate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_units = "MinimumUnits",
            .maximum_units = "MaximumUnits",
            .auto_scaling_disabled = "AutoScalingDisabled",
            .auto_scaling_role_arn = "AutoScalingRoleArn",
            .scaling_policy_update = "ScalingPolicyUpdate",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingPolicyUpdate = struct {
    policy_name: ?[]const u8 = null,
    target_tracking_scaling_policy_configuration: AutoScalingTargetTrackingScalingPolicyConfigurationUpdate,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
            .target_tracking_scaling_policy_configuration = "TargetTrackingScalingPolicyConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingTargetTrackingScalingPolicyConfigurationUpdate = struct {
    disable_scale_in: ?bool = null,
    scale_in_cooldown: ?i64 = null,
    scale_out_cooldown: ?i64 = null,
    target_value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disable_scale_in = "DisableScaleIn",
            .scale_in_cooldown = "ScaleInCooldown",
            .scale_out_cooldown = "ScaleOutCooldown",
            .target_value = "TargetValue",
        };
        return @field(mappings, field_name);
    }
};

pub const TableDescription = struct {
    attribute_definitions: ?[]AttributeDefinition = null,
    table_name: ?[]const u8 = null,
    key_schema: ?[]KeySchemaElement = null,
    table_status: ?[]const u8 = null,
    creation_date_time: ?i64 = null,
    provisioned_throughput: ?ProvisionedThroughputDescription = null,
    table_size_bytes: ?i64 = null,
    item_count: ?i64 = null,
    table_arn: ?[]const u8 = null,
    table_id: ?[]const u8 = null,
    billing_mode_summary: ?BillingModeSummary = null,
    local_secondary_indexes: ?[]LocalSecondaryIndexDescription = null,
    global_secondary_indexes: ?[]GlobalSecondaryIndexDescription = null,
    stream_specification: ?StreamSpecification = null,
    latest_stream_label: ?[]const u8 = null,
    latest_stream_arn: ?[]const u8 = null,
    global_table_version: ?[]const u8 = null,
    replicas: ?[]ReplicaDescription = null,
    restore_summary: ?RestoreSummary = null,
    sse_description: ?SSEDescription = null,
    archival_summary: ?ArchivalSummary = null,
    table_class_summary: ?TableClassSummary = null,
    deletion_protection_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_definitions = "AttributeDefinitions",
            .table_name = "TableName",
            .key_schema = "KeySchema",
            .table_status = "TableStatus",
            .creation_date_time = "CreationDateTime",
            .provisioned_throughput = "ProvisionedThroughput",
            .table_size_bytes = "TableSizeBytes",
            .item_count = "ItemCount",
            .table_arn = "TableArn",
            .table_id = "TableId",
            .billing_mode_summary = "BillingModeSummary",
            .local_secondary_indexes = "LocalSecondaryIndexes",
            .global_secondary_indexes = "GlobalSecondaryIndexes",
            .stream_specification = "StreamSpecification",
            .latest_stream_label = "LatestStreamLabel",
            .latest_stream_arn = "LatestStreamArn",
            .global_table_version = "GlobalTableVersion",
            .replicas = "Replicas",
            .restore_summary = "RestoreSummary",
            .sse_description = "SSEDescription",
            .archival_summary = "ArchivalSummary",
            .table_class_summary = "TableClassSummary",
            .deletion_protection_enabled = "DeletionProtectionEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const TableClassSummary = struct {
    table_class: ?[]const u8 = null,
    last_update_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_class = "TableClass",
            .last_update_date_time = "LastUpdateDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ArchivalSummary = struct {
    archival_date_time: ?i64 = null,
    archival_reason: ?[]const u8 = null,
    archival_backup_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .archival_date_time = "ArchivalDateTime",
            .archival_reason = "ArchivalReason",
            .archival_backup_arn = "ArchivalBackupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SSEDescription = struct {
    status: ?[]const u8 = null,
    sse_type: ?[]const u8 = null,
    kms_master_key_arn: ?[]const u8 = null,
    inaccessible_encryption_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .sse_type = "SSEType",
            .kms_master_key_arn = "KMSMasterKeyArn",
            .inaccessible_encryption_date_time = "InaccessibleEncryptionDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const RestoreSummary = struct {
    source_backup_arn: ?[]const u8 = null,
    source_table_arn: ?[]const u8 = null,
    restore_date_time: i64,
    restore_in_progress: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_backup_arn = "SourceBackupArn",
            .source_table_arn = "SourceTableArn",
            .restore_date_time = "RestoreDateTime",
            .restore_in_progress = "RestoreInProgress",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaDescription = struct {
    region_name: ?[]const u8 = null,
    replica_status: ?[]const u8 = null,
    replica_status_description: ?[]const u8 = null,
    replica_status_percent_progress: ?[]const u8 = null,
    kms_master_key_id: ?[]const u8 = null,
    provisioned_throughput_override: ?ProvisionedThroughputOverride = null,
    global_secondary_indexes: ?[]ReplicaGlobalSecondaryIndexDescription = null,
    replica_inaccessible_date_time: ?i64 = null,
    replica_table_class_summary: ?TableClassSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region_name = "RegionName",
            .replica_status = "ReplicaStatus",
            .replica_status_description = "ReplicaStatusDescription",
            .replica_status_percent_progress = "ReplicaStatusPercentProgress",
            .kms_master_key_id = "KMSMasterKeyId",
            .provisioned_throughput_override = "ProvisionedThroughputOverride",
            .global_secondary_indexes = "GlobalSecondaryIndexes",
            .replica_inaccessible_date_time = "ReplicaInaccessibleDateTime",
            .replica_table_class_summary = "ReplicaTableClassSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaGlobalSecondaryIndexDescription = struct {
    index_name: ?[]const u8 = null,
    provisioned_throughput_override: ?ProvisionedThroughputOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .provisioned_throughput_override = "ProvisionedThroughputOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisionedThroughputOverride = struct {
    read_capacity_units: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_capacity_units = "ReadCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamSpecification = struct {
    stream_enabled: bool,
    stream_view_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_enabled = "StreamEnabled",
            .stream_view_type = "StreamViewType",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalSecondaryIndexDescription = struct {
    index_name: ?[]const u8 = null,
    key_schema: ?[]KeySchemaElement = null,
    projection: ?Projection = null,
    index_status: ?[]const u8 = null,
    backfilling: ?bool = null,
    provisioned_throughput: ?ProvisionedThroughputDescription = null,
    index_size_bytes: ?i64 = null,
    item_count: ?i64 = null,
    index_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .key_schema = "KeySchema",
            .projection = "Projection",
            .index_status = "IndexStatus",
            .backfilling = "Backfilling",
            .provisioned_throughput = "ProvisionedThroughput",
            .index_size_bytes = "IndexSizeBytes",
            .item_count = "ItemCount",
            .index_arn = "IndexArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisionedThroughputDescription = struct {
    last_increase_date_time: ?i64 = null,
    last_decrease_date_time: ?i64 = null,
    number_of_decreases_today: ?i64 = null,
    read_capacity_units: ?i64 = null,
    write_capacity_units: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_increase_date_time = "LastIncreaseDateTime",
            .last_decrease_date_time = "LastDecreaseDateTime",
            .number_of_decreases_today = "NumberOfDecreasesToday",
            .read_capacity_units = "ReadCapacityUnits",
            .write_capacity_units = "WriteCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const Projection = struct {
    projection_type: ?[]const u8 = null,
    non_key_attributes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .projection_type = "ProjectionType",
            .non_key_attributes = "NonKeyAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const KeySchemaElement = struct {
    attribute_name: []const u8,
    key_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .key_type = "KeyType",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalSecondaryIndexDescription = struct {
    index_name: ?[]const u8 = null,
    key_schema: ?[]KeySchemaElement = null,
    projection: ?Projection = null,
    index_size_bytes: ?i64 = null,
    item_count: ?i64 = null,
    index_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .key_schema = "KeySchema",
            .projection = "Projection",
            .index_size_bytes = "IndexSizeBytes",
            .item_count = "ItemCount",
            .index_arn = "IndexArn",
        };
        return @field(mappings, field_name);
    }
};

pub const BillingModeSummary = struct {
    billing_mode: ?[]const u8 = null,
    last_update_to_pay_per_request_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .billing_mode = "BillingMode",
            .last_update_to_pay_per_request_date_time = "LastUpdateToPayPerRequestDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeDefinition = struct {
    attribute_name: []const u8,
    attribute_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_type = "AttributeType",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaGlobalSecondaryIndex = struct {
    index_name: []const u8,
    provisioned_throughput_override: ?ProvisionedThroughputOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .provisioned_throughput_override = "ProvisionedThroughputOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const SSESpecification = struct {
    enabled: ?bool = null,
    sse_type: ?[]const u8 = null,
    kms_master_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .sse_type = "SSEType",
            .kms_master_key_id = "KMSMasterKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisionedThroughput = struct {
    read_capacity_units: i64,
    write_capacity_units: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_capacity_units = "ReadCapacityUnits",
            .write_capacity_units = "WriteCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateKinesisStreamingConfiguration = struct {
    approximate_creation_date_time_precision: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .approximate_creation_date_time_precision = "ApproximateCreationDateTimePrecision",
        };
        return @field(mappings, field_name);
    }
};

pub const ItemCollectionMetrics = struct {
    item_collection_key: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AttributeValue = null,
    } = null,
    size_estimate_range_gb: ?[]f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_collection_key = "ItemCollectionKey",
            .size_estimate_range_gb = "SizeEstimateRangeGB",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "item_collection_key", field_name))
            return try serializeMap(self.item_collection_key, self.fieldNameFor("item_collection_key"), options, out_stream);
        return false;
    }
};

pub const AttributeValue = union {
    s: ?[]const u8,
    n: ?[]const u8,
    b: ?[]const u8,
    ss: ?[][]const u8,
    ns: ?[][]const u8,
    bs: ?[][]const u8,
    m: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AttributeValue = null,
    },
    l: ?[]AttributeValue,
    @"null": ?bool,
    bool: ?bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s = "S",
            .n = "N",
            .b = "B",
            .ss = "SS",
            .ns = "NS",
            .bs = "BS",
            .m = "M",
            .l = "L",
            .@"null" = "NULL",
            .bool = "BOOL",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "m", field_name))
            return try serializeMap(self.m, self.fieldNameFor("m"), options, out_stream);
        return false;
    }
};

pub const ConsumedCapacity = struct {
    table_name: ?[]const u8 = null,
    capacity_units: ?f64 = null,
    read_capacity_units: ?f64 = null,
    write_capacity_units: ?f64 = null,
    table: ?Capacity = null,
    local_secondary_indexes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Capacity = null,
    } = null,
    global_secondary_indexes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Capacity = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "TableName",
            .capacity_units = "CapacityUnits",
            .read_capacity_units = "ReadCapacityUnits",
            .write_capacity_units = "WriteCapacityUnits",
            .table = "Table",
            .local_secondary_indexes = "LocalSecondaryIndexes",
            .global_secondary_indexes = "GlobalSecondaryIndexes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "local_secondary_indexes", field_name))
            return try serializeMap(self.local_secondary_indexes, self.fieldNameFor("local_secondary_indexes"), options, out_stream);
        if (std.mem.eql(u8, "global_secondary_indexes", field_name))
            return try serializeMap(self.global_secondary_indexes, self.fieldNameFor("global_secondary_indexes"), options, out_stream);
        return false;
    }
};

pub const Capacity = struct {
    read_capacity_units: ?f64 = null,
    write_capacity_units: ?f64 = null,
    capacity_units: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_capacity_units = "ReadCapacityUnits",
            .write_capacity_units = "WriteCapacityUnits",
            .capacity_units = "CapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpectedAttributeValue = struct {
    value: ?AttributeValue = null,
    exists: ?bool = null,
    comparison_operator: ?[]const u8 = null,
    attribute_value_list: ?[]AttributeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .exists = "Exists",
            .comparison_operator = "ComparisonOperator",
            .attribute_value_list = "AttributeValueList",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaSettingsDescription = struct {
    region_name: []const u8,
    replica_status: ?[]const u8 = null,
    replica_billing_mode_summary: ?BillingModeSummary = null,
    replica_provisioned_read_capacity_units: ?i64 = null,
    replica_provisioned_read_capacity_auto_scaling_settings: ?AutoScalingSettingsDescription = null,
    replica_provisioned_write_capacity_units: ?i64 = null,
    replica_provisioned_write_capacity_auto_scaling_settings: ?AutoScalingSettingsDescription = null,
    replica_global_secondary_index_settings: ?[]ReplicaGlobalSecondaryIndexSettingsDescription = null,
    replica_table_class_summary: ?TableClassSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region_name = "RegionName",
            .replica_status = "ReplicaStatus",
            .replica_billing_mode_summary = "ReplicaBillingModeSummary",
            .replica_provisioned_read_capacity_units = "ReplicaProvisionedReadCapacityUnits",
            .replica_provisioned_read_capacity_auto_scaling_settings = "ReplicaProvisionedReadCapacityAutoScalingSettings",
            .replica_provisioned_write_capacity_units = "ReplicaProvisionedWriteCapacityUnits",
            .replica_provisioned_write_capacity_auto_scaling_settings = "ReplicaProvisionedWriteCapacityAutoScalingSettings",
            .replica_global_secondary_index_settings = "ReplicaGlobalSecondaryIndexSettings",
            .replica_table_class_summary = "ReplicaTableClassSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaGlobalSecondaryIndexSettingsDescription = struct {
    index_name: []const u8,
    index_status: ?[]const u8 = null,
    provisioned_read_capacity_units: ?i64 = null,
    provisioned_read_capacity_auto_scaling_settings: ?AutoScalingSettingsDescription = null,
    provisioned_write_capacity_units: ?i64 = null,
    provisioned_write_capacity_auto_scaling_settings: ?AutoScalingSettingsDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .index_status = "IndexStatus",
            .provisioned_read_capacity_units = "ProvisionedReadCapacityUnits",
            .provisioned_read_capacity_auto_scaling_settings = "ProvisionedReadCapacityAutoScalingSettings",
            .provisioned_write_capacity_units = "ProvisionedWriteCapacityUnits",
            .provisioned_write_capacity_auto_scaling_settings = "ProvisionedWriteCapacityAutoScalingSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalTableDescription = struct {
    replication_group: ?[]ReplicaDescription = null,
    global_table_arn: ?[]const u8 = null,
    creation_date_time: ?i64 = null,
    global_table_status: ?[]const u8 = null,
    global_table_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_group = "ReplicationGroup",
            .global_table_arn = "GlobalTableArn",
            .creation_date_time = "CreationDateTime",
            .global_table_status = "GlobalTableStatus",
            .global_table_name = "GlobalTableName",
        };
        return @field(mappings, field_name);
    }
};

pub const ContinuousBackupsDescription = struct {
    continuous_backups_status: []const u8,
    point_in_time_recovery_description: ?PointInTimeRecoveryDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .continuous_backups_status = "ContinuousBackupsStatus",
            .point_in_time_recovery_description = "PointInTimeRecoveryDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const PointInTimeRecoveryDescription = struct {
    point_in_time_recovery_status: ?[]const u8 = null,
    earliest_restorable_date_time: ?i64 = null,
    latest_restorable_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .point_in_time_recovery_status = "PointInTimeRecoveryStatus",
            .earliest_restorable_date_time = "EarliestRestorableDateTime",
            .latest_restorable_date_time = "LatestRestorableDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ItemResponse = struct {
    item: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AttributeValue = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item = "Item",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "item", field_name))
            return try serializeMap(self.item, self.fieldNameFor("item"), options, out_stream);
        return false;
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    attribute_value_list: ?[]AttributeValue = null,
    comparison_operator: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_value_list = "AttributeValueList",
            .comparison_operator = "ComparisonOperator",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalSecondaryIndex = struct {
    index_name: []const u8,
    key_schema: []KeySchemaElement,
    projection: Projection,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .key_schema = "KeySchema",
            .projection = "Projection",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalSecondaryIndex = struct {
    index_name: []const u8,
    key_schema: []KeySchemaElement,
    projection: Projection,
    provisioned_throughput: ?ProvisionedThroughput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .key_schema = "KeySchema",
            .projection = "Projection",
            .provisioned_throughput = "ProvisionedThroughput",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketSource = struct {
    s3_bucket_owner: ?[]const u8 = null,
    s3_bucket: []const u8,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_owner = "S3BucketOwner",
            .s3_bucket = "S3Bucket",
            .s3_key_prefix = "S3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Replica = struct {
    region_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region_name = "RegionName",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportTableDescription = struct {
    import_arn: ?[]const u8 = null,
    import_status: ?[]const u8 = null,
    table_arn: ?[]const u8 = null,
    table_id: ?[]const u8 = null,
    client_token: ?[]const u8 = null,
    s3_bucket_source: ?S3BucketSource = null,
    error_count: ?i64 = null,
    cloud_watch_log_group_arn: ?[]const u8 = null,
    input_format: ?[]const u8 = null,
    input_format_options: ?InputFormatOptions = null,
    input_compression_type: ?[]const u8 = null,
    table_creation_parameters: ?TableCreationParameters = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    processed_size_bytes: ?i64 = null,
    processed_item_count: ?i64 = null,
    imported_item_count: ?i64 = null,
    failure_code: ?[]const u8 = null,
    failure_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .import_arn = "ImportArn",
            .import_status = "ImportStatus",
            .table_arn = "TableArn",
            .table_id = "TableId",
            .client_token = "ClientToken",
            .s3_bucket_source = "S3BucketSource",
            .error_count = "ErrorCount",
            .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
            .input_format = "InputFormat",
            .input_format_options = "InputFormatOptions",
            .input_compression_type = "InputCompressionType",
            .table_creation_parameters = "TableCreationParameters",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .processed_size_bytes = "ProcessedSizeBytes",
            .processed_item_count = "ProcessedItemCount",
            .imported_item_count = "ImportedItemCount",
            .failure_code = "FailureCode",
            .failure_message = "FailureMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const TableCreationParameters = struct {
    table_name: []const u8,
    attribute_definitions: []AttributeDefinition,
    key_schema: []KeySchemaElement,
    billing_mode: ?[]const u8 = null,
    provisioned_throughput: ?ProvisionedThroughput = null,
    sse_specification: ?SSESpecification = null,
    global_secondary_indexes: ?[]GlobalSecondaryIndex = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "TableName",
            .attribute_definitions = "AttributeDefinitions",
            .key_schema = "KeySchema",
            .billing_mode = "BillingMode",
            .provisioned_throughput = "ProvisionedThroughput",
            .sse_specification = "SSESpecification",
            .global_secondary_indexes = "GlobalSecondaryIndexes",
        };
        return @field(mappings, field_name);
    }
};

pub const InputFormatOptions = struct {
    csv: ?CsvOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv = "Csv",
        };
        return @field(mappings, field_name);
    }
};

pub const CsvOptions = struct {
    delimiter: ?[]const u8 = null,
    header_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delimiter = "Delimiter",
            .header_list = "HeaderList",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportDescription = struct {
    export_arn: ?[]const u8 = null,
    export_status: ?[]const u8 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    export_manifest: ?[]const u8 = null,
    table_arn: ?[]const u8 = null,
    table_id: ?[]const u8 = null,
    export_time: ?i64 = null,
    client_token: ?[]const u8 = null,
    s3_bucket: ?[]const u8 = null,
    s3_bucket_owner: ?[]const u8 = null,
    s3_prefix: ?[]const u8 = null,
    s3_sse_algorithm: ?[]const u8 = null,
    s3_sse_kms_key_id: ?[]const u8 = null,
    failure_code: ?[]const u8 = null,
    failure_message: ?[]const u8 = null,
    export_format: ?[]const u8 = null,
    billed_size_bytes: ?i64 = null,
    item_count: ?i64 = null,
    export_type: ?[]const u8 = null,
    incremental_export_specification: ?IncrementalExportSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .export_arn = "ExportArn",
            .export_status = "ExportStatus",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .export_manifest = "ExportManifest",
            .table_arn = "TableArn",
            .table_id = "TableId",
            .export_time = "ExportTime",
            .client_token = "ClientToken",
            .s3_bucket = "S3Bucket",
            .s3_bucket_owner = "S3BucketOwner",
            .s3_prefix = "S3Prefix",
            .s3_sse_algorithm = "S3SseAlgorithm",
            .s3_sse_kms_key_id = "S3SseKmsKeyId",
            .failure_code = "FailureCode",
            .failure_message = "FailureMessage",
            .export_format = "ExportFormat",
            .billed_size_bytes = "BilledSizeBytes",
            .item_count = "ItemCount",
            .export_type = "ExportType",
            .incremental_export_specification = "IncrementalExportSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const IncrementalExportSpecification = struct {
    export_from_time: ?i64 = null,
    export_to_time: ?i64 = null,
    export_view_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .export_from_time = "ExportFromTime",
            .export_to_time = "ExportToTime",
            .export_view_type = "ExportViewType",
        };
        return @field(mappings, field_name);
    }
};

pub const EnableKinesisStreamingConfiguration = struct {
    approximate_creation_date_time_precision: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .approximate_creation_date_time_precision = "ApproximateCreationDateTimePrecision",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeToLiveDescription = struct {
    time_to_live_status: ?[]const u8 = null,
    attribute_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_to_live_status = "TimeToLiveStatus",
            .attribute_name = "AttributeName",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupDescription = struct {
    backup_details: ?BackupDetails = null,
    source_table_details: ?SourceTableDetails = null,
    source_table_feature_details: ?SourceTableFeatureDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_details = "BackupDetails",
            .source_table_details = "SourceTableDetails",
            .source_table_feature_details = "SourceTableFeatureDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceTableFeatureDetails = struct {
    local_secondary_indexes: ?[]LocalSecondaryIndexInfo = null,
    global_secondary_indexes: ?[]GlobalSecondaryIndexInfo = null,
    stream_description: ?StreamSpecification = null,
    time_to_live_description: ?TimeToLiveDescription = null,
    sse_description: ?SSEDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_secondary_indexes = "LocalSecondaryIndexes",
            .global_secondary_indexes = "GlobalSecondaryIndexes",
            .stream_description = "StreamDescription",
            .time_to_live_description = "TimeToLiveDescription",
            .sse_description = "SSEDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalSecondaryIndexInfo = struct {
    index_name: ?[]const u8 = null,
    key_schema: ?[]KeySchemaElement = null,
    projection: ?Projection = null,
    provisioned_throughput: ?ProvisionedThroughput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .key_schema = "KeySchema",
            .projection = "Projection",
            .provisioned_throughput = "ProvisionedThroughput",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalSecondaryIndexInfo = struct {
    index_name: ?[]const u8 = null,
    key_schema: ?[]KeySchemaElement = null,
    projection: ?Projection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .key_schema = "KeySchema",
            .projection = "Projection",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceTableDetails = struct {
    table_name: []const u8,
    table_id: []const u8,
    table_arn: ?[]const u8 = null,
    table_size_bytes: ?i64 = null,
    key_schema: []KeySchemaElement,
    table_creation_date_time: i64,
    provisioned_throughput: ProvisionedThroughput,
    item_count: ?i64 = null,
    billing_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "TableName",
            .table_id = "TableId",
            .table_arn = "TableArn",
            .table_size_bytes = "TableSizeBytes",
            .key_schema = "KeySchema",
            .table_creation_date_time = "TableCreationDateTime",
            .provisioned_throughput = "ProvisionedThroughput",
            .item_count = "ItemCount",
            .billing_mode = "BillingMode",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupDetails = struct {
    backup_arn: []const u8,
    backup_name: []const u8,
    backup_size_bytes: ?i64 = null,
    backup_status: []const u8,
    backup_type: []const u8,
    backup_creation_date_time: i64,
    backup_expiry_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_arn = "BackupArn",
            .backup_name = "BackupName",
            .backup_size_bytes = "BackupSizeBytes",
            .backup_status = "BackupStatus",
            .backup_type = "BackupType",
            .backup_creation_date_time = "BackupCreationDateTime",
            .backup_expiry_date_time = "BackupExpiryDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const WriteRequest = struct {
    put_request: ?PutRequest = null,
    delete_request: ?DeleteRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .put_request = "PutRequest",
            .delete_request = "DeleteRequest",
        };
        return @field(mappings, field_name);
    }
};

pub const DeleteRequest = struct {
    key: []struct {
        key: ?[]const u8 = null,
        value: ?AttributeValue = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "key", field_name))
            return try serializeMap(self.key, self.fieldNameFor("key"), options, out_stream);
        return false;
    }
};

pub const PutRequest = struct {
    item: []struct {
        key: ?[]const u8 = null,
        value: ?AttributeValue = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item = "Item",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "item", field_name))
            return try serializeMap(self.item, self.fieldNameFor("item"), options, out_stream);
        return false;
    }
};

pub const KeysAndAttributes = struct {
    keys: [][]struct {
        key: ?[]const u8 = null,
        value: ?AttributeValue = null,
    },
    attributes_to_get: ?[][]const u8 = null,
    consistent_read: ?bool = null,
    projection_expression: ?[]const u8 = null,
    expression_attribute_names: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .keys = "Keys",
            .attributes_to_get = "AttributesToGet",
            .consistent_read = "ConsistentRead",
            .projection_expression = "ProjectionExpression",
            .expression_attribute_names = "ExpressionAttributeNames",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "keys", field_name))
            return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
        if (std.mem.eql(u8, "expression_attribute_names", field_name))
            return try serializeMap(self.expression_attribute_names, self.fieldNameFor("expression_attribute_names"), options, out_stream);
        return false;
    }
};
