const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-08-10";
pub const sdk_id: []const u8 = "DynamoDB Streams";
pub const arn_namespace: ?[]const u8 = "dynamodb";
pub const endpoint_prefix: []const u8 = "streams.dynamodb";
pub const sigv4_name: []const u8 = "dynamodb";
pub const name: []const u8 = "DynamoDBStreams_20120810";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2012-08-10",
    sdk_id: []const u8 = "DynamoDB Streams",
    arn_namespace: ?[]const u8 = "dynamodb",
    endpoint_prefix: []const u8 = "streams.dynamodb",
    sigv4_name: []const u8 = "dynamodb",
    name: []const u8 = "DynamoDBStreams_20120810",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const describe_stream: struct {
    action_name: []const u8 = "DescribeStream",
    Request: type = struct {
        stream_arn: []const u8,
        limit: ?i64 = null,
        exclusive_start_shard_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamArn",
                .limit = "Limit",
                .exclusive_start_shard_id = "ExclusiveStartShardId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stream) } {
            return .{ .service_metadata = service_metadata, .action = describe_stream };
        }
    },
    Response: type = struct {
        stream_description: ?struct {
            stream_arn: ?[]const u8 = null,
            stream_label: ?[]const u8 = null,
            stream_status: ?[]const u8 = null,
            stream_view_type: ?[]const u8 = null,
            creation_request_date_time: ?i64 = null,
            table_name: ?[]const u8 = null,
            key_schema: ?[]struct {
                attribute_name: []const u8,
                key_type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attribute_name = "AttributeName",
                        .key_type = "KeyType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            shards: ?[]struct {
                shard_id: ?[]const u8 = null,
                sequence_number_range: ?struct {
                    starting_sequence_number: ?[]const u8 = null,
                    ending_sequence_number: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .starting_sequence_number = "StartingSequenceNumber",
                            .ending_sequence_number = "EndingSequenceNumber",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                parent_shard_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .shard_id = "ShardId",
                        .sequence_number_range = "SequenceNumberRange",
                        .parent_shard_id = "ParentShardId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_evaluated_shard_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stream_arn = "StreamArn",
                    .stream_label = "StreamLabel",
                    .stream_status = "StreamStatus",
                    .stream_view_type = "StreamViewType",
                    .creation_request_date_time = "CreationRequestDateTime",
                    .table_name = "TableName",
                    .key_schema = "KeySchema",
                    .shards = "Shards",
                    .last_evaluated_shard_id = "LastEvaluatedShardId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_description = "StreamDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceNotFound,
    },
} = .{};
pub const get_records: struct {
    action_name: []const u8 = "GetRecords",
    Request: type = struct {
        shard_iterator: []const u8,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shard_iterator = "ShardIterator",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_records) } {
            return .{ .service_metadata = service_metadata, .action = get_records };
        }
    },
    Response: type = struct {
        records: ?[]struct {
            event_id: ?[]const u8 = null,
            event_name: ?[]const u8 = null,
            event_version: ?[]const u8 = null,
            event_source: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,
            dynamodb: ?struct {
                approximate_creation_date_time: ?i64 = null,
                keys: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                } = null,
                new_image: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                } = null,
                old_image: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?AttributeValue = null,
                } = null,
                sequence_number: ?[]const u8 = null,
                size_bytes: ?i64 = null,
                stream_view_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .approximate_creation_date_time = "ApproximateCreationDateTime",
                        .keys = "Keys",
                        .new_image = "NewImage",
                        .old_image = "OldImage",
                        .sequence_number = "SequenceNumber",
                        .size_bytes = "SizeBytes",
                        .stream_view_type = "StreamViewType",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "keys", field_name))
                        return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
                    if (std.mem.eql(u8, "new_image", field_name))
                        return try serializeMap(self.new_image, self.fieldNameFor("new_image"), options, out_stream);
                    if (std.mem.eql(u8, "old_image", field_name))
                        return try serializeMap(self.old_image, self.fieldNameFor("old_image"), options, out_stream);
                    return false;
                }
            } = null,
            user_identity: ?struct {
                principal_id: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .principal_id = "PrincipalId",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_id = "eventID",
                    .event_name = "eventName",
                    .event_version = "eventVersion",
                    .event_source = "eventSource",
                    .aws_region = "awsRegion",
                    .dynamodb = "dynamodb",
                    .user_identity = "userIdentity",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_shard_iterator: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
                .next_shard_iterator = "NextShardIterator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredIterator,
        InternalServerError,
        LimitExceeded,
        ResourceNotFound,
        TrimmedDataAccess,
    },
} = .{};
pub const get_shard_iterator: struct {
    action_name: []const u8 = "GetShardIterator",
    Request: type = struct {
        stream_arn: []const u8,
        shard_id: []const u8,
        shard_iterator_type: []const u8,
        sequence_number: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamArn",
                .shard_id = "ShardId",
                .shard_iterator_type = "ShardIteratorType",
                .sequence_number = "SequenceNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_shard_iterator) } {
            return .{ .service_metadata = service_metadata, .action = get_shard_iterator };
        }
    },
    Response: type = struct {
        shard_iterator: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shard_iterator = "ShardIterator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceNotFound,
        TrimmedDataAccess,
    },
} = .{};
pub const list_streams: struct {
    action_name: []const u8 = "ListStreams",
    Request: type = struct {
        table_name: ?[]const u8 = null,
        limit: ?i64 = null,
        exclusive_start_stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .limit = "Limit",
                .exclusive_start_stream_arn = "ExclusiveStartStreamArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_streams) } {
            return .{ .service_metadata = service_metadata, .action = list_streams };
        }
    },
    Response: type = struct {
        streams: ?[]struct {
            stream_arn: ?[]const u8 = null,
            table_name: ?[]const u8 = null,
            stream_label: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stream_arn = "StreamArn",
                    .table_name = "TableName",
                    .stream_label = "StreamLabel",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_evaluated_stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streams = "Streams",
                .last_evaluated_stream_arn = "LastEvaluatedStreamArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceNotFound,
    },
} = .{};

pub const AttributeValue = union {
    s: ?[]const u8,
    n: ?[]const u8,
    b: ?[]const u8,
    ss: ?[][]const u8,
    ns: ?[][]const u8,
    bs: ?[][]const u8,
    m: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AttributeValue = null,
    },
    l: ?[]AttributeValue,
    @"null": ?bool,
    bool: ?bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s = "S",
            .n = "N",
            .b = "B",
            .ss = "SS",
            .ns = "NS",
            .bs = "BS",
            .m = "M",
            .l = "L",
            .@"null" = "NULL",
            .bool = "BOOL",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "m", field_name))
            return try serializeMap(self.m, self.fieldNameFor("m"), options, out_stream);
        return false;
    }
};
