const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-11-02";
pub const sdk_id: []const u8 = "EBS";
pub const arn_namespace: ?[]const u8 = "ebs";
pub const endpoint_prefix: []const u8 = "ebs";
pub const sigv4_name: []const u8 = "ebs";
pub const name: []const u8 = "Ebs";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-11-02",
    sdk_id: []const u8 = "EBS",
    arn_namespace: ?[]const u8 = "ebs",
    endpoint_prefix: []const u8 = "ebs",
    sigv4_name: []const u8 = "ebs",
    name: []const u8 = "Ebs",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const complete_snapshot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/snapshots/completion/{SnapshotId}",
        .success_code = 202,
    };

    action_name: []const u8 = "CompleteSnapshot",
    Request: type = struct {
        snapshot_id: []const u8,
        changed_blocks_count: i64,
        checksum: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        checksum_aggregation_method: ?[]const u8 = null,
        pub const http_header = .{
            .changed_blocks_count = "x-amz-ChangedBlocksCount",
            .checksum = "x-amz-Checksum",
            .checksum_algorithm = "x-amz-Checksum-Algorithm",
            .checksum_aggregation_method = "x-amz-Checksum-Aggregation-Method",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .changed_blocks_count = "ChangedBlocksCount",
                .checksum = "Checksum",
                .checksum_algorithm = "ChecksumAlgorithm",
                .checksum_aggregation_method = "ChecksumAggregationMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(complete_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = complete_snapshot };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestThrottled,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const get_snapshot_block: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/snapshots/{SnapshotId}/blocks/{BlockIndex}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSnapshotBlock",
    Request: type = struct {
        snapshot_id: []const u8,
        block_index: i64,
        block_token: []const u8,

        pub const http_query = .{
            .block_token = "blockToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .block_index = "BlockIndex",
                .block_token = "BlockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_snapshot_block) } {
            return .{ .service_metadata = service_metadata, .action = get_snapshot_block };
        }
    },
    Response: type = struct {
        data_length: ?i64 = null,
        block_data: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        pub const http_header = .{
            .data_length = "x-amz-Data-Length",
            .checksum = "x-amz-Checksum",
            .checksum_algorithm = "x-amz-Checksum-Algorithm",
        };

        pub const http_payload: []const u8 = "block_data";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_length = "DataLength",
                .block_data = "BlockData",
                .checksum = "Checksum",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestThrottled,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_changed_blocks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/snapshots/{SecondSnapshotId}/changedblocks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChangedBlocks",
    Request: type = struct {
        first_snapshot_id: ?[]const u8 = null,
        second_snapshot_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        starting_block_index: ?i64 = null,

        pub const http_query = .{
            .first_snapshot_id = "firstSnapshotId",
            .next_token = "pageToken",
            .max_results = "maxResults",
            .starting_block_index = "startingBlockIndex",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .first_snapshot_id = "FirstSnapshotId",
                .second_snapshot_id = "SecondSnapshotId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .starting_block_index = "StartingBlockIndex",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_changed_blocks) } {
            return .{ .service_metadata = service_metadata, .action = list_changed_blocks };
        }
    },
    Response: type = struct {
        changed_blocks: ?[]struct {
            block_index: ?i64 = null,
            first_block_token: ?[]const u8 = null,
            second_block_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .block_index = "BlockIndex",
                    .first_block_token = "FirstBlockToken",
                    .second_block_token = "SecondBlockToken",
                };
                return @field(mappings, field_name);
            }
        } = null,
        expiry_time: ?i64 = null,
        volume_size: ?i64 = null,
        block_size: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .changed_blocks = "ChangedBlocks",
                .expiry_time = "ExpiryTime",
                .volume_size = "VolumeSize",
                .block_size = "BlockSize",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestThrottled,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_snapshot_blocks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/snapshots/{SnapshotId}/blocks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSnapshotBlocks",
    Request: type = struct {
        snapshot_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        starting_block_index: ?i64 = null,

        pub const http_query = .{
            .next_token = "pageToken",
            .max_results = "maxResults",
            .starting_block_index = "startingBlockIndex",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .starting_block_index = "StartingBlockIndex",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_snapshot_blocks) } {
            return .{ .service_metadata = service_metadata, .action = list_snapshot_blocks };
        }
    },
    Response: type = struct {
        blocks: ?[]struct {
            block_index: ?i64 = null,
            block_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .block_index = "BlockIndex",
                    .block_token = "BlockToken",
                };
                return @field(mappings, field_name);
            }
        } = null,
        expiry_time: ?i64 = null,
        volume_size: ?i64 = null,
        block_size: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blocks = "Blocks",
                .expiry_time = "ExpiryTime",
                .volume_size = "VolumeSize",
                .block_size = "BlockSize",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestThrottled,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const put_snapshot_block: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/snapshots/{SnapshotId}/blocks/{BlockIndex}",
        .success_code = 201,
    };

    action_name: []const u8 = "PutSnapshotBlock",
    Request: type = struct {
        snapshot_id: []const u8,
        block_index: i64,
        block_data: []const u8,
        data_length: i64,
        progress: ?i64 = null,
        checksum: []const u8,
        checksum_algorithm: []const u8,
        pub const http_header = .{
            .data_length = "x-amz-Data-Length",
            .progress = "x-amz-Progress",
            .checksum = "x-amz-Checksum",
            .checksum_algorithm = "x-amz-Checksum-Algorithm",
        };

        pub const http_payload: []const u8 = "block_data";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .block_index = "BlockIndex",
                .block_data = "BlockData",
                .data_length = "DataLength",
                .progress = "Progress",
                .checksum = "Checksum",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_snapshot_block) } {
            return .{ .service_metadata = service_metadata, .action = put_snapshot_block };
        }
    },
    Response: type = struct {
        checksum: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        pub const http_header = .{
            .checksum = "x-amz-Checksum",
            .checksum_algorithm = "x-amz-Checksum-Algorithm",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .checksum = "Checksum",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestThrottled,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const start_snapshot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/snapshots",
        .success_code = 201,
    };

    action_name: []const u8 = "StartSnapshot",
    Request: type = struct {
        volume_size: i64,
        parent_snapshot_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        encrypted: ?bool = null,
        kms_key_arn: ?[]const u8 = null,
        timeout: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_size = "VolumeSize",
                .parent_snapshot_id = "ParentSnapshotId",
                .tags = "Tags",
                .description = "Description",
                .client_token = "ClientToken",
                .encrypted = "Encrypted",
                .kms_key_arn = "KmsKeyArn",
                .timeout = "Timeout",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = start_snapshot };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        snapshot_id: ?[]const u8 = null,
        owner_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        start_time: ?i64 = null,
        volume_size: ?i64 = null,
        block_size: ?i64 = null,
        tags: ?[]Tag = null,
        parent_snapshot_id: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        sse_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .snapshot_id = "SnapshotId",
                .owner_id = "OwnerId",
                .status = "Status",
                .start_time = "StartTime",
                .volume_size = "VolumeSize",
                .block_size = "BlockSize",
                .tags = "Tags",
                .parent_snapshot_id = "ParentSnapshotId",
                .kms_key_arn = "KmsKeyArn",
                .sse_type = "SseType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentLimitExceeded,
        Conflict,
        InternalServer,
        RequestThrottled,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
