const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-04-02";
pub const sdk_id: []const u8 = "EC2 Instance Connect";
pub const arn_namespace: ?[]const u8 = "ec2-instance-connect";
pub const endpoint_prefix: []const u8 = "ec2-instance-connect";
pub const sigv4_name: []const u8 = "ec2-instance-connect";
pub const name: []const u8 = "AWSEC2InstanceConnectService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-04-02",
    sdk_id: []const u8 = "EC2 Instance Connect",
    arn_namespace: ?[]const u8 = "ec2-instance-connect",
    endpoint_prefix: []const u8 = "ec2-instance-connect",
    sigv4_name: []const u8 = "ec2-instance-connect",
    name: []const u8 = "AWSEC2InstanceConnectService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const send_serial_console_ssh_public_key: struct {
    action_name: []const u8 = "SendSerialConsoleSSHPublicKey",
    Request: type = struct {
        instance_id: []const u8,
        serial_port: ?i64 = null,
        ssh_public_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .serial_port = "SerialPort",
                .ssh_public_key = "SSHPublicKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_serial_console_ssh_public_key) } {
            return .{ .service_metadata = service_metadata, .action = send_serial_console_ssh_public_key };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        success: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .success = "Success",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Auth,
        EC2InstanceNotFound,
        EC2InstanceStateInvalid,
        EC2InstanceTypeInvalid,
        EC2InstanceUnavailable,
        InvalidArgs,
        SerialConsoleAccessDisabled,
        SerialConsoleSessionLimitExceeded,
        SerialConsoleSessionUnavailable,
        Service,
        Throttling,
    },
} = .{};
pub const send_ssh_public_key: struct {
    action_name: []const u8 = "SendSSHPublicKey",
    Request: type = struct {
        instance_id: []const u8,
        instance_os_user: []const u8,
        ssh_public_key: []const u8,
        availability_zone: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .instance_os_user = "InstanceOSUser",
                .ssh_public_key = "SSHPublicKey",
                .availability_zone = "AvailabilityZone",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_ssh_public_key) } {
            return .{ .service_metadata = service_metadata, .action = send_ssh_public_key };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        success: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .success = "Success",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Auth,
        EC2InstanceNotFound,
        EC2InstanceStateInvalid,
        EC2InstanceUnavailable,
        InvalidArgs,
        Service,
        Throttling,
    },
} = .{};
