const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-10-30";
pub const sdk_id: []const u8 = "ECR PUBLIC";
pub const arn_namespace: ?[]const u8 = "ecr-public";
pub const endpoint_prefix: []const u8 = "api.ecr-public";
pub const sigv4_name: []const u8 = "ecr-public";
pub const name: []const u8 = "SpencerFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-10-30",
    sdk_id: []const u8 = "ECR PUBLIC",
    arn_namespace: ?[]const u8 = "ecr-public",
    endpoint_prefix: []const u8 = "api.ecr-public",
    sigv4_name: []const u8 = "ecr-public",
    name: []const u8 = "SpencerFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_check_layer_availability: struct {
    action_name: []const u8 = "BatchCheckLayerAvailability",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        layer_digests: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .layer_digests = "layerDigests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_check_layer_availability) } {
            return .{ .service_metadata = service_metadata, .action = batch_check_layer_availability };
        }
    },
    Response: type = struct {
        layers: ?[]struct {
            layer_digest: ?[]const u8 = null,
            layer_availability: ?[]const u8 = null,
            layer_size: ?i64 = null,
            media_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .layer_digest = "layerDigest",
                    .layer_availability = "layerAvailability",
                    .layer_size = "layerSize",
                    .media_type = "mediaType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failures: ?[]struct {
            layer_digest: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .layer_digest = "layerDigest",
                    .failure_code = "failureCode",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .layers = "layers",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RegistryNotFound,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const batch_delete_image: struct {
    action_name: []const u8 = "BatchDeleteImage",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_ids: []ImageIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_ids = "imageIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_image) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_image };
        }
    },
    Response: type = struct {
        image_ids: ?[]ImageIdentifier = null,
        failures: ?[]struct {
            image_id: ?ImageIdentifier = null,
            failure_code: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_id = "imageId",
                    .failure_code = "failureCode",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_ids = "imageIds",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const complete_layer_upload: struct {
    action_name: []const u8 = "CompleteLayerUpload",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        upload_id: []const u8,
        layer_digests: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .upload_id = "uploadId",
                .layer_digests = "layerDigests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(complete_layer_upload) } {
            return .{ .service_metadata = service_metadata, .action = complete_layer_upload };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        upload_id: ?[]const u8 = null,
        layer_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .upload_id = "uploadId",
                .layer_digest = "layerDigest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EmptyUpload,
        InvalidLayer,
        InvalidParameter,
        LayerAlreadyExists,
        LayerPartTooSmall,
        RegistryNotFound,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
        UploadNotFound,
    },
} = .{};
pub const create_repository: struct {
    action_name: []const u8 = "CreateRepository",
    Request: type = struct {
        repository_name: []const u8,
        catalog_data: ?RepositoryCatalogDataInput = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .catalog_data = "catalogData",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_repository) } {
            return .{ .service_metadata = service_metadata, .action = create_repository };
        }
    },
    Response: type = struct {
        repository: ?Repository = null,
        catalog_data: ?RepositoryCatalogData = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
                .catalog_data = "catalogData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidTagParameter,
        LimitExceeded,
        RepositoryAlreadyExists,
        Server,
        TooManyTags,
        UnsupportedCommand,
    },
} = .{};
pub const delete_repository: struct {
    action_name: []const u8 = "DeleteRepository",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_repository) } {
            return .{ .service_metadata = service_metadata, .action = delete_repository };
        }
    },
    Response: type = struct {
        repository: ?Repository = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotEmpty,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const delete_repository_policy: struct {
    action_name: []const u8 = "DeleteRepositoryPolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_repository_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_repository_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        RepositoryPolicyNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const describe_images: struct {
    action_name: []const u8 = "DescribeImages",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_ids: ?[]ImageIdentifier = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_ids = "imageIds",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_images) } {
            return .{ .service_metadata = service_metadata, .action = describe_images };
        }
    },
    Response: type = struct {
        image_details: ?[]struct {
            registry_id: ?[]const u8 = null,
            repository_name: ?[]const u8 = null,
            image_digest: ?[]const u8 = null,
            image_tags: ?[][]const u8 = null,
            image_size_in_bytes: ?i64 = null,
            image_pushed_at: ?i64 = null,
            image_manifest_media_type: ?[]const u8 = null,
            artifact_media_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_id = "registryId",
                    .repository_name = "repositoryName",
                    .image_digest = "imageDigest",
                    .image_tags = "imageTags",
                    .image_size_in_bytes = "imageSizeInBytes",
                    .image_pushed_at = "imagePushedAt",
                    .image_manifest_media_type = "imageManifestMediaType",
                    .artifact_media_type = "artifactMediaType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_details = "imageDetails",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImageNotFound,
        InvalidParameter,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const describe_image_tags: struct {
    action_name: []const u8 = "DescribeImageTags",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_image_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_image_tags };
        }
    },
    Response: type = struct {
        image_tag_details: ?[]struct {
            image_tag: ?[]const u8 = null,
            created_at: ?i64 = null,
            image_detail: ?struct {
                image_digest: ?[]const u8 = null,
                image_size_in_bytes: ?i64 = null,
                image_pushed_at: ?i64 = null,
                image_manifest_media_type: ?[]const u8 = null,
                artifact_media_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .image_digest = "imageDigest",
                        .image_size_in_bytes = "imageSizeInBytes",
                        .image_pushed_at = "imagePushedAt",
                        .image_manifest_media_type = "imageManifestMediaType",
                        .artifact_media_type = "artifactMediaType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_tag = "imageTag",
                    .created_at = "createdAt",
                    .image_detail = "imageDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_tag_details = "imageTagDetails",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const describe_registries: struct {
    action_name: []const u8 = "DescribeRegistries",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registries) } {
            return .{ .service_metadata = service_metadata, .action = describe_registries };
        }
    },
    Response: type = struct {
        registries: []struct {
            registry_id: []const u8,
            registry_arn: []const u8,
            registry_uri: []const u8,
            verified: bool,
            aliases: []struct {
                name: []const u8,
                status: []const u8,
                primary_registry_alias: bool,
                default_registry_alias: bool,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .status = "status",
                        .primary_registry_alias = "primaryRegistryAlias",
                        .default_registry_alias = "defaultRegistryAlias",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_id = "registryId",
                    .registry_arn = "registryArn",
                    .registry_uri = "registryUri",
                    .verified = "verified",
                    .aliases = "aliases",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registries = "registries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const describe_repositories: struct {
    action_name: []const u8 = "DescribeRepositories",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_names = "repositoryNames",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_repositories) } {
            return .{ .service_metadata = service_metadata, .action = describe_repositories };
        }
    },
    Response: type = struct {
        repositories: ?[]Repository = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repositories = "repositories",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const get_authorization_token: struct {
    action_name: []const u8 = "GetAuthorizationToken",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_authorization_token) } {
            return .{ .service_metadata = service_metadata, .action = get_authorization_token };
        }
    },
    Response: type = struct {
        authorization_data: ?struct {
            authorization_token: ?[]const u8 = null,
            expires_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authorization_token = "authorizationToken",
                    .expires_at = "expiresAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization_data = "authorizationData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const get_registry_catalog_data: struct {
    action_name: []const u8 = "GetRegistryCatalogData",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_registry_catalog_data) } {
            return .{ .service_metadata = service_metadata, .action = get_registry_catalog_data };
        }
    },
    Response: type = struct {
        registry_catalog_data: RegistryCatalogData,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_catalog_data = "registryCatalogData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const get_repository_catalog_data: struct {
    action_name: []const u8 = "GetRepositoryCatalogData",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_catalog_data) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_catalog_data };
        }
    },
    Response: type = struct {
        catalog_data: ?RepositoryCatalogData = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_data = "catalogData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryCatalogDataNotFound,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const get_repository_policy: struct {
    action_name: []const u8 = "GetRepositoryPolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        RepositoryPolicyNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const initiate_layer_upload: struct {
    action_name: []const u8 = "InitiateLayerUpload",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initiate_layer_upload) } {
            return .{ .service_metadata = service_metadata, .action = initiate_layer_upload };
        }
    },
    Response: type = struct {
        upload_id: ?[]const u8 = null,
        part_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload_id = "uploadId",
                .part_size = "partSize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RegistryNotFound,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const put_image: struct {
    action_name: []const u8 = "PutImage",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_manifest: []const u8,
        image_manifest_media_type: ?[]const u8 = null,
        image_tag: ?[]const u8 = null,
        image_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_manifest = "imageManifest",
                .image_manifest_media_type = "imageManifestMediaType",
                .image_tag = "imageTag",
                .image_digest = "imageDigest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_image) } {
            return .{ .service_metadata = service_metadata, .action = put_image };
        }
    },
    Response: type = struct {
        image: ?struct {
            registry_id: ?[]const u8 = null,
            repository_name: ?[]const u8 = null,
            image_id: ?ImageIdentifier = null,
            image_manifest: ?[]const u8 = null,
            image_manifest_media_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_id = "registryId",
                    .repository_name = "repositoryName",
                    .image_id = "imageId",
                    .image_manifest = "imageManifest",
                    .image_manifest_media_type = "imageManifestMediaType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "image",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImageAlreadyExists,
        ImageDigestDoesNotMatch,
        ImageTagAlreadyExists,
        InvalidParameter,
        LayersNotFound,
        LimitExceeded,
        ReferencedImagesNotFound,
        RegistryNotFound,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const put_registry_catalog_data: struct {
    action_name: []const u8 = "PutRegistryCatalogData",
    Request: type = struct {
        display_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .display_name = "displayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_registry_catalog_data) } {
            return .{ .service_metadata = service_metadata, .action = put_registry_catalog_data };
        }
    },
    Response: type = struct {
        registry_catalog_data: RegistryCatalogData,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_catalog_data = "registryCatalogData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const put_repository_catalog_data: struct {
    action_name: []const u8 = "PutRepositoryCatalogData",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        catalog_data: RepositoryCatalogDataInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .catalog_data = "catalogData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_repository_catalog_data) } {
            return .{ .service_metadata = service_metadata, .action = put_repository_catalog_data };
        }
    },
    Response: type = struct {
        catalog_data: ?RepositoryCatalogData = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_data = "catalogData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const set_repository_policy: struct {
    action_name: []const u8 = "SetRepositoryPolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        policy_text: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .policy_text = "policyText",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_repository_policy) } {
            return .{ .service_metadata = service_metadata, .action = set_repository_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidTagParameter,
        RepositoryNotFound,
        Server,
        TooManyTags,
        UnsupportedCommand,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidTagParameter,
        RepositoryNotFound,
        Server,
        TooManyTags,
        UnsupportedCommand,
    },
} = .{};
pub const upload_layer_part: struct {
    action_name: []const u8 = "UploadLayerPart",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        upload_id: []const u8,
        part_first_byte: i64,
        part_last_byte: i64,
        layer_part_blob: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .upload_id = "uploadId",
                .part_first_byte = "partFirstByte",
                .part_last_byte = "partLastByte",
                .layer_part_blob = "layerPartBlob",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upload_layer_part) } {
            return .{ .service_metadata = service_metadata, .action = upload_layer_part };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        upload_id: ?[]const u8 = null,
        last_byte_received: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .upload_id = "uploadId",
                .last_byte_received = "lastByteReceived",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLayerPart,
        InvalidParameter,
        LimitExceeded,
        RegistryNotFound,
        RepositoryNotFound,
        Server,
        UnsupportedCommand,
        UploadNotFound,
    },
} = .{};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryCatalogData = struct {
    description: ?[]const u8 = null,
    architectures: ?[][]const u8 = null,
    operating_systems: ?[][]const u8 = null,
    logo_url: ?[]const u8 = null,
    about_text: ?[]const u8 = null,
    usage_text: ?[]const u8 = null,
    marketplace_certified: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .architectures = "architectures",
            .operating_systems = "operatingSystems",
            .logo_url = "logoUrl",
            .about_text = "aboutText",
            .usage_text = "usageText",
            .marketplace_certified = "marketplaceCertified",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryCatalogDataInput = struct {
    description: ?[]const u8 = null,
    architectures: ?[][]const u8 = null,
    operating_systems: ?[][]const u8 = null,
    logo_image_blob: ?[]const u8 = null,
    about_text: ?[]const u8 = null,
    usage_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .architectures = "architectures",
            .operating_systems = "operatingSystems",
            .logo_image_blob = "logoImageBlob",
            .about_text = "aboutText",
            .usage_text = "usageText",
        };
        return @field(mappings, field_name);
    }
};

pub const RegistryCatalogData = struct {
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_name = "displayName",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageIdentifier = struct {
    image_digest: ?[]const u8 = null,
    image_tag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_digest = "imageDigest",
            .image_tag = "imageTag",
        };
        return @field(mappings, field_name);
    }
};

pub const Repository = struct {
    repository_arn: ?[]const u8 = null,
    registry_id: ?[]const u8 = null,
    repository_name: ?[]const u8 = null,
    repository_uri: ?[]const u8 = null,
    created_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_arn = "repositoryArn",
            .registry_id = "registryId",
            .repository_name = "repositoryName",
            .repository_uri = "repositoryUri",
            .created_at = "createdAt",
        };
        return @field(mappings, field_name);
    }
};
