const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-11-13";
pub const sdk_id: []const u8 = "ECS";
pub const arn_namespace: ?[]const u8 = "ecs";
pub const endpoint_prefix: []const u8 = "ecs";
pub const sigv4_name: []const u8 = "ecs";
pub const name: []const u8 = "AmazonEC2ContainerServiceV20141113";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2014-11-13",
    sdk_id: []const u8 = "ECS",
    arn_namespace: ?[]const u8 = "ecs",
    endpoint_prefix: []const u8 = "ecs",
    sigv4_name: []const u8 = "ecs",
    name: []const u8 = "AmazonEC2ContainerServiceV20141113",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_capacity_provider: struct {
    action_name: []const u8 = "CreateCapacityProvider",
    Request: type = struct {
        name: []const u8,
        auto_scaling_group_provider: AutoScalingGroupProvider,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .auto_scaling_group_provider = "autoScalingGroupProvider",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_capacity_provider) } {
            return .{ .service_metadata = service_metadata, .action = create_capacity_provider };
        }
    },
    Response: type = struct {
        capacity_provider: ?CapacityProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_provider = "capacityProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        LimitExceeded,
        Server,
        UpdateInProgress,
    },
} = .{};
pub const create_cluster: struct {
    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        cluster_name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        settings: ?[]ClusterSetting = null,
        configuration: ?ClusterConfiguration = null,
        capacity_providers: ?[][]const u8 = null,
        default_capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
        service_connect_defaults: ?ClusterServiceConnectDefaultsRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .tags = "tags",
                .settings = "settings",
                .configuration = "configuration",
                .capacity_providers = "capacityProviders",
                .default_capacity_provider_strategy = "defaultCapacityProviderStrategy",
                .service_connect_defaults = "serviceConnectDefaults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        NamespaceNotFound,
        Server,
    },
} = .{};
pub const create_service: struct {
    action_name: []const u8 = "CreateService",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        service_name: []const u8,
        task_definition: ?[]const u8 = null,
        load_balancers: ?[]LoadBalancer = null,
        service_registries: ?[]ServiceRegistry = null,
        desired_count: ?i64 = null,
        client_token: ?[]const u8 = null,
        launch_type: ?[]const u8 = null,
        capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
        platform_version: ?[]const u8 = null,
        role: ?[]const u8 = null,
        deployment_configuration: ?DeploymentConfiguration = null,
        placement_constraints: ?[]PlacementConstraint = null,
        placement_strategy: ?[]PlacementStrategy = null,
        network_configuration: ?NetworkConfiguration = null,
        health_check_grace_period_seconds: ?i64 = null,
        scheduling_strategy: ?[]const u8 = null,
        deployment_controller: ?DeploymentController = null,
        tags: ?[]Tag = null,
        enable_ecs_managed_tags: ?bool = null,
        propagate_tags: ?[]const u8 = null,
        enable_execute_command: ?bool = null,
        service_connect_configuration: ?ServiceConnectConfiguration = null,
        volume_configurations: ?[]ServiceVolumeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .service_name = "serviceName",
                .task_definition = "taskDefinition",
                .load_balancers = "loadBalancers",
                .service_registries = "serviceRegistries",
                .desired_count = "desiredCount",
                .client_token = "clientToken",
                .launch_type = "launchType",
                .capacity_provider_strategy = "capacityProviderStrategy",
                .platform_version = "platformVersion",
                .role = "role",
                .deployment_configuration = "deploymentConfiguration",
                .placement_constraints = "placementConstraints",
                .placement_strategy = "placementStrategy",
                .network_configuration = "networkConfiguration",
                .health_check_grace_period_seconds = "healthCheckGracePeriodSeconds",
                .scheduling_strategy = "schedulingStrategy",
                .deployment_controller = "deploymentController",
                .tags = "tags",
                .enable_ecs_managed_tags = "enableECSManagedTags",
                .propagate_tags = "propagateTags",
                .enable_execute_command = "enableExecuteCommand",
                .service_connect_configuration = "serviceConnectConfiguration",
                .volume_configurations = "volumeConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_service) } {
            return .{ .service_metadata = service_metadata, .action = create_service };
        }
    },
    Response: type = struct {
        service: ?Service = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "service",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        NamespaceNotFound,
        PlatformTaskDefinitionIncompatibility,
        PlatformUnknown,
        Server,
        UnsupportedFeature,
    },
} = .{};
pub const create_task_set: struct {
    action_name: []const u8 = "CreateTaskSet",
    Request: type = struct {
        service: []const u8,
        cluster: []const u8,
        external_id: ?[]const u8 = null,
        task_definition: []const u8,
        network_configuration: ?NetworkConfiguration = null,
        load_balancers: ?[]LoadBalancer = null,
        service_registries: ?[]ServiceRegistry = null,
        launch_type: ?[]const u8 = null,
        capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
        platform_version: ?[]const u8 = null,
        scale: ?Scale = null,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "service",
                .cluster = "cluster",
                .external_id = "externalId",
                .task_definition = "taskDefinition",
                .network_configuration = "networkConfiguration",
                .load_balancers = "loadBalancers",
                .service_registries = "serviceRegistries",
                .launch_type = "launchType",
                .capacity_provider_strategy = "capacityProviderStrategy",
                .platform_version = "platformVersion",
                .scale = "scale",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_task_set) } {
            return .{ .service_metadata = service_metadata, .action = create_task_set };
        }
    },
    Response: type = struct {
        task_set: ?TaskSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_set = "taskSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        NamespaceNotFound,
        PlatformTaskDefinitionIncompatibility,
        PlatformUnknown,
        Server,
        ServiceNotActive,
        ServiceNotFound,
        UnsupportedFeature,
    },
} = .{};
pub const delete_account_setting: struct {
    action_name: []const u8 = "DeleteAccountSetting",
    Request: type = struct {
        name: []const u8,
        principal_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .principal_arn = "principalArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_account_setting) } {
            return .{ .service_metadata = service_metadata, .action = delete_account_setting };
        }
    },
    Response: type = struct {
        setting: ?Setting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .setting = "setting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const delete_attributes: struct {
    action_name: []const u8 = "DeleteAttributes",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        attributes: []Attribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_attributes) } {
            return .{ .service_metadata = service_metadata, .action = delete_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]Attribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidParameter,
        TargetNotFound,
    },
} = .{};
pub const delete_capacity_provider: struct {
    action_name: []const u8 = "DeleteCapacityProvider",
    Request: type = struct {
        capacity_provider: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_provider = "capacityProvider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_capacity_provider) } {
            return .{ .service_metadata = service_metadata, .action = delete_capacity_provider };
        }
    },
    Response: type = struct {
        capacity_provider: ?CapacityProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_provider = "capacityProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const delete_cluster: struct {
    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        cluster: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterContainsContainerInstances,
        ClusterContainsServices,
        ClusterContainsTasks,
        ClusterNotFound,
        InvalidParameter,
        Server,
        UpdateInProgress,
    },
} = .{};
pub const delete_service: struct {
    action_name: []const u8 = "DeleteService",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        service: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .service = "service",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_service) } {
            return .{ .service_metadata = service_metadata, .action = delete_service };
        }
    },
    Response: type = struct {
        service: ?Service = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "service",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
        ServiceNotFound,
    },
} = .{};
pub const delete_task_definitions: struct {
    action_name: []const u8 = "DeleteTaskDefinitions",
    Request: type = struct {
        task_definitions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_definitions = "taskDefinitions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_task_definitions) } {
            return .{ .service_metadata = service_metadata, .action = delete_task_definitions };
        }
    },
    Response: type = struct {
        task_definitions: ?[]TaskDefinition = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_definitions = "taskDefinitions",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const delete_task_set: struct {
    action_name: []const u8 = "DeleteTaskSet",
    Request: type = struct {
        cluster: []const u8,
        service: []const u8,
        task_set: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .service = "service",
                .task_set = "taskSet",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_task_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_task_set };
        }
    },
    Response: type = struct {
        task_set: ?TaskSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_set = "taskSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
        ServiceNotActive,
        ServiceNotFound,
        TaskSetNotFound,
        UnsupportedFeature,
    },
} = .{};
pub const deregister_container_instance: struct {
    action_name: []const u8 = "DeregisterContainerInstance",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        container_instance: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .container_instance = "containerInstance",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_container_instance) } {
            return .{ .service_metadata = service_metadata, .action = deregister_container_instance };
        }
    },
    Response: type = struct {
        container_instance: ?ContainerInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_instance = "containerInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const deregister_task_definition: struct {
    action_name: []const u8 = "DeregisterTaskDefinition",
    Request: type = struct {
        task_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_definition = "taskDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = deregister_task_definition };
        }
    },
    Response: type = struct {
        task_definition: ?TaskDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_definition = "taskDefinition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const describe_capacity_providers: struct {
    action_name: []const u8 = "DescribeCapacityProviders",
    Request: type = struct {
        capacity_providers: ?[][]const u8 = null,
        include: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_providers = "capacityProviders",
                .include = "include",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_capacity_providers) } {
            return .{ .service_metadata = service_metadata, .action = describe_capacity_providers };
        }
    },
    Response: type = struct {
        capacity_providers: ?[]CapacityProvider = null,
        failures: ?[]Failure = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_providers = "capacityProviders",
                .failures = "failures",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const describe_clusters: struct {
    action_name: []const u8 = "DescribeClusters",
    Request: type = struct {
        clusters: ?[][]const u8 = null,
        include: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .clusters = "clusters",
                .include = "include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_clusters };
        }
    },
    Response: type = struct {
        clusters: ?[]Cluster = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .clusters = "clusters",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const describe_container_instances: struct {
    action_name: []const u8 = "DescribeContainerInstances",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        container_instances: [][]const u8,
        include: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .container_instances = "containerInstances",
                .include = "include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_container_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_container_instances };
        }
    },
    Response: type = struct {
        container_instances: ?[]ContainerInstance = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_instances = "containerInstances",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const describe_services: struct {
    action_name: []const u8 = "DescribeServices",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        services: [][]const u8,
        include: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .services = "services",
                .include = "include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_services) } {
            return .{ .service_metadata = service_metadata, .action = describe_services };
        }
    },
    Response: type = struct {
        services: ?[]Service = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .services = "services",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const describe_task_definition: struct {
    action_name: []const u8 = "DescribeTaskDefinition",
    Request: type = struct {
        task_definition: []const u8,
        include: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_definition = "taskDefinition",
                .include = "include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_task_definition };
        }
    },
    Response: type = struct {
        task_definition: ?TaskDefinition = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_definition = "taskDefinition",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const describe_tasks: struct {
    action_name: []const u8 = "DescribeTasks",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        tasks: [][]const u8,
        include: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .tasks = "tasks",
                .include = "include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_tasks };
        }
    },
    Response: type = struct {
        tasks: ?[]Task = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "tasks",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const describe_task_sets: struct {
    action_name: []const u8 = "DescribeTaskSets",
    Request: type = struct {
        cluster: []const u8,
        service: []const u8,
        task_sets: ?[][]const u8 = null,
        include: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .service = "service",
                .task_sets = "taskSets",
                .include = "include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_task_sets) } {
            return .{ .service_metadata = service_metadata, .action = describe_task_sets };
        }
    },
    Response: type = struct {
        task_sets: ?[]TaskSet = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_sets = "taskSets",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
        ServiceNotActive,
        ServiceNotFound,
        UnsupportedFeature,
    },
} = .{};
pub const discover_poll_endpoint: struct {
    action_name: []const u8 = "DiscoverPollEndpoint",
    Request: type = struct {
        container_instance: ?[]const u8 = null,
        cluster: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_instance = "containerInstance",
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(discover_poll_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = discover_poll_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?[]const u8 = null,
        telemetry_endpoint: ?[]const u8 = null,
        service_connect_endpoint: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "endpoint",
                .telemetry_endpoint = "telemetryEndpoint",
                .service_connect_endpoint = "serviceConnectEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const execute_command: struct {
    action_name: []const u8 = "ExecuteCommand",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        container: ?[]const u8 = null,
        command: []const u8,
        interactive: bool,
        task: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .container = "container",
                .command = "command",
                .interactive = "interactive",
                .task = "task",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_command) } {
            return .{ .service_metadata = service_metadata, .action = execute_command };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        container_arn: ?[]const u8 = null,
        container_name: ?[]const u8 = null,
        interactive: ?bool = null,
        session: ?struct {
            session_id: ?[]const u8 = null,
            stream_url: ?[]const u8 = null,
            token_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_id = "sessionId",
                    .stream_url = "streamUrl",
                    .token_value = "tokenValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        task_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .container_arn = "containerArn",
                .container_name = "containerName",
                .interactive = "interactive",
                .session = "session",
                .task_arn = "taskArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
        TargetNotConnected,
    },
} = .{};
pub const get_task_protection: struct {
    action_name: []const u8 = "GetTaskProtection",
    Request: type = struct {
        cluster: []const u8,
        tasks: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .tasks = "tasks",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_task_protection) } {
            return .{ .service_metadata = service_metadata, .action = get_task_protection };
        }
    },
    Response: type = struct {
        protected_tasks: ?[]ProtectedTask = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .protected_tasks = "protectedTasks",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        ResourceNotFound,
        Server,
        UnsupportedFeature,
    },
} = .{};
pub const list_account_settings: struct {
    action_name: []const u8 = "ListAccountSettings",
    Request: type = struct {
        name: ?[]const u8 = null,
        value: ?[]const u8 = null,
        principal_arn: ?[]const u8 = null,
        effective_settings: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .value = "value",
                .principal_arn = "principalArn",
                .effective_settings = "effectiveSettings",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = list_account_settings };
        }
    },
    Response: type = struct {
        settings: ?[]Setting = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .settings = "settings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const list_attributes: struct {
    action_name: []const u8 = "ListAttributes",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        target_type: []const u8,
        attribute_name: ?[]const u8 = null,
        attribute_value: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .target_type = "targetType",
                .attribute_name = "attributeName",
                .attribute_value = "attributeValue",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attributes) } {
            return .{ .service_metadata = service_metadata, .action = list_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]Attribute = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "attributes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidParameter,
    },
} = .{};
pub const list_clusters: struct {
    action_name: []const u8 = "ListClusters",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_clusters };
        }
    },
    Response: type = struct {
        cluster_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arns = "clusterArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const list_container_instances: struct {
    action_name: []const u8 = "ListContainerInstances",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        filter: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_container_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_container_instances };
        }
    },
    Response: type = struct {
        container_instance_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_instance_arns = "containerInstanceArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const list_services: struct {
    action_name: []const u8 = "ListServices",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        launch_type: ?[]const u8 = null,
        scheduling_strategy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .launch_type = "launchType",
                .scheduling_strategy = "schedulingStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_services) } {
            return .{ .service_metadata = service_metadata, .action = list_services };
        }
    },
    Response: type = struct {
        service_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arns = "serviceArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const list_services_by_namespace: struct {
    action_name: []const u8 = "ListServicesByNamespace",
    Request: type = struct {
        namespace: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace = "namespace",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_services_by_namespace) } {
            return .{ .service_metadata = service_metadata, .action = list_services_by_namespace };
        }
    },
    Response: type = struct {
        service_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_arns = "serviceArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        NamespaceNotFound,
        Server,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const list_task_definition_families: struct {
    action_name: []const u8 = "ListTaskDefinitionFamilies",
    Request: type = struct {
        family_prefix: ?[]const u8 = null,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .family_prefix = "familyPrefix",
                .status = "status",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_task_definition_families) } {
            return .{ .service_metadata = service_metadata, .action = list_task_definition_families };
        }
    },
    Response: type = struct {
        families: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .families = "families",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const list_task_definitions: struct {
    action_name: []const u8 = "ListTaskDefinitions",
    Request: type = struct {
        family_prefix: ?[]const u8 = null,
        status: ?[]const u8 = null,
        sort: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .family_prefix = "familyPrefix",
                .status = "status",
                .sort = "sort",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_task_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_task_definitions };
        }
    },
    Response: type = struct {
        task_definition_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_definition_arns = "taskDefinitionArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const list_tasks: struct {
    action_name: []const u8 = "ListTasks",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        container_instance: ?[]const u8 = null,
        family: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        started_by: ?[]const u8 = null,
        service_name: ?[]const u8 = null,
        desired_status: ?[]const u8 = null,
        launch_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .container_instance = "containerInstance",
                .family = "family",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .started_by = "startedBy",
                .service_name = "serviceName",
                .desired_status = "desiredStatus",
                .launch_type = "launchType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_tasks };
        }
    },
    Response: type = struct {
        task_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arns = "taskArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
        ServiceNotFound,
    },
} = .{};
pub const put_account_setting: struct {
    action_name: []const u8 = "PutAccountSetting",
    Request: type = struct {
        name: []const u8,
        value: []const u8,
        principal_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .value = "value",
                .principal_arn = "principalArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_setting) } {
            return .{ .service_metadata = service_metadata, .action = put_account_setting };
        }
    },
    Response: type = struct {
        setting: ?Setting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .setting = "setting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const put_account_setting_default: struct {
    action_name: []const u8 = "PutAccountSettingDefault",
    Request: type = struct {
        name: []const u8,
        value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .value = "value",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_setting_default) } {
            return .{ .service_metadata = service_metadata, .action = put_account_setting_default };
        }
    },
    Response: type = struct {
        setting: ?Setting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .setting = "setting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const put_attributes: struct {
    action_name: []const u8 = "PutAttributes",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        attributes: []Attribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]Attribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AttributeLimitExceeded,
        ClusterNotFound,
        InvalidParameter,
        TargetNotFound,
    },
} = .{};
pub const put_cluster_capacity_providers: struct {
    action_name: []const u8 = "PutClusterCapacityProviders",
    Request: type = struct {
        cluster: []const u8,
        capacity_providers: [][]const u8,
        default_capacity_provider_strategy: []CapacityProviderStrategyItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .capacity_providers = "capacityProviders",
                .default_capacity_provider_strategy = "defaultCapacityProviderStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_cluster_capacity_providers) } {
            return .{ .service_metadata = service_metadata, .action = put_cluster_capacity_providers };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        ResourceInUse,
        Server,
        UpdateInProgress,
    },
} = .{};
pub const register_container_instance: struct {
    action_name: []const u8 = "RegisterContainerInstance",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        instance_identity_document: ?[]const u8 = null,
        instance_identity_document_signature: ?[]const u8 = null,
        total_resources: ?[]Resource = null,
        version_info: ?VersionInfo = null,
        container_instance_arn: ?[]const u8 = null,
        attributes: ?[]Attribute = null,
        platform_devices: ?[]struct {
            id: []const u8,
            type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .instance_identity_document = "instanceIdentityDocument",
                .instance_identity_document_signature = "instanceIdentityDocumentSignature",
                .total_resources = "totalResources",
                .version_info = "versionInfo",
                .container_instance_arn = "containerInstanceArn",
                .attributes = "attributes",
                .platform_devices = "platformDevices",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_container_instance) } {
            return .{ .service_metadata = service_metadata, .action = register_container_instance };
        }
    },
    Response: type = struct {
        container_instance: ?ContainerInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_instance = "containerInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const register_task_definition: struct {
    action_name: []const u8 = "RegisterTaskDefinition",
    Request: type = struct {
        family: []const u8,
        task_role_arn: ?[]const u8 = null,
        execution_role_arn: ?[]const u8 = null,
        network_mode: ?[]const u8 = null,
        container_definitions: []ContainerDefinition,
        volumes: ?[]Volume = null,
        placement_constraints: ?[]TaskDefinitionPlacementConstraint = null,
        requires_compatibilities: ?[][]const u8 = null,
        cpu: ?[]const u8 = null,
        memory: ?[]const u8 = null,
        tags: ?[]Tag = null,
        pid_mode: ?[]const u8 = null,
        ipc_mode: ?[]const u8 = null,
        proxy_configuration: ?ProxyConfiguration = null,
        inference_accelerators: ?[]InferenceAccelerator = null,
        ephemeral_storage: ?EphemeralStorage = null,
        runtime_platform: ?RuntimePlatform = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .family = "family",
                .task_role_arn = "taskRoleArn",
                .execution_role_arn = "executionRoleArn",
                .network_mode = "networkMode",
                .container_definitions = "containerDefinitions",
                .volumes = "volumes",
                .placement_constraints = "placementConstraints",
                .requires_compatibilities = "requiresCompatibilities",
                .cpu = "cpu",
                .memory = "memory",
                .tags = "tags",
                .pid_mode = "pidMode",
                .ipc_mode = "ipcMode",
                .proxy_configuration = "proxyConfiguration",
                .inference_accelerators = "inferenceAccelerators",
                .ephemeral_storage = "ephemeralStorage",
                .runtime_platform = "runtimePlatform",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = register_task_definition };
        }
    },
    Response: type = struct {
        task_definition: ?TaskDefinition = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_definition = "taskDefinition",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const run_task: struct {
    action_name: []const u8 = "RunTask",
    Request: type = struct {
        capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
        cluster: ?[]const u8 = null,
        count: ?i64 = null,
        enable_ecs_managed_tags: ?bool = null,
        enable_execute_command: ?bool = null,
        group: ?[]const u8 = null,
        launch_type: ?[]const u8 = null,
        network_configuration: ?NetworkConfiguration = null,
        overrides: ?TaskOverride = null,
        placement_constraints: ?[]PlacementConstraint = null,
        placement_strategy: ?[]PlacementStrategy = null,
        platform_version: ?[]const u8 = null,
        propagate_tags: ?[]const u8 = null,
        reference_id: ?[]const u8 = null,
        started_by: ?[]const u8 = null,
        tags: ?[]Tag = null,
        task_definition: []const u8,
        client_token: ?[]const u8 = null,
        volume_configurations: ?[]TaskVolumeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_provider_strategy = "capacityProviderStrategy",
                .cluster = "cluster",
                .count = "count",
                .enable_ecs_managed_tags = "enableECSManagedTags",
                .enable_execute_command = "enableExecuteCommand",
                .group = "group",
                .launch_type = "launchType",
                .network_configuration = "networkConfiguration",
                .overrides = "overrides",
                .placement_constraints = "placementConstraints",
                .placement_strategy = "placementStrategy",
                .platform_version = "platformVersion",
                .propagate_tags = "propagateTags",
                .reference_id = "referenceId",
                .started_by = "startedBy",
                .tags = "tags",
                .task_definition = "taskDefinition",
                .client_token = "clientToken",
                .volume_configurations = "volumeConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(run_task) } {
            return .{ .service_metadata = service_metadata, .action = run_task };
        }
    },
    Response: type = struct {
        tasks: ?[]Task = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "tasks",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Blocked,
        Client,
        ClusterNotFound,
        Conflict,
        InvalidParameter,
        PlatformTaskDefinitionIncompatibility,
        PlatformUnknown,
        Server,
        UnsupportedFeature,
    },
} = .{};
pub const start_task: struct {
    action_name: []const u8 = "StartTask",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        container_instances: [][]const u8,
        enable_ecs_managed_tags: ?bool = null,
        enable_execute_command: ?bool = null,
        group: ?[]const u8 = null,
        network_configuration: ?NetworkConfiguration = null,
        overrides: ?TaskOverride = null,
        propagate_tags: ?[]const u8 = null,
        reference_id: ?[]const u8 = null,
        started_by: ?[]const u8 = null,
        tags: ?[]Tag = null,
        task_definition: []const u8,
        volume_configurations: ?[]TaskVolumeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .container_instances = "containerInstances",
                .enable_ecs_managed_tags = "enableECSManagedTags",
                .enable_execute_command = "enableExecuteCommand",
                .group = "group",
                .network_configuration = "networkConfiguration",
                .overrides = "overrides",
                .propagate_tags = "propagateTags",
                .reference_id = "referenceId",
                .started_by = "startedBy",
                .tags = "tags",
                .task_definition = "taskDefinition",
                .volume_configurations = "volumeConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_task) } {
            return .{ .service_metadata = service_metadata, .action = start_task };
        }
    },
    Response: type = struct {
        tasks: ?[]Task = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "tasks",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
        UnsupportedFeature,
    },
} = .{};
pub const stop_task: struct {
    action_name: []const u8 = "StopTask",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        task: []const u8,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .task = "task",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_task) } {
            return .{ .service_metadata = service_metadata, .action = stop_task };
        }
    },
    Response: type = struct {
        task: ?Task = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task = "task",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const submit_attachment_state_changes: struct {
    action_name: []const u8 = "SubmitAttachmentStateChanges",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        attachments: []AttachmentStateChange,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .attachments = "attachments",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_attachment_state_changes) } {
            return .{ .service_metadata = service_metadata, .action = submit_attachment_state_changes };
        }
    },
    Response: type = struct {
        acknowledgment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acknowledgment = "acknowledgment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const submit_container_state_change: struct {
    action_name: []const u8 = "SubmitContainerStateChange",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        task: ?[]const u8 = null,
        container_name: ?[]const u8 = null,
        runtime_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        exit_code: ?i64 = null,
        reason: ?[]const u8 = null,
        network_bindings: ?[]NetworkBinding = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .task = "task",
                .container_name = "containerName",
                .runtime_id = "runtimeId",
                .status = "status",
                .exit_code = "exitCode",
                .reason = "reason",
                .network_bindings = "networkBindings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_container_state_change) } {
            return .{ .service_metadata = service_metadata, .action = submit_container_state_change };
        }
    },
    Response: type = struct {
        acknowledgment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acknowledgment = "acknowledgment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        Server,
    },
} = .{};
pub const submit_task_state_change: struct {
    action_name: []const u8 = "SubmitTaskStateChange",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        task: ?[]const u8 = null,
        status: ?[]const u8 = null,
        reason: ?[]const u8 = null,
        containers: ?[]struct {
            container_name: ?[]const u8 = null,
            image_digest: ?[]const u8 = null,
            runtime_id: ?[]const u8 = null,
            exit_code: ?i64 = null,
            network_bindings: ?[]NetworkBinding = null,
            reason: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .container_name = "containerName",
                    .image_digest = "imageDigest",
                    .runtime_id = "runtimeId",
                    .exit_code = "exitCode",
                    .network_bindings = "networkBindings",
                    .reason = "reason",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        attachments: ?[]AttachmentStateChange = null,
        managed_agents: ?[]struct {
            container_name: []const u8,
            managed_agent_name: []const u8,
            status: []const u8,
            reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .container_name = "containerName",
                    .managed_agent_name = "managedAgentName",
                    .status = "status",
                    .reason = "reason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pull_started_at: ?i64 = null,
        pull_stopped_at: ?i64 = null,
        execution_stopped_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .task = "task",
                .status = "status",
                .reason = "reason",
                .containers = "containers",
                .attachments = "attachments",
                .managed_agents = "managedAgents",
                .pull_started_at = "pullStartedAt",
                .pull_stopped_at = "pullStoppedAt",
                .execution_stopped_at = "executionStoppedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_task_state_change) } {
            return .{ .service_metadata = service_metadata, .action = submit_task_state_change };
        }
    },
    Response: type = struct {
        acknowledgment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acknowledgment = "acknowledgment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const update_capacity_provider: struct {
    action_name: []const u8 = "UpdateCapacityProvider",
    Request: type = struct {
        name: []const u8,
        auto_scaling_group_provider: struct {
            managed_scaling: ?ManagedScaling = null,
            managed_termination_protection: ?[]const u8 = null,
            managed_draining: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .managed_scaling = "managedScaling",
                    .managed_termination_protection = "managedTerminationProtection",
                    .managed_draining = "managedDraining",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .auto_scaling_group_provider = "autoScalingGroupProvider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_capacity_provider) } {
            return .{ .service_metadata = service_metadata, .action = update_capacity_provider };
        }
    },
    Response: type = struct {
        capacity_provider: ?CapacityProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_provider = "capacityProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
    },
} = .{};
pub const update_cluster: struct {
    action_name: []const u8 = "UpdateCluster",
    Request: type = struct {
        cluster: []const u8,
        settings: ?[]ClusterSetting = null,
        configuration: ?ClusterConfiguration = null,
        service_connect_defaults: ?ClusterServiceConnectDefaultsRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .settings = "settings",
                .configuration = "configuration",
                .service_connect_defaults = "serviceConnectDefaults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        NamespaceNotFound,
        Server,
    },
} = .{};
pub const update_cluster_settings: struct {
    action_name: []const u8 = "UpdateClusterSettings",
    Request: type = struct {
        cluster: []const u8,
        settings: []ClusterSetting,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .settings = "settings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster_settings };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const update_container_agent: struct {
    action_name: []const u8 = "UpdateContainerAgent",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        container_instance: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .container_instance = "containerInstance",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_container_agent) } {
            return .{ .service_metadata = service_metadata, .action = update_container_agent };
        }
    },
    Response: type = struct {
        container_instance: ?ContainerInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_instance = "containerInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        MissingVersion,
        NoUpdateAvailable,
        Server,
        UpdateInProgress,
    },
} = .{};
pub const update_container_instances_state: struct {
    action_name: []const u8 = "UpdateContainerInstancesState",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        container_instances: [][]const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .container_instances = "containerInstances",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_container_instances_state) } {
            return .{ .service_metadata = service_metadata, .action = update_container_instances_state };
        }
    },
    Response: type = struct {
        container_instances: ?[]ContainerInstance = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_instances = "containerInstances",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
    },
} = .{};
pub const update_service: struct {
    action_name: []const u8 = "UpdateService",
    Request: type = struct {
        cluster: ?[]const u8 = null,
        service: []const u8,
        desired_count: ?i64 = null,
        task_definition: ?[]const u8 = null,
        capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
        deployment_configuration: ?DeploymentConfiguration = null,
        network_configuration: ?NetworkConfiguration = null,
        placement_constraints: ?[]PlacementConstraint = null,
        placement_strategy: ?[]PlacementStrategy = null,
        platform_version: ?[]const u8 = null,
        force_new_deployment: ?bool = null,
        health_check_grace_period_seconds: ?i64 = null,
        enable_execute_command: ?bool = null,
        enable_ecs_managed_tags: ?bool = null,
        load_balancers: ?[]LoadBalancer = null,
        propagate_tags: ?[]const u8 = null,
        service_registries: ?[]ServiceRegistry = null,
        service_connect_configuration: ?ServiceConnectConfiguration = null,
        volume_configurations: ?[]ServiceVolumeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .service = "service",
                .desired_count = "desiredCount",
                .task_definition = "taskDefinition",
                .capacity_provider_strategy = "capacityProviderStrategy",
                .deployment_configuration = "deploymentConfiguration",
                .network_configuration = "networkConfiguration",
                .placement_constraints = "placementConstraints",
                .placement_strategy = "placementStrategy",
                .platform_version = "platformVersion",
                .force_new_deployment = "forceNewDeployment",
                .health_check_grace_period_seconds = "healthCheckGracePeriodSeconds",
                .enable_execute_command = "enableExecuteCommand",
                .enable_ecs_managed_tags = "enableECSManagedTags",
                .load_balancers = "loadBalancers",
                .propagate_tags = "propagateTags",
                .service_registries = "serviceRegistries",
                .service_connect_configuration = "serviceConnectConfiguration",
                .volume_configurations = "volumeConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service) } {
            return .{ .service_metadata = service_metadata, .action = update_service };
        }
    },
    Response: type = struct {
        service: ?Service = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "service",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        NamespaceNotFound,
        PlatformTaskDefinitionIncompatibility,
        PlatformUnknown,
        Server,
        ServiceNotActive,
        ServiceNotFound,
        UnsupportedFeature,
    },
} = .{};
pub const update_service_primary_task_set: struct {
    action_name: []const u8 = "UpdateServicePrimaryTaskSet",
    Request: type = struct {
        cluster: []const u8,
        service: []const u8,
        primary_task_set: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .service = "service",
                .primary_task_set = "primaryTaskSet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service_primary_task_set) } {
            return .{ .service_metadata = service_metadata, .action = update_service_primary_task_set };
        }
    },
    Response: type = struct {
        task_set: ?TaskSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_set = "taskSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
        ServiceNotActive,
        ServiceNotFound,
        TaskSetNotFound,
        UnsupportedFeature,
    },
} = .{};
pub const update_task_protection: struct {
    action_name: []const u8 = "UpdateTaskProtection",
    Request: type = struct {
        cluster: []const u8,
        tasks: [][]const u8,
        protection_enabled: bool,
        expires_in_minutes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .tasks = "tasks",
                .protection_enabled = "protectionEnabled",
                .expires_in_minutes = "expiresInMinutes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_task_protection) } {
            return .{ .service_metadata = service_metadata, .action = update_task_protection };
        }
    },
    Response: type = struct {
        protected_tasks: ?[]ProtectedTask = null,
        failures: ?[]Failure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .protected_tasks = "protectedTasks",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        ResourceNotFound,
        Server,
        UnsupportedFeature,
    },
} = .{};
pub const update_task_set: struct {
    action_name: []const u8 = "UpdateTaskSet",
    Request: type = struct {
        cluster: []const u8,
        service: []const u8,
        task_set: []const u8,
        scale: Scale,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
                .service = "service",
                .task_set = "taskSet",
                .scale = "scale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_task_set) } {
            return .{ .service_metadata = service_metadata, .action = update_task_set };
        }
    },
    Response: type = struct {
        task_set: ?TaskSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_set = "taskSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ClusterNotFound,
        InvalidParameter,
        Server,
        ServiceNotActive,
        ServiceNotFound,
        TaskSetNotFound,
        UnsupportedFeature,
    },
} = .{};

pub const TaskSet = struct {
    id: ?[]const u8 = null,
    task_set_arn: ?[]const u8 = null,
    service_arn: ?[]const u8 = null,
    cluster_arn: ?[]const u8 = null,
    started_by: ?[]const u8 = null,
    external_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    task_definition: ?[]const u8 = null,
    computed_desired_count: ?i64 = null,
    pending_count: ?i64 = null,
    running_count: ?i64 = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,
    launch_type: ?[]const u8 = null,
    capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
    platform_version: ?[]const u8 = null,
    platform_family: ?[]const u8 = null,
    network_configuration: ?NetworkConfiguration = null,
    load_balancers: ?[]LoadBalancer = null,
    service_registries: ?[]ServiceRegistry = null,
    scale: ?Scale = null,
    stability_status: ?[]const u8 = null,
    stability_status_at: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .task_set_arn = "taskSetArn",
            .service_arn = "serviceArn",
            .cluster_arn = "clusterArn",
            .started_by = "startedBy",
            .external_id = "externalId",
            .status = "status",
            .task_definition = "taskDefinition",
            .computed_desired_count = "computedDesiredCount",
            .pending_count = "pendingCount",
            .running_count = "runningCount",
            .created_at = "createdAt",
            .updated_at = "updatedAt",
            .launch_type = "launchType",
            .capacity_provider_strategy = "capacityProviderStrategy",
            .platform_version = "platformVersion",
            .platform_family = "platformFamily",
            .network_configuration = "networkConfiguration",
            .load_balancers = "loadBalancers",
            .service_registries = "serviceRegistries",
            .scale = "scale",
            .stability_status = "stabilityStatus",
            .stability_status_at = "stabilityStatusAt",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Scale = struct {
    value: ?f64 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .unit = "unit",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceRegistry = struct {
    registry_arn: ?[]const u8 = null,
    port: ?i64 = null,
    container_name: ?[]const u8 = null,
    container_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .registry_arn = "registryArn",
            .port = "port",
            .container_name = "containerName",
            .container_port = "containerPort",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancer = struct {
    target_group_arn: ?[]const u8 = null,
    load_balancer_name: ?[]const u8 = null,
    container_name: ?[]const u8 = null,
    container_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_group_arn = "targetGroupArn",
            .load_balancer_name = "loadBalancerName",
            .container_name = "containerName",
            .container_port = "containerPort",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkConfiguration = struct {
    awsvpc_configuration: ?AwsVpcConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .awsvpc_configuration = "awsvpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsVpcConfiguration = struct {
    subnets: [][]const u8,
    security_groups: ?[][]const u8 = null,
    assign_public_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnets = "subnets",
            .security_groups = "securityGroups",
            .assign_public_ip = "assignPublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityProviderStrategyItem = struct {
    capacity_provider: []const u8,
    weight: ?i64 = null,
    base: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_provider = "capacityProvider",
            .weight = "weight",
            .base = "base",
        };
        return @field(mappings, field_name);
    }
};

pub const Failure = struct {
    arn: ?[]const u8 = null,
    reason: ?[]const u8 = null,
    detail: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .reason = "reason",
            .detail = "detail",
        };
        return @field(mappings, field_name);
    }
};

pub const ProtectedTask = struct {
    task_arn: ?[]const u8 = null,
    protection_enabled: ?bool = null,
    expiration_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_arn = "taskArn",
            .protection_enabled = "protectionEnabled",
            .expiration_date = "expirationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const Service = struct {
    service_arn: ?[]const u8 = null,
    service_name: ?[]const u8 = null,
    cluster_arn: ?[]const u8 = null,
    load_balancers: ?[]LoadBalancer = null,
    service_registries: ?[]ServiceRegistry = null,
    status: ?[]const u8 = null,
    desired_count: ?i64 = null,
    running_count: ?i64 = null,
    pending_count: ?i64 = null,
    launch_type: ?[]const u8 = null,
    capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
    platform_version: ?[]const u8 = null,
    platform_family: ?[]const u8 = null,
    task_definition: ?[]const u8 = null,
    deployment_configuration: ?DeploymentConfiguration = null,
    task_sets: ?[]TaskSet = null,
    deployments: ?[]Deployment = null,
    role_arn: ?[]const u8 = null,
    events: ?[]ServiceEvent = null,
    created_at: ?i64 = null,
    placement_constraints: ?[]PlacementConstraint = null,
    placement_strategy: ?[]PlacementStrategy = null,
    network_configuration: ?NetworkConfiguration = null,
    health_check_grace_period_seconds: ?i64 = null,
    scheduling_strategy: ?[]const u8 = null,
    deployment_controller: ?DeploymentController = null,
    tags: ?[]Tag = null,
    created_by: ?[]const u8 = null,
    enable_ecs_managed_tags: ?bool = null,
    propagate_tags: ?[]const u8 = null,
    enable_execute_command: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_arn = "serviceArn",
            .service_name = "serviceName",
            .cluster_arn = "clusterArn",
            .load_balancers = "loadBalancers",
            .service_registries = "serviceRegistries",
            .status = "status",
            .desired_count = "desiredCount",
            .running_count = "runningCount",
            .pending_count = "pendingCount",
            .launch_type = "launchType",
            .capacity_provider_strategy = "capacityProviderStrategy",
            .platform_version = "platformVersion",
            .platform_family = "platformFamily",
            .task_definition = "taskDefinition",
            .deployment_configuration = "deploymentConfiguration",
            .task_sets = "taskSets",
            .deployments = "deployments",
            .role_arn = "roleArn",
            .events = "events",
            .created_at = "createdAt",
            .placement_constraints = "placementConstraints",
            .placement_strategy = "placementStrategy",
            .network_configuration = "networkConfiguration",
            .health_check_grace_period_seconds = "healthCheckGracePeriodSeconds",
            .scheduling_strategy = "schedulingStrategy",
            .deployment_controller = "deploymentController",
            .tags = "tags",
            .created_by = "createdBy",
            .enable_ecs_managed_tags = "enableECSManagedTags",
            .propagate_tags = "propagateTags",
            .enable_execute_command = "enableExecuteCommand",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentController = struct {
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementStrategy = struct {
    type: ?[]const u8 = null,
    field: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .field = "field",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementConstraint = struct {
    type: ?[]const u8 = null,
    expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .expression = "expression",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceEvent = struct {
    id: ?[]const u8 = null,
    created_at: ?i64 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .created_at = "createdAt",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const Deployment = struct {
    id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    task_definition: ?[]const u8 = null,
    desired_count: ?i64 = null,
    pending_count: ?i64 = null,
    running_count: ?i64 = null,
    failed_tasks: ?i64 = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,
    capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
    launch_type: ?[]const u8 = null,
    platform_version: ?[]const u8 = null,
    platform_family: ?[]const u8 = null,
    network_configuration: ?NetworkConfiguration = null,
    rollout_state: ?[]const u8 = null,
    rollout_state_reason: ?[]const u8 = null,
    service_connect_configuration: ?ServiceConnectConfiguration = null,
    service_connect_resources: ?[]ServiceConnectServiceResource = null,
    volume_configurations: ?[]ServiceVolumeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .status = "status",
            .task_definition = "taskDefinition",
            .desired_count = "desiredCount",
            .pending_count = "pendingCount",
            .running_count = "runningCount",
            .failed_tasks = "failedTasks",
            .created_at = "createdAt",
            .updated_at = "updatedAt",
            .capacity_provider_strategy = "capacityProviderStrategy",
            .launch_type = "launchType",
            .platform_version = "platformVersion",
            .platform_family = "platformFamily",
            .network_configuration = "networkConfiguration",
            .rollout_state = "rolloutState",
            .rollout_state_reason = "rolloutStateReason",
            .service_connect_configuration = "serviceConnectConfiguration",
            .service_connect_resources = "serviceConnectResources",
            .volume_configurations = "volumeConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceVolumeConfiguration = struct {
    name: []const u8,
    managed_ebs_volume: ?ServiceManagedEBSVolumeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .managed_ebs_volume = "managedEBSVolume",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceManagedEBSVolumeConfiguration = struct {
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    volume_type: ?[]const u8 = null,
    size_in_gib: ?i64 = null,
    snapshot_id: ?[]const u8 = null,
    iops: ?i64 = null,
    throughput: ?i64 = null,
    tag_specifications: ?[]EBSTagSpecification = null,
    role_arn: []const u8,
    filesystem_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encrypted = "encrypted",
            .kms_key_id = "kmsKeyId",
            .volume_type = "volumeType",
            .size_in_gib = "sizeInGiB",
            .snapshot_id = "snapshotId",
            .iops = "iops",
            .throughput = "throughput",
            .tag_specifications = "tagSpecifications",
            .role_arn = "roleArn",
            .filesystem_type = "filesystemType",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSTagSpecification = struct {
    resource_type: []const u8,
    tags: ?[]Tag = null,
    propagate_tags: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .tags = "tags",
            .propagate_tags = "propagateTags",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceConnectServiceResource = struct {
    discovery_name: ?[]const u8 = null,
    discovery_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .discovery_name = "discoveryName",
            .discovery_arn = "discoveryArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceConnectConfiguration = struct {
    enabled: bool,
    namespace: ?[]const u8 = null,
    services: ?[]ServiceConnectService = null,
    log_configuration: ?LogConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .namespace = "namespace",
            .services = "services",
            .log_configuration = "logConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LogConfiguration = struct {
    log_driver: []const u8,
    options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    secret_options: ?[]Secret = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_driver = "logDriver",
            .options = "options",
            .secret_options = "secretOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const Secret = struct {
    name: []const u8,
    value_from: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value_from = "valueFrom",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceConnectService = struct {
    port_name: []const u8,
    discovery_name: ?[]const u8 = null,
    client_aliases: ?[]ServiceConnectClientAlias = null,
    ingress_port_override: ?i64 = null,
    timeout: ?TimeoutConfiguration = null,
    tls: ?ServiceConnectTlsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port_name = "portName",
            .discovery_name = "discoveryName",
            .client_aliases = "clientAliases",
            .ingress_port_override = "ingressPortOverride",
            .timeout = "timeout",
            .tls = "tls",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceConnectTlsConfiguration = struct {
    issuer_certificate_authority: ServiceConnectTlsCertificateAuthority,
    kms_key: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issuer_certificate_authority = "issuerCertificateAuthority",
            .kms_key = "kmsKey",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceConnectTlsCertificateAuthority = struct {
    aws_pca_authority_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_pca_authority_arn = "awsPcaAuthorityArn",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeoutConfiguration = struct {
    idle_timeout_seconds: ?i64 = null,
    per_request_timeout_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .idle_timeout_seconds = "idleTimeoutSeconds",
            .per_request_timeout_seconds = "perRequestTimeoutSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceConnectClientAlias = struct {
    port: i64,
    dns_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port = "port",
            .dns_name = "dnsName",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentConfiguration = struct {
    deployment_circuit_breaker: ?DeploymentCircuitBreaker = null,
    maximum_percent: ?i64 = null,
    minimum_healthy_percent: ?i64 = null,
    alarms: ?DeploymentAlarms = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deployment_circuit_breaker = "deploymentCircuitBreaker",
            .maximum_percent = "maximumPercent",
            .minimum_healthy_percent = "minimumHealthyPercent",
            .alarms = "alarms",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentAlarms = struct {
    alarm_names: [][]const u8,
    enable: bool,
    rollback: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alarm_names = "alarmNames",
            .enable = "enable",
            .rollback = "rollback",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentCircuitBreaker = struct {
    enable: bool,
    rollback: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable = "enable",
            .rollback = "rollback",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerInstance = struct {
    container_instance_arn: ?[]const u8 = null,
    ec2_instance_id: ?[]const u8 = null,
    capacity_provider_name: ?[]const u8 = null,
    version: ?i64 = null,
    version_info: ?VersionInfo = null,
    remaining_resources: ?[]Resource = null,
    registered_resources: ?[]Resource = null,
    status: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    agent_connected: ?bool = null,
    running_tasks_count: ?i64 = null,
    pending_tasks_count: ?i64 = null,
    agent_update_status: ?[]const u8 = null,
    attributes: ?[]Attribute = null,
    registered_at: ?i64 = null,
    attachments: ?[]Attachment = null,
    tags: ?[]Tag = null,
    health_status: ?ContainerInstanceHealthStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_instance_arn = "containerInstanceArn",
            .ec2_instance_id = "ec2InstanceId",
            .capacity_provider_name = "capacityProviderName",
            .version = "version",
            .version_info = "versionInfo",
            .remaining_resources = "remainingResources",
            .registered_resources = "registeredResources",
            .status = "status",
            .status_reason = "statusReason",
            .agent_connected = "agentConnected",
            .running_tasks_count = "runningTasksCount",
            .pending_tasks_count = "pendingTasksCount",
            .agent_update_status = "agentUpdateStatus",
            .attributes = "attributes",
            .registered_at = "registeredAt",
            .attachments = "attachments",
            .tags = "tags",
            .health_status = "healthStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerInstanceHealthStatus = struct {
    overall_status: ?[]const u8 = null,
    details: ?[]InstanceHealthCheckResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .overall_status = "overallStatus",
            .details = "details",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceHealthCheckResult = struct {
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    last_updated: ?i64 = null,
    last_status_change: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .status = "status",
            .last_updated = "lastUpdated",
            .last_status_change = "lastStatusChange",
        };
        return @field(mappings, field_name);
    }
};

pub const Attachment = struct {
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    details: ?[]KeyValuePair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .type = "type",
            .status = "status",
            .details = "details",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyValuePair = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Attribute = struct {
    name: []const u8,
    value: ?[]const u8 = null,
    target_type: ?[]const u8 = null,
    target_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
            .target_type = "targetType",
            .target_id = "targetId",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    double_value: ?f64 = null,
    long_value: ?i64 = null,
    integer_value: ?i64 = null,
    string_set_value: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .type = "type",
            .double_value = "doubleValue",
            .long_value = "longValue",
            .integer_value = "integerValue",
            .string_set_value = "stringSetValue",
        };
        return @field(mappings, field_name);
    }
};

pub const VersionInfo = struct {
    agent_version: ?[]const u8 = null,
    agent_hash: ?[]const u8 = null,
    docker_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .agent_version = "agentVersion",
            .agent_hash = "agentHash",
            .docker_version = "dockerVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const Cluster = struct {
    cluster_arn: ?[]const u8 = null,
    cluster_name: ?[]const u8 = null,
    configuration: ?ClusterConfiguration = null,
    status: ?[]const u8 = null,
    registered_container_instances_count: ?i64 = null,
    running_tasks_count: ?i64 = null,
    pending_tasks_count: ?i64 = null,
    active_services_count: ?i64 = null,
    statistics: ?[]KeyValuePair = null,
    tags: ?[]Tag = null,
    settings: ?[]ClusterSetting = null,
    capacity_providers: ?[][]const u8 = null,
    default_capacity_provider_strategy: ?[]CapacityProviderStrategyItem = null,
    attachments: ?[]Attachment = null,
    attachments_status: ?[]const u8 = null,
    service_connect_defaults: ?ClusterServiceConnectDefaults = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_arn = "clusterArn",
            .cluster_name = "clusterName",
            .configuration = "configuration",
            .status = "status",
            .registered_container_instances_count = "registeredContainerInstancesCount",
            .running_tasks_count = "runningTasksCount",
            .pending_tasks_count = "pendingTasksCount",
            .active_services_count = "activeServicesCount",
            .statistics = "statistics",
            .tags = "tags",
            .settings = "settings",
            .capacity_providers = "capacityProviders",
            .default_capacity_provider_strategy = "defaultCapacityProviderStrategy",
            .attachments = "attachments",
            .attachments_status = "attachmentsStatus",
            .service_connect_defaults = "serviceConnectDefaults",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterServiceConnectDefaults = struct {
    namespace: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "namespace",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterSetting = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterConfiguration = struct {
    execute_command_configuration: ?ExecuteCommandConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execute_command_configuration = "executeCommandConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecuteCommandConfiguration = struct {
    kms_key_id: ?[]const u8 = null,
    logging: ?[]const u8 = null,
    log_configuration: ?ExecuteCommandLogConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "kmsKeyId",
            .logging = "logging",
            .log_configuration = "logConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecuteCommandLogConfiguration = struct {
    cloud_watch_log_group_name: ?[]const u8 = null,
    cloud_watch_encryption_enabled: ?bool = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_encryption_enabled: ?bool = null,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_log_group_name = "cloudWatchLogGroupName",
            .cloud_watch_encryption_enabled = "cloudWatchEncryptionEnabled",
            .s3_bucket_name = "s3BucketName",
            .s3_encryption_enabled = "s3EncryptionEnabled",
            .s3_key_prefix = "s3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterServiceConnectDefaultsRequest = struct {
    namespace: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "namespace",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityProvider = struct {
    capacity_provider_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    auto_scaling_group_provider: ?AutoScalingGroupProvider = null,
    update_status: ?[]const u8 = null,
    update_status_reason: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_provider_arn = "capacityProviderArn",
            .name = "name",
            .status = "status",
            .auto_scaling_group_provider = "autoScalingGroupProvider",
            .update_status = "updateStatus",
            .update_status_reason = "updateStatusReason",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingGroupProvider = struct {
    auto_scaling_group_arn: []const u8,
    managed_scaling: ?ManagedScaling = null,
    managed_termination_protection: ?[]const u8 = null,
    managed_draining: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_scaling_group_arn = "autoScalingGroupArn",
            .managed_scaling = "managedScaling",
            .managed_termination_protection = "managedTerminationProtection",
            .managed_draining = "managedDraining",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedScaling = struct {
    status: ?[]const u8 = null,
    target_capacity: ?i64 = null,
    minimum_scaling_step_size: ?i64 = null,
    maximum_scaling_step_size: ?i64 = null,
    instance_warmup_period: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .target_capacity = "targetCapacity",
            .minimum_scaling_step_size = "minimumScalingStepSize",
            .maximum_scaling_step_size = "maximumScalingStepSize",
            .instance_warmup_period = "instanceWarmupPeriod",
        };
        return @field(mappings, field_name);
    }
};

pub const AttachmentStateChange = struct {
    attachment_arn: []const u8,
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment_arn = "attachmentArn",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkBinding = struct {
    bind_ip: ?[]const u8 = null,
    container_port: ?i64 = null,
    host_port: ?i64 = null,
    protocol: ?[]const u8 = null,
    container_port_range: ?[]const u8 = null,
    host_port_range: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bind_ip = "bindIP",
            .container_port = "containerPort",
            .host_port = "hostPort",
            .protocol = "protocol",
            .container_port_range = "containerPortRange",
            .host_port_range = "hostPortRange",
        };
        return @field(mappings, field_name);
    }
};

pub const Task = struct {
    attachments: ?[]Attachment = null,
    attributes: ?[]Attribute = null,
    availability_zone: ?[]const u8 = null,
    capacity_provider_name: ?[]const u8 = null,
    cluster_arn: ?[]const u8 = null,
    connectivity: ?[]const u8 = null,
    connectivity_at: ?i64 = null,
    container_instance_arn: ?[]const u8 = null,
    containers: ?[]Container = null,
    cpu: ?[]const u8 = null,
    created_at: ?i64 = null,
    desired_status: ?[]const u8 = null,
    enable_execute_command: ?bool = null,
    execution_stopped_at: ?i64 = null,
    group: ?[]const u8 = null,
    health_status: ?[]const u8 = null,
    inference_accelerators: ?[]InferenceAccelerator = null,
    last_status: ?[]const u8 = null,
    launch_type: ?[]const u8 = null,
    memory: ?[]const u8 = null,
    overrides: ?TaskOverride = null,
    platform_version: ?[]const u8 = null,
    platform_family: ?[]const u8 = null,
    pull_started_at: ?i64 = null,
    pull_stopped_at: ?i64 = null,
    started_at: ?i64 = null,
    started_by: ?[]const u8 = null,
    stop_code: ?[]const u8 = null,
    stopped_at: ?i64 = null,
    stopped_reason: ?[]const u8 = null,
    stopping_at: ?i64 = null,
    tags: ?[]Tag = null,
    task_arn: ?[]const u8 = null,
    task_definition_arn: ?[]const u8 = null,
    version: ?i64 = null,
    ephemeral_storage: ?EphemeralStorage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachments = "attachments",
            .attributes = "attributes",
            .availability_zone = "availabilityZone",
            .capacity_provider_name = "capacityProviderName",
            .cluster_arn = "clusterArn",
            .connectivity = "connectivity",
            .connectivity_at = "connectivityAt",
            .container_instance_arn = "containerInstanceArn",
            .containers = "containers",
            .cpu = "cpu",
            .created_at = "createdAt",
            .desired_status = "desiredStatus",
            .enable_execute_command = "enableExecuteCommand",
            .execution_stopped_at = "executionStoppedAt",
            .group = "group",
            .health_status = "healthStatus",
            .inference_accelerators = "inferenceAccelerators",
            .last_status = "lastStatus",
            .launch_type = "launchType",
            .memory = "memory",
            .overrides = "overrides",
            .platform_version = "platformVersion",
            .platform_family = "platformFamily",
            .pull_started_at = "pullStartedAt",
            .pull_stopped_at = "pullStoppedAt",
            .started_at = "startedAt",
            .started_by = "startedBy",
            .stop_code = "stopCode",
            .stopped_at = "stoppedAt",
            .stopped_reason = "stoppedReason",
            .stopping_at = "stoppingAt",
            .tags = "tags",
            .task_arn = "taskArn",
            .task_definition_arn = "taskDefinitionArn",
            .version = "version",
            .ephemeral_storage = "ephemeralStorage",
        };
        return @field(mappings, field_name);
    }
};

pub const EphemeralStorage = struct {
    size_in_gib: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .size_in_gib = "sizeInGiB",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskOverride = struct {
    container_overrides: ?[]ContainerOverride = null,
    cpu: ?[]const u8 = null,
    inference_accelerator_overrides: ?[]InferenceAcceleratorOverride = null,
    execution_role_arn: ?[]const u8 = null,
    memory: ?[]const u8 = null,
    task_role_arn: ?[]const u8 = null,
    ephemeral_storage: ?EphemeralStorage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_overrides = "containerOverrides",
            .cpu = "cpu",
            .inference_accelerator_overrides = "inferenceAcceleratorOverrides",
            .execution_role_arn = "executionRoleArn",
            .memory = "memory",
            .task_role_arn = "taskRoleArn",
            .ephemeral_storage = "ephemeralStorage",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceAcceleratorOverride = struct {
    device_name: ?[]const u8 = null,
    device_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "deviceName",
            .device_type = "deviceType",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerOverride = struct {
    name: ?[]const u8 = null,
    command: ?[][]const u8 = null,
    environment: ?[]KeyValuePair = null,
    environment_files: ?[]EnvironmentFile = null,
    cpu: ?i64 = null,
    memory: ?i64 = null,
    memory_reservation: ?i64 = null,
    resource_requirements: ?[]ResourceRequirement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .command = "command",
            .environment = "environment",
            .environment_files = "environmentFiles",
            .cpu = "cpu",
            .memory = "memory",
            .memory_reservation = "memoryReservation",
            .resource_requirements = "resourceRequirements",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceRequirement = struct {
    value: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const EnvironmentFile = struct {
    value: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceAccelerator = struct {
    device_name: []const u8,
    device_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "deviceName",
            .device_type = "deviceType",
        };
        return @field(mappings, field_name);
    }
};

pub const Container = struct {
    container_arn: ?[]const u8 = null,
    task_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    image: ?[]const u8 = null,
    image_digest: ?[]const u8 = null,
    runtime_id: ?[]const u8 = null,
    last_status: ?[]const u8 = null,
    exit_code: ?i64 = null,
    reason: ?[]const u8 = null,
    network_bindings: ?[]NetworkBinding = null,
    network_interfaces: ?[]NetworkInterface = null,
    health_status: ?[]const u8 = null,
    managed_agents: ?[]ManagedAgent = null,
    cpu: ?[]const u8 = null,
    memory: ?[]const u8 = null,
    memory_reservation: ?[]const u8 = null,
    gpu_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_arn = "containerArn",
            .task_arn = "taskArn",
            .name = "name",
            .image = "image",
            .image_digest = "imageDigest",
            .runtime_id = "runtimeId",
            .last_status = "lastStatus",
            .exit_code = "exitCode",
            .reason = "reason",
            .network_bindings = "networkBindings",
            .network_interfaces = "networkInterfaces",
            .health_status = "healthStatus",
            .managed_agents = "managedAgents",
            .cpu = "cpu",
            .memory = "memory",
            .memory_reservation = "memoryReservation",
            .gpu_ids = "gpuIds",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedAgent = struct {
    last_started_at: ?i64 = null,
    name: ?[]const u8 = null,
    reason: ?[]const u8 = null,
    last_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_started_at = "lastStartedAt",
            .name = "name",
            .reason = "reason",
            .last_status = "lastStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterface = struct {
    attachment_id: ?[]const u8 = null,
    private_ipv4_address: ?[]const u8 = null,
    ipv6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment_id = "attachmentId",
            .private_ipv4_address = "privateIpv4Address",
            .ipv6_address = "ipv6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskVolumeConfiguration = struct {
    name: []const u8,
    managed_ebs_volume: ?TaskManagedEBSVolumeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .managed_ebs_volume = "managedEBSVolume",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskManagedEBSVolumeConfiguration = struct {
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    volume_type: ?[]const u8 = null,
    size_in_gib: ?i64 = null,
    snapshot_id: ?[]const u8 = null,
    iops: ?i64 = null,
    throughput: ?i64 = null,
    tag_specifications: ?[]EBSTagSpecification = null,
    role_arn: []const u8,
    termination_policy: ?TaskManagedEBSVolumeTerminationPolicy = null,
    filesystem_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encrypted = "encrypted",
            .kms_key_id = "kmsKeyId",
            .volume_type = "volumeType",
            .size_in_gib = "sizeInGiB",
            .snapshot_id = "snapshotId",
            .iops = "iops",
            .throughput = "throughput",
            .tag_specifications = "tagSpecifications",
            .role_arn = "roleArn",
            .termination_policy = "terminationPolicy",
            .filesystem_type = "filesystemType",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskManagedEBSVolumeTerminationPolicy = struct {
    delete_on_termination: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_on_termination = "deleteOnTermination",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskDefinition = struct {
    task_definition_arn: ?[]const u8 = null,
    container_definitions: ?[]ContainerDefinition = null,
    family: ?[]const u8 = null,
    task_role_arn: ?[]const u8 = null,
    execution_role_arn: ?[]const u8 = null,
    network_mode: ?[]const u8 = null,
    revision: ?i64 = null,
    volumes: ?[]Volume = null,
    status: ?[]const u8 = null,
    requires_attributes: ?[]Attribute = null,
    placement_constraints: ?[]TaskDefinitionPlacementConstraint = null,
    compatibilities: ?[][]const u8 = null,
    runtime_platform: ?RuntimePlatform = null,
    requires_compatibilities: ?[][]const u8 = null,
    cpu: ?[]const u8 = null,
    memory: ?[]const u8 = null,
    inference_accelerators: ?[]InferenceAccelerator = null,
    pid_mode: ?[]const u8 = null,
    ipc_mode: ?[]const u8 = null,
    proxy_configuration: ?ProxyConfiguration = null,
    registered_at: ?i64 = null,
    deregistered_at: ?i64 = null,
    registered_by: ?[]const u8 = null,
    ephemeral_storage: ?EphemeralStorage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_definition_arn = "taskDefinitionArn",
            .container_definitions = "containerDefinitions",
            .family = "family",
            .task_role_arn = "taskRoleArn",
            .execution_role_arn = "executionRoleArn",
            .network_mode = "networkMode",
            .revision = "revision",
            .volumes = "volumes",
            .status = "status",
            .requires_attributes = "requiresAttributes",
            .placement_constraints = "placementConstraints",
            .compatibilities = "compatibilities",
            .runtime_platform = "runtimePlatform",
            .requires_compatibilities = "requiresCompatibilities",
            .cpu = "cpu",
            .memory = "memory",
            .inference_accelerators = "inferenceAccelerators",
            .pid_mode = "pidMode",
            .ipc_mode = "ipcMode",
            .proxy_configuration = "proxyConfiguration",
            .registered_at = "registeredAt",
            .deregistered_at = "deregisteredAt",
            .registered_by = "registeredBy",
            .ephemeral_storage = "ephemeralStorage",
        };
        return @field(mappings, field_name);
    }
};

pub const ProxyConfiguration = struct {
    type: ?[]const u8 = null,
    container_name: []const u8,
    properties: ?[]KeyValuePair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .container_name = "containerName",
            .properties = "properties",
        };
        return @field(mappings, field_name);
    }
};

pub const RuntimePlatform = struct {
    cpu_architecture: ?[]const u8 = null,
    operating_system_family: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu_architecture = "cpuArchitecture",
            .operating_system_family = "operatingSystemFamily",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskDefinitionPlacementConstraint = struct {
    type: ?[]const u8 = null,
    expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .expression = "expression",
        };
        return @field(mappings, field_name);
    }
};

pub const Volume = struct {
    name: ?[]const u8 = null,
    host: ?HostVolumeProperties = null,
    docker_volume_configuration: ?DockerVolumeConfiguration = null,
    efs_volume_configuration: ?EFSVolumeConfiguration = null,
    fsx_windows_file_server_volume_configuration: ?FSxWindowsFileServerVolumeConfiguration = null,
    configured_at_launch: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .host = "host",
            .docker_volume_configuration = "dockerVolumeConfiguration",
            .efs_volume_configuration = "efsVolumeConfiguration",
            .fsx_windows_file_server_volume_configuration = "fsxWindowsFileServerVolumeConfiguration",
            .configured_at_launch = "configuredAtLaunch",
        };
        return @field(mappings, field_name);
    }
};

pub const FSxWindowsFileServerVolumeConfiguration = struct {
    file_system_id: []const u8,
    root_directory: []const u8,
    authorization_config: FSxWindowsFileServerAuthorizationConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_system_id = "fileSystemId",
            .root_directory = "rootDirectory",
            .authorization_config = "authorizationConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const FSxWindowsFileServerAuthorizationConfig = struct {
    credentials_parameter: []const u8,
    domain: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credentials_parameter = "credentialsParameter",
            .domain = "domain",
        };
        return @field(mappings, field_name);
    }
};

pub const EFSVolumeConfiguration = struct {
    file_system_id: []const u8,
    root_directory: ?[]const u8 = null,
    transit_encryption: ?[]const u8 = null,
    transit_encryption_port: ?i64 = null,
    authorization_config: ?EFSAuthorizationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_system_id = "fileSystemId",
            .root_directory = "rootDirectory",
            .transit_encryption = "transitEncryption",
            .transit_encryption_port = "transitEncryptionPort",
            .authorization_config = "authorizationConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const EFSAuthorizationConfig = struct {
    access_point_id: ?[]const u8 = null,
    iam: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_point_id = "accessPointId",
            .iam = "iam",
        };
        return @field(mappings, field_name);
    }
};

pub const DockerVolumeConfiguration = struct {
    scope: ?[]const u8 = null,
    autoprovision: ?bool = null,
    driver: ?[]const u8 = null,
    driver_opts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    labels: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scope = "scope",
            .autoprovision = "autoprovision",
            .driver = "driver",
            .driver_opts = "driverOpts",
            .labels = "labels",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "driver_opts", field_name))
            return try serializeMap(self.driver_opts, self.fieldNameFor("driver_opts"), options, out_stream);
        if (std.mem.eql(u8, "labels", field_name))
            return try serializeMap(self.labels, self.fieldNameFor("labels"), options, out_stream);
        return false;
    }
};

pub const HostVolumeProperties = struct {
    source_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_path = "sourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerDefinition = struct {
    name: ?[]const u8 = null,
    image: ?[]const u8 = null,
    repository_credentials: ?RepositoryCredentials = null,
    cpu: ?i64 = null,
    memory: ?i64 = null,
    memory_reservation: ?i64 = null,
    links: ?[][]const u8 = null,
    port_mappings: ?[]PortMapping = null,
    essential: ?bool = null,
    entry_point: ?[][]const u8 = null,
    command: ?[][]const u8 = null,
    environment: ?[]KeyValuePair = null,
    environment_files: ?[]EnvironmentFile = null,
    mount_points: ?[]MountPoint = null,
    volumes_from: ?[]VolumeFrom = null,
    linux_parameters: ?LinuxParameters = null,
    secrets: ?[]Secret = null,
    depends_on: ?[]ContainerDependency = null,
    start_timeout: ?i64 = null,
    stop_timeout: ?i64 = null,
    hostname: ?[]const u8 = null,
    user: ?[]const u8 = null,
    working_directory: ?[]const u8 = null,
    disable_networking: ?bool = null,
    privileged: ?bool = null,
    readonly_root_filesystem: ?bool = null,
    dns_servers: ?[][]const u8 = null,
    dns_search_domains: ?[][]const u8 = null,
    extra_hosts: ?[]HostEntry = null,
    docker_security_options: ?[][]const u8 = null,
    interactive: ?bool = null,
    pseudo_terminal: ?bool = null,
    docker_labels: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    ulimits: ?[]Ulimit = null,
    log_configuration: ?LogConfiguration = null,
    health_check: ?HealthCheck = null,
    system_controls: ?[]SystemControl = null,
    resource_requirements: ?[]ResourceRequirement = null,
    firelens_configuration: ?FirelensConfiguration = null,
    credential_specs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .image = "image",
            .repository_credentials = "repositoryCredentials",
            .cpu = "cpu",
            .memory = "memory",
            .memory_reservation = "memoryReservation",
            .links = "links",
            .port_mappings = "portMappings",
            .essential = "essential",
            .entry_point = "entryPoint",
            .command = "command",
            .environment = "environment",
            .environment_files = "environmentFiles",
            .mount_points = "mountPoints",
            .volumes_from = "volumesFrom",
            .linux_parameters = "linuxParameters",
            .secrets = "secrets",
            .depends_on = "dependsOn",
            .start_timeout = "startTimeout",
            .stop_timeout = "stopTimeout",
            .hostname = "hostname",
            .user = "user",
            .working_directory = "workingDirectory",
            .disable_networking = "disableNetworking",
            .privileged = "privileged",
            .readonly_root_filesystem = "readonlyRootFilesystem",
            .dns_servers = "dnsServers",
            .dns_search_domains = "dnsSearchDomains",
            .extra_hosts = "extraHosts",
            .docker_security_options = "dockerSecurityOptions",
            .interactive = "interactive",
            .pseudo_terminal = "pseudoTerminal",
            .docker_labels = "dockerLabels",
            .ulimits = "ulimits",
            .log_configuration = "logConfiguration",
            .health_check = "healthCheck",
            .system_controls = "systemControls",
            .resource_requirements = "resourceRequirements",
            .firelens_configuration = "firelensConfiguration",
            .credential_specs = "credentialSpecs",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "docker_labels", field_name))
            return try serializeMap(self.docker_labels, self.fieldNameFor("docker_labels"), options, out_stream);
        return false;
    }
};

pub const FirelensConfiguration = struct {
    type: []const u8,
    options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .options = "options",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const SystemControl = struct {
    namespace: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "namespace",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const HealthCheck = struct {
    command: [][]const u8,
    interval: ?i64 = null,
    timeout: ?i64 = null,
    retries: ?i64 = null,
    start_period: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .command = "command",
            .interval = "interval",
            .timeout = "timeout",
            .retries = "retries",
            .start_period = "startPeriod",
        };
        return @field(mappings, field_name);
    }
};

pub const Ulimit = struct {
    name: []const u8,
    soft_limit: i64,
    hard_limit: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .soft_limit = "softLimit",
            .hard_limit = "hardLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const HostEntry = struct {
    hostname: []const u8,
    ip_address: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname = "hostname",
            .ip_address = "ipAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerDependency = struct {
    container_name: []const u8,
    condition: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_name = "containerName",
            .condition = "condition",
        };
        return @field(mappings, field_name);
    }
};

pub const LinuxParameters = struct {
    capabilities: ?KernelCapabilities = null,
    devices: ?[]Device = null,
    init_process_enabled: ?bool = null,
    shared_memory_size: ?i64 = null,
    tmpfs: ?[]Tmpfs = null,
    max_swap: ?i64 = null,
    swappiness: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capabilities = "capabilities",
            .devices = "devices",
            .init_process_enabled = "initProcessEnabled",
            .shared_memory_size = "sharedMemorySize",
            .tmpfs = "tmpfs",
            .max_swap = "maxSwap",
            .swappiness = "swappiness",
        };
        return @field(mappings, field_name);
    }
};

pub const Tmpfs = struct {
    container_path: []const u8,
    size: i64,
    mount_options: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_path = "containerPath",
            .size = "size",
            .mount_options = "mountOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const Device = struct {
    host_path: []const u8,
    container_path: ?[]const u8 = null,
    permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_path = "hostPath",
            .container_path = "containerPath",
            .permissions = "permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const KernelCapabilities = struct {
    add: ?[][]const u8 = null,
    drop: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .add = "add",
            .drop = "drop",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeFrom = struct {
    source_container: ?[]const u8 = null,
    read_only: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_container = "sourceContainer",
            .read_only = "readOnly",
        };
        return @field(mappings, field_name);
    }
};

pub const MountPoint = struct {
    source_volume: ?[]const u8 = null,
    container_path: ?[]const u8 = null,
    read_only: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_volume = "sourceVolume",
            .container_path = "containerPath",
            .read_only = "readOnly",
        };
        return @field(mappings, field_name);
    }
};

pub const PortMapping = struct {
    container_port: ?i64 = null,
    host_port: ?i64 = null,
    protocol: ?[]const u8 = null,
    name: ?[]const u8 = null,
    app_protocol: ?[]const u8 = null,
    container_port_range: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_port = "containerPort",
            .host_port = "hostPort",
            .protocol = "protocol",
            .name = "name",
            .app_protocol = "appProtocol",
            .container_port_range = "containerPortRange",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryCredentials = struct {
    credentials_parameter: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credentials_parameter = "credentialsParameter",
        };
        return @field(mappings, field_name);
    }
};

pub const Setting = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,
    principal_arn: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
            .principal_arn = "principalArn",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};
