const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-02-01";
pub const sdk_id: []const u8 = "EFS";
pub const arn_namespace: ?[]const u8 = "elasticfilesystem";
pub const endpoint_prefix: []const u8 = "elasticfilesystem";
pub const sigv4_name: []const u8 = "elasticfilesystem";
pub const name: []const u8 = "MagnolioAPIService_v20150201";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-02-01",
    sdk_id: []const u8 = "EFS",
    arn_namespace: ?[]const u8 = "elasticfilesystem",
    endpoint_prefix: []const u8 = "elasticfilesystem",
    sigv4_name: []const u8 = "elasticfilesystem",
    name: []const u8 = "MagnolioAPIService_v20150201",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_access_point: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-02-01/access-points",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessPoint",
    Request: type = struct {
        client_token: []const u8,
        tags: ?[]Tag = null,
        file_system_id: []const u8,
        posix_user: ?PosixUser = null,
        root_directory: ?RootDirectory = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .tags = "Tags",
                .file_system_id = "FileSystemId",
                .posix_user = "PosixUser",
                .root_directory = "RootDirectory",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_point) } {
            return .{ .service_metadata = service_metadata, .action = create_access_point };
        }
    },
    Response: type = struct {
        client_token: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        access_point_id: ?[]const u8 = null,
        access_point_arn: ?[]const u8 = null,
        file_system_id: ?[]const u8 = null,
        posix_user: ?PosixUser = null,
        root_directory: ?RootDirectory = null,
        owner_id: ?[]const u8 = null,
        life_cycle_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .name = "Name",
                .tags = "Tags",
                .access_point_id = "AccessPointId",
                .access_point_arn = "AccessPointArn",
                .file_system_id = "FileSystemId",
                .posix_user = "PosixUser",
                .root_directory = "RootDirectory",
                .owner_id = "OwnerId",
                .life_cycle_state = "LifeCycleState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointAlreadyExists,
        AccessPointLimitExceeded,
        BadRequest,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InternalServerError,
        Throttling,
    },
} = .{};
pub const create_file_system: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-02-01/file-systems",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFileSystem",
    Request: type = struct {
        creation_token: []const u8,
        performance_mode: ?[]const u8 = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        throughput_mode: ?[]const u8 = null,
        provisioned_throughput_in_mibps: ?f64 = null,
        availability_zone_name: ?[]const u8 = null,
        backup: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_token = "CreationToken",
                .performance_mode = "PerformanceMode",
                .encrypted = "Encrypted",
                .kms_key_id = "KmsKeyId",
                .throughput_mode = "ThroughputMode",
                .provisioned_throughput_in_mibps = "ProvisionedThroughputInMibps",
                .availability_zone_name = "AvailabilityZoneName",
                .backup = "Backup",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_file_system) } {
            return .{ .service_metadata = service_metadata, .action = create_file_system };
        }
    },
    Response: type = struct {
        owner_id: []const u8,
        creation_token: []const u8,
        file_system_id: []const u8,
        file_system_arn: ?[]const u8 = null,
        creation_time: i64,
        life_cycle_state: []const u8,
        name: ?[]const u8 = null,
        number_of_mount_targets: i64,
        size_in_bytes: FileSystemSize,
        performance_mode: []const u8,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        throughput_mode: ?[]const u8 = null,
        provisioned_throughput_in_mibps: ?f64 = null,
        availability_zone_name: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        tags: []Tag,
        file_system_protection: ?FileSystemProtectionDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_id = "OwnerId",
                .creation_token = "CreationToken",
                .file_system_id = "FileSystemId",
                .file_system_arn = "FileSystemArn",
                .creation_time = "CreationTime",
                .life_cycle_state = "LifeCycleState",
                .name = "Name",
                .number_of_mount_targets = "NumberOfMountTargets",
                .size_in_bytes = "SizeInBytes",
                .performance_mode = "PerformanceMode",
                .encrypted = "Encrypted",
                .kms_key_id = "KmsKeyId",
                .throughput_mode = "ThroughputMode",
                .provisioned_throughput_in_mibps = "ProvisionedThroughputInMibps",
                .availability_zone_name = "AvailabilityZoneName",
                .availability_zone_id = "AvailabilityZoneId",
                .tags = "Tags",
                .file_system_protection = "FileSystemProtection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemAlreadyExists,
        FileSystemLimitExceeded,
        InsufficientThroughputCapacity,
        InternalServerError,
        ThroughputLimitExceeded,
        UnsupportedAvailabilityZone,
    },
} = .{};
pub const create_mount_target: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-02-01/mount-targets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMountTarget",
    Request: type = struct {
        file_system_id: []const u8,
        subnet_id: []const u8,
        ip_address: ?[]const u8 = null,
        security_groups: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .subnet_id = "SubnetId",
                .ip_address = "IpAddress",
                .security_groups = "SecurityGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_mount_target) } {
            return .{ .service_metadata = service_metadata, .action = create_mount_target };
        }
    },
    Response: type = struct {
        owner_id: ?[]const u8 = null,
        mount_target_id: []const u8,
        file_system_id: []const u8,
        subnet_id: []const u8,
        life_cycle_state: []const u8,
        ip_address: ?[]const u8 = null,
        network_interface_id: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        availability_zone_name: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_id = "OwnerId",
                .mount_target_id = "MountTargetId",
                .file_system_id = "FileSystemId",
                .subnet_id = "SubnetId",
                .life_cycle_state = "LifeCycleState",
                .ip_address = "IpAddress",
                .network_interface_id = "NetworkInterfaceId",
                .availability_zone_id = "AvailabilityZoneId",
                .availability_zone_name = "AvailabilityZoneName",
                .vpc_id = "VpcId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AvailabilityZonesMismatch,
        BadRequest,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InternalServerError,
        IpAddressInUse,
        MountTargetConflict,
        NetworkInterfaceLimitExceeded,
        NoFreeAddressesInSubnet,
        SecurityGroupLimitExceeded,
        SecurityGroupNotFound,
        SubnetNotFound,
        UnsupportedAvailabilityZone,
    },
} = .{};
pub const create_replication_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-02-01/file-systems/{SourceFileSystemId}/replication-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateReplicationConfiguration",
    Request: type = struct {
        source_file_system_id: []const u8,
        destinations: []struct {
            region: ?[]const u8 = null,
            availability_zone_name: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            file_system_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "Region",
                    .availability_zone_name = "AvailabilityZoneName",
                    .kms_key_id = "KmsKeyId",
                    .file_system_id = "FileSystemId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_file_system_id = "SourceFileSystemId",
                .destinations = "Destinations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_configuration };
        }
    },
    Response: type = struct {
        source_file_system_id: []const u8,
        source_file_system_region: []const u8,
        source_file_system_arn: []const u8,
        original_source_file_system_arn: []const u8,
        creation_time: i64,
        destinations: []Destination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_file_system_id = "SourceFileSystemId",
                .source_file_system_region = "SourceFileSystemRegion",
                .source_file_system_arn = "SourceFileSystemArn",
                .original_source_file_system_arn = "OriginalSourceFileSystemArn",
                .creation_time = "CreationTime",
                .destinations = "Destinations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        FileSystemLimitExceeded,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InsufficientThroughputCapacity,
        InternalServerError,
        ReplicationNotFound,
        ThroughputLimitExceeded,
        UnsupportedAvailabilityZone,
        Validation,
    },
} = .{};
pub const create_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-02-01/create-tags/{FileSystemId}",
        .success_code = 204,
    };

    action_name: []const u8 = "CreateTags",
    Request: type = struct {
        file_system_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const delete_access_point: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-02-01/access-points/{AccessPointId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAccessPoint",
    Request: type = struct {
        access_point_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_point_id = "AccessPointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessPointNotFound,
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const delete_file_system: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-02-01/file-systems/{FileSystemId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFileSystem",
    Request: type = struct {
        file_system_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_file_system) } {
            return .{ .service_metadata = service_metadata, .action = delete_file_system };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        FileSystemInUse,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const delete_file_system_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-02-01/file-systems/{FileSystemId}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFileSystemPolicy",
    Request: type = struct {
        file_system_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_file_system_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_file_system_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InternalServerError,
    },
} = .{};
pub const delete_mount_target: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-02-01/mount-targets/{MountTargetId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMountTarget",
    Request: type = struct {
        mount_target_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mount_target_id = "MountTargetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_mount_target) } {
            return .{ .service_metadata = service_metadata, .action = delete_mount_target };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        DependencyTimeout,
        InternalServerError,
        MountTargetNotFound,
    },
} = .{};
pub const delete_replication_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-02-01/file-systems/{SourceFileSystemId}/replication-configuration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteReplicationConfiguration",
    Request: type = struct {
        source_file_system_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_file_system_id = "SourceFileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
        ReplicationNotFound,
    },
} = .{};
pub const delete_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-02-01/delete-tags/{FileSystemId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        file_system_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_access_points: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/access-points",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccessPoints",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        access_point_id: ?[]const u8 = null,
        file_system_id: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
            .access_point_id = "AccessPointId",
            .file_system_id = "FileSystemId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .access_point_id = "AccessPointId",
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_access_points) } {
            return .{ .service_metadata = service_metadata, .action = describe_access_points };
        }
    },
    Response: type = struct {
        access_points: ?[]AccessPointDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_points = "AccessPoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_account_preferences: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/account-preferences",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountPreferences",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_preferences) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_preferences };
        }
    },
    Response: type = struct {
        resource_id_preference: ?ResourceIdPreference = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id_preference = "ResourceIdPreference",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_backup_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/file-systems/{FileSystemId}/backup-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBackupPolicy",
    Request: type = struct {
        file_system_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_backup_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_backup_policy };
        }
    },
    Response: type = struct {
        backup_policy: ?BackupPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_policy = "BackupPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
        PolicyNotFound,
        Validation,
    },
} = .{};
pub const describe_file_system_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/file-systems/{FileSystemId}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFileSystemPolicy",
    Request: type = struct {
        file_system_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_file_system_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_file_system_policy };
        }
    },
    Response: type = struct {
        file_system_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
        PolicyNotFound,
    },
} = .{};
pub const describe_file_systems: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/file-systems",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFileSystems",
    Request: type = struct {
        max_items: ?i64 = null,
        marker: ?[]const u8 = null,
        creation_token: ?[]const u8 = null,
        file_system_id: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "MaxItems",
            .marker = "Marker",
            .creation_token = "CreationToken",
            .file_system_id = "FileSystemId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "MaxItems",
                .marker = "Marker",
                .creation_token = "CreationToken",
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_file_systems) } {
            return .{ .service_metadata = service_metadata, .action = describe_file_systems };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        file_systems: ?[]FileSystemDescription = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .file_systems = "FileSystems",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/file-systems/{FileSystemId}/lifecycle-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeLifecycleConfiguration",
    Request: type = struct {
        file_system_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_lifecycle_configuration };
        }
    },
    Response: type = struct {
        lifecycle_policies: ?[]LifecyclePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policies = "LifecyclePolicies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_mount_targets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/mount-targets",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeMountTargets",
    Request: type = struct {
        max_items: ?i64 = null,
        marker: ?[]const u8 = null,
        file_system_id: ?[]const u8 = null,
        mount_target_id: ?[]const u8 = null,
        access_point_id: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "MaxItems",
            .marker = "Marker",
            .file_system_id = "FileSystemId",
            .mount_target_id = "MountTargetId",
            .access_point_id = "AccessPointId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "MaxItems",
                .marker = "Marker",
                .file_system_id = "FileSystemId",
                .mount_target_id = "MountTargetId",
                .access_point_id = "AccessPointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_mount_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_mount_targets };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        mount_targets: ?[]MountTargetDescription = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .mount_targets = "MountTargets",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
        MountTargetNotFound,
    },
} = .{};
pub const describe_mount_target_security_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/mount-targets/{MountTargetId}/security-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeMountTargetSecurityGroups",
    Request: type = struct {
        mount_target_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mount_target_id = "MountTargetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_mount_target_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_mount_target_security_groups };
        }
    },
    Response: type = struct {
        security_groups: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_groups = "SecurityGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        IncorrectMountTargetState,
        InternalServerError,
        MountTargetNotFound,
    },
} = .{};
pub const describe_replication_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/file-systems/replication-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReplicationConfigurations",
    Request: type = struct {
        file_system_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .file_system_id = "FileSystemId",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_configurations) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_configurations };
        }
    },
    Response: type = struct {
        replications: ?[]ReplicationConfigurationDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replications = "Replications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
        ReplicationNotFound,
        Validation,
    },
} = .{};
pub const describe_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/tags/{FileSystemId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        max_items: ?i64 = null,
        marker: ?[]const u8 = null,
        file_system_id: []const u8,

        pub const http_query = .{
            .max_items = "MaxItems",
            .marker = "Marker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "MaxItems",
                .marker = "Marker",
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        tags: []Tag,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .tags = "Tags",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-02-01/resource-tags/{ResourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const modify_mount_target_security_groups: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-02-01/mount-targets/{MountTargetId}/security-groups",
        .success_code = 204,
    };

    action_name: []const u8 = "ModifyMountTargetSecurityGroups",
    Request: type = struct {
        mount_target_id: []const u8,
        security_groups: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mount_target_id = "MountTargetId",
                .security_groups = "SecurityGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_mount_target_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = modify_mount_target_security_groups };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        IncorrectMountTargetState,
        InternalServerError,
        MountTargetNotFound,
        SecurityGroupLimitExceeded,
        SecurityGroupNotFound,
    },
} = .{};
pub const put_account_preferences: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-02-01/account-preferences",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccountPreferences",
    Request: type = struct {
        resource_id_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id_type = "ResourceIdType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_preferences) } {
            return .{ .service_metadata = service_metadata, .action = put_account_preferences };
        }
    },
    Response: type = struct {
        resource_id_preference: ?ResourceIdPreference = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id_preference = "ResourceIdPreference",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const put_backup_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-02-01/file-systems/{FileSystemId}/backup-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBackupPolicy",
    Request: type = struct {
        file_system_id: []const u8,
        backup_policy: BackupPolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .backup_policy = "BackupPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_backup_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_backup_policy };
        }
    },
    Response: type = struct {
        backup_policy: ?BackupPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_policy = "BackupPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InternalServerError,
        Validation,
    },
} = .{};
pub const put_file_system_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-02-01/file-systems/{FileSystemId}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFileSystemPolicy",
    Request: type = struct {
        file_system_id: []const u8,
        policy: []const u8,
        bypass_policy_lockout_safety_check: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .policy = "Policy",
                .bypass_policy_lockout_safety_check = "BypassPolicyLockoutSafetyCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_file_system_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_file_system_policy };
        }
    },
    Response: type = struct {
        file_system_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InternalServerError,
        InvalidPolicy,
    },
} = .{};
pub const put_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-02-01/file-systems/{FileSystemId}/lifecycle-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutLifecycleConfiguration",
    Request: type = struct {
        file_system_id: []const u8,
        lifecycle_policies: []LifecyclePolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .lifecycle_policies = "LifecyclePolicies",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_lifecycle_configuration };
        }
    },
    Response: type = struct {
        lifecycle_policies: ?[]LifecyclePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policies = "LifecyclePolicies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InternalServerError,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-02-01/resource-tags/{ResourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessPointNotFound,
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-02-01/resource-tags/{ResourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_id: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessPointNotFound,
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const update_file_system: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-02-01/file-systems/{FileSystemId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateFileSystem",
    Request: type = struct {
        file_system_id: []const u8,
        throughput_mode: ?[]const u8 = null,
        provisioned_throughput_in_mibps: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .throughput_mode = "ThroughputMode",
                .provisioned_throughput_in_mibps = "ProvisionedThroughputInMibps",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_file_system) } {
            return .{ .service_metadata = service_metadata, .action = update_file_system };
        }
    },
    Response: type = struct {
        owner_id: []const u8,
        creation_token: []const u8,
        file_system_id: []const u8,
        file_system_arn: ?[]const u8 = null,
        creation_time: i64,
        life_cycle_state: []const u8,
        name: ?[]const u8 = null,
        number_of_mount_targets: i64,
        size_in_bytes: FileSystemSize,
        performance_mode: []const u8,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        throughput_mode: ?[]const u8 = null,
        provisioned_throughput_in_mibps: ?f64 = null,
        availability_zone_name: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        tags: []Tag,
        file_system_protection: ?FileSystemProtectionDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_id = "OwnerId",
                .creation_token = "CreationToken",
                .file_system_id = "FileSystemId",
                .file_system_arn = "FileSystemArn",
                .creation_time = "CreationTime",
                .life_cycle_state = "LifeCycleState",
                .name = "Name",
                .number_of_mount_targets = "NumberOfMountTargets",
                .size_in_bytes = "SizeInBytes",
                .performance_mode = "PerformanceMode",
                .encrypted = "Encrypted",
                .kms_key_id = "KmsKeyId",
                .throughput_mode = "ThroughputMode",
                .provisioned_throughput_in_mibps = "ProvisionedThroughputInMibps",
                .availability_zone_name = "AvailabilityZoneName",
                .availability_zone_id = "AvailabilityZoneId",
                .tags = "Tags",
                .file_system_protection = "FileSystemProtection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InsufficientThroughputCapacity,
        InternalServerError,
        ThroughputLimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const update_file_system_protection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-02-01/file-systems/{FileSystemId}/protection",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFileSystemProtection",
    Request: type = struct {
        file_system_id: []const u8,
        replication_overwrite_protection: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .replication_overwrite_protection = "ReplicationOverwriteProtection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_file_system_protection) } {
            return .{ .service_metadata = service_metadata, .action = update_file_system_protection };
        }
    },
    Response: type = struct {
        replication_overwrite_protection: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_overwrite_protection = "ReplicationOverwriteProtection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncorrectFileSystemLifeCycleState,
        InsufficientThroughputCapacity,
        InternalServerError,
        ReplicationAlreadyExists,
        ThroughputLimitExceeded,
        TooManyRequests,
    },
} = .{};

pub const FileSystemProtectionDescription = struct {
    replication_overwrite_protection: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_overwrite_protection = "ReplicationOverwriteProtection",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemSize = struct {
    value: i64,
    timestamp: ?i64 = null,
    value_in_ia: ?i64 = null,
    value_in_standard: ?i64 = null,
    value_in_archive: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .timestamp = "Timestamp",
            .value_in_ia = "ValueInIA",
            .value_in_standard = "ValueInStandard",
            .value_in_archive = "ValueInArchive",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecyclePolicy = struct {
    transition_to_ia: ?[]const u8 = null,
    transition_to_primary_storage_class: ?[]const u8 = null,
    transition_to_archive: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transition_to_ia = "TransitionToIA",
            .transition_to_primary_storage_class = "TransitionToPrimaryStorageClass",
            .transition_to_archive = "TransitionToArchive",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupPolicy = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceIdPreference = struct {
    resource_id_type: ?[]const u8 = null,
    resources: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id_type = "ResourceIdType",
            .resources = "Resources",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationConfigurationDescription = struct {
    source_file_system_id: []const u8,
    source_file_system_region: []const u8,
    source_file_system_arn: []const u8,
    original_source_file_system_arn: []const u8,
    creation_time: i64,
    destinations: []Destination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_file_system_id = "SourceFileSystemId",
            .source_file_system_region = "SourceFileSystemRegion",
            .source_file_system_arn = "SourceFileSystemArn",
            .original_source_file_system_arn = "OriginalSourceFileSystemArn",
            .creation_time = "CreationTime",
            .destinations = "Destinations",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = struct {
    status: []const u8,
    file_system_id: []const u8,
    region: []const u8,
    last_replicated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .file_system_id = "FileSystemId",
            .region = "Region",
            .last_replicated_timestamp = "LastReplicatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const MountTargetDescription = struct {
    owner_id: ?[]const u8 = null,
    mount_target_id: []const u8,
    file_system_id: []const u8,
    subnet_id: []const u8,
    life_cycle_state: []const u8,
    ip_address: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,
    availability_zone_name: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .mount_target_id = "MountTargetId",
            .file_system_id = "FileSystemId",
            .subnet_id = "SubnetId",
            .life_cycle_state = "LifeCycleState",
            .ip_address = "IpAddress",
            .network_interface_id = "NetworkInterfaceId",
            .availability_zone_id = "AvailabilityZoneId",
            .availability_zone_name = "AvailabilityZoneName",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemDescription = struct {
    owner_id: []const u8,
    creation_token: []const u8,
    file_system_id: []const u8,
    file_system_arn: ?[]const u8 = null,
    creation_time: i64,
    life_cycle_state: []const u8,
    name: ?[]const u8 = null,
    number_of_mount_targets: i64,
    size_in_bytes: FileSystemSize,
    performance_mode: []const u8,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    throughput_mode: ?[]const u8 = null,
    provisioned_throughput_in_mibps: ?f64 = null,
    availability_zone_name: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,
    tags: []Tag,
    file_system_protection: ?FileSystemProtectionDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .creation_token = "CreationToken",
            .file_system_id = "FileSystemId",
            .file_system_arn = "FileSystemArn",
            .creation_time = "CreationTime",
            .life_cycle_state = "LifeCycleState",
            .name = "Name",
            .number_of_mount_targets = "NumberOfMountTargets",
            .size_in_bytes = "SizeInBytes",
            .performance_mode = "PerformanceMode",
            .encrypted = "Encrypted",
            .kms_key_id = "KmsKeyId",
            .throughput_mode = "ThroughputMode",
            .provisioned_throughput_in_mibps = "ProvisionedThroughputInMibps",
            .availability_zone_name = "AvailabilityZoneName",
            .availability_zone_id = "AvailabilityZoneId",
            .tags = "Tags",
            .file_system_protection = "FileSystemProtection",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessPointDescription = struct {
    client_token: ?[]const u8 = null,
    name: ?[]const u8 = null,
    tags: ?[]Tag = null,
    access_point_id: ?[]const u8 = null,
    access_point_arn: ?[]const u8 = null,
    file_system_id: ?[]const u8 = null,
    posix_user: ?PosixUser = null,
    root_directory: ?RootDirectory = null,
    owner_id: ?[]const u8 = null,
    life_cycle_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_token = "ClientToken",
            .name = "Name",
            .tags = "Tags",
            .access_point_id = "AccessPointId",
            .access_point_arn = "AccessPointArn",
            .file_system_id = "FileSystemId",
            .posix_user = "PosixUser",
            .root_directory = "RootDirectory",
            .owner_id = "OwnerId",
            .life_cycle_state = "LifeCycleState",
        };
        return @field(mappings, field_name);
    }
};

pub const RootDirectory = struct {
    path: ?[]const u8 = null,
    creation_info: ?CreationInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .creation_info = "CreationInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const CreationInfo = struct {
    owner_uid: i64,
    owner_gid: i64,
    permissions: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_uid = "OwnerUid",
            .owner_gid = "OwnerGid",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const PosixUser = struct {
    uid: i64,
    gid: i64,
    secondary_gids: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uid = "Uid",
            .gid = "Gid",
            .secondary_gids = "SecondaryGids",
        };
        return @field(mappings, field_name);
    }
};
