const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-11-01";
pub const sdk_id: []const u8 = "EKS";
pub const arn_namespace: ?[]const u8 = "eks";
pub const endpoint_prefix: []const u8 = "eks";
pub const sigv4_name: []const u8 = "eks";
pub const name: []const u8 = "AWSWesleyFrontend";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-11-01",
    sdk_id: []const u8 = "EKS",
    arn_namespace: ?[]const u8 = "eks",
    endpoint_prefix: []const u8 = "eks",
    sigv4_name: []const u8 = "eks",
    name: []const u8 = "AWSWesleyFrontend",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_access_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/access-entries/{principalArn}/access-policies",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateAccessPolicy",
    Request: type = struct {
        cluster_name: []const u8,
        principal_arn: []const u8,
        policy_arn: []const u8,
        access_scope: AccessScope,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
                .policy_arn = "policyArn",
                .access_scope = "accessScope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = associate_access_policy };
        }
    },
    Response: type = struct {
        cluster_name: ?[]const u8 = null,
        principal_arn: ?[]const u8 = null,
        associated_access_policy: ?AssociatedAccessPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
                .associated_access_policy = "associatedAccessPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const associate_encryption_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/encryption-config/associate",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateEncryptionConfig",
    Request: type = struct {
        cluster_name: []const u8,
        encryption_config: []EncryptionConfig,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .encryption_config = "encryptionConfig",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_encryption_config) } {
            return .{ .service_metadata = service_metadata, .action = associate_encryption_config };
        }
    },
    Response: type = struct {
        update: ?Update = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const associate_identity_provider_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/identity-provider-configs/associate",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateIdentityProviderConfig",
    Request: type = struct {
        cluster_name: []const u8,
        oidc: struct {
            identity_provider_config_name: []const u8,
            issuer_url: []const u8,
            client_id: []const u8,
            username_claim: ?[]const u8 = null,
            username_prefix: ?[]const u8 = null,
            groups_claim: ?[]const u8 = null,
            groups_prefix: ?[]const u8 = null,
            required_claims: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identity_provider_config_name = "identityProviderConfigName",
                    .issuer_url = "issuerUrl",
                    .client_id = "clientId",
                    .username_claim = "usernameClaim",
                    .username_prefix = "usernamePrefix",
                    .groups_claim = "groupsClaim",
                    .groups_prefix = "groupsPrefix",
                    .required_claims = "requiredClaims",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "required_claims", field_name))
                    return try serializeMap(self.required_claims, self.fieldNameFor("required_claims"), options, out_stream);
                return false;
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .oidc = "oidc",
                .tags = "tags",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_identity_provider_config) } {
            return .{ .service_metadata = service_metadata, .action = associate_identity_provider_config };
        }
    },
    Response: type = struct {
        update: ?Update = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const create_access_entry: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/access-entries",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessEntry",
    Request: type = struct {
        cluster_name: []const u8,
        principal_arn: []const u8,
        kubernetes_groups: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_request_token: ?[]const u8 = null,
        username: ?[]const u8 = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
                .kubernetes_groups = "kubernetesGroups",
                .tags = "tags",
                .client_request_token = "clientRequestToken",
                .username = "username",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_entry) } {
            return .{ .service_metadata = service_metadata, .action = create_access_entry };
        }
    },
    Response: type = struct {
        access_entry: ?AccessEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_entry = "accessEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceLimitExceeded,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const create_addon: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/addons",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAddon",
    Request: type = struct {
        cluster_name: []const u8,
        addon_name: []const u8,
        addon_version: ?[]const u8 = null,
        service_account_role_arn: ?[]const u8 = null,
        resolve_conflicts: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        configuration_values: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .addon_name = "addonName",
                .addon_version = "addonVersion",
                .service_account_role_arn = "serviceAccountRoleArn",
                .resolve_conflicts = "resolveConflicts",
                .client_request_token = "clientRequestToken",
                .tags = "tags",
                .configuration_values = "configurationValues",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_addon) } {
            return .{ .service_metadata = service_metadata, .action = create_addon };
        }
    },
    Response: type = struct {
        addon: ?Addon = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addon = "addon",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const create_cluster: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        name: []const u8,
        version: ?[]const u8 = null,
        role_arn: []const u8,
        resources_vpc_config: VpcConfigRequest,
        kubernetes_network_config: ?struct {
            service_ipv4_cidr: ?[]const u8 = null,
            ip_family: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_ipv4_cidr = "serviceIpv4Cidr",
                    .ip_family = "ipFamily",
                };
                return @field(mappings, field_name);
            }
        } = null,
        logging: ?Logging = null,
        client_request_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        encryption_config: ?[]EncryptionConfig = null,
        outpost_config: ?struct {
            outpost_arns: [][]const u8,
            control_plane_instance_type: []const u8,
            control_plane_placement: ?struct {
                group_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group_name = "groupName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .outpost_arns = "outpostArns",
                    .control_plane_instance_type = "controlPlaneInstanceType",
                    .control_plane_placement = "controlPlanePlacement",
                };
                return @field(mappings, field_name);
            }
        } = null,
        access_config: ?struct {
            bootstrap_cluster_creator_admin_permissions: ?bool = null,
            authentication_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bootstrap_cluster_creator_admin_permissions = "bootstrapClusterCreatorAdminPermissions",
                    .authentication_mode = "authenticationMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
                .role_arn = "roleArn",
                .resources_vpc_config = "resourcesVpcConfig",
                .kubernetes_network_config = "kubernetesNetworkConfig",
                .logging = "logging",
                .client_request_token = "clientRequestToken",
                .tags = "tags",
                .encryption_config = "encryptionConfig",
                .outpost_config = "outpostConfig",
                .access_config = "accessConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceInUse,
        ResourceLimitExceeded,
        Server,
        ServiceUnavailable,
        UnsupportedAvailabilityZone,
    },
} = .{};
pub const create_eks_anywhere_subscription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/eks-anywhere-subscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEksAnywhereSubscription",
    Request: type = struct {
        name: []const u8,
        term: EksAnywhereSubscriptionTerm,
        license_quantity: ?i64 = null,
        license_type: ?[]const u8 = null,
        auto_renew: ?bool = null,
        client_request_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .term = "term",
                .license_quantity = "licenseQuantity",
                .license_type = "licenseType",
                .auto_renew = "autoRenew",
                .client_request_token = "clientRequestToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_eks_anywhere_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_eks_anywhere_subscription };
        }
    },
    Response: type = struct {
        subscription: ?EksAnywhereSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription = "subscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceLimitExceeded,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const create_fargate_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/fargate-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFargateProfile",
    Request: type = struct {
        fargate_profile_name: []const u8,
        cluster_name: []const u8,
        pod_execution_role_arn: []const u8,
        subnets: ?[][]const u8 = null,
        selectors: ?[]FargateProfileSelector = null,
        client_request_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fargate_profile_name = "fargateProfileName",
                .cluster_name = "clusterName",
                .pod_execution_role_arn = "podExecutionRoleArn",
                .subnets = "subnets",
                .selectors = "selectors",
                .client_request_token = "clientRequestToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fargate_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_fargate_profile };
        }
    },
    Response: type = struct {
        fargate_profile: ?FargateProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fargate_profile = "fargateProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceLimitExceeded,
        Server,
        UnsupportedAvailabilityZone,
    },
} = .{};
pub const create_nodegroup: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/node-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNodegroup",
    Request: type = struct {
        cluster_name: []const u8,
        nodegroup_name: []const u8,
        scaling_config: ?NodegroupScalingConfig = null,
        disk_size: ?i64 = null,
        subnets: [][]const u8,
        instance_types: ?[][]const u8 = null,
        ami_type: ?[]const u8 = null,
        remote_access: ?RemoteAccessConfig = null,
        node_role: []const u8,
        labels: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        taints: ?[]Taint = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_request_token: ?[]const u8 = null,
        launch_template: ?LaunchTemplateSpecification = null,
        update_config: ?NodegroupUpdateConfig = null,
        capacity_type: ?[]const u8 = null,
        version: ?[]const u8 = null,
        release_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .nodegroup_name = "nodegroupName",
                .scaling_config = "scalingConfig",
                .disk_size = "diskSize",
                .subnets = "subnets",
                .instance_types = "instanceTypes",
                .ami_type = "amiType",
                .remote_access = "remoteAccess",
                .node_role = "nodeRole",
                .labels = "labels",
                .taints = "taints",
                .tags = "tags",
                .client_request_token = "clientRequestToken",
                .launch_template = "launchTemplate",
                .update_config = "updateConfig",
                .capacity_type = "capacityType",
                .version = "version",
                .release_version = "releaseVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "labels", field_name))
                return try serializeMap(self.labels, self.fieldNameFor("labels"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_nodegroup) } {
            return .{ .service_metadata = service_metadata, .action = create_nodegroup };
        }
    },
    Response: type = struct {
        nodegroup: ?Nodegroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nodegroup = "nodegroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceLimitExceeded,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const create_pod_identity_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/pod-identity-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePodIdentityAssociation",
    Request: type = struct {
        cluster_name: []const u8,
        namespace: []const u8,
        service_account: []const u8,
        role_arn: []const u8,
        client_request_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .namespace = "namespace",
                .service_account = "serviceAccount",
                .role_arn = "roleArn",
                .client_request_token = "clientRequestToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pod_identity_association) } {
            return .{ .service_metadata = service_metadata, .action = create_pod_identity_association };
        }
    },
    Response: type = struct {
        association: ?PodIdentityAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "association",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceLimitExceeded,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const delete_access_entry: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/clusters/{clusterName}/access-entries/{principalArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessEntry",
    Request: type = struct {
        cluster_name: []const u8,
        principal_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_entry) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_entry };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const delete_addon: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/clusters/{clusterName}/addons/{addonName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAddon",
    Request: type = struct {
        cluster_name: []const u8,
        addon_name: []const u8,
        preserve: ?bool = null,

        pub const http_query = .{
            .preserve = "preserve",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .addon_name = "addonName",
                .preserve = "preserve",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_addon) } {
            return .{ .service_metadata = service_metadata, .action = delete_addon };
        }
    },
    Response: type = struct {
        addon: ?Addon = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addon = "addon",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const delete_cluster: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/clusters/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ResourceInUse,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const delete_eks_anywhere_subscription: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/eks-anywhere-subscriptions/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEksAnywhereSubscription",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_eks_anywhere_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_eks_anywhere_subscription };
        }
    },
    Response: type = struct {
        subscription: ?EksAnywhereSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription = "subscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const delete_fargate_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/clusters/{clusterName}/fargate-profiles/{fargateProfileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFargateProfile",
    Request: type = struct {
        cluster_name: []const u8,
        fargate_profile_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .fargate_profile_name = "fargateProfileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fargate_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_fargate_profile };
        }
    },
    Response: type = struct {
        fargate_profile: ?FargateProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fargate_profile = "fargateProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const delete_nodegroup: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/clusters/{clusterName}/node-groups/{nodegroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteNodegroup",
    Request: type = struct {
        cluster_name: []const u8,
        nodegroup_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .nodegroup_name = "nodegroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_nodegroup) } {
            return .{ .service_metadata = service_metadata, .action = delete_nodegroup };
        }
    },
    Response: type = struct {
        nodegroup: ?Nodegroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nodegroup = "nodegroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceInUse,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const delete_pod_identity_association: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/clusters/{clusterName}/pod-identity-associations/{associationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePodIdentityAssociation",
    Request: type = struct {
        cluster_name: []const u8,
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .association_id = "associationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pod_identity_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_pod_identity_association };
        }
    },
    Response: type = struct {
        association: ?PodIdentityAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "association",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const deregister_cluster: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/cluster-registrations/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterCluster",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_cluster) } {
            return .{ .service_metadata = service_metadata, .action = deregister_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        ResourceInUse,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const describe_access_entry: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/access-entries/{principalArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccessEntry",
    Request: type = struct {
        cluster_name: []const u8,
        principal_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_access_entry) } {
            return .{ .service_metadata = service_metadata, .action = describe_access_entry };
        }
    },
    Response: type = struct {
        access_entry: ?AccessEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_entry = "accessEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const describe_addon: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/addons/{addonName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAddon",
    Request: type = struct {
        cluster_name: []const u8,
        addon_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .addon_name = "addonName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_addon) } {
            return .{ .service_metadata = service_metadata, .action = describe_addon };
        }
    },
    Response: type = struct {
        addon: ?Addon = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addon = "addon",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const describe_addon_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/addons/configuration-schemas",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAddonConfiguration",
    Request: type = struct {
        addon_name: []const u8,
        addon_version: []const u8,

        pub const http_query = .{
            .addon_name = "addonName",
            .addon_version = "addonVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addon_name = "addonName",
                .addon_version = "addonVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_addon_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_addon_configuration };
        }
    },
    Response: type = struct {
        addon_name: ?[]const u8 = null,
        addon_version: ?[]const u8 = null,
        configuration_schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addon_name = "addonName",
                .addon_version = "addonVersion",
                .configuration_schema = "configurationSchema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const describe_addon_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/addons/supported-versions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAddonVersions",
    Request: type = struct {
        kubernetes_version: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        addon_name: ?[]const u8 = null,
        types: ?[][]const u8 = null,
        publishers: ?[][]const u8 = null,
        owners: ?[][]const u8 = null,

        pub const http_query = .{
            .kubernetes_version = "kubernetesVersion",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .addon_name = "addonName",
            .types = "types",
            .publishers = "publishers",
            .owners = "owners",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kubernetes_version = "kubernetesVersion",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .addon_name = "addonName",
                .types = "types",
                .publishers = "publishers",
                .owners = "owners",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_addon_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_addon_versions };
        }
    },
    Response: type = struct {
        addons: ?[]struct {
            addon_name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            addon_versions: ?[]struct {
                addon_version: ?[]const u8 = null,
                architecture: ?[][]const u8 = null,
                compatibilities: ?[]struct {
                    cluster_version: ?[]const u8 = null,
                    platform_versions: ?[][]const u8 = null,
                    default_version: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cluster_version = "clusterVersion",
                            .platform_versions = "platformVersions",
                            .default_version = "defaultVersion",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                requires_configuration: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .addon_version = "addonVersion",
                        .architecture = "architecture",
                        .compatibilities = "compatibilities",
                        .requires_configuration = "requiresConfiguration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            publisher: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            marketplace_information: ?MarketplaceInformation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .addon_name = "addonName",
                    .type = "type",
                    .addon_versions = "addonVersions",
                    .publisher = "publisher",
                    .owner = "owner",
                    .marketplace_information = "marketplaceInformation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addons = "addons",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const describe_cluster: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCluster",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const describe_eks_anywhere_subscription: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/eks-anywhere-subscriptions/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeEksAnywhereSubscription",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_eks_anywhere_subscription) } {
            return .{ .service_metadata = service_metadata, .action = describe_eks_anywhere_subscription };
        }
    },
    Response: type = struct {
        subscription: ?EksAnywhereSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription = "subscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const describe_fargate_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/fargate-profiles/{fargateProfileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFargateProfile",
    Request: type = struct {
        cluster_name: []const u8,
        fargate_profile_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .fargate_profile_name = "fargateProfileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fargate_profile) } {
            return .{ .service_metadata = service_metadata, .action = describe_fargate_profile };
        }
    },
    Response: type = struct {
        fargate_profile: ?FargateProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fargate_profile = "fargateProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const describe_identity_provider_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/identity-provider-configs/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIdentityProviderConfig",
    Request: type = struct {
        cluster_name: []const u8,
        identity_provider_config: IdentityProviderConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .identity_provider_config = "identityProviderConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_identity_provider_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_identity_provider_config };
        }
    },
    Response: type = struct {
        identity_provider_config: ?struct {
            oidc: ?struct {
                identity_provider_config_name: ?[]const u8 = null,
                identity_provider_config_arn: ?[]const u8 = null,
                cluster_name: ?[]const u8 = null,
                issuer_url: ?[]const u8 = null,
                client_id: ?[]const u8 = null,
                username_claim: ?[]const u8 = null,
                username_prefix: ?[]const u8 = null,
                groups_claim: ?[]const u8 = null,
                groups_prefix: ?[]const u8 = null,
                required_claims: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                tags: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .identity_provider_config_name = "identityProviderConfigName",
                        .identity_provider_config_arn = "identityProviderConfigArn",
                        .cluster_name = "clusterName",
                        .issuer_url = "issuerUrl",
                        .client_id = "clientId",
                        .username_claim = "usernameClaim",
                        .username_prefix = "usernamePrefix",
                        .groups_claim = "groupsClaim",
                        .groups_prefix = "groupsPrefix",
                        .required_claims = "requiredClaims",
                        .tags = "tags",
                        .status = "status",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "required_claims", field_name))
                        return try serializeMap(self.required_claims, self.fieldNameFor("required_claims"), options, out_stream);
                    if (std.mem.eql(u8, "tags", field_name))
                        return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .oidc = "oidc",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider_config = "identityProviderConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const describe_insight: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/insights/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInsight",
    Request: type = struct {
        cluster_name: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_insight) } {
            return .{ .service_metadata = service_metadata, .action = describe_insight };
        }
    },
    Response: type = struct {
        insight: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            category: ?[]const u8 = null,
            kubernetes_version: ?[]const u8 = null,
            last_refresh_time: ?i64 = null,
            last_transition_time: ?i64 = null,
            description: ?[]const u8 = null,
            insight_status: ?InsightStatus = null,
            recommendation: ?[]const u8 = null,
            additional_info: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            resources: ?[]struct {
                insight_status: ?InsightStatus = null,
                kubernetes_resource_uri: ?[]const u8 = null,
                arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .insight_status = "insightStatus",
                        .kubernetes_resource_uri = "kubernetesResourceUri",
                        .arn = "arn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            category_specific_summary: ?struct {
                deprecation_details: ?[]struct {
                    usage: ?[]const u8 = null,
                    replaced_with: ?[]const u8 = null,
                    stop_serving_version: ?[]const u8 = null,
                    start_serving_replacement_version: ?[]const u8 = null,
                    client_stats: ?[]struct {
                        user_agent: ?[]const u8 = null,
                        number_of_requests_last30_days: ?i64 = null,
                        last_request_time: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .user_agent = "userAgent",
                                .number_of_requests_last30_days = "numberOfRequestsLast30Days",
                                .last_request_time = "lastRequestTime",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .usage = "usage",
                            .replaced_with = "replacedWith",
                            .stop_serving_version = "stopServingVersion",
                            .start_serving_replacement_version = "startServingReplacementVersion",
                            .client_stats = "clientStats",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .deprecation_details = "deprecationDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .category = "category",
                    .kubernetes_version = "kubernetesVersion",
                    .last_refresh_time = "lastRefreshTime",
                    .last_transition_time = "lastTransitionTime",
                    .description = "description",
                    .insight_status = "insightStatus",
                    .recommendation = "recommendation",
                    .additional_info = "additionalInfo",
                    .resources = "resources",
                    .category_specific_summary = "categorySpecificSummary",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "additional_info", field_name))
                    return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight = "insight",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const describe_nodegroup: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/node-groups/{nodegroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeNodegroup",
    Request: type = struct {
        cluster_name: []const u8,
        nodegroup_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .nodegroup_name = "nodegroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_nodegroup) } {
            return .{ .service_metadata = service_metadata, .action = describe_nodegroup };
        }
    },
    Response: type = struct {
        nodegroup: ?Nodegroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nodegroup = "nodegroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const describe_pod_identity_association: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/pod-identity-associations/{associationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePodIdentityAssociation",
    Request: type = struct {
        cluster_name: []const u8,
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .association_id = "associationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pod_identity_association) } {
            return .{ .service_metadata = service_metadata, .action = describe_pod_identity_association };
        }
    },
    Response: type = struct {
        association: ?PodIdentityAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "association",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const describe_update: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{name}/updates/{updateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUpdate",
    Request: type = struct {
        name: []const u8,
        update_id: []const u8,
        nodegroup_name: ?[]const u8 = null,
        addon_name: ?[]const u8 = null,

        pub const http_query = .{
            .nodegroup_name = "nodegroupName",
            .addon_name = "addonName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .update_id = "updateId",
                .nodegroup_name = "nodegroupName",
                .addon_name = "addonName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_update) } {
            return .{ .service_metadata = service_metadata, .action = describe_update };
        }
    },
    Response: type = struct {
        update: ?Update = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const disassociate_access_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/clusters/{clusterName}/access-entries/{principalArn}/access-policies/{policyArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateAccessPolicy",
    Request: type = struct {
        cluster_name: []const u8,
        principal_arn: []const u8,
        policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
                .policy_arn = "policyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_access_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const disassociate_identity_provider_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/identity-provider-configs/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateIdentityProviderConfig",
    Request: type = struct {
        cluster_name: []const u8,
        identity_provider_config: IdentityProviderConfig,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .identity_provider_config = "identityProviderConfig",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_identity_provider_config) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_identity_provider_config };
        }
    },
    Response: type = struct {
        update: ?Update = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const list_access_entries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/access-entries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessEntries",
    Request: type = struct {
        cluster_name: []const u8,
        associated_policy_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .associated_policy_arn = "associatedPolicyArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .associated_policy_arn = "associatedPolicyArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_entries) } {
            return .{ .service_metadata = service_metadata, .action = list_access_entries };
        }
    },
    Response: type = struct {
        access_entries: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_entries = "accessEntries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const list_access_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/access-policies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessPolicies",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_access_policies };
        }
    },
    Response: type = struct {
        access_policies: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policies = "accessPolicies",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Server,
    },
} = .{};
pub const list_addons: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/addons",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAddons",
    Request: type = struct {
        cluster_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_addons) } {
            return .{ .service_metadata = service_metadata, .action = list_addons };
        }
    },
    Response: type = struct {
        addons: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addons = "addons",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const list_associated_access_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/access-entries/{principalArn}/access-policies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssociatedAccessPolicies",
    Request: type = struct {
        cluster_name: []const u8,
        principal_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associated_access_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_associated_access_policies };
        }
    },
    Response: type = struct {
        cluster_name: ?[]const u8 = null,
        principal_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        associated_access_policies: ?[]AssociatedAccessPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
                .next_token = "nextToken",
                .associated_access_policies = "associatedAccessPolicies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const list_clusters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters",
        .success_code = 200,
    };

    action_name: []const u8 = "ListClusters",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        include: ?[][]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .include = "include",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .include = "include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_clusters };
        }
    },
    Response: type = struct {
        clusters: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .clusters = "clusters",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const list_eks_anywhere_subscriptions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/eks-anywhere-subscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEksAnywhereSubscriptions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        include_status: ?[][]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .include_status = "includeStatus",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .include_status = "includeStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_eks_anywhere_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = list_eks_anywhere_subscriptions };
        }
    },
    Response: type = struct {
        subscriptions: ?[]EksAnywhereSubscription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscriptions = "subscriptions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const list_fargate_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/fargate-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFargateProfiles",
    Request: type = struct {
        cluster_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fargate_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_fargate_profiles };
        }
    },
    Response: type = struct {
        fargate_profile_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fargate_profile_names = "fargateProfileNames",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const list_identity_provider_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/identity-provider-configs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIdentityProviderConfigs",
    Request: type = struct {
        cluster_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identity_provider_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_identity_provider_configs };
        }
    },
    Response: type = struct {
        identity_provider_configs: ?[]IdentityProviderConfig = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider_configs = "identityProviderConfigs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const list_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/insights",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInsights",
    Request: type = struct {
        cluster_name: []const u8,
        filter: ?struct {
            categories: ?[][]const u8 = null,
            kubernetes_versions: ?[][]const u8 = null,
            statuses: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .categories = "categories",
                    .kubernetes_versions = "kubernetesVersions",
                    .statuses = "statuses",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .filter = "filter",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_insights) } {
            return .{ .service_metadata = service_metadata, .action = list_insights };
        }
    },
    Response: type = struct {
        insights: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            category: ?[]const u8 = null,
            kubernetes_version: ?[]const u8 = null,
            last_refresh_time: ?i64 = null,
            last_transition_time: ?i64 = null,
            description: ?[]const u8 = null,
            insight_status: ?InsightStatus = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .category = "category",
                    .kubernetes_version = "kubernetesVersion",
                    .last_refresh_time = "lastRefreshTime",
                    .last_transition_time = "lastTransitionTime",
                    .description = "description",
                    .insight_status = "insightStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insights = "insights",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const list_nodegroups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/node-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNodegroups",
    Request: type = struct {
        cluster_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_nodegroups) } {
            return .{ .service_metadata = service_metadata, .action = list_nodegroups };
        }
    },
    Response: type = struct {
        nodegroups: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nodegroups = "nodegroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const list_pod_identity_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{clusterName}/pod-identity-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPodIdentityAssociations",
    Request: type = struct {
        cluster_name: []const u8,
        namespace: ?[]const u8 = null,
        service_account: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .namespace = "namespace",
            .service_account = "serviceAccount",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .namespace = "namespace",
                .service_account = "serviceAccount",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pod_identity_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_pod_identity_associations };
        }
    },
    Response: type = struct {
        associations: ?[]struct {
            cluster_name: ?[]const u8 = null,
            namespace: ?[]const u8 = null,
            service_account: ?[]const u8 = null,
            association_arn: ?[]const u8 = null,
            association_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_name = "clusterName",
                    .namespace = "namespace",
                    .service_account = "serviceAccount",
                    .association_arn = "associationArn",
                    .association_id = "associationId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "associations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
    },
} = .{};
pub const list_updates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clusters/{name}/updates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUpdates",
    Request: type = struct {
        name: []const u8,
        nodegroup_name: ?[]const u8 = null,
        addon_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .nodegroup_name = "nodegroupName",
            .addon_name = "addonName",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .nodegroup_name = "nodegroupName",
                .addon_name = "addonName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_updates) } {
            return .{ .service_metadata = service_metadata, .action = list_updates };
        }
    },
    Response: type = struct {
        update_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_ids = "updateIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const register_cluster: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cluster-registrations",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterCluster",
    Request: type = struct {
        name: []const u8,
        connector_config: struct {
            role_arn: []const u8,
            provider: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .role_arn = "roleArn",
                    .provider = "provider",
                };
                return @field(mappings, field_name);
            }
        },
        client_request_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .connector_config = "connectorConfig",
                .client_request_token = "clientRequestToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_cluster) } {
            return .{ .service_metadata = service_metadata, .action = register_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Client,
        InvalidParameter,
        ResourceInUse,
        ResourceLimitExceeded,
        ResourcePropagationDelay,
        Server,
        ServiceUnavailable,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
    },
} = .{};
pub const update_access_entry: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/access-entries/{principalArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccessEntry",
    Request: type = struct {
        cluster_name: []const u8,
        principal_arn: []const u8,
        kubernetes_groups: ?[][]const u8 = null,
        client_request_token: ?[]const u8 = null,
        username: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .principal_arn = "principalArn",
                .kubernetes_groups = "kubernetesGroups",
                .client_request_token = "clientRequestToken",
                .username = "username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_access_entry) } {
            return .{ .service_metadata = service_metadata, .action = update_access_entry };
        }
    },
    Response: type = struct {
        access_entry: ?AccessEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_entry = "accessEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const update_addon: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/addons/{addonName}/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAddon",
    Request: type = struct {
        cluster_name: []const u8,
        addon_name: []const u8,
        addon_version: ?[]const u8 = null,
        service_account_role_arn: ?[]const u8 = null,
        resolve_conflicts: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        configuration_values: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .addon_name = "addonName",
                .addon_version = "addonVersion",
                .service_account_role_arn = "serviceAccountRoleArn",
                .resolve_conflicts = "resolveConflicts",
                .client_request_token = "clientRequestToken",
                .configuration_values = "configurationValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_addon) } {
            return .{ .service_metadata = service_metadata, .action = update_addon };
        }
    },
    Response: type = struct {
        update: ?Update = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const update_cluster_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{name}/update-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateClusterConfig",
    Request: type = struct {
        name: []const u8,
        resources_vpc_config: ?VpcConfigRequest = null,
        logging: ?Logging = null,
        client_request_token: ?[]const u8 = null,
        access_config: ?struct {
            authentication_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authentication_mode = "authenticationMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .resources_vpc_config = "resourcesVpcConfig",
                .logging = "logging",
                .client_request_token = "clientRequestToken",
                .access_config = "accessConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster_config) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster_config };
        }
    },
    Response: type = struct {
        update: ?Update = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const update_cluster_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{name}/updates",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateClusterVersion",
    Request: type = struct {
        name: []const u8,
        version: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster_version) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster_version };
        }
    },
    Response: type = struct {
        update: ?Update = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const update_eks_anywhere_subscription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/eks-anywhere-subscriptions/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEksAnywhereSubscription",
    Request: type = struct {
        id: []const u8,
        auto_renew: bool,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .auto_renew = "autoRenew",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_eks_anywhere_subscription) } {
            return .{ .service_metadata = service_metadata, .action = update_eks_anywhere_subscription };
        }
    },
    Response: type = struct {
        subscription: ?EksAnywhereSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription = "subscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const update_nodegroup_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/node-groups/{nodegroupName}/update-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateNodegroupConfig",
    Request: type = struct {
        cluster_name: []const u8,
        nodegroup_name: []const u8,
        labels: ?struct {
            add_or_update_labels: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            remove_labels: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_or_update_labels = "addOrUpdateLabels",
                    .remove_labels = "removeLabels",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "add_or_update_labels", field_name))
                    return try serializeMap(self.add_or_update_labels, self.fieldNameFor("add_or_update_labels"), options, out_stream);
                return false;
            }
        } = null,
        taints: ?struct {
            add_or_update_taints: ?[]Taint = null,
            remove_taints: ?[]Taint = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_or_update_taints = "addOrUpdateTaints",
                    .remove_taints = "removeTaints",
                };
                return @field(mappings, field_name);
            }
        } = null,
        scaling_config: ?NodegroupScalingConfig = null,
        update_config: ?NodegroupUpdateConfig = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .nodegroup_name = "nodegroupName",
                .labels = "labels",
                .taints = "taints",
                .scaling_config = "scalingConfig",
                .update_config = "updateConfig",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_nodegroup_config) } {
            return .{ .service_metadata = service_metadata, .action = update_nodegroup_config };
        }
    },
    Response: type = struct {
        update: ?Update = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const update_nodegroup_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/node-groups/{nodegroupName}/update-version",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateNodegroupVersion",
    Request: type = struct {
        cluster_name: []const u8,
        nodegroup_name: []const u8,
        version: ?[]const u8 = null,
        release_version: ?[]const u8 = null,
        launch_template: ?LaunchTemplateSpecification = null,
        force: ?bool = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .nodegroup_name = "nodegroupName",
                .version = "version",
                .release_version = "releaseVersion",
                .launch_template = "launchTemplate",
                .force = "force",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_nodegroup_version) } {
            return .{ .service_metadata = service_metadata, .action = update_nodegroup_version };
        }
    },
    Response: type = struct {
        update: ?Update = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update = "update",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Server,
    },
} = .{};
pub const update_pod_identity_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/pod-identity-associations/{associationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePodIdentityAssociation",
    Request: type = struct {
        cluster_name: []const u8,
        association_id: []const u8,
        role_arn: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .association_id = "associationId",
                .role_arn = "roleArn",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pod_identity_association) } {
            return .{ .service_metadata = service_metadata, .action = update_pod_identity_association };
        }
    },
    Response: type = struct {
        association: ?PodIdentityAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "association",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Server,
    },
} = .{};

pub const PodIdentityAssociation = struct {
    cluster_name: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    service_account: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    association_arn: ?[]const u8 = null,
    association_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    created_at: ?i64 = null,
    modified_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_name = "clusterName",
            .namespace = "namespace",
            .service_account = "serviceAccount",
            .role_arn = "roleArn",
            .association_arn = "associationArn",
            .association_id = "associationId",
            .tags = "tags",
            .created_at = "createdAt",
            .modified_at = "modifiedAt",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Update = struct {
    id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    type: ?[]const u8 = null,
    params: ?[]UpdateParam = null,
    created_at: ?i64 = null,
    errors: ?[]ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .status = "status",
            .type = "type",
            .params = "params",
            .created_at = "createdAt",
            .errors = "errors",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetail = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    resource_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "errorCode",
            .error_message = "errorMessage",
            .resource_ids = "resourceIds",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateParam = struct {
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateSpecification = struct {
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .version = "version",
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const NodegroupUpdateConfig = struct {
    max_unavailable: ?i64 = null,
    max_unavailable_percentage: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_unavailable = "maxUnavailable",
            .max_unavailable_percentage = "maxUnavailablePercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const NodegroupScalingConfig = struct {
    min_size: ?i64 = null,
    max_size: ?i64 = null,
    desired_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_size = "minSize",
            .max_size = "maxSize",
            .desired_size = "desiredSize",
        };
        return @field(mappings, field_name);
    }
};

pub const Taint = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    effect: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
            .effect = "effect",
        };
        return @field(mappings, field_name);
    }
};

pub const EksAnywhereSubscription = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    effective_date: ?i64 = null,
    expiration_date: ?i64 = null,
    license_quantity: ?i64 = null,
    license_type: ?[]const u8 = null,
    term: ?EksAnywhereSubscriptionTerm = null,
    status: ?[]const u8 = null,
    auto_renew: ?bool = null,
    license_arns: ?[][]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .created_at = "createdAt",
            .effective_date = "effectiveDate",
            .expiration_date = "expirationDate",
            .license_quantity = "licenseQuantity",
            .license_type = "licenseType",
            .term = "term",
            .status = "status",
            .auto_renew = "autoRenew",
            .license_arns = "licenseArns",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const EksAnywhereSubscriptionTerm = struct {
    duration: ?i64 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "duration",
            .unit = "unit",
        };
        return @field(mappings, field_name);
    }
};

pub const Logging = struct {
    cluster_logging: ?[]LogSetup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_logging = "clusterLogging",
        };
        return @field(mappings, field_name);
    }
};

pub const LogSetup = struct {
    types: ?[][]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .types = "types",
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfigRequest = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    endpoint_public_access: ?bool = null,
    endpoint_private_access: ?bool = null,
    public_access_cidrs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "subnetIds",
            .security_group_ids = "securityGroupIds",
            .endpoint_public_access = "endpointPublicAccess",
            .endpoint_private_access = "endpointPrivateAccess",
            .public_access_cidrs = "publicAccessCidrs",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessEntry = struct {
    cluster_name: ?[]const u8 = null,
    principal_arn: ?[]const u8 = null,
    kubernetes_groups: ?[][]const u8 = null,
    access_entry_arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    modified_at: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    username: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_name = "clusterName",
            .principal_arn = "principalArn",
            .kubernetes_groups = "kubernetesGroups",
            .access_entry_arn = "accessEntryArn",
            .created_at = "createdAt",
            .modified_at = "modifiedAt",
            .tags = "tags",
            .username = "username",
            .type = "type",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Cluster = struct {
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    version: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    resources_vpc_config: ?VpcConfigResponse = null,
    kubernetes_network_config: ?KubernetesNetworkConfigResponse = null,
    logging: ?Logging = null,
    identity: ?Identity = null,
    status: ?[]const u8 = null,
    certificate_authority: ?Certificate = null,
    client_request_token: ?[]const u8 = null,
    platform_version: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    encryption_config: ?[]EncryptionConfig = null,
    connector_config: ?ConnectorConfigResponse = null,
    id: ?[]const u8 = null,
    health: ?ClusterHealth = null,
    outpost_config: ?OutpostConfigResponse = null,
    access_config: ?AccessConfigResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .arn = "arn",
            .created_at = "createdAt",
            .version = "version",
            .endpoint = "endpoint",
            .role_arn = "roleArn",
            .resources_vpc_config = "resourcesVpcConfig",
            .kubernetes_network_config = "kubernetesNetworkConfig",
            .logging = "logging",
            .identity = "identity",
            .status = "status",
            .certificate_authority = "certificateAuthority",
            .client_request_token = "clientRequestToken",
            .platform_version = "platformVersion",
            .tags = "tags",
            .encryption_config = "encryptionConfig",
            .connector_config = "connectorConfig",
            .id = "id",
            .health = "health",
            .outpost_config = "outpostConfig",
            .access_config = "accessConfig",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const AccessConfigResponse = struct {
    bootstrap_cluster_creator_admin_permissions: ?bool = null,
    authentication_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bootstrap_cluster_creator_admin_permissions = "bootstrapClusterCreatorAdminPermissions",
            .authentication_mode = "authenticationMode",
        };
        return @field(mappings, field_name);
    }
};

pub const OutpostConfigResponse = struct {
    outpost_arns: [][]const u8,
    control_plane_instance_type: []const u8,
    control_plane_placement: ?ControlPlanePlacementResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .outpost_arns = "outpostArns",
            .control_plane_instance_type = "controlPlaneInstanceType",
            .control_plane_placement = "controlPlanePlacement",
        };
        return @field(mappings, field_name);
    }
};

pub const ControlPlanePlacementResponse = struct {
    group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "groupName",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterHealth = struct {
    issues: ?[]ClusterIssue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issues = "issues",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterIssue = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,
    resource_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
            .resource_ids = "resourceIds",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorConfigResponse = struct {
    activation_id: ?[]const u8 = null,
    activation_code: ?[]const u8 = null,
    activation_expiry: ?i64 = null,
    provider: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activation_id = "activationId",
            .activation_code = "activationCode",
            .activation_expiry = "activationExpiry",
            .provider = "provider",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfig = struct {
    resources: ?[][]const u8 = null,
    provider: ?Provider = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resources = "resources",
            .provider = "provider",
        };
        return @field(mappings, field_name);
    }
};

pub const Provider = struct {
    key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_arn = "keyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Certificate = struct {
    data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "data",
        };
        return @field(mappings, field_name);
    }
};

pub const Identity = struct {
    oidc: ?OIDC = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .oidc = "oidc",
        };
        return @field(mappings, field_name);
    }
};

pub const OIDC = struct {
    issuer: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issuer = "issuer",
        };
        return @field(mappings, field_name);
    }
};

pub const KubernetesNetworkConfigResponse = struct {
    service_ipv4_cidr: ?[]const u8 = null,
    service_ipv6_cidr: ?[]const u8 = null,
    ip_family: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_ipv4_cidr = "serviceIpv4Cidr",
            .service_ipv6_cidr = "serviceIpv6Cidr",
            .ip_family = "ipFamily",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfigResponse = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    cluster_security_group_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    endpoint_public_access: ?bool = null,
    endpoint_private_access: ?bool = null,
    public_access_cidrs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "subnetIds",
            .security_group_ids = "securityGroupIds",
            .cluster_security_group_id = "clusterSecurityGroupId",
            .vpc_id = "vpcId",
            .endpoint_public_access = "endpointPublicAccess",
            .endpoint_private_access = "endpointPrivateAccess",
            .public_access_cidrs = "publicAccessCidrs",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightStatus = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityProviderConfig = struct {
    type: []const u8,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociatedAccessPolicy = struct {
    policy_arn: ?[]const u8 = null,
    access_scope: ?AccessScope = null,
    associated_at: ?i64 = null,
    modified_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_arn = "policyArn",
            .access_scope = "accessScope",
            .associated_at = "associatedAt",
            .modified_at = "modifiedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessScope = struct {
    type: ?[]const u8 = null,
    namespaces: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .namespaces = "namespaces",
        };
        return @field(mappings, field_name);
    }
};

pub const Nodegroup = struct {
    nodegroup_name: ?[]const u8 = null,
    nodegroup_arn: ?[]const u8 = null,
    cluster_name: ?[]const u8 = null,
    version: ?[]const u8 = null,
    release_version: ?[]const u8 = null,
    created_at: ?i64 = null,
    modified_at: ?i64 = null,
    status: ?[]const u8 = null,
    capacity_type: ?[]const u8 = null,
    scaling_config: ?NodegroupScalingConfig = null,
    instance_types: ?[][]const u8 = null,
    subnets: ?[][]const u8 = null,
    remote_access: ?RemoteAccessConfig = null,
    ami_type: ?[]const u8 = null,
    node_role: ?[]const u8 = null,
    labels: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    taints: ?[]Taint = null,
    resources: ?NodegroupResources = null,
    disk_size: ?i64 = null,
    health: ?NodegroupHealth = null,
    update_config: ?NodegroupUpdateConfig = null,
    launch_template: ?LaunchTemplateSpecification = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nodegroup_name = "nodegroupName",
            .nodegroup_arn = "nodegroupArn",
            .cluster_name = "clusterName",
            .version = "version",
            .release_version = "releaseVersion",
            .created_at = "createdAt",
            .modified_at = "modifiedAt",
            .status = "status",
            .capacity_type = "capacityType",
            .scaling_config = "scalingConfig",
            .instance_types = "instanceTypes",
            .subnets = "subnets",
            .remote_access = "remoteAccess",
            .ami_type = "amiType",
            .node_role = "nodeRole",
            .labels = "labels",
            .taints = "taints",
            .resources = "resources",
            .disk_size = "diskSize",
            .health = "health",
            .update_config = "updateConfig",
            .launch_template = "launchTemplate",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "labels", field_name))
            return try serializeMap(self.labels, self.fieldNameFor("labels"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const NodegroupHealth = struct {
    issues: ?[]Issue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issues = "issues",
        };
        return @field(mappings, field_name);
    }
};

pub const Issue = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,
    resource_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
            .resource_ids = "resourceIds",
        };
        return @field(mappings, field_name);
    }
};

pub const NodegroupResources = struct {
    auto_scaling_groups: ?[]AutoScalingGroup = null,
    remote_access_security_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_scaling_groups = "autoScalingGroups",
            .remote_access_security_group = "remoteAccessSecurityGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingGroup = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const RemoteAccessConfig = struct {
    ec2_ssh_key: ?[]const u8 = null,
    source_security_groups: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ec2_ssh_key = "ec2SshKey",
            .source_security_groups = "sourceSecurityGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const FargateProfile = struct {
    fargate_profile_name: ?[]const u8 = null,
    fargate_profile_arn: ?[]const u8 = null,
    cluster_name: ?[]const u8 = null,
    created_at: ?i64 = null,
    pod_execution_role_arn: ?[]const u8 = null,
    subnets: ?[][]const u8 = null,
    selectors: ?[]FargateProfileSelector = null,
    status: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fargate_profile_name = "fargateProfileName",
            .fargate_profile_arn = "fargateProfileArn",
            .cluster_name = "clusterName",
            .created_at = "createdAt",
            .pod_execution_role_arn = "podExecutionRoleArn",
            .subnets = "subnets",
            .selectors = "selectors",
            .status = "status",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const FargateProfileSelector = struct {
    namespace: ?[]const u8 = null,
    labels: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "namespace",
            .labels = "labels",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "labels", field_name))
            return try serializeMap(self.labels, self.fieldNameFor("labels"), options, out_stream);
        return false;
    }
};

pub const MarketplaceInformation = struct {
    product_id: ?[]const u8 = null,
    product_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_id = "productId",
            .product_url = "productUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const Addon = struct {
    addon_name: ?[]const u8 = null,
    cluster_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    addon_version: ?[]const u8 = null,
    health: ?AddonHealth = null,
    addon_arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    modified_at: ?i64 = null,
    service_account_role_arn: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    publisher: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    marketplace_information: ?MarketplaceInformation = null,
    configuration_values: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .addon_name = "addonName",
            .cluster_name = "clusterName",
            .status = "status",
            .addon_version = "addonVersion",
            .health = "health",
            .addon_arn = "addonArn",
            .created_at = "createdAt",
            .modified_at = "modifiedAt",
            .service_account_role_arn = "serviceAccountRoleArn",
            .tags = "tags",
            .publisher = "publisher",
            .owner = "owner",
            .marketplace_information = "marketplaceInformation",
            .configuration_values = "configurationValues",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const AddonHealth = struct {
    issues: ?[]AddonIssue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issues = "issues",
        };
        return @field(mappings, field_name);
    }
};

pub const AddonIssue = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,
    resource_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
            .resource_ids = "resourceIds",
        };
        return @field(mappings, field_name);
    }
};
