const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-11-26";
pub const sdk_id: []const u8 = "EKS Auth";
pub const arn_namespace: ?[]const u8 = "eks-auth";
pub const endpoint_prefix: []const u8 = "eks-auth";
pub const sigv4_name: []const u8 = "eks-auth";
pub const name: []const u8 = "EKSAuthFrontend";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-11-26",
    sdk_id: []const u8 = "EKS Auth",
    arn_namespace: ?[]const u8 = "eks-auth",
    endpoint_prefix: []const u8 = "eks-auth",
    sigv4_name: []const u8 = "eks-auth",
    name: []const u8 = "EKSAuthFrontend",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const assume_role_for_pod_identity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clusters/{clusterName}/assume-role-for-pod-identity",
        .success_code = 200,
    };

    action_name: []const u8 = "AssumeRoleForPodIdentity",
    Request: type = struct {
        cluster_name: []const u8,
        token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "clusterName",
                .token = "token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assume_role_for_pod_identity) } {
            return .{ .service_metadata = service_metadata, .action = assume_role_for_pod_identity };
        }
    },
    Response: type = struct {
        subject: struct {
            namespace: []const u8,
            service_account: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .namespace = "namespace",
                    .service_account = "serviceAccount",
                };
                return @field(mappings, field_name);
            }
        },
        audience: []const u8,
        pod_identity_association: struct {
            association_arn: []const u8,
            association_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_arn = "associationArn",
                    .association_id = "associationId",
                };
                return @field(mappings, field_name);
            }
        },
        assumed_role_user: struct {
            arn: []const u8,
            assume_role_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .assume_role_id = "assumeRoleId",
                };
                return @field(mappings, field_name);
            }
        },
        credentials: struct {
            session_token: []const u8,
            secret_access_key: []const u8,
            access_key_id: []const u8,
            expiration: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_token = "sessionToken",
                    .secret_access_key = "secretAccessKey",
                    .access_key_id = "accessKeyId",
                    .expiration = "expiration",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subject = "subject",
                .audience = "audience",
                .pod_identity_association = "podIdentityAssociation",
                .assumed_role_user = "assumedRoleUser",
                .credentials = "credentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredToken,
        InternalServer,
        InvalidParameter,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
