const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-02-02";
pub const sdk_id: []const u8 = "ElastiCache";
pub const arn_namespace: ?[]const u8 = "elasticache";
pub const endpoint_prefix: []const u8 = "elasticache";
pub const sigv4_name: []const u8 = "elasticache";
pub const name: []const u8 = "AmazonElastiCacheV9";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2015-02-02",
    sdk_id: []const u8 = "ElastiCache",
    arn_namespace: ?[]const u8 = "elasticache",
    endpoint_prefix: []const u8 = "elasticache",
    sigv4_name: []const u8 = "elasticache",
    name: []const u8 = "AmazonElastiCacheV9",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_name: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        CacheParameterGroupNotFound,
        CacheSecurityGroupNotFound,
        CacheSubnetGroupNotFound,
        InvalidARN,
        InvalidReplicationGroupState,
        InvalidServerlessCacheSnapshotState,
        InvalidServerlessCacheState,
        ReplicationGroupNotFound,
        ReservedCacheNodeNotFound,
        ServerlessCacheNotFound,
        ServerlessCacheSnapshotNotFound,
        SnapshotNotFound,
        TagQuotaPerResourceExceeded,
        UserGroupNotFound,
        UserNotFound,
    },
} = .{};
pub const authorize_cache_security_group_ingress: struct {
    action_name: []const u8 = "AuthorizeCacheSecurityGroupIngress",
    Request: type = struct {
        cache_security_group_name: []const u8,
        ec2_security_group_name: []const u8,
        ec2_security_group_owner_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_security_group_name = "CacheSecurityGroupName",
                .ec2_security_group_name = "EC2SecurityGroupName",
                .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_cache_security_group_ingress) } {
            return .{ .service_metadata = service_metadata, .action = authorize_cache_security_group_ingress };
        }
    },
    Response: type = struct {
        cache_security_group: ?CacheSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_security_group = "CacheSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationAlreadyExists,
        CacheSecurityGroupNotFound,
        InvalidCacheSecurityGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const batch_apply_update_action: struct {
    action_name: []const u8 = "BatchApplyUpdateAction",
    Request: type = struct {
        replication_group_ids: ?[][]const u8 = null,
        cache_cluster_ids: ?[][]const u8 = null,
        service_update_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_ids = "ReplicationGroupIds",
                .cache_cluster_ids = "CacheClusterIds",
                .service_update_name = "ServiceUpdateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_apply_update_action) } {
            return .{ .service_metadata = service_metadata, .action = batch_apply_update_action };
        }
    },
    Response: type = struct {
        processed_update_actions: ?[]ProcessedUpdateAction = null,
        unprocessed_update_actions: ?[]UnprocessedUpdateAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processed_update_actions = "ProcessedUpdateActions",
                .unprocessed_update_actions = "UnprocessedUpdateActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUpdateNotFound,
    },
} = .{};
pub const batch_stop_update_action: struct {
    action_name: []const u8 = "BatchStopUpdateAction",
    Request: type = struct {
        replication_group_ids: ?[][]const u8 = null,
        cache_cluster_ids: ?[][]const u8 = null,
        service_update_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_ids = "ReplicationGroupIds",
                .cache_cluster_ids = "CacheClusterIds",
                .service_update_name = "ServiceUpdateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_stop_update_action) } {
            return .{ .service_metadata = service_metadata, .action = batch_stop_update_action };
        }
    },
    Response: type = struct {
        processed_update_actions: ?[]ProcessedUpdateAction = null,
        unprocessed_update_actions: ?[]UnprocessedUpdateAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processed_update_actions = "ProcessedUpdateActions",
                .unprocessed_update_actions = "UnprocessedUpdateActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUpdateNotFound,
    },
} = .{};
pub const complete_migration: struct {
    action_name: []const u8 = "CompleteMigration",
    Request: type = struct {
        replication_group_id: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .force = "Force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(complete_migration) } {
            return .{ .service_metadata = service_metadata, .action = complete_migration };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidReplicationGroupState,
        ReplicationGroupNotFound,
        ReplicationGroupNotUnderMigration,
    },
} = .{};
pub const copy_serverless_cache_snapshot: struct {
    action_name: []const u8 = "CopyServerlessCacheSnapshot",
    Request: type = struct {
        source_serverless_cache_snapshot_name: []const u8,
        target_serverless_cache_snapshot_name: []const u8,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_serverless_cache_snapshot_name = "SourceServerlessCacheSnapshotName",
                .target_serverless_cache_snapshot_name = "TargetServerlessCacheSnapshotName",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_serverless_cache_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = copy_serverless_cache_snapshot };
        }
    },
    Response: type = struct {
        serverless_cache_snapshot: ?ServerlessCacheSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_snapshot = "ServerlessCacheSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidServerlessCacheSnapshotState,
        ServerlessCacheSnapshotAlreadyExists,
        ServerlessCacheSnapshotNotFound,
        ServerlessCacheSnapshotQuotaExceeded,
        ServiceLinkedRoleNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const copy_snapshot: struct {
    action_name: []const u8 = "CopySnapshot",
    Request: type = struct {
        source_snapshot_name: []const u8,
        target_snapshot_name: []const u8,
        target_bucket: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_snapshot_name = "SourceSnapshotName",
                .target_snapshot_name = "TargetSnapshotName",
                .target_bucket = "TargetBucket",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = copy_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidSnapshotState,
        SnapshotAlreadyExists,
        SnapshotNotFound,
        SnapshotQuotaExceeded,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_cache_cluster: struct {
    action_name: []const u8 = "CreateCacheCluster",
    Request: type = struct {
        cache_cluster_id: []const u8,
        replication_group_id: ?[]const u8 = null,
        az_mode: ?[]const u8 = null,
        preferred_availability_zone: ?[]const u8 = null,
        preferred_availability_zones: ?[][]const u8 = null,
        num_cache_nodes: ?i64 = null,
        cache_node_type: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        cache_parameter_group_name: ?[]const u8 = null,
        cache_subnet_group_name: ?[]const u8 = null,
        cache_security_group_names: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        snapshot_arns: ?[][]const u8 = null,
        snapshot_name: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        port: ?i64 = null,
        notification_topic_arn: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        snapshot_retention_limit: ?i64 = null,
        snapshot_window: ?[]const u8 = null,
        auth_token: ?[]const u8 = null,
        outpost_mode: ?[]const u8 = null,
        preferred_outpost_arn: ?[]const u8 = null,
        preferred_outpost_arns: ?[][]const u8 = null,
        log_delivery_configurations: ?[]LogDeliveryConfigurationRequest = null,
        transit_encryption_enabled: ?bool = null,
        network_type: ?[]const u8 = null,
        ip_discovery: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster_id = "CacheClusterId",
                .replication_group_id = "ReplicationGroupId",
                .az_mode = "AZMode",
                .preferred_availability_zone = "PreferredAvailabilityZone",
                .preferred_availability_zones = "PreferredAvailabilityZones",
                .num_cache_nodes = "NumCacheNodes",
                .cache_node_type = "CacheNodeType",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .cache_parameter_group_name = "CacheParameterGroupName",
                .cache_subnet_group_name = "CacheSubnetGroupName",
                .cache_security_group_names = "CacheSecurityGroupNames",
                .security_group_ids = "SecurityGroupIds",
                .tags = "Tags",
                .snapshot_arns = "SnapshotArns",
                .snapshot_name = "SnapshotName",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .port = "Port",
                .notification_topic_arn = "NotificationTopicArn",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .snapshot_retention_limit = "SnapshotRetentionLimit",
                .snapshot_window = "SnapshotWindow",
                .auth_token = "AuthToken",
                .outpost_mode = "OutpostMode",
                .preferred_outpost_arn = "PreferredOutpostArn",
                .preferred_outpost_arns = "PreferredOutpostArns",
                .log_delivery_configurations = "LogDeliveryConfigurations",
                .transit_encryption_enabled = "TransitEncryptionEnabled",
                .network_type = "NetworkType",
                .ip_discovery = "IpDiscovery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cache_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cache_cluster };
        }
    },
    Response: type = struct {
        cache_cluster: ?CacheCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster = "CacheCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterAlreadyExists,
        CacheParameterGroupNotFound,
        CacheSecurityGroupNotFound,
        CacheSubnetGroupNotFound,
        ClusterQuotaForCustomerExceeded,
        InsufficientCacheClusterCapacity,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        InvalidVPCNetworkState,
        NodeQuotaForClusterExceeded,
        NodeQuotaForCustomerExceeded,
        ReplicationGroupNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_cache_parameter_group: struct {
    action_name: []const u8 = "CreateCacheParameterGroup",
    Request: type = struct {
        cache_parameter_group_name: []const u8,
        cache_parameter_group_family: []const u8,
        description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_name = "CacheParameterGroupName",
                .cache_parameter_group_family = "CacheParameterGroupFamily",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cache_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = create_cache_parameter_group };
        }
    },
    Response: type = struct {
        cache_parameter_group: ?CacheParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group = "CacheParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheParameterGroupAlreadyExists,
        CacheParameterGroupQuotaExceeded,
        InvalidCacheParameterGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_cache_security_group: struct {
    action_name: []const u8 = "CreateCacheSecurityGroup",
    Request: type = struct {
        cache_security_group_name: []const u8,
        description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_security_group_name = "CacheSecurityGroupName",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cache_security_group) } {
            return .{ .service_metadata = service_metadata, .action = create_cache_security_group };
        }
    },
    Response: type = struct {
        cache_security_group: ?CacheSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_security_group = "CacheSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheSecurityGroupAlreadyExists,
        CacheSecurityGroupQuotaExceeded,
        InvalidParameterCombination,
        InvalidParameterValue,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_cache_subnet_group: struct {
    action_name: []const u8 = "CreateCacheSubnetGroup",
    Request: type = struct {
        cache_subnet_group_name: []const u8,
        cache_subnet_group_description: []const u8,
        subnet_ids: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_subnet_group_name = "CacheSubnetGroupName",
                .cache_subnet_group_description = "CacheSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cache_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = create_cache_subnet_group };
        }
    },
    Response: type = struct {
        cache_subnet_group: ?CacheSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_subnet_group = "CacheSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheSubnetGroupAlreadyExists,
        CacheSubnetGroupQuotaExceeded,
        CacheSubnetQuotaExceeded,
        InvalidSubnet,
        SubnetNotAllowed,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_global_replication_group: struct {
    action_name: []const u8 = "CreateGlobalReplicationGroup",
    Request: type = struct {
        global_replication_group_id_suffix: []const u8,
        global_replication_group_description: ?[]const u8 = null,
        primary_replication_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id_suffix = "GlobalReplicationGroupIdSuffix",
                .global_replication_group_description = "GlobalReplicationGroupDescription",
                .primary_replication_group_id = "PrimaryReplicationGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_global_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = create_global_replication_group };
        }
    },
    Response: type = struct {
        global_replication_group: ?GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group = "GlobalReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupAlreadyExists,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        ReplicationGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const create_replication_group: struct {
    action_name: []const u8 = "CreateReplicationGroup",
    Request: type = struct {
        replication_group_id: []const u8,
        replication_group_description: []const u8,
        global_replication_group_id: ?[]const u8 = null,
        primary_cluster_id: ?[]const u8 = null,
        automatic_failover_enabled: ?bool = null,
        multi_az_enabled: ?bool = null,
        num_cache_clusters: ?i64 = null,
        preferred_cache_cluster_a_zs: ?[][]const u8 = null,
        num_node_groups: ?i64 = null,
        replicas_per_node_group: ?i64 = null,
        node_group_configuration: ?[]NodeGroupConfiguration = null,
        cache_node_type: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        cache_parameter_group_name: ?[]const u8 = null,
        cache_subnet_group_name: ?[]const u8 = null,
        cache_security_group_names: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        snapshot_arns: ?[][]const u8 = null,
        snapshot_name: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        port: ?i64 = null,
        notification_topic_arn: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        snapshot_retention_limit: ?i64 = null,
        snapshot_window: ?[]const u8 = null,
        auth_token: ?[]const u8 = null,
        transit_encryption_enabled: ?bool = null,
        at_rest_encryption_enabled: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        user_group_ids: ?[][]const u8 = null,
        log_delivery_configurations: ?[]LogDeliveryConfigurationRequest = null,
        data_tiering_enabled: ?bool = null,
        network_type: ?[]const u8 = null,
        ip_discovery: ?[]const u8 = null,
        transit_encryption_mode: ?[]const u8 = null,
        cluster_mode: ?[]const u8 = null,
        serverless_cache_snapshot_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .replication_group_description = "ReplicationGroupDescription",
                .global_replication_group_id = "GlobalReplicationGroupId",
                .primary_cluster_id = "PrimaryClusterId",
                .automatic_failover_enabled = "AutomaticFailoverEnabled",
                .multi_az_enabled = "MultiAZEnabled",
                .num_cache_clusters = "NumCacheClusters",
                .preferred_cache_cluster_a_zs = "PreferredCacheClusterAZs",
                .num_node_groups = "NumNodeGroups",
                .replicas_per_node_group = "ReplicasPerNodeGroup",
                .node_group_configuration = "NodeGroupConfiguration",
                .cache_node_type = "CacheNodeType",
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .cache_parameter_group_name = "CacheParameterGroupName",
                .cache_subnet_group_name = "CacheSubnetGroupName",
                .cache_security_group_names = "CacheSecurityGroupNames",
                .security_group_ids = "SecurityGroupIds",
                .tags = "Tags",
                .snapshot_arns = "SnapshotArns",
                .snapshot_name = "SnapshotName",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .port = "Port",
                .notification_topic_arn = "NotificationTopicArn",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .snapshot_retention_limit = "SnapshotRetentionLimit",
                .snapshot_window = "SnapshotWindow",
                .auth_token = "AuthToken",
                .transit_encryption_enabled = "TransitEncryptionEnabled",
                .at_rest_encryption_enabled = "AtRestEncryptionEnabled",
                .kms_key_id = "KmsKeyId",
                .user_group_ids = "UserGroupIds",
                .log_delivery_configurations = "LogDeliveryConfigurations",
                .data_tiering_enabled = "DataTieringEnabled",
                .network_type = "NetworkType",
                .ip_discovery = "IpDiscovery",
                .transit_encryption_mode = "TransitEncryptionMode",
                .cluster_mode = "ClusterMode",
                .serverless_cache_snapshot_name = "ServerlessCacheSnapshotName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_group };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        CacheParameterGroupNotFound,
        CacheSecurityGroupNotFound,
        CacheSubnetGroupNotFound,
        ClusterQuotaForCustomerExceeded,
        GlobalReplicationGroupNotFound,
        InsufficientCacheClusterCapacity,
        InvalidCacheClusterState,
        InvalidGlobalReplicationGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidUserGroupState,
        InvalidVPCNetworkState,
        NodeGroupsPerReplicationGroupQuotaExceeded,
        NodeQuotaForClusterExceeded,
        NodeQuotaForCustomerExceeded,
        ReplicationGroupAlreadyExists,
        TagQuotaPerResourceExceeded,
        UserGroupNotFound,
    },
} = .{};
pub const create_serverless_cache: struct {
    action_name: []const u8 = "CreateServerlessCache",
    Request: type = struct {
        serverless_cache_name: []const u8,
        description: ?[]const u8 = null,
        engine: []const u8,
        major_engine_version: ?[]const u8 = null,
        cache_usage_limits: ?CacheUsageLimits = null,
        kms_key_id: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        snapshot_arns_to_restore: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        user_group_id: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        snapshot_retention_limit: ?i64 = null,
        daily_snapshot_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_name = "ServerlessCacheName",
                .description = "Description",
                .engine = "Engine",
                .major_engine_version = "MajorEngineVersion",
                .cache_usage_limits = "CacheUsageLimits",
                .kms_key_id = "KmsKeyId",
                .security_group_ids = "SecurityGroupIds",
                .snapshot_arns_to_restore = "SnapshotArnsToRestore",
                .tags = "Tags",
                .user_group_id = "UserGroupId",
                .subnet_ids = "SubnetIds",
                .snapshot_retention_limit = "SnapshotRetentionLimit",
                .daily_snapshot_time = "DailySnapshotTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_serverless_cache) } {
            return .{ .service_metadata = service_metadata, .action = create_serverless_cache };
        }
    },
    Response: type = struct {
        serverless_cache: ?ServerlessCache = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache = "ServerlessCache",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidCredentials,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidServerlessCacheState,
        InvalidUserGroupState,
        ServerlessCacheAlreadyExists,
        ServerlessCacheNotFound,
        ServerlessCacheQuotaForCustomerExceeded,
        ServiceLinkedRoleNotFound,
        TagQuotaPerResourceExceeded,
        UserGroupNotFound,
    },
} = .{};
pub const create_serverless_cache_snapshot: struct {
    action_name: []const u8 = "CreateServerlessCacheSnapshot",
    Request: type = struct {
        serverless_cache_snapshot_name: []const u8,
        serverless_cache_name: []const u8,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_snapshot_name = "ServerlessCacheSnapshotName",
                .serverless_cache_name = "ServerlessCacheName",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_serverless_cache_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_serverless_cache_snapshot };
        }
    },
    Response: type = struct {
        serverless_cache_snapshot: ?ServerlessCacheSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_snapshot = "ServerlessCacheSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidServerlessCacheState,
        ServerlessCacheNotFound,
        ServerlessCacheSnapshotAlreadyExists,
        ServerlessCacheSnapshotQuotaExceeded,
        ServiceLinkedRoleNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_snapshot: struct {
    action_name: []const u8 = "CreateSnapshot",
    Request: type = struct {
        replication_group_id: ?[]const u8 = null,
        cache_cluster_id: ?[]const u8 = null,
        snapshot_name: []const u8,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .cache_cluster_id = "CacheClusterId",
                .snapshot_name = "SnapshotName",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        InvalidCacheClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        ReplicationGroupNotFound,
        SnapshotAlreadyExists,
        SnapshotFeatureNotSupported,
        SnapshotQuotaExceeded,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_user: struct {
    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        user_id: []const u8,
        user_name: []const u8,
        engine: []const u8,
        passwords: ?[][]const u8 = null,
        access_string: []const u8,
        no_password_required: ?bool = null,
        tags: ?[]Tag = null,
        authentication_mode: ?AuthenticationMode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .user_name = "UserName",
                .engine = "Engine",
                .passwords = "Passwords",
                .access_string = "AccessString",
                .no_password_required = "NoPasswordRequired",
                .tags = "Tags",
                .authentication_mode = "AuthenticationMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        user_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        minimum_engine_version: ?[]const u8 = null,
        access_string: ?[]const u8 = null,
        user_group_ids: ?[][]const u8 = null,
        authentication: ?Authentication = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .user_name = "UserName",
                .status = "Status",
                .engine = "Engine",
                .minimum_engine_version = "MinimumEngineVersion",
                .access_string = "AccessString",
                .user_group_ids = "UserGroupIds",
                .authentication = "Authentication",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateUserName,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
        TagQuotaPerResourceExceeded,
        UserAlreadyExists,
        UserQuotaExceeded,
    },
} = .{};
pub const create_user_group: struct {
    action_name: []const u8 = "CreateUserGroup",
    Request: type = struct {
        user_group_id: []const u8,
        engine: []const u8,
        user_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_group_id = "UserGroupId",
                .engine = "Engine",
                .user_ids = "UserIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_group) } {
            return .{ .service_metadata = service_metadata, .action = create_user_group };
        }
    },
    Response: type = struct {
        user_group_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        user_ids: ?[][]const u8 = null,
        minimum_engine_version: ?[]const u8 = null,
        pending_changes: ?UserGroupPendingChanges = null,
        replication_groups: ?[][]const u8 = null,
        serverless_caches: ?[][]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_group_id = "UserGroupId",
                .status = "Status",
                .engine = "Engine",
                .user_ids = "UserIds",
                .minimum_engine_version = "MinimumEngineVersion",
                .pending_changes = "PendingChanges",
                .replication_groups = "ReplicationGroups",
                .serverless_caches = "ServerlessCaches",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DefaultUserRequired,
        DuplicateUserName,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
        TagQuotaPerResourceExceeded,
        UserGroupAlreadyExists,
        UserGroupQuotaExceeded,
        UserNotFound,
    },
} = .{};
pub const decrease_node_groups_in_global_replication_group: struct {
    action_name: []const u8 = "DecreaseNodeGroupsInGlobalReplicationGroup",
    Request: type = struct {
        global_replication_group_id: []const u8,
        node_group_count: i64,
        global_node_groups_to_remove: ?[][]const u8 = null,
        global_node_groups_to_retain: ?[][]const u8 = null,
        apply_immediately: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id = "GlobalReplicationGroupId",
                .node_group_count = "NodeGroupCount",
                .global_node_groups_to_remove = "GlobalNodeGroupsToRemove",
                .global_node_groups_to_retain = "GlobalNodeGroupsToRetain",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decrease_node_groups_in_global_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = decrease_node_groups_in_global_replication_group };
        }
    },
    Response: type = struct {
        global_replication_group: ?GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group = "GlobalReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupNotFound,
        InvalidGlobalReplicationGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const decrease_replica_count: struct {
    action_name: []const u8 = "DecreaseReplicaCount",
    Request: type = struct {
        replication_group_id: []const u8,
        new_replica_count: ?i64 = null,
        replica_configuration: ?[]ConfigureShard = null,
        replicas_to_remove: ?[][]const u8 = null,
        apply_immediately: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .new_replica_count = "NewReplicaCount",
                .replica_configuration = "ReplicaConfiguration",
                .replicas_to_remove = "ReplicasToRemove",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decrease_replica_count) } {
            return .{ .service_metadata = service_metadata, .action = decrease_replica_count };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterQuotaForCustomerExceeded,
        InsufficientCacheClusterCapacity,
        InvalidCacheClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        InvalidVPCNetworkState,
        NodeGroupsPerReplicationGroupQuotaExceeded,
        NodeQuotaForCustomerExceeded,
        NoOperation,
        ReplicationGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const delete_cache_cluster: struct {
    action_name: []const u8 = "DeleteCacheCluster",
    Request: type = struct {
        cache_cluster_id: []const u8,
        final_snapshot_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster_id = "CacheClusterId",
                .final_snapshot_identifier = "FinalSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cache_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cache_cluster };
        }
    },
    Response: type = struct {
        cache_cluster: ?CacheCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster = "CacheCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        InvalidCacheClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        SnapshotAlreadyExists,
        SnapshotFeatureNotSupported,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const delete_cache_parameter_group: struct {
    action_name: []const u8 = "DeleteCacheParameterGroup",
    Request: type = struct {
        cache_parameter_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_name = "CacheParameterGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cache_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_cache_parameter_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CacheParameterGroupNotFound,
        InvalidCacheParameterGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const delete_cache_security_group: struct {
    action_name: []const u8 = "DeleteCacheSecurityGroup",
    Request: type = struct {
        cache_security_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_security_group_name = "CacheSecurityGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cache_security_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_cache_security_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CacheSecurityGroupNotFound,
        InvalidCacheSecurityGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const delete_cache_subnet_group: struct {
    action_name: []const u8 = "DeleteCacheSubnetGroup",
    Request: type = struct {
        cache_subnet_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_subnet_group_name = "CacheSubnetGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cache_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_cache_subnet_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CacheSubnetGroupInUse,
        CacheSubnetGroupNotFound,
    },
} = .{};
pub const delete_global_replication_group: struct {
    action_name: []const u8 = "DeleteGlobalReplicationGroup",
    Request: type = struct {
        global_replication_group_id: []const u8,
        retain_primary_replication_group: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id = "GlobalReplicationGroupId",
                .retain_primary_replication_group = "RetainPrimaryReplicationGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_global_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_global_replication_group };
        }
    },
    Response: type = struct {
        global_replication_group: ?GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group = "GlobalReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupNotFound,
        InvalidGlobalReplicationGroupState,
        InvalidParameterValue,
    },
} = .{};
pub const delete_replication_group: struct {
    action_name: []const u8 = "DeleteReplicationGroup",
    Request: type = struct {
        replication_group_id: []const u8,
        retain_primary_cluster: ?bool = null,
        final_snapshot_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .retain_primary_cluster = "RetainPrimaryCluster",
                .final_snapshot_identifier = "FinalSnapshotIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_group };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        ReplicationGroupNotFound,
        SnapshotAlreadyExists,
        SnapshotFeatureNotSupported,
        SnapshotQuotaExceeded,
    },
} = .{};
pub const delete_serverless_cache: struct {
    action_name: []const u8 = "DeleteServerlessCache",
    Request: type = struct {
        serverless_cache_name: []const u8,
        final_snapshot_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_name = "ServerlessCacheName",
                .final_snapshot_name = "FinalSnapshotName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_serverless_cache) } {
            return .{ .service_metadata = service_metadata, .action = delete_serverless_cache };
        }
    },
    Response: type = struct {
        serverless_cache: ?ServerlessCache = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache = "ServerlessCache",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidCredentials,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidServerlessCacheState,
        ServerlessCacheNotFound,
        ServerlessCacheSnapshotAlreadyExists,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const delete_serverless_cache_snapshot: struct {
    action_name: []const u8 = "DeleteServerlessCacheSnapshot",
    Request: type = struct {
        serverless_cache_snapshot_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_snapshot_name = "ServerlessCacheSnapshotName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_serverless_cache_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_serverless_cache_snapshot };
        }
    },
    Response: type = struct {
        serverless_cache_snapshot: ?ServerlessCacheSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_snapshot = "ServerlessCacheSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidServerlessCacheSnapshotState,
        ServerlessCacheSnapshotNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const delete_snapshot: struct {
    action_name: []const u8 = "DeleteSnapshot",
    Request: type = struct {
        snapshot_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_name = "SnapshotName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidSnapshotState,
        SnapshotNotFound,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        user_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        minimum_engine_version: ?[]const u8 = null,
        access_string: ?[]const u8 = null,
        user_group_ids: ?[][]const u8 = null,
        authentication: ?Authentication = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .user_name = "UserName",
                .status = "Status",
                .engine = "Engine",
                .minimum_engine_version = "MinimumEngineVersion",
                .access_string = "AccessString",
                .user_group_ids = "UserGroupIds",
                .authentication = "Authentication",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DefaultUserAssociatedToUserGroup,
        InvalidParameterValue,
        InvalidUserState,
        ServiceLinkedRoleNotFound,
        UserNotFound,
    },
} = .{};
pub const delete_user_group: struct {
    action_name: []const u8 = "DeleteUserGroup",
    Request: type = struct {
        user_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_group_id = "UserGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_group };
        }
    },
    Response: type = struct {
        user_group_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        user_ids: ?[][]const u8 = null,
        minimum_engine_version: ?[]const u8 = null,
        pending_changes: ?UserGroupPendingChanges = null,
        replication_groups: ?[][]const u8 = null,
        serverless_caches: ?[][]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_group_id = "UserGroupId",
                .status = "Status",
                .engine = "Engine",
                .user_ids = "UserIds",
                .minimum_engine_version = "MinimumEngineVersion",
                .pending_changes = "PendingChanges",
                .replication_groups = "ReplicationGroups",
                .serverless_caches = "ServerlessCaches",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidUserGroupState,
        ServiceLinkedRoleNotFound,
        UserGroupNotFound,
    },
} = .{};
pub const describe_cache_clusters: struct {
    action_name: []const u8 = "DescribeCacheClusters",
    Request: type = struct {
        cache_cluster_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        show_cache_node_info: ?bool = null,
        show_cache_clusters_not_in_replication_groups: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster_id = "CacheClusterId",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .show_cache_node_info = "ShowCacheNodeInfo",
                .show_cache_clusters_not_in_replication_groups = "ShowCacheClustersNotInReplicationGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cache_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_cache_clusters };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cache_clusters: ?[]CacheCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cache_clusters = "CacheClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_cache_engine_versions: struct {
    action_name: []const u8 = "DescribeCacheEngineVersions",
    Request: type = struct {
        engine: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        cache_parameter_group_family: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        default_only: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .engine_version = "EngineVersion",
                .cache_parameter_group_family = "CacheParameterGroupFamily",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .default_only = "DefaultOnly",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cache_engine_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_cache_engine_versions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cache_engine_versions: ?[]struct {
            engine: ?[]const u8 = null,
            engine_version: ?[]const u8 = null,
            cache_parameter_group_family: ?[]const u8 = null,
            cache_engine_description: ?[]const u8 = null,
            cache_engine_version_description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine = "Engine",
                    .engine_version = "EngineVersion",
                    .cache_parameter_group_family = "CacheParameterGroupFamily",
                    .cache_engine_description = "CacheEngineDescription",
                    .cache_engine_version_description = "CacheEngineVersionDescription",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cache_engine_versions = "CacheEngineVersions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_cache_parameter_groups: struct {
    action_name: []const u8 = "DescribeCacheParameterGroups",
    Request: type = struct {
        cache_parameter_group_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_name = "CacheParameterGroupName",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cache_parameter_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_cache_parameter_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cache_parameter_groups: ?[]CacheParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cache_parameter_groups = "CacheParameterGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheParameterGroupNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_cache_parameters: struct {
    action_name: []const u8 = "DescribeCacheParameters",
    Request: type = struct {
        cache_parameter_group_name: []const u8,
        source: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_name = "CacheParameterGroupName",
                .source = "Source",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cache_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_cache_parameters };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        parameters: ?[]Parameter = null,
        cache_node_type_specific_parameters: ?[]CacheNodeTypeSpecificParameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .parameters = "Parameters",
                .cache_node_type_specific_parameters = "CacheNodeTypeSpecificParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheParameterGroupNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_cache_security_groups: struct {
    action_name: []const u8 = "DescribeCacheSecurityGroups",
    Request: type = struct {
        cache_security_group_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_security_group_name = "CacheSecurityGroupName",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cache_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_cache_security_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cache_security_groups: ?[]CacheSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cache_security_groups = "CacheSecurityGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheSecurityGroupNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_cache_subnet_groups: struct {
    action_name: []const u8 = "DescribeCacheSubnetGroups",
    Request: type = struct {
        cache_subnet_group_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_subnet_group_name = "CacheSubnetGroupName",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cache_subnet_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_cache_subnet_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cache_subnet_groups: ?[]CacheSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cache_subnet_groups = "CacheSubnetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheSubnetGroupNotFound,
    },
} = .{};
pub const describe_engine_default_parameters: struct {
    action_name: []const u8 = "DescribeEngineDefaultParameters",
    Request: type = struct {
        cache_parameter_group_family: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_family = "CacheParameterGroupFamily",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_engine_default_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_engine_default_parameters };
        }
    },
    Response: type = struct {
        engine_defaults: ?struct {
            cache_parameter_group_family: ?[]const u8 = null,
            marker: ?[]const u8 = null,
            parameters: ?[]Parameter = null,
            cache_node_type_specific_parameters: ?[]CacheNodeTypeSpecificParameter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cache_parameter_group_family = "CacheParameterGroupFamily",
                    .marker = "Marker",
                    .parameters = "Parameters",
                    .cache_node_type_specific_parameters = "CacheNodeTypeSpecificParameters",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_defaults = "EngineDefaults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        source_identifier: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        duration: ?i64 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_identifier = "SourceIdentifier",
                .source_type = "SourceType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .duration = "Duration",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        events: ?[]struct {
            source_identifier: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_identifier = "SourceIdentifier",
                    .source_type = "SourceType",
                    .message = "Message",
                    .date = "Date",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_global_replication_groups: struct {
    action_name: []const u8 = "DescribeGlobalReplicationGroups",
    Request: type = struct {
        global_replication_group_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        show_member_info: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id = "GlobalReplicationGroupId",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .show_member_info = "ShowMemberInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_global_replication_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_global_replication_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        global_replication_groups: ?[]GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .global_replication_groups = "GlobalReplicationGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_replication_groups: struct {
    action_name: []const u8 = "DescribeReplicationGroups",
    Request: type = struct {
        replication_group_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_groups: ?[]ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_groups = "ReplicationGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ReplicationGroupNotFound,
    },
} = .{};
pub const describe_reserved_cache_nodes: struct {
    action_name: []const u8 = "DescribeReservedCacheNodes",
    Request: type = struct {
        reserved_cache_node_id: ?[]const u8 = null,
        reserved_cache_nodes_offering_id: ?[]const u8 = null,
        cache_node_type: ?[]const u8 = null,
        duration: ?[]const u8 = null,
        product_description: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_cache_node_id = "ReservedCacheNodeId",
                .reserved_cache_nodes_offering_id = "ReservedCacheNodesOfferingId",
                .cache_node_type = "CacheNodeType",
                .duration = "Duration",
                .product_description = "ProductDescription",
                .offering_type = "OfferingType",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_cache_nodes) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_cache_nodes };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        reserved_cache_nodes: ?[]ReservedCacheNode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .reserved_cache_nodes = "ReservedCacheNodes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ReservedCacheNodeNotFound,
    },
} = .{};
pub const describe_reserved_cache_nodes_offerings: struct {
    action_name: []const u8 = "DescribeReservedCacheNodesOfferings",
    Request: type = struct {
        reserved_cache_nodes_offering_id: ?[]const u8 = null,
        cache_node_type: ?[]const u8 = null,
        duration: ?[]const u8 = null,
        product_description: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_cache_nodes_offering_id = "ReservedCacheNodesOfferingId",
                .cache_node_type = "CacheNodeType",
                .duration = "Duration",
                .product_description = "ProductDescription",
                .offering_type = "OfferingType",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_cache_nodes_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_cache_nodes_offerings };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        reserved_cache_nodes_offerings: ?[]struct {
            reserved_cache_nodes_offering_id: ?[]const u8 = null,
            cache_node_type: ?[]const u8 = null,
            duration: ?i64 = null,
            fixed_price: ?f64 = null,
            usage_price: ?f64 = null,
            product_description: ?[]const u8 = null,
            offering_type: ?[]const u8 = null,
            recurring_charges: ?[]RecurringCharge = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reserved_cache_nodes_offering_id = "ReservedCacheNodesOfferingId",
                    .cache_node_type = "CacheNodeType",
                    .duration = "Duration",
                    .fixed_price = "FixedPrice",
                    .usage_price = "UsagePrice",
                    .product_description = "ProductDescription",
                    .offering_type = "OfferingType",
                    .recurring_charges = "RecurringCharges",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .reserved_cache_nodes_offerings = "ReservedCacheNodesOfferings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ReservedCacheNodesOfferingNotFound,
    },
} = .{};
pub const describe_serverless_caches: struct {
    action_name: []const u8 = "DescribeServerlessCaches",
    Request: type = struct {
        serverless_cache_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_name = "ServerlessCacheName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_serverless_caches) } {
            return .{ .service_metadata = service_metadata, .action = describe_serverless_caches };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        serverless_caches: ?[]ServerlessCache = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .serverless_caches = "ServerlessCaches",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ServerlessCacheNotFound,
    },
} = .{};
pub const describe_serverless_cache_snapshots: struct {
    action_name: []const u8 = "DescribeServerlessCacheSnapshots",
    Request: type = struct {
        serverless_cache_name: ?[]const u8 = null,
        serverless_cache_snapshot_name: ?[]const u8 = null,
        snapshot_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_name = "ServerlessCacheName",
                .serverless_cache_snapshot_name = "ServerlessCacheSnapshotName",
                .snapshot_type = "SnapshotType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_serverless_cache_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_serverless_cache_snapshots };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        serverless_cache_snapshots: ?[]ServerlessCacheSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .serverless_cache_snapshots = "ServerlessCacheSnapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ServerlessCacheNotFound,
        ServerlessCacheSnapshotNotFound,
    },
} = .{};
pub const describe_service_updates: struct {
    action_name: []const u8 = "DescribeServiceUpdates",
    Request: type = struct {
        service_update_name: ?[]const u8 = null,
        service_update_status: ?[][]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_update_name = "ServiceUpdateName",
                .service_update_status = "ServiceUpdateStatus",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_service_updates) } {
            return .{ .service_metadata = service_metadata, .action = describe_service_updates };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        service_updates: ?[]struct {
            service_update_name: ?[]const u8 = null,
            service_update_release_date: ?i64 = null,
            service_update_end_date: ?i64 = null,
            service_update_severity: ?[]const u8 = null,
            service_update_recommended_apply_by_date: ?i64 = null,
            service_update_status: ?[]const u8 = null,
            service_update_description: ?[]const u8 = null,
            service_update_type: ?[]const u8 = null,
            engine: ?[]const u8 = null,
            engine_version: ?[]const u8 = null,
            auto_update_after_recommended_apply_by_date: ?bool = null,
            estimated_update_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_update_name = "ServiceUpdateName",
                    .service_update_release_date = "ServiceUpdateReleaseDate",
                    .service_update_end_date = "ServiceUpdateEndDate",
                    .service_update_severity = "ServiceUpdateSeverity",
                    .service_update_recommended_apply_by_date = "ServiceUpdateRecommendedApplyByDate",
                    .service_update_status = "ServiceUpdateStatus",
                    .service_update_description = "ServiceUpdateDescription",
                    .service_update_type = "ServiceUpdateType",
                    .engine = "Engine",
                    .engine_version = "EngineVersion",
                    .auto_update_after_recommended_apply_by_date = "AutoUpdateAfterRecommendedApplyByDate",
                    .estimated_update_time = "EstimatedUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .service_updates = "ServiceUpdates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceUpdateNotFound,
    },
} = .{};
pub const describe_snapshots: struct {
    action_name: []const u8 = "DescribeSnapshots",
    Request: type = struct {
        replication_group_id: ?[]const u8 = null,
        cache_cluster_id: ?[]const u8 = null,
        snapshot_name: ?[]const u8 = null,
        snapshot_source: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,
        show_node_group_config: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .cache_cluster_id = "CacheClusterId",
                .snapshot_name = "SnapshotName",
                .snapshot_source = "SnapshotSource",
                .marker = "Marker",
                .max_records = "MaxRecords",
                .show_node_group_config = "ShowNodeGroupConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshots };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        snapshots: ?[]Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .snapshots = "Snapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
        SnapshotNotFound,
    },
} = .{};
pub const describe_update_actions: struct {
    action_name: []const u8 = "DescribeUpdateActions",
    Request: type = struct {
        service_update_name: ?[]const u8 = null,
        replication_group_ids: ?[][]const u8 = null,
        cache_cluster_ids: ?[][]const u8 = null,
        engine: ?[]const u8 = null,
        service_update_status: ?[][]const u8 = null,
        service_update_time_range: ?struct {
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        update_action_status: ?[][]const u8 = null,
        show_node_level_update_status: ?bool = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_update_name = "ServiceUpdateName",
                .replication_group_ids = "ReplicationGroupIds",
                .cache_cluster_ids = "CacheClusterIds",
                .engine = "Engine",
                .service_update_status = "ServiceUpdateStatus",
                .service_update_time_range = "ServiceUpdateTimeRange",
                .update_action_status = "UpdateActionStatus",
                .show_node_level_update_status = "ShowNodeLevelUpdateStatus",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_update_actions) } {
            return .{ .service_metadata = service_metadata, .action = describe_update_actions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        update_actions: ?[]struct {
            replication_group_id: ?[]const u8 = null,
            cache_cluster_id: ?[]const u8 = null,
            service_update_name: ?[]const u8 = null,
            service_update_release_date: ?i64 = null,
            service_update_severity: ?[]const u8 = null,
            service_update_status: ?[]const u8 = null,
            service_update_recommended_apply_by_date: ?i64 = null,
            service_update_type: ?[]const u8 = null,
            update_action_available_date: ?i64 = null,
            update_action_status: ?[]const u8 = null,
            nodes_updated: ?[]const u8 = null,
            update_action_status_modified_date: ?i64 = null,
            sla_met: ?[]const u8 = null,
            node_group_update_status: ?[]struct {
                node_group_id: ?[]const u8 = null,
                node_group_member_update_status: ?[]struct {
                    cache_cluster_id: ?[]const u8 = null,
                    cache_node_id: ?[]const u8 = null,
                    node_update_status: ?[]const u8 = null,
                    node_deletion_date: ?i64 = null,
                    node_update_start_date: ?i64 = null,
                    node_update_end_date: ?i64 = null,
                    node_update_initiated_by: ?[]const u8 = null,
                    node_update_initiated_date: ?i64 = null,
                    node_update_status_modified_date: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cache_cluster_id = "CacheClusterId",
                            .cache_node_id = "CacheNodeId",
                            .node_update_status = "NodeUpdateStatus",
                            .node_deletion_date = "NodeDeletionDate",
                            .node_update_start_date = "NodeUpdateStartDate",
                            .node_update_end_date = "NodeUpdateEndDate",
                            .node_update_initiated_by = "NodeUpdateInitiatedBy",
                            .node_update_initiated_date = "NodeUpdateInitiatedDate",
                            .node_update_status_modified_date = "NodeUpdateStatusModifiedDate",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .node_group_id = "NodeGroupId",
                        .node_group_member_update_status = "NodeGroupMemberUpdateStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            cache_node_update_status: ?[]struct {
                cache_node_id: ?[]const u8 = null,
                node_update_status: ?[]const u8 = null,
                node_deletion_date: ?i64 = null,
                node_update_start_date: ?i64 = null,
                node_update_end_date: ?i64 = null,
                node_update_initiated_by: ?[]const u8 = null,
                node_update_initiated_date: ?i64 = null,
                node_update_status_modified_date: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cache_node_id = "CacheNodeId",
                        .node_update_status = "NodeUpdateStatus",
                        .node_deletion_date = "NodeDeletionDate",
                        .node_update_start_date = "NodeUpdateStartDate",
                        .node_update_end_date = "NodeUpdateEndDate",
                        .node_update_initiated_by = "NodeUpdateInitiatedBy",
                        .node_update_initiated_date = "NodeUpdateInitiatedDate",
                        .node_update_status_modified_date = "NodeUpdateStatusModifiedDate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            estimated_update_time: ?[]const u8 = null,
            engine: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_group_id = "ReplicationGroupId",
                    .cache_cluster_id = "CacheClusterId",
                    .service_update_name = "ServiceUpdateName",
                    .service_update_release_date = "ServiceUpdateReleaseDate",
                    .service_update_severity = "ServiceUpdateSeverity",
                    .service_update_status = "ServiceUpdateStatus",
                    .service_update_recommended_apply_by_date = "ServiceUpdateRecommendedApplyByDate",
                    .service_update_type = "ServiceUpdateType",
                    .update_action_available_date = "UpdateActionAvailableDate",
                    .update_action_status = "UpdateActionStatus",
                    .nodes_updated = "NodesUpdated",
                    .update_action_status_modified_date = "UpdateActionStatusModifiedDate",
                    .sla_met = "SlaMet",
                    .node_group_update_status = "NodeGroupUpdateStatus",
                    .cache_node_update_status = "CacheNodeUpdateStatus",
                    .estimated_update_time = "EstimatedUpdateTime",
                    .engine = "Engine",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .update_actions = "UpdateActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_user_groups: struct {
    action_name: []const u8 = "DescribeUserGroups",
    Request: type = struct {
        user_group_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_group_id = "UserGroupId",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_groups };
        }
    },
    Response: type = struct {
        user_groups: ?[]UserGroup = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_groups = "UserGroups",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        ServiceLinkedRoleNotFound,
        UserGroupNotFound,
    },
} = .{};
pub const describe_users: struct {
    action_name: []const u8 = "DescribeUsers",
    Request: type = struct {
        engine: ?[]const u8 = null,
        user_id: ?[]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .user_id = "UserId",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_users) } {
            return .{ .service_metadata = service_metadata, .action = describe_users };
        }
    },
    Response: type = struct {
        users: ?[]User = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        ServiceLinkedRoleNotFound,
        UserNotFound,
    },
} = .{};
pub const disassociate_global_replication_group: struct {
    action_name: []const u8 = "DisassociateGlobalReplicationGroup",
    Request: type = struct {
        global_replication_group_id: []const u8,
        replication_group_id: []const u8,
        replication_group_region: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id = "GlobalReplicationGroupId",
                .replication_group_id = "ReplicationGroupId",
                .replication_group_region = "ReplicationGroupRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_global_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_global_replication_group };
        }
    },
    Response: type = struct {
        global_replication_group: ?GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group = "GlobalReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupNotFound,
        InvalidGlobalReplicationGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const export_serverless_cache_snapshot: struct {
    action_name: []const u8 = "ExportServerlessCacheSnapshot",
    Request: type = struct {
        serverless_cache_snapshot_name: []const u8,
        s3_bucket_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_snapshot_name = "ServerlessCacheSnapshotName",
                .s3_bucket_name = "S3BucketName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_serverless_cache_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = export_serverless_cache_snapshot };
        }
    },
    Response: type = struct {
        serverless_cache_snapshot: ?ServerlessCacheSnapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_snapshot = "ServerlessCacheSnapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidServerlessCacheSnapshotState,
        ServerlessCacheSnapshotNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const failover_global_replication_group: struct {
    action_name: []const u8 = "FailoverGlobalReplicationGroup",
    Request: type = struct {
        global_replication_group_id: []const u8,
        primary_region: []const u8,
        primary_replication_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id = "GlobalReplicationGroupId",
                .primary_region = "PrimaryRegion",
                .primary_replication_group_id = "PrimaryReplicationGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(failover_global_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = failover_global_replication_group };
        }
    },
    Response: type = struct {
        global_replication_group: ?GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group = "GlobalReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupNotFound,
        InvalidGlobalReplicationGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const increase_node_groups_in_global_replication_group: struct {
    action_name: []const u8 = "IncreaseNodeGroupsInGlobalReplicationGroup",
    Request: type = struct {
        global_replication_group_id: []const u8,
        node_group_count: i64,
        regional_configurations: ?[]struct {
            replication_group_id: []const u8,
            replication_group_region: []const u8,
            resharding_configuration: []ReshardingConfiguration,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_group_id = "ReplicationGroupId",
                    .replication_group_region = "ReplicationGroupRegion",
                    .resharding_configuration = "ReshardingConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        apply_immediately: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id = "GlobalReplicationGroupId",
                .node_group_count = "NodeGroupCount",
                .regional_configurations = "RegionalConfigurations",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(increase_node_groups_in_global_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = increase_node_groups_in_global_replication_group };
        }
    },
    Response: type = struct {
        global_replication_group: ?GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group = "GlobalReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupNotFound,
        InvalidGlobalReplicationGroupState,
        InvalidParameterValue,
    },
} = .{};
pub const increase_replica_count: struct {
    action_name: []const u8 = "IncreaseReplicaCount",
    Request: type = struct {
        replication_group_id: []const u8,
        new_replica_count: ?i64 = null,
        replica_configuration: ?[]ConfigureShard = null,
        apply_immediately: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .new_replica_count = "NewReplicaCount",
                .replica_configuration = "ReplicaConfiguration",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(increase_replica_count) } {
            return .{ .service_metadata = service_metadata, .action = increase_replica_count };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterQuotaForCustomerExceeded,
        InsufficientCacheClusterCapacity,
        InvalidCacheClusterState,
        InvalidKMSKey,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        InvalidVPCNetworkState,
        NodeGroupsPerReplicationGroupQuotaExceeded,
        NodeQuotaForCustomerExceeded,
        NoOperation,
        ReplicationGroupNotFound,
    },
} = .{};
pub const list_allowed_node_type_modifications: struct {
    action_name: []const u8 = "ListAllowedNodeTypeModifications",
    Request: type = struct {
        cache_cluster_id: ?[]const u8 = null,
        replication_group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster_id = "CacheClusterId",
                .replication_group_id = "ReplicationGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_allowed_node_type_modifications) } {
            return .{ .service_metadata = service_metadata, .action = list_allowed_node_type_modifications };
        }
    },
    Response: type = struct {
        scale_up_modifications: ?[][]const u8 = null,
        scale_down_modifications: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scale_up_modifications = "ScaleUpModifications",
                .scale_down_modifications = "ScaleDownModifications",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
        ReplicationGroupNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        CacheParameterGroupNotFound,
        CacheSecurityGroupNotFound,
        CacheSubnetGroupNotFound,
        InvalidARN,
        InvalidReplicationGroupState,
        InvalidServerlessCacheSnapshotState,
        InvalidServerlessCacheState,
        ReplicationGroupNotFound,
        ReservedCacheNodeNotFound,
        ServerlessCacheNotFound,
        ServerlessCacheSnapshotNotFound,
        SnapshotNotFound,
        UserGroupNotFound,
        UserNotFound,
    },
} = .{};
pub const modify_cache_cluster: struct {
    action_name: []const u8 = "ModifyCacheCluster",
    Request: type = struct {
        cache_cluster_id: []const u8,
        num_cache_nodes: ?i64 = null,
        cache_node_ids_to_remove: ?[][]const u8 = null,
        az_mode: ?[]const u8 = null,
        new_availability_zones: ?[][]const u8 = null,
        cache_security_group_names: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        notification_topic_arn: ?[]const u8 = null,
        cache_parameter_group_name: ?[]const u8 = null,
        notification_topic_status: ?[]const u8 = null,
        apply_immediately: ?bool = null,
        engine_version: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        snapshot_retention_limit: ?i64 = null,
        snapshot_window: ?[]const u8 = null,
        cache_node_type: ?[]const u8 = null,
        auth_token: ?[]const u8 = null,
        auth_token_update_strategy: ?[]const u8 = null,
        log_delivery_configurations: ?[]LogDeliveryConfigurationRequest = null,
        ip_discovery: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster_id = "CacheClusterId",
                .num_cache_nodes = "NumCacheNodes",
                .cache_node_ids_to_remove = "CacheNodeIdsToRemove",
                .az_mode = "AZMode",
                .new_availability_zones = "NewAvailabilityZones",
                .cache_security_group_names = "CacheSecurityGroupNames",
                .security_group_ids = "SecurityGroupIds",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .notification_topic_arn = "NotificationTopicArn",
                .cache_parameter_group_name = "CacheParameterGroupName",
                .notification_topic_status = "NotificationTopicStatus",
                .apply_immediately = "ApplyImmediately",
                .engine_version = "EngineVersion",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .snapshot_retention_limit = "SnapshotRetentionLimit",
                .snapshot_window = "SnapshotWindow",
                .cache_node_type = "CacheNodeType",
                .auth_token = "AuthToken",
                .auth_token_update_strategy = "AuthTokenUpdateStrategy",
                .log_delivery_configurations = "LogDeliveryConfigurations",
                .ip_discovery = "IpDiscovery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cache_cluster) } {
            return .{ .service_metadata = service_metadata, .action = modify_cache_cluster };
        }
    },
    Response: type = struct {
        cache_cluster: ?CacheCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster = "CacheCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        CacheParameterGroupNotFound,
        CacheSecurityGroupNotFound,
        InsufficientCacheClusterCapacity,
        InvalidCacheClusterState,
        InvalidCacheSecurityGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidVPCNetworkState,
        NodeQuotaForClusterExceeded,
        NodeQuotaForCustomerExceeded,
    },
} = .{};
pub const modify_cache_parameter_group: struct {
    action_name: []const u8 = "ModifyCacheParameterGroup",
    Request: type = struct {
        cache_parameter_group_name: []const u8,
        parameter_name_values: []ParameterNameValue,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_name = "CacheParameterGroupName",
                .parameter_name_values = "ParameterNameValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cache_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_cache_parameter_group };
        }
    },
    Response: type = struct {
        cache_parameter_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_name = "CacheParameterGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheParameterGroupNotFound,
        InvalidCacheParameterGroupState,
        InvalidGlobalReplicationGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const modify_cache_subnet_group: struct {
    action_name: []const u8 = "ModifyCacheSubnetGroup",
    Request: type = struct {
        cache_subnet_group_name: []const u8,
        cache_subnet_group_description: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_subnet_group_name = "CacheSubnetGroupName",
                .cache_subnet_group_description = "CacheSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cache_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_cache_subnet_group };
        }
    },
    Response: type = struct {
        cache_subnet_group: ?CacheSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_subnet_group = "CacheSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheSubnetGroupNotFound,
        CacheSubnetQuotaExceeded,
        InvalidSubnet,
        SubnetInUse,
        SubnetNotAllowed,
    },
} = .{};
pub const modify_global_replication_group: struct {
    action_name: []const u8 = "ModifyGlobalReplicationGroup",
    Request: type = struct {
        global_replication_group_id: []const u8,
        apply_immediately: bool,
        cache_node_type: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        cache_parameter_group_name: ?[]const u8 = null,
        global_replication_group_description: ?[]const u8 = null,
        automatic_failover_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id = "GlobalReplicationGroupId",
                .apply_immediately = "ApplyImmediately",
                .cache_node_type = "CacheNodeType",
                .engine_version = "EngineVersion",
                .cache_parameter_group_name = "CacheParameterGroupName",
                .global_replication_group_description = "GlobalReplicationGroupDescription",
                .automatic_failover_enabled = "AutomaticFailoverEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_global_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_global_replication_group };
        }
    },
    Response: type = struct {
        global_replication_group: ?GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group = "GlobalReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupNotFound,
        InvalidGlobalReplicationGroupState,
        InvalidParameterValue,
    },
} = .{};
pub const modify_replication_group: struct {
    action_name: []const u8 = "ModifyReplicationGroup",
    Request: type = struct {
        replication_group_id: []const u8,
        replication_group_description: ?[]const u8 = null,
        primary_cluster_id: ?[]const u8 = null,
        snapshotting_cluster_id: ?[]const u8 = null,
        automatic_failover_enabled: ?bool = null,
        multi_az_enabled: ?bool = null,
        node_group_id: ?[]const u8 = null,
        cache_security_group_names: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        notification_topic_arn: ?[]const u8 = null,
        cache_parameter_group_name: ?[]const u8 = null,
        notification_topic_status: ?[]const u8 = null,
        apply_immediately: ?bool = null,
        engine_version: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        snapshot_retention_limit: ?i64 = null,
        snapshot_window: ?[]const u8 = null,
        cache_node_type: ?[]const u8 = null,
        auth_token: ?[]const u8 = null,
        auth_token_update_strategy: ?[]const u8 = null,
        user_group_ids_to_add: ?[][]const u8 = null,
        user_group_ids_to_remove: ?[][]const u8 = null,
        remove_user_groups: ?bool = null,
        log_delivery_configurations: ?[]LogDeliveryConfigurationRequest = null,
        ip_discovery: ?[]const u8 = null,
        transit_encryption_enabled: ?bool = null,
        transit_encryption_mode: ?[]const u8 = null,
        cluster_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .replication_group_description = "ReplicationGroupDescription",
                .primary_cluster_id = "PrimaryClusterId",
                .snapshotting_cluster_id = "SnapshottingClusterId",
                .automatic_failover_enabled = "AutomaticFailoverEnabled",
                .multi_az_enabled = "MultiAZEnabled",
                .node_group_id = "NodeGroupId",
                .cache_security_group_names = "CacheSecurityGroupNames",
                .security_group_ids = "SecurityGroupIds",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .notification_topic_arn = "NotificationTopicArn",
                .cache_parameter_group_name = "CacheParameterGroupName",
                .notification_topic_status = "NotificationTopicStatus",
                .apply_immediately = "ApplyImmediately",
                .engine_version = "EngineVersion",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .snapshot_retention_limit = "SnapshotRetentionLimit",
                .snapshot_window = "SnapshotWindow",
                .cache_node_type = "CacheNodeType",
                .auth_token = "AuthToken",
                .auth_token_update_strategy = "AuthTokenUpdateStrategy",
                .user_group_ids_to_add = "UserGroupIdsToAdd",
                .user_group_ids_to_remove = "UserGroupIdsToRemove",
                .remove_user_groups = "RemoveUserGroups",
                .log_delivery_configurations = "LogDeliveryConfigurations",
                .ip_discovery = "IpDiscovery",
                .transit_encryption_enabled = "TransitEncryptionEnabled",
                .transit_encryption_mode = "TransitEncryptionMode",
                .cluster_mode = "ClusterMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_group };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        CacheParameterGroupNotFound,
        CacheSecurityGroupNotFound,
        InsufficientCacheClusterCapacity,
        InvalidCacheClusterState,
        InvalidCacheSecurityGroupState,
        InvalidKMSKey,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        InvalidUserGroupState,
        InvalidVPCNetworkState,
        NodeQuotaForClusterExceeded,
        NodeQuotaForCustomerExceeded,
        ReplicationGroupNotFound,
        UserGroupNotFound,
    },
} = .{};
pub const modify_replication_group_shard_configuration: struct {
    action_name: []const u8 = "ModifyReplicationGroupShardConfiguration",
    Request: type = struct {
        replication_group_id: []const u8,
        node_group_count: i64,
        apply_immediately: bool,
        resharding_configuration: ?[]ReshardingConfiguration = null,
        node_groups_to_remove: ?[][]const u8 = null,
        node_groups_to_retain: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .node_group_count = "NodeGroupCount",
                .apply_immediately = "ApplyImmediately",
                .resharding_configuration = "ReshardingConfiguration",
                .node_groups_to_remove = "NodeGroupsToRemove",
                .node_groups_to_retain = "NodeGroupsToRetain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_group_shard_configuration) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_group_shard_configuration };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientCacheClusterCapacity,
        InvalidCacheClusterState,
        InvalidKMSKey,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        InvalidVPCNetworkState,
        NodeGroupsPerReplicationGroupQuotaExceeded,
        NodeQuotaForCustomerExceeded,
        ReplicationGroupNotFound,
    },
} = .{};
pub const modify_serverless_cache: struct {
    action_name: []const u8 = "ModifyServerlessCache",
    Request: type = struct {
        serverless_cache_name: []const u8,
        description: ?[]const u8 = null,
        cache_usage_limits: ?CacheUsageLimits = null,
        remove_user_group: ?bool = null,
        user_group_id: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        snapshot_retention_limit: ?i64 = null,
        daily_snapshot_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache_name = "ServerlessCacheName",
                .description = "Description",
                .cache_usage_limits = "CacheUsageLimits",
                .remove_user_group = "RemoveUserGroup",
                .user_group_id = "UserGroupId",
                .security_group_ids = "SecurityGroupIds",
                .snapshot_retention_limit = "SnapshotRetentionLimit",
                .daily_snapshot_time = "DailySnapshotTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_serverless_cache) } {
            return .{ .service_metadata = service_metadata, .action = modify_serverless_cache };
        }
    },
    Response: type = struct {
        serverless_cache: ?ServerlessCache = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serverless_cache = "ServerlessCache",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidCredentials,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidServerlessCacheState,
        InvalidUserGroupState,
        ServerlessCacheNotFound,
        ServiceLinkedRoleNotFound,
        UserGroupNotFound,
    },
} = .{};
pub const modify_user: struct {
    action_name: []const u8 = "ModifyUser",
    Request: type = struct {
        user_id: []const u8,
        access_string: ?[]const u8 = null,
        append_access_string: ?[]const u8 = null,
        passwords: ?[][]const u8 = null,
        no_password_required: ?bool = null,
        authentication_mode: ?AuthenticationMode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .access_string = "AccessString",
                .append_access_string = "AppendAccessString",
                .passwords = "Passwords",
                .no_password_required = "NoPasswordRequired",
                .authentication_mode = "AuthenticationMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_user) } {
            return .{ .service_metadata = service_metadata, .action = modify_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        user_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        minimum_engine_version: ?[]const u8 = null,
        access_string: ?[]const u8 = null,
        user_group_ids: ?[][]const u8 = null,
        authentication: ?Authentication = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .user_name = "UserName",
                .status = "Status",
                .engine = "Engine",
                .minimum_engine_version = "MinimumEngineVersion",
                .access_string = "AccessString",
                .user_group_ids = "UserGroupIds",
                .authentication = "Authentication",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidUserState,
        ServiceLinkedRoleNotFound,
        UserNotFound,
    },
} = .{};
pub const modify_user_group: struct {
    action_name: []const u8 = "ModifyUserGroup",
    Request: type = struct {
        user_group_id: []const u8,
        user_ids_to_add: ?[][]const u8 = null,
        user_ids_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_group_id = "UserGroupId",
                .user_ids_to_add = "UserIdsToAdd",
                .user_ids_to_remove = "UserIdsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_user_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_user_group };
        }
    },
    Response: type = struct {
        user_group_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        user_ids: ?[][]const u8 = null,
        minimum_engine_version: ?[]const u8 = null,
        pending_changes: ?UserGroupPendingChanges = null,
        replication_groups: ?[][]const u8 = null,
        serverless_caches: ?[][]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_group_id = "UserGroupId",
                .status = "Status",
                .engine = "Engine",
                .user_ids = "UserIds",
                .minimum_engine_version = "MinimumEngineVersion",
                .pending_changes = "PendingChanges",
                .replication_groups = "ReplicationGroups",
                .serverless_caches = "ServerlessCaches",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DefaultUserRequired,
        DuplicateUserName,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidUserGroupState,
        ServiceLinkedRoleNotFound,
        UserGroupNotFound,
        UserNotFound,
    },
} = .{};
pub const purchase_reserved_cache_nodes_offering: struct {
    action_name: []const u8 = "PurchaseReservedCacheNodesOffering",
    Request: type = struct {
        reserved_cache_nodes_offering_id: []const u8,
        reserved_cache_node_id: ?[]const u8 = null,
        cache_node_count: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_cache_nodes_offering_id = "ReservedCacheNodesOfferingId",
                .reserved_cache_node_id = "ReservedCacheNodeId",
                .cache_node_count = "CacheNodeCount",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_reserved_cache_nodes_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_reserved_cache_nodes_offering };
        }
    },
    Response: type = struct {
        reserved_cache_node: ?ReservedCacheNode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_cache_node = "ReservedCacheNode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ReservedCacheNodeAlreadyExists,
        ReservedCacheNodeQuotaExceeded,
        ReservedCacheNodesOfferingNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const rebalance_slots_in_global_replication_group: struct {
    action_name: []const u8 = "RebalanceSlotsInGlobalReplicationGroup",
    Request: type = struct {
        global_replication_group_id: []const u8,
        apply_immediately: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group_id = "GlobalReplicationGroupId",
                .apply_immediately = "ApplyImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rebalance_slots_in_global_replication_group) } {
            return .{ .service_metadata = service_metadata, .action = rebalance_slots_in_global_replication_group };
        }
    },
    Response: type = struct {
        global_replication_group: ?GlobalReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_replication_group = "GlobalReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlobalReplicationGroupNotFound,
        InvalidGlobalReplicationGroupState,
        InvalidParameterValue,
    },
} = .{};
pub const reboot_cache_cluster: struct {
    action_name: []const u8 = "RebootCacheCluster",
    Request: type = struct {
        cache_cluster_id: []const u8,
        cache_node_ids_to_reboot: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster_id = "CacheClusterId",
                .cache_node_ids_to_reboot = "CacheNodeIdsToReboot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_cache_cluster) } {
            return .{ .service_metadata = service_metadata, .action = reboot_cache_cluster };
        }
    },
    Response: type = struct {
        cache_cluster: ?CacheCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_cluster = "CacheCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        InvalidCacheClusterState,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_name: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheClusterNotFound,
        CacheParameterGroupNotFound,
        CacheSecurityGroupNotFound,
        CacheSubnetGroupNotFound,
        InvalidARN,
        InvalidReplicationGroupState,
        InvalidServerlessCacheSnapshotState,
        InvalidServerlessCacheState,
        ReplicationGroupNotFound,
        ReservedCacheNodeNotFound,
        ServerlessCacheNotFound,
        ServerlessCacheSnapshotNotFound,
        SnapshotNotFound,
        TagNotFound,
        UserGroupNotFound,
        UserNotFound,
    },
} = .{};
pub const reset_cache_parameter_group: struct {
    action_name: []const u8 = "ResetCacheParameterGroup",
    Request: type = struct {
        cache_parameter_group_name: []const u8,
        reset_all_parameters: ?bool = null,
        parameter_name_values: ?[]ParameterNameValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_name = "CacheParameterGroupName",
                .reset_all_parameters = "ResetAllParameters",
                .parameter_name_values = "ParameterNameValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_cache_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = reset_cache_parameter_group };
        }
    },
    Response: type = struct {
        cache_parameter_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_parameter_group_name = "CacheParameterGroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CacheParameterGroupNotFound,
        InvalidCacheParameterGroupState,
        InvalidGlobalReplicationGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const revoke_cache_security_group_ingress: struct {
    action_name: []const u8 = "RevokeCacheSecurityGroupIngress",
    Request: type = struct {
        cache_security_group_name: []const u8,
        ec2_security_group_name: []const u8,
        ec2_security_group_owner_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_security_group_name = "CacheSecurityGroupName",
                .ec2_security_group_name = "EC2SecurityGroupName",
                .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_cache_security_group_ingress) } {
            return .{ .service_metadata = service_metadata, .action = revoke_cache_security_group_ingress };
        }
    },
    Response: type = struct {
        cache_security_group: ?CacheSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cache_security_group = "CacheSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        CacheSecurityGroupNotFound,
        InvalidCacheSecurityGroupState,
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const start_migration: struct {
    action_name: []const u8 = "StartMigration",
    Request: type = struct {
        replication_group_id: []const u8,
        customer_node_endpoint_list: []CustomerNodeEndpoint,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .customer_node_endpoint_list = "CustomerNodeEndpointList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_migration) } {
            return .{ .service_metadata = service_metadata, .action = start_migration };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidReplicationGroupState,
        ReplicationGroupAlreadyUnderMigration,
        ReplicationGroupNotFound,
    },
} = .{};
pub const test_failover: struct {
    action_name: []const u8 = "TestFailover",
    Request: type = struct {
        replication_group_id: []const u8,
        node_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .node_group_id = "NodeGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_failover) } {
            return .{ .service_metadata = service_metadata, .action = test_failover };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        APICallRateForCustomerExceeded,
        InvalidCacheClusterState,
        InvalidKMSKey,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidReplicationGroupState,
        NodeGroupNotFound,
        ReplicationGroupNotFound,
        TestFailoverNotAvailable,
    },
} = .{};
pub const test_migration: struct {
    action_name: []const u8 = "TestMigration",
    Request: type = struct {
        replication_group_id: []const u8,
        customer_node_endpoint_list: []CustomerNodeEndpoint,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group_id = "ReplicationGroupId",
                .customer_node_endpoint_list = "CustomerNodeEndpointList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_migration) } {
            return .{ .service_metadata = service_metadata, .action = test_migration };
        }
    },
    Response: type = struct {
        replication_group: ?ReplicationGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_group = "ReplicationGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidReplicationGroupState,
        ReplicationGroupAlreadyUnderMigration,
        ReplicationGroupNotFound,
    },
} = .{};

pub const ReplicationGroup = struct {
    replication_group_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    global_replication_group_info: ?GlobalReplicationGroupInfo = null,
    status: ?[]const u8 = null,
    pending_modified_values: ?ReplicationGroupPendingModifiedValues = null,
    member_clusters: ?[][]const u8 = null,
    node_groups: ?[]NodeGroup = null,
    snapshotting_cluster_id: ?[]const u8 = null,
    automatic_failover: ?[]const u8 = null,
    multi_az: ?[]const u8 = null,
    configuration_endpoint: ?Endpoint = null,
    snapshot_retention_limit: ?i64 = null,
    snapshot_window: ?[]const u8 = null,
    cluster_enabled: ?bool = null,
    cache_node_type: ?[]const u8 = null,
    auth_token_enabled: ?bool = null,
    auth_token_last_modified_date: ?i64 = null,
    transit_encryption_enabled: ?bool = null,
    at_rest_encryption_enabled: ?bool = null,
    member_clusters_outpost_arns: ?[][]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    user_group_ids: ?[][]const u8 = null,
    log_delivery_configurations: ?[]LogDeliveryConfiguration = null,
    replication_group_create_time: ?i64 = null,
    data_tiering: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    network_type: ?[]const u8 = null,
    ip_discovery: ?[]const u8 = null,
    transit_encryption_mode: ?[]const u8 = null,
    cluster_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_group_id = "ReplicationGroupId",
            .description = "Description",
            .global_replication_group_info = "GlobalReplicationGroupInfo",
            .status = "Status",
            .pending_modified_values = "PendingModifiedValues",
            .member_clusters = "MemberClusters",
            .node_groups = "NodeGroups",
            .snapshotting_cluster_id = "SnapshottingClusterId",
            .automatic_failover = "AutomaticFailover",
            .multi_az = "MultiAZ",
            .configuration_endpoint = "ConfigurationEndpoint",
            .snapshot_retention_limit = "SnapshotRetentionLimit",
            .snapshot_window = "SnapshotWindow",
            .cluster_enabled = "ClusterEnabled",
            .cache_node_type = "CacheNodeType",
            .auth_token_enabled = "AuthTokenEnabled",
            .auth_token_last_modified_date = "AuthTokenLastModifiedDate",
            .transit_encryption_enabled = "TransitEncryptionEnabled",
            .at_rest_encryption_enabled = "AtRestEncryptionEnabled",
            .member_clusters_outpost_arns = "MemberClustersOutpostArns",
            .kms_key_id = "KmsKeyId",
            .arn = "ARN",
            .user_group_ids = "UserGroupIds",
            .log_delivery_configurations = "LogDeliveryConfigurations",
            .replication_group_create_time = "ReplicationGroupCreateTime",
            .data_tiering = "DataTiering",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .network_type = "NetworkType",
            .ip_discovery = "IpDiscovery",
            .transit_encryption_mode = "TransitEncryptionMode",
            .cluster_mode = "ClusterMode",
        };
        return @field(mappings, field_name);
    }
};

pub const LogDeliveryConfiguration = struct {
    log_type: ?[]const u8 = null,
    destination_type: ?[]const u8 = null,
    destination_details: ?DestinationDetails = null,
    log_format: ?[]const u8 = null,
    status: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_type = "LogType",
            .destination_type = "DestinationType",
            .destination_details = "DestinationDetails",
            .log_format = "LogFormat",
            .status = "Status",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationDetails = struct {
    cloud_watch_logs_details: ?CloudWatchLogsDestinationDetails = null,
    kinesis_firehose_details: ?KinesisFirehoseDestinationDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_details = "CloudWatchLogsDetails",
            .kinesis_firehose_details = "KinesisFirehoseDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisFirehoseDestinationDetails = struct {
    delivery_stream: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_stream = "DeliveryStream",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogsDestinationDetails = struct {
    log_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group = "LogGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeGroup = struct {
    node_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    primary_endpoint: ?Endpoint = null,
    reader_endpoint: ?Endpoint = null,
    slots: ?[]const u8 = null,
    node_group_members: ?[]NodeGroupMember = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_group_id = "NodeGroupId",
            .status = "Status",
            .primary_endpoint = "PrimaryEndpoint",
            .reader_endpoint = "ReaderEndpoint",
            .slots = "Slots",
            .node_group_members = "NodeGroupMembers",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeGroupMember = struct {
    cache_cluster_id: ?[]const u8 = null,
    cache_node_id: ?[]const u8 = null,
    read_endpoint: ?Endpoint = null,
    preferred_availability_zone: ?[]const u8 = null,
    preferred_outpost_arn: ?[]const u8 = null,
    current_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_cluster_id = "CacheClusterId",
            .cache_node_id = "CacheNodeId",
            .read_endpoint = "ReadEndpoint",
            .preferred_availability_zone = "PreferredAvailabilityZone",
            .preferred_outpost_arn = "PreferredOutpostArn",
            .current_role = "CurrentRole",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationGroupPendingModifiedValues = struct {
    primary_cluster_id: ?[]const u8 = null,
    automatic_failover_status: ?[]const u8 = null,
    resharding: ?ReshardingStatus = null,
    auth_token_status: ?[]const u8 = null,
    user_groups: ?UserGroupsUpdateStatus = null,
    log_delivery_configurations: ?[]PendingLogDeliveryConfiguration = null,
    transit_encryption_enabled: ?bool = null,
    transit_encryption_mode: ?[]const u8 = null,
    cluster_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_cluster_id = "PrimaryClusterId",
            .automatic_failover_status = "AutomaticFailoverStatus",
            .resharding = "Resharding",
            .auth_token_status = "AuthTokenStatus",
            .user_groups = "UserGroups",
            .log_delivery_configurations = "LogDeliveryConfigurations",
            .transit_encryption_enabled = "TransitEncryptionEnabled",
            .transit_encryption_mode = "TransitEncryptionMode",
            .cluster_mode = "ClusterMode",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingLogDeliveryConfiguration = struct {
    log_type: ?[]const u8 = null,
    destination_type: ?[]const u8 = null,
    destination_details: ?DestinationDetails = null,
    log_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_type = "LogType",
            .destination_type = "DestinationType",
            .destination_details = "DestinationDetails",
            .log_format = "LogFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const UserGroupsUpdateStatus = struct {
    user_group_ids_to_add: ?[][]const u8 = null,
    user_group_ids_to_remove: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_group_ids_to_add = "UserGroupIdsToAdd",
            .user_group_ids_to_remove = "UserGroupIdsToRemove",
        };
        return @field(mappings, field_name);
    }
};

pub const ReshardingStatus = struct {
    slot_migration: ?SlotMigration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .slot_migration = "SlotMigration",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotMigration = struct {
    progress_percentage: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .progress_percentage = "ProgressPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalReplicationGroupInfo = struct {
    global_replication_group_id: ?[]const u8 = null,
    global_replication_group_member_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_replication_group_id = "GlobalReplicationGroupId",
            .global_replication_group_member_role = "GlobalReplicationGroupMemberRole",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerNodeEndpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheSecurityGroup = struct {
    owner_id: ?[]const u8 = null,
    cache_security_group_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    ec2_security_groups: ?[]EC2SecurityGroup = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .cache_security_group_name = "CacheSecurityGroupName",
            .description = "Description",
            .ec2_security_groups = "EC2SecurityGroups",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const EC2SecurityGroup = struct {
    status: ?[]const u8 = null,
    ec2_security_group_name: ?[]const u8 = null,
    ec2_security_group_owner_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .ec2_security_group_name = "EC2SecurityGroupName",
            .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterNameValue = struct {
    parameter_name: ?[]const u8 = null,
    parameter_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_value = "ParameterValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheCluster = struct {
    cache_cluster_id: ?[]const u8 = null,
    configuration_endpoint: ?Endpoint = null,
    client_download_landing_page: ?[]const u8 = null,
    cache_node_type: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    cache_cluster_status: ?[]const u8 = null,
    num_cache_nodes: ?i64 = null,
    preferred_availability_zone: ?[]const u8 = null,
    preferred_outpost_arn: ?[]const u8 = null,
    cache_cluster_create_time: ?i64 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    pending_modified_values: ?PendingModifiedValues = null,
    notification_configuration: ?NotificationConfiguration = null,
    cache_security_groups: ?[]CacheSecurityGroupMembership = null,
    cache_parameter_group: ?CacheParameterGroupStatus = null,
    cache_subnet_group_name: ?[]const u8 = null,
    cache_nodes: ?[]CacheNode = null,
    auto_minor_version_upgrade: ?bool = null,
    security_groups: ?[]SecurityGroupMembership = null,
    replication_group_id: ?[]const u8 = null,
    snapshot_retention_limit: ?i64 = null,
    snapshot_window: ?[]const u8 = null,
    auth_token_enabled: ?bool = null,
    auth_token_last_modified_date: ?i64 = null,
    transit_encryption_enabled: ?bool = null,
    at_rest_encryption_enabled: ?bool = null,
    arn: ?[]const u8 = null,
    replication_group_log_delivery_enabled: ?bool = null,
    log_delivery_configurations: ?[]LogDeliveryConfiguration = null,
    network_type: ?[]const u8 = null,
    ip_discovery: ?[]const u8 = null,
    transit_encryption_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_cluster_id = "CacheClusterId",
            .configuration_endpoint = "ConfigurationEndpoint",
            .client_download_landing_page = "ClientDownloadLandingPage",
            .cache_node_type = "CacheNodeType",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .cache_cluster_status = "CacheClusterStatus",
            .num_cache_nodes = "NumCacheNodes",
            .preferred_availability_zone = "PreferredAvailabilityZone",
            .preferred_outpost_arn = "PreferredOutpostArn",
            .cache_cluster_create_time = "CacheClusterCreateTime",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .pending_modified_values = "PendingModifiedValues",
            .notification_configuration = "NotificationConfiguration",
            .cache_security_groups = "CacheSecurityGroups",
            .cache_parameter_group = "CacheParameterGroup",
            .cache_subnet_group_name = "CacheSubnetGroupName",
            .cache_nodes = "CacheNodes",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .security_groups = "SecurityGroups",
            .replication_group_id = "ReplicationGroupId",
            .snapshot_retention_limit = "SnapshotRetentionLimit",
            .snapshot_window = "SnapshotWindow",
            .auth_token_enabled = "AuthTokenEnabled",
            .auth_token_last_modified_date = "AuthTokenLastModifiedDate",
            .transit_encryption_enabled = "TransitEncryptionEnabled",
            .at_rest_encryption_enabled = "AtRestEncryptionEnabled",
            .arn = "ARN",
            .replication_group_log_delivery_enabled = "ReplicationGroupLogDeliveryEnabled",
            .log_delivery_configurations = "LogDeliveryConfigurations",
            .network_type = "NetworkType",
            .ip_discovery = "IpDiscovery",
            .transit_encryption_mode = "TransitEncryptionMode",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityGroupMembership = struct {
    security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_id = "SecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheNode = struct {
    cache_node_id: ?[]const u8 = null,
    cache_node_status: ?[]const u8 = null,
    cache_node_create_time: ?i64 = null,
    endpoint: ?Endpoint = null,
    parameter_group_status: ?[]const u8 = null,
    source_cache_node_id: ?[]const u8 = null,
    customer_availability_zone: ?[]const u8 = null,
    customer_outpost_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_node_id = "CacheNodeId",
            .cache_node_status = "CacheNodeStatus",
            .cache_node_create_time = "CacheNodeCreateTime",
            .endpoint = "Endpoint",
            .parameter_group_status = "ParameterGroupStatus",
            .source_cache_node_id = "SourceCacheNodeId",
            .customer_availability_zone = "CustomerAvailabilityZone",
            .customer_outpost_arn = "CustomerOutpostArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheParameterGroupStatus = struct {
    cache_parameter_group_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,
    cache_node_ids_to_reboot: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_parameter_group_name = "CacheParameterGroupName",
            .parameter_apply_status = "ParameterApplyStatus",
            .cache_node_ids_to_reboot = "CacheNodeIdsToReboot",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheSecurityGroupMembership = struct {
    cache_security_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_security_group_name = "CacheSecurityGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationConfiguration = struct {
    topic_arn: ?[]const u8 = null,
    topic_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
            .topic_status = "TopicStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingModifiedValues = struct {
    num_cache_nodes: ?i64 = null,
    cache_node_ids_to_remove: ?[][]const u8 = null,
    engine_version: ?[]const u8 = null,
    cache_node_type: ?[]const u8 = null,
    auth_token_status: ?[]const u8 = null,
    log_delivery_configurations: ?[]PendingLogDeliveryConfiguration = null,
    transit_encryption_enabled: ?bool = null,
    transit_encryption_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .num_cache_nodes = "NumCacheNodes",
            .cache_node_ids_to_remove = "CacheNodeIdsToRemove",
            .engine_version = "EngineVersion",
            .cache_node_type = "CacheNodeType",
            .auth_token_status = "AuthTokenStatus",
            .log_delivery_configurations = "LogDeliveryConfigurations",
            .transit_encryption_enabled = "TransitEncryptionEnabled",
            .transit_encryption_mode = "TransitEncryptionMode",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalReplicationGroup = struct {
    global_replication_group_id: ?[]const u8 = null,
    global_replication_group_description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    cache_node_type: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    members: ?[]GlobalReplicationGroupMember = null,
    cluster_enabled: ?bool = null,
    global_node_groups: ?[]GlobalNodeGroup = null,
    auth_token_enabled: ?bool = null,
    transit_encryption_enabled: ?bool = null,
    at_rest_encryption_enabled: ?bool = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_replication_group_id = "GlobalReplicationGroupId",
            .global_replication_group_description = "GlobalReplicationGroupDescription",
            .status = "Status",
            .cache_node_type = "CacheNodeType",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .members = "Members",
            .cluster_enabled = "ClusterEnabled",
            .global_node_groups = "GlobalNodeGroups",
            .auth_token_enabled = "AuthTokenEnabled",
            .transit_encryption_enabled = "TransitEncryptionEnabled",
            .at_rest_encryption_enabled = "AtRestEncryptionEnabled",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalNodeGroup = struct {
    global_node_group_id: ?[]const u8 = null,
    slots: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_node_group_id = "GlobalNodeGroupId",
            .slots = "Slots",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalReplicationGroupMember = struct {
    replication_group_id: ?[]const u8 = null,
    replication_group_region: ?[]const u8 = null,
    role: ?[]const u8 = null,
    automatic_failover: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_group_id = "ReplicationGroupId",
            .replication_group_region = "ReplicationGroupRegion",
            .role = "Role",
            .automatic_failover = "AutomaticFailover",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedCacheNode = struct {
    reserved_cache_node_id: ?[]const u8 = null,
    reserved_cache_nodes_offering_id: ?[]const u8 = null,
    cache_node_type: ?[]const u8 = null,
    start_time: ?i64 = null,
    duration: ?i64 = null,
    fixed_price: ?f64 = null,
    usage_price: ?f64 = null,
    cache_node_count: ?i64 = null,
    product_description: ?[]const u8 = null,
    offering_type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    recurring_charges: ?[]RecurringCharge = null,
    reservation_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reserved_cache_node_id = "ReservedCacheNodeId",
            .reserved_cache_nodes_offering_id = "ReservedCacheNodesOfferingId",
            .cache_node_type = "CacheNodeType",
            .start_time = "StartTime",
            .duration = "Duration",
            .fixed_price = "FixedPrice",
            .usage_price = "UsagePrice",
            .cache_node_count = "CacheNodeCount",
            .product_description = "ProductDescription",
            .offering_type = "OfferingType",
            .state = "State",
            .recurring_charges = "RecurringCharges",
            .reservation_arn = "ReservationARN",
        };
        return @field(mappings, field_name);
    }
};

pub const RecurringCharge = struct {
    recurring_charge_amount: ?f64 = null,
    recurring_charge_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recurring_charge_amount = "RecurringChargeAmount",
            .recurring_charge_frequency = "RecurringChargeFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const UserGroupPendingChanges = struct {
    user_ids_to_remove: ?[][]const u8 = null,
    user_ids_to_add: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_ids_to_remove = "UserIdsToRemove",
            .user_ids_to_add = "UserIdsToAdd",
        };
        return @field(mappings, field_name);
    }
};

pub const Authentication = struct {
    type: ?[]const u8 = null,
    password_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .password_count = "PasswordCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthenticationMode = struct {
    type: ?[]const u8 = null,
    passwords: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .passwords = "Passwords",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerlessCache = struct {
    serverless_cache_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    create_time: ?i64 = null,
    status: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    major_engine_version: ?[]const u8 = null,
    full_engine_version: ?[]const u8 = null,
    cache_usage_limits: ?CacheUsageLimits = null,
    kms_key_id: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    endpoint: ?Endpoint = null,
    reader_endpoint: ?Endpoint = null,
    arn: ?[]const u8 = null,
    user_group_id: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    snapshot_retention_limit: ?i64 = null,
    daily_snapshot_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .serverless_cache_name = "ServerlessCacheName",
            .description = "Description",
            .create_time = "CreateTime",
            .status = "Status",
            .engine = "Engine",
            .major_engine_version = "MajorEngineVersion",
            .full_engine_version = "FullEngineVersion",
            .cache_usage_limits = "CacheUsageLimits",
            .kms_key_id = "KmsKeyId",
            .security_group_ids = "SecurityGroupIds",
            .endpoint = "Endpoint",
            .reader_endpoint = "ReaderEndpoint",
            .arn = "ARN",
            .user_group_id = "UserGroupId",
            .subnet_ids = "SubnetIds",
            .snapshot_retention_limit = "SnapshotRetentionLimit",
            .daily_snapshot_time = "DailySnapshotTime",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheUsageLimits = struct {
    data_storage: ?DataStorage = null,
    ecpu_per_second: ?ECPUPerSecond = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_storage = "DataStorage",
            .ecpu_per_second = "ECPUPerSecond",
        };
        return @field(mappings, field_name);
    }
};

pub const ECPUPerSecond = struct {
    maximum: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum = "Maximum",
        };
        return @field(mappings, field_name);
    }
};

pub const DataStorage = struct {
    maximum: i64,
    unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum = "Maximum",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const ReshardingConfiguration = struct {
    node_group_id: ?[]const u8 = null,
    preferred_availability_zones: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_group_id = "NodeGroupId",
            .preferred_availability_zones = "PreferredAvailabilityZones",
        };
        return @field(mappings, field_name);
    }
};

pub const LogDeliveryConfigurationRequest = struct {
    log_type: ?[]const u8 = null,
    destination_type: ?[]const u8 = null,
    destination_details: ?DestinationDetails = null,
    log_format: ?[]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_type = "LogType",
            .destination_type = "DestinationType",
            .destination_details = "DestinationDetails",
            .log_format = "LogFormat",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheSubnetGroup = struct {
    cache_subnet_group_name: ?[]const u8 = null,
    cache_subnet_group_description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnets: ?[]Subnet = null,
    arn: ?[]const u8 = null,
    supported_network_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_subnet_group_name = "CacheSubnetGroupName",
            .cache_subnet_group_description = "CacheSubnetGroupDescription",
            .vpc_id = "VpcId",
            .subnets = "Subnets",
            .arn = "ARN",
            .supported_network_types = "SupportedNetworkTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?AvailabilityZone = null,
    subnet_outpost: ?SubnetOutpost = null,
    supported_network_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
            .subnet_outpost = "SubnetOutpost",
            .supported_network_types = "SupportedNetworkTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetOutpost = struct {
    subnet_outpost_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_outpost_arn = "SubnetOutpostArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigureShard = struct {
    node_group_id: []const u8,
    new_replica_count: i64,
    preferred_availability_zones: ?[][]const u8 = null,
    preferred_outpost_arns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_group_id = "NodeGroupId",
            .new_replica_count = "NewReplicaCount",
            .preferred_availability_zones = "PreferredAvailabilityZones",
            .preferred_outpost_arns = "PreferredOutpostArns",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerlessCacheSnapshot = struct {
    serverless_cache_snapshot_name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    create_time: ?i64 = null,
    expiry_time: ?i64 = null,
    bytes_used_for_cache: ?[]const u8 = null,
    serverless_cache_configuration: ?ServerlessCacheConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .serverless_cache_snapshot_name = "ServerlessCacheSnapshotName",
            .arn = "ARN",
            .kms_key_id = "KmsKeyId",
            .snapshot_type = "SnapshotType",
            .status = "Status",
            .create_time = "CreateTime",
            .expiry_time = "ExpiryTime",
            .bytes_used_for_cache = "BytesUsedForCache",
            .serverless_cache_configuration = "ServerlessCacheConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerlessCacheConfiguration = struct {
    serverless_cache_name: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    major_engine_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .serverless_cache_name = "ServerlessCacheName",
            .engine = "Engine",
            .major_engine_version = "MajorEngineVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const User = struct {
    user_id: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    minimum_engine_version: ?[]const u8 = null,
    access_string: ?[]const u8 = null,
    user_group_ids: ?[][]const u8 = null,
    authentication: ?Authentication = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_id = "UserId",
            .user_name = "UserName",
            .status = "Status",
            .engine = "Engine",
            .minimum_engine_version = "MinimumEngineVersion",
            .access_string = "AccessString",
            .user_group_ids = "UserGroupIds",
            .authentication = "Authentication",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const UserGroup = struct {
    user_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    user_ids: ?[][]const u8 = null,
    minimum_engine_version: ?[]const u8 = null,
    pending_changes: ?UserGroupPendingChanges = null,
    replication_groups: ?[][]const u8 = null,
    serverless_caches: ?[][]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_group_id = "UserGroupId",
            .status = "Status",
            .engine = "Engine",
            .user_ids = "UserIds",
            .minimum_engine_version = "MinimumEngineVersion",
            .pending_changes = "PendingChanges",
            .replication_groups = "ReplicationGroups",
            .serverless_caches = "ServerlessCaches",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const Snapshot = struct {
    snapshot_name: ?[]const u8 = null,
    replication_group_id: ?[]const u8 = null,
    replication_group_description: ?[]const u8 = null,
    cache_cluster_id: ?[]const u8 = null,
    snapshot_status: ?[]const u8 = null,
    snapshot_source: ?[]const u8 = null,
    cache_node_type: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    num_cache_nodes: ?i64 = null,
    preferred_availability_zone: ?[]const u8 = null,
    preferred_outpost_arn: ?[]const u8 = null,
    cache_cluster_create_time: ?i64 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    topic_arn: ?[]const u8 = null,
    port: ?i64 = null,
    cache_parameter_group_name: ?[]const u8 = null,
    cache_subnet_group_name: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    snapshot_retention_limit: ?i64 = null,
    snapshot_window: ?[]const u8 = null,
    num_node_groups: ?i64 = null,
    automatic_failover: ?[]const u8 = null,
    node_snapshots: ?[]NodeSnapshot = null,
    kms_key_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    data_tiering: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snapshot_name = "SnapshotName",
            .replication_group_id = "ReplicationGroupId",
            .replication_group_description = "ReplicationGroupDescription",
            .cache_cluster_id = "CacheClusterId",
            .snapshot_status = "SnapshotStatus",
            .snapshot_source = "SnapshotSource",
            .cache_node_type = "CacheNodeType",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .num_cache_nodes = "NumCacheNodes",
            .preferred_availability_zone = "PreferredAvailabilityZone",
            .preferred_outpost_arn = "PreferredOutpostArn",
            .cache_cluster_create_time = "CacheClusterCreateTime",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .topic_arn = "TopicArn",
            .port = "Port",
            .cache_parameter_group_name = "CacheParameterGroupName",
            .cache_subnet_group_name = "CacheSubnetGroupName",
            .vpc_id = "VpcId",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .snapshot_retention_limit = "SnapshotRetentionLimit",
            .snapshot_window = "SnapshotWindow",
            .num_node_groups = "NumNodeGroups",
            .automatic_failover = "AutomaticFailover",
            .node_snapshots = "NodeSnapshots",
            .kms_key_id = "KmsKeyId",
            .arn = "ARN",
            .data_tiering = "DataTiering",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeSnapshot = struct {
    cache_cluster_id: ?[]const u8 = null,
    node_group_id: ?[]const u8 = null,
    cache_node_id: ?[]const u8 = null,
    node_group_configuration: ?NodeGroupConfiguration = null,
    cache_size: ?[]const u8 = null,
    cache_node_create_time: ?i64 = null,
    snapshot_create_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_cluster_id = "CacheClusterId",
            .node_group_id = "NodeGroupId",
            .cache_node_id = "CacheNodeId",
            .node_group_configuration = "NodeGroupConfiguration",
            .cache_size = "CacheSize",
            .cache_node_create_time = "CacheNodeCreateTime",
            .snapshot_create_time = "SnapshotCreateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeGroupConfiguration = struct {
    node_group_id: ?[]const u8 = null,
    slots: ?[]const u8 = null,
    replica_count: ?i64 = null,
    primary_availability_zone: ?[]const u8 = null,
    replica_availability_zones: ?[][]const u8 = null,
    primary_outpost_arn: ?[]const u8 = null,
    replica_outpost_arns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_group_id = "NodeGroupId",
            .slots = "Slots",
            .replica_count = "ReplicaCount",
            .primary_availability_zone = "PrimaryAvailabilityZone",
            .replica_availability_zones = "ReplicaAvailabilityZones",
            .primary_outpost_arn = "PrimaryOutpostArn",
            .replica_outpost_arns = "ReplicaOutpostArns",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheNodeTypeSpecificParameter = struct {
    parameter_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    source: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    allowed_values: ?[]const u8 = null,
    is_modifiable: ?bool = null,
    minimum_engine_version: ?[]const u8 = null,
    cache_node_type_specific_values: ?[]CacheNodeTypeSpecificValue = null,
    change_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .description = "Description",
            .source = "Source",
            .data_type = "DataType",
            .allowed_values = "AllowedValues",
            .is_modifiable = "IsModifiable",
            .minimum_engine_version = "MinimumEngineVersion",
            .cache_node_type_specific_values = "CacheNodeTypeSpecificValues",
            .change_type = "ChangeType",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheNodeTypeSpecificValue = struct {
    cache_node_type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_node_type = "CacheNodeType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameter = struct {
    parameter_name: ?[]const u8 = null,
    parameter_value: ?[]const u8 = null,
    description: ?[]const u8 = null,
    source: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    allowed_values: ?[]const u8 = null,
    is_modifiable: ?bool = null,
    minimum_engine_version: ?[]const u8 = null,
    change_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_value = "ParameterValue",
            .description = "Description",
            .source = "Source",
            .data_type = "DataType",
            .allowed_values = "AllowedValues",
            .is_modifiable = "IsModifiable",
            .minimum_engine_version = "MinimumEngineVersion",
            .change_type = "ChangeType",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheParameterGroup = struct {
    cache_parameter_group_name: ?[]const u8 = null,
    cache_parameter_group_family: ?[]const u8 = null,
    description: ?[]const u8 = null,
    is_global: ?bool = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_parameter_group_name = "CacheParameterGroupName",
            .cache_parameter_group_family = "CacheParameterGroupFamily",
            .description = "Description",
            .is_global = "IsGlobal",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const UnprocessedUpdateAction = struct {
    replication_group_id: ?[]const u8 = null,
    cache_cluster_id: ?[]const u8 = null,
    service_update_name: ?[]const u8 = null,
    error_type: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_group_id = "ReplicationGroupId",
            .cache_cluster_id = "CacheClusterId",
            .service_update_name = "ServiceUpdateName",
            .error_type = "ErrorType",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessedUpdateAction = struct {
    replication_group_id: ?[]const u8 = null,
    cache_cluster_id: ?[]const u8 = null,
    service_update_name: ?[]const u8 = null,
    update_action_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_group_id = "ReplicationGroupId",
            .cache_cluster_id = "CacheClusterId",
            .service_update_name = "ServiceUpdateName",
            .update_action_status = "UpdateActionStatus",
        };
        return @field(mappings, field_name);
    }
};
