const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2010-12-01";
pub const sdk_id: []const u8 = "Elastic Beanstalk";
pub const arn_namespace: ?[]const u8 = "elasticbeanstalk";
pub const endpoint_prefix: []const u8 = "elasticbeanstalk";
pub const sigv4_name: []const u8 = "elasticbeanstalk";
pub const name: []const u8 = "AWSElasticBeanstalkService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2010-12-01",
    sdk_id: []const u8 = "Elastic Beanstalk",
    arn_namespace: ?[]const u8 = "elasticbeanstalk",
    endpoint_prefix: []const u8 = "elasticbeanstalk",
    sigv4_name: []const u8 = "elasticbeanstalk",
    name: []const u8 = "AWSElasticBeanstalkService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const abort_environment_update: struct {
    action_name: []const u8 = "AbortEnvironmentUpdate",
    Request: type = struct {
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(abort_environment_update) } {
            return .{ .service_metadata = service_metadata, .action = abort_environment_update };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientPrivileges,
    },
} = .{};
pub const apply_environment_managed_action: struct {
    action_name: []const u8 = "ApplyEnvironmentManagedAction",
    Request: type = struct {
        environment_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .environment_id = "EnvironmentId",
                .action_id = "ActionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_environment_managed_action) } {
            return .{ .service_metadata = service_metadata, .action = apply_environment_managed_action };
        }
    },
    Response: type = struct {
        action_id: ?[]const u8 = null,
        action_description: ?[]const u8 = null,
        action_type: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_id = "ActionId",
                .action_description = "ActionDescription",
                .action_type = "ActionType",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
        ManagedActionInvalidState,
    },
} = .{};
pub const associate_environment_operations_role: struct {
    action_name: []const u8 = "AssociateEnvironmentOperationsRole",
    Request: type = struct {
        environment_name: []const u8,
        operations_role: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .operations_role = "OperationsRole",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_environment_operations_role) } {
            return .{ .service_metadata = service_metadata, .action = associate_environment_operations_role };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientPrivileges,
    },
} = .{};
pub const check_dns_availability: struct {
    action_name: []const u8 = "CheckDNSAvailability",
    Request: type = struct {
        cname_prefix: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cname_prefix = "CNAMEPrefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_dns_availability) } {
            return .{ .service_metadata = service_metadata, .action = check_dns_availability };
        }
    },
    Response: type = struct {
        available: ?bool = null,
        fully_qualified_cname: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .available = "Available",
                .fully_qualified_cname = "FullyQualifiedCNAME",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const compose_environments: struct {
    action_name: []const u8 = "ComposeEnvironments",
    Request: type = struct {
        application_name: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        version_labels: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .group_name = "GroupName",
                .version_labels = "VersionLabels",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(compose_environments) } {
            return .{ .service_metadata = service_metadata, .action = compose_environments };
        }
    },
    Response: type = struct {
        environments: ?[]EnvironmentDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environments = "Environments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
        TooManyEnvironments,
    },
} = .{};
pub const create_application: struct {
    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        application_name: []const u8,
        description: ?[]const u8 = null,
        resource_lifecycle_config: ?ApplicationResourceLifecycleConfig = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .description = "Description",
                .resource_lifecycle_config = "ResourceLifecycleConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        application: ?ApplicationDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "Application",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TooManyApplications,
    },
} = .{};
pub const create_application_version: struct {
    action_name: []const u8 = "CreateApplicationVersion",
    Request: type = struct {
        application_name: []const u8,
        version_label: []const u8,
        description: ?[]const u8 = null,
        source_build_information: ?SourceBuildInformation = null,
        source_bundle: ?S3Location = null,
        build_configuration: ?struct {
            artifact_name: ?[]const u8 = null,
            code_build_service_role: []const u8,
            compute_type: ?[]const u8 = null,
            image: []const u8,
            timeout_in_minutes: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .artifact_name = "ArtifactName",
                    .code_build_service_role = "CodeBuildServiceRole",
                    .compute_type = "ComputeType",
                    .image = "Image",
                    .timeout_in_minutes = "TimeoutInMinutes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        auto_create_application: ?bool = null,
        process: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .version_label = "VersionLabel",
                .description = "Description",
                .source_build_information = "SourceBuildInformation",
                .source_bundle = "SourceBundle",
                .build_configuration = "BuildConfiguration",
                .auto_create_application = "AutoCreateApplication",
                .process = "Process",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application_version) } {
            return .{ .service_metadata = service_metadata, .action = create_application_version };
        }
    },
    Response: type = struct {
        application_version: ?ApplicationVersionDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_version = "ApplicationVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeBuildNotInServiceRegion,
        InsufficientPrivileges,
        S3LocationNotInServiceRegion,
        TooManyApplications,
        TooManyApplicationVersions,
    },
} = .{};
pub const create_configuration_template: struct {
    action_name: []const u8 = "CreateConfigurationTemplate",
    Request: type = struct {
        application_name: []const u8,
        template_name: []const u8,
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        source_configuration: ?struct {
            application_name: ?[]const u8 = null,
            template_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_name = "ApplicationName",
                    .template_name = "TemplateName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        environment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        option_settings: ?[]ConfigurationOptionSetting = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .template_name = "TemplateName",
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .source_configuration = "SourceConfiguration",
                .environment_id = "EnvironmentId",
                .description = "Description",
                .option_settings = "OptionSettings",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_template) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_template };
        }
    },
    Response: type = struct {
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        application_name: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        deployment_status: ?[]const u8 = null,
        date_created: ?i64 = null,
        date_updated: ?i64 = null,
        option_settings: ?[]ConfigurationOptionSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .application_name = "ApplicationName",
                .template_name = "TemplateName",
                .description = "Description",
                .environment_name = "EnvironmentName",
                .deployment_status = "DeploymentStatus",
                .date_created = "DateCreated",
                .date_updated = "DateUpdated",
                .option_settings = "OptionSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
        TooManyBuckets,
        TooManyConfigurationTemplates,
    },
} = .{};
pub const create_environment: struct {
    action_name: []const u8 = "CreateEnvironment",
    Request: type = struct {
        application_name: []const u8,
        environment_name: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        cname_prefix: ?[]const u8 = null,
        tier: ?EnvironmentTier = null,
        tags: ?[]Tag = null,
        version_label: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        option_settings: ?[]ConfigurationOptionSetting = null,
        options_to_remove: ?[]OptionSpecification = null,
        operations_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .environment_name = "EnvironmentName",
                .group_name = "GroupName",
                .description = "Description",
                .cname_prefix = "CNAMEPrefix",
                .tier = "Tier",
                .tags = "Tags",
                .version_label = "VersionLabel",
                .template_name = "TemplateName",
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .option_settings = "OptionSettings",
                .options_to_remove = "OptionsToRemove",
                .operations_role = "OperationsRole",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_environment };
        }
    },
    Response: type = struct {
        environment_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        application_name: ?[]const u8 = null,
        version_label: ?[]const u8 = null,
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        endpoint_url: ?[]const u8 = null,
        cname: ?[]const u8 = null,
        date_created: ?i64 = null,
        date_updated: ?i64 = null,
        status: ?[]const u8 = null,
        abortable_operation_in_progress: ?bool = null,
        health: ?[]const u8 = null,
        health_status: ?[]const u8 = null,
        resources: ?EnvironmentResourcesDescription = null,
        tier: ?EnvironmentTier = null,
        environment_links: ?[]EnvironmentLink = null,
        environment_arn: ?[]const u8 = null,
        operations_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .environment_id = "EnvironmentId",
                .application_name = "ApplicationName",
                .version_label = "VersionLabel",
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .template_name = "TemplateName",
                .description = "Description",
                .endpoint_url = "EndpointURL",
                .cname = "CNAME",
                .date_created = "DateCreated",
                .date_updated = "DateUpdated",
                .status = "Status",
                .abortable_operation_in_progress = "AbortableOperationInProgress",
                .health = "Health",
                .health_status = "HealthStatus",
                .resources = "Resources",
                .tier = "Tier",
                .environment_links = "EnvironmentLinks",
                .environment_arn = "EnvironmentArn",
                .operations_role = "OperationsRole",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
        TooManyEnvironments,
    },
} = .{};
pub const create_platform_version: struct {
    action_name: []const u8 = "CreatePlatformVersion",
    Request: type = struct {
        platform_name: []const u8,
        platform_version: []const u8,
        platform_definition_bundle: S3Location,
        environment_name: ?[]const u8 = null,
        option_settings: ?[]ConfigurationOptionSetting = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_name = "PlatformName",
                .platform_version = "PlatformVersion",
                .platform_definition_bundle = "PlatformDefinitionBundle",
                .environment_name = "EnvironmentName",
                .option_settings = "OptionSettings",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_platform_version) } {
            return .{ .service_metadata = service_metadata, .action = create_platform_version };
        }
    },
    Response: type = struct {
        platform_summary: ?PlatformSummary = null,
        builder: ?struct {
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "ARN",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_summary = "PlatformSummary",
                .builder = "Builder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
        InsufficientPrivileges,
        TooManyPlatforms,
    },
} = .{};
pub const create_storage_location: struct {
    action_name: []const u8 = "CreateStorageLocation",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_storage_location) } {
            return .{ .service_metadata = service_metadata, .action = create_storage_location };
        }
    },
    Response: type = struct {
        s3_bucket: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_bucket = "S3Bucket",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
        S3SubscriptionRequired,
        TooManyBuckets,
    },
} = .{};
pub const delete_application: struct {
    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        application_name: []const u8,
        terminate_env_by_force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .terminate_env_by_force = "TerminateEnvByForce",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationInProgress,
    },
} = .{};
pub const delete_application_version: struct {
    action_name: []const u8 = "DeleteApplicationVersion",
    Request: type = struct {
        application_name: []const u8,
        version_label: []const u8,
        delete_source_bundle: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .version_label = "VersionLabel",
                .delete_source_bundle = "DeleteSourceBundle",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_application_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientPrivileges,
        OperationInProgress,
        S3LocationNotInServiceRegion,
        SourceBundleDeletion,
    },
} = .{};
pub const delete_configuration_template: struct {
    action_name: []const u8 = "DeleteConfigurationTemplate",
    Request: type = struct {
        application_name: []const u8,
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_template };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationInProgress,
    },
} = .{};
pub const delete_environment_configuration: struct {
    action_name: []const u8 = "DeleteEnvironmentConfiguration",
    Request: type = struct {
        application_name: []const u8,
        environment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .environment_name = "EnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_platform_version: struct {
    action_name: []const u8 = "DeletePlatformVersion",
    Request: type = struct {
        platform_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_arn = "PlatformArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_platform_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_platform_version };
        }
    },
    Response: type = struct {
        platform_summary: ?PlatformSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_summary = "PlatformSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
        InsufficientPrivileges,
        OperationInProgress,
        PlatformVersionStillReferenced,
    },
} = .{};
pub const describe_account_attributes: struct {
    action_name: []const u8 = "DescribeAccountAttributes",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_attributes };
        }
    },
    Response: type = struct {
        resource_quotas: ?struct {
            application_quota: ?ResourceQuota = null,
            application_version_quota: ?ResourceQuota = null,
            environment_quota: ?ResourceQuota = null,
            configuration_template_quota: ?ResourceQuota = null,
            custom_platform_quota: ?ResourceQuota = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_quota = "ApplicationQuota",
                    .application_version_quota = "ApplicationVersionQuota",
                    .environment_quota = "EnvironmentQuota",
                    .configuration_template_quota = "ConfigurationTemplateQuota",
                    .custom_platform_quota = "CustomPlatformQuota",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_quotas = "ResourceQuotas",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
    },
} = .{};
pub const describe_applications: struct {
    action_name: []const u8 = "DescribeApplications",
    Request: type = struct {
        application_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_names = "ApplicationNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_applications) } {
            return .{ .service_metadata = service_metadata, .action = describe_applications };
        }
    },
    Response: type = struct {
        applications: ?[]ApplicationDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "Applications",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_application_versions: struct {
    action_name: []const u8 = "DescribeApplicationVersions",
    Request: type = struct {
        application_name: ?[]const u8 = null,
        version_labels: ?[][]const u8 = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .version_labels = "VersionLabels",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_application_versions };
        }
    },
    Response: type = struct {
        application_versions: ?[]ApplicationVersionDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_versions = "ApplicationVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_configuration_options: struct {
    action_name: []const u8 = "DescribeConfigurationOptions",
    Request: type = struct {
        application_name: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        options: ?[]OptionSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .template_name = "TemplateName",
                .environment_name = "EnvironmentName",
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_options };
        }
    },
    Response: type = struct {
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        options: ?[]struct {
            namespace: ?[]const u8 = null,
            name: ?[]const u8 = null,
            default_value: ?[]const u8 = null,
            change_severity: ?[]const u8 = null,
            user_defined: ?bool = null,
            value_type: ?[]const u8 = null,
            value_options: ?[][]const u8 = null,
            min_value: ?i64 = null,
            max_value: ?i64 = null,
            max_length: ?i64 = null,
            regex: ?struct {
                pattern: ?[]const u8 = null,
                label: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pattern = "Pattern",
                        .label = "Label",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .namespace = "Namespace",
                    .name = "Name",
                    .default_value = "DefaultValue",
                    .change_severity = "ChangeSeverity",
                    .user_defined = "UserDefined",
                    .value_type = "ValueType",
                    .value_options = "ValueOptions",
                    .min_value = "MinValue",
                    .max_value = "MaxValue",
                    .max_length = "MaxLength",
                    .regex = "Regex",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TooManyBuckets,
    },
} = .{};
pub const describe_configuration_settings: struct {
    action_name: []const u8 = "DescribeConfigurationSettings",
    Request: type = struct {
        application_name: []const u8,
        template_name: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .template_name = "TemplateName",
                .environment_name = "EnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_settings };
        }
    },
    Response: type = struct {
        configuration_settings: ?[]ConfigurationSettingsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_settings = "ConfigurationSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TooManyBuckets,
    },
} = .{};
pub const describe_environment_health: struct {
    action_name: []const u8 = "DescribeEnvironmentHealth",
    Request: type = struct {
        environment_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        attribute_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .environment_id = "EnvironmentId",
                .attribute_names = "AttributeNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_environment_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_environment_health };
        }
    },
    Response: type = struct {
        environment_name: ?[]const u8 = null,
        health_status: ?[]const u8 = null,
        status: ?[]const u8 = null,
        color: ?[]const u8 = null,
        causes: ?[][]const u8 = null,
        application_metrics: ?ApplicationMetrics = null,
        instances_health: ?struct {
            no_data: ?i64 = null,
            unknown: ?i64 = null,
            pending: ?i64 = null,
            ok: ?i64 = null,
            info: ?i64 = null,
            warning: ?i64 = null,
            degraded: ?i64 = null,
            severe: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .no_data = "NoData",
                    .unknown = "Unknown",
                    .pending = "Pending",
                    .ok = "Ok",
                    .info = "Info",
                    .warning = "Warning",
                    .degraded = "Degraded",
                    .severe = "Severe",
                };
                return @field(mappings, field_name);
            }
        } = null,
        refreshed_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .health_status = "HealthStatus",
                .status = "Status",
                .color = "Color",
                .causes = "Causes",
                .application_metrics = "ApplicationMetrics",
                .instances_health = "InstancesHealth",
                .refreshed_at = "RefreshedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
        InvalidRequest,
    },
} = .{};
pub const describe_environment_managed_action_history: struct {
    action_name: []const u8 = "DescribeEnvironmentManagedActionHistory",
    Request: type = struct {
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
                .next_token = "NextToken",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_environment_managed_action_history) } {
            return .{ .service_metadata = service_metadata, .action = describe_environment_managed_action_history };
        }
    },
    Response: type = struct {
        managed_action_history_items: ?[]struct {
            action_id: ?[]const u8 = null,
            action_type: ?[]const u8 = null,
            action_description: ?[]const u8 = null,
            failure_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            failure_description: ?[]const u8 = null,
            executed_time: ?i64 = null,
            finished_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_id = "ActionId",
                    .action_type = "ActionType",
                    .action_description = "ActionDescription",
                    .failure_type = "FailureType",
                    .status = "Status",
                    .failure_description = "FailureDescription",
                    .executed_time = "ExecutedTime",
                    .finished_time = "FinishedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_action_history_items = "ManagedActionHistoryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
    },
} = .{};
pub const describe_environment_managed_actions: struct {
    action_name: []const u8 = "DescribeEnvironmentManagedActions",
    Request: type = struct {
        environment_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .environment_id = "EnvironmentId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_environment_managed_actions) } {
            return .{ .service_metadata = service_metadata, .action = describe_environment_managed_actions };
        }
    },
    Response: type = struct {
        managed_actions: ?[]struct {
            action_id: ?[]const u8 = null,
            action_description: ?[]const u8 = null,
            action_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            window_start_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_id = "ActionId",
                    .action_description = "ActionDescription",
                    .action_type = "ActionType",
                    .status = "Status",
                    .window_start_time = "WindowStartTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_actions = "ManagedActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
    },
} = .{};
pub const describe_environment_resources: struct {
    action_name: []const u8 = "DescribeEnvironmentResources",
    Request: type = struct {
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_environment_resources) } {
            return .{ .service_metadata = service_metadata, .action = describe_environment_resources };
        }
    },
    Response: type = struct {
        environment_resources: ?struct {
            environment_name: ?[]const u8 = null,
            auto_scaling_groups: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instances: ?[]struct {
                id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            launch_configurations: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            launch_templates: ?[]struct {
                id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            load_balancers: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            triggers: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            queues: ?[]struct {
                name: ?[]const u8 = null,
                url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .url = "URL",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .environment_name = "EnvironmentName",
                    .auto_scaling_groups = "AutoScalingGroups",
                    .instances = "Instances",
                    .launch_configurations = "LaunchConfigurations",
                    .launch_templates = "LaunchTemplates",
                    .load_balancers = "LoadBalancers",
                    .triggers = "Triggers",
                    .queues = "Queues",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_resources = "EnvironmentResources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
    },
} = .{};
pub const describe_environments: struct {
    action_name: []const u8 = "DescribeEnvironments",
    Request: type = struct {
        application_name: ?[]const u8 = null,
        version_label: ?[]const u8 = null,
        environment_ids: ?[][]const u8 = null,
        environment_names: ?[][]const u8 = null,
        include_deleted: ?bool = null,
        included_deleted_back_to: ?i64 = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .version_label = "VersionLabel",
                .environment_ids = "EnvironmentIds",
                .environment_names = "EnvironmentNames",
                .include_deleted = "IncludeDeleted",
                .included_deleted_back_to = "IncludedDeletedBackTo",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_environments) } {
            return .{ .service_metadata = service_metadata, .action = describe_environments };
        }
    },
    Response: type = struct {
        environments: ?[]EnvironmentDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environments = "Environments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        application_name: ?[]const u8 = null,
        version_label: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        severity: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .version_label = "VersionLabel",
                .template_name = "TemplateName",
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
                .platform_arn = "PlatformArn",
                .request_id = "RequestId",
                .severity = "Severity",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        events: ?[]struct {
            event_date: ?i64 = null,
            message: ?[]const u8 = null,
            application_name: ?[]const u8 = null,
            version_label: ?[]const u8 = null,
            template_name: ?[]const u8 = null,
            environment_name: ?[]const u8 = null,
            platform_arn: ?[]const u8 = null,
            request_id: ?[]const u8 = null,
            severity: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_date = "EventDate",
                    .message = "Message",
                    .application_name = "ApplicationName",
                    .version_label = "VersionLabel",
                    .template_name = "TemplateName",
                    .environment_name = "EnvironmentName",
                    .platform_arn = "PlatformArn",
                    .request_id = "RequestId",
                    .severity = "Severity",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "Events",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instances_health: struct {
    action_name: []const u8 = "DescribeInstancesHealth",
    Request: type = struct {
        environment_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        attribute_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .environment_id = "EnvironmentId",
                .attribute_names = "AttributeNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instances_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_instances_health };
        }
    },
    Response: type = struct {
        instance_health_list: ?[]struct {
            instance_id: ?[]const u8 = null,
            health_status: ?[]const u8 = null,
            color: ?[]const u8 = null,
            causes: ?[][]const u8 = null,
            launched_at: ?i64 = null,
            application_metrics: ?ApplicationMetrics = null,
            system: ?struct {
                cpu_utilization: ?struct {
                    user: ?f64 = null,
                    nice: ?f64 = null,
                    system: ?f64 = null,
                    idle: ?f64 = null,
                    io_wait: ?f64 = null,
                    irq: ?f64 = null,
                    soft_irq: ?f64 = null,
                    privileged: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .user = "User",
                            .nice = "Nice",
                            .system = "System",
                            .idle = "Idle",
                            .io_wait = "IOWait",
                            .irq = "IRQ",
                            .soft_irq = "SoftIRQ",
                            .privileged = "Privileged",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                load_average: ?[]f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cpu_utilization = "CPUUtilization",
                        .load_average = "LoadAverage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            deployment: ?struct {
                version_label: ?[]const u8 = null,
                deployment_id: ?i64 = null,
                status: ?[]const u8 = null,
                deployment_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .version_label = "VersionLabel",
                        .deployment_id = "DeploymentId",
                        .status = "Status",
                        .deployment_time = "DeploymentTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            availability_zone: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .health_status = "HealthStatus",
                    .color = "Color",
                    .causes = "Causes",
                    .launched_at = "LaunchedAt",
                    .application_metrics = "ApplicationMetrics",
                    .system = "System",
                    .deployment = "Deployment",
                    .availability_zone = "AvailabilityZone",
                    .instance_type = "InstanceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        refreshed_at: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_health_list = "InstanceHealthList",
                .refreshed_at = "RefreshedAt",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
        InvalidRequest,
    },
} = .{};
pub const describe_platform_version: struct {
    action_name: []const u8 = "DescribePlatformVersion",
    Request: type = struct {
        platform_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_arn = "PlatformArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_platform_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_platform_version };
        }
    },
    Response: type = struct {
        platform_description: ?struct {
            platform_arn: ?[]const u8 = null,
            platform_owner: ?[]const u8 = null,
            platform_name: ?[]const u8 = null,
            platform_version: ?[]const u8 = null,
            solution_stack_name: ?[]const u8 = null,
            platform_status: ?[]const u8 = null,
            date_created: ?i64 = null,
            date_updated: ?i64 = null,
            platform_category: ?[]const u8 = null,
            description: ?[]const u8 = null,
            maintainer: ?[]const u8 = null,
            operating_system_name: ?[]const u8 = null,
            operating_system_version: ?[]const u8 = null,
            programming_languages: ?[]struct {
                name: ?[]const u8 = null,
                version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .version = "Version",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            frameworks: ?[]struct {
                name: ?[]const u8 = null,
                version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .version = "Version",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            custom_ami_list: ?[]struct {
                virtualization_type: ?[]const u8 = null,
                image_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .virtualization_type = "VirtualizationType",
                        .image_id = "ImageId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            supported_tier_list: ?[][]const u8 = null,
            supported_addon_list: ?[][]const u8 = null,
            platform_lifecycle_state: ?[]const u8 = null,
            platform_branch_name: ?[]const u8 = null,
            platform_branch_lifecycle_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .platform_arn = "PlatformArn",
                    .platform_owner = "PlatformOwner",
                    .platform_name = "PlatformName",
                    .platform_version = "PlatformVersion",
                    .solution_stack_name = "SolutionStackName",
                    .platform_status = "PlatformStatus",
                    .date_created = "DateCreated",
                    .date_updated = "DateUpdated",
                    .platform_category = "PlatformCategory",
                    .description = "Description",
                    .maintainer = "Maintainer",
                    .operating_system_name = "OperatingSystemName",
                    .operating_system_version = "OperatingSystemVersion",
                    .programming_languages = "ProgrammingLanguages",
                    .frameworks = "Frameworks",
                    .custom_ami_list = "CustomAmiList",
                    .supported_tier_list = "SupportedTierList",
                    .supported_addon_list = "SupportedAddonList",
                    .platform_lifecycle_state = "PlatformLifecycleState",
                    .platform_branch_name = "PlatformBranchName",
                    .platform_branch_lifecycle_state = "PlatformBranchLifecycleState",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_description = "PlatformDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
        InsufficientPrivileges,
    },
} = .{};
pub const disassociate_environment_operations_role: struct {
    action_name: []const u8 = "DisassociateEnvironmentOperationsRole",
    Request: type = struct {
        environment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_environment_operations_role) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_environment_operations_role };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientPrivileges,
    },
} = .{};
pub const list_available_solution_stacks: struct {
    action_name: []const u8 = "ListAvailableSolutionStacks",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_solution_stacks) } {
            return .{ .service_metadata = service_metadata, .action = list_available_solution_stacks };
        }
    },
    Response: type = struct {
        solution_stacks: ?[][]const u8 = null,
        solution_stack_details: ?[]struct {
            solution_stack_name: ?[]const u8 = null,
            permitted_file_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .solution_stack_name = "SolutionStackName",
                    .permitted_file_types = "PermittedFileTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_stacks = "SolutionStacks",
                .solution_stack_details = "SolutionStackDetails",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_platform_branches: struct {
    action_name: []const u8 = "ListPlatformBranches",
    Request: type = struct {
        filters: ?[]struct {
            attribute: ?[]const u8 = null,
            operator: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "Attribute",
                    .operator = "Operator",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_platform_branches) } {
            return .{ .service_metadata = service_metadata, .action = list_platform_branches };
        }
    },
    Response: type = struct {
        platform_branch_summary_list: ?[]struct {
            platform_name: ?[]const u8 = null,
            branch_name: ?[]const u8 = null,
            lifecycle_state: ?[]const u8 = null,
            branch_order: ?i64 = null,
            supported_tier_list: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .platform_name = "PlatformName",
                    .branch_name = "BranchName",
                    .lifecycle_state = "LifecycleState",
                    .branch_order = "BranchOrder",
                    .supported_tier_list = "SupportedTierList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_branch_summary_list = "PlatformBranchSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_platform_versions: struct {
    action_name: []const u8 = "ListPlatformVersions",
    Request: type = struct {
        filters: ?[]struct {
            type: ?[]const u8 = null,
            operator: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .operator = "Operator",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_platform_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_platform_versions };
        }
    },
    Response: type = struct {
        platform_summary_list: ?[]PlatformSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_summary_list = "PlatformSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ElasticBeanstalkService,
        InsufficientPrivileges,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        resource_tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
        ResourceNotFound,
        ResourceTypeNotSupported,
    },
} = .{};
pub const rebuild_environment: struct {
    action_name: []const u8 = "RebuildEnvironment",
    Request: type = struct {
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rebuild_environment) } {
            return .{ .service_metadata = service_metadata, .action = rebuild_environment };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientPrivileges,
    },
} = .{};
pub const request_environment_info: struct {
    action_name: []const u8 = "RequestEnvironmentInfo",
    Request: type = struct {
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        info_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
                .info_type = "InfoType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(request_environment_info) } {
            return .{ .service_metadata = service_metadata, .action = request_environment_info };
        }
    },
    Response: type = struct {},
} = .{};
pub const restart_app_server: struct {
    action_name: []const u8 = "RestartAppServer",
    Request: type = struct {
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restart_app_server) } {
            return .{ .service_metadata = service_metadata, .action = restart_app_server };
        }
    },
    Response: type = struct {},
} = .{};
pub const retrieve_environment_info: struct {
    action_name: []const u8 = "RetrieveEnvironmentInfo",
    Request: type = struct {
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        info_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
                .info_type = "InfoType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(retrieve_environment_info) } {
            return .{ .service_metadata = service_metadata, .action = retrieve_environment_info };
        }
    },
    Response: type = struct {
        environment_info: ?[]struct {
            info_type: ?[]const u8 = null,
            ec2_instance_id: ?[]const u8 = null,
            sample_timestamp: ?i64 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .info_type = "InfoType",
                    .ec2_instance_id = "Ec2InstanceId",
                    .sample_timestamp = "SampleTimestamp",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_info = "EnvironmentInfo",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const swap_environment_cnam_es: struct {
    action_name: []const u8 = "SwapEnvironmentCNAMEs",
    Request: type = struct {
        source_environment_id: ?[]const u8 = null,
        source_environment_name: ?[]const u8 = null,
        destination_environment_id: ?[]const u8 = null,
        destination_environment_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_environment_id = "SourceEnvironmentId",
                .source_environment_name = "SourceEnvironmentName",
                .destination_environment_id = "DestinationEnvironmentId",
                .destination_environment_name = "DestinationEnvironmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(swap_environment_cnam_es) } {
            return .{ .service_metadata = service_metadata, .action = swap_environment_cnam_es };
        }
    },
    Response: type = struct {},
} = .{};
pub const terminate_environment: struct {
    action_name: []const u8 = "TerminateEnvironment",
    Request: type = struct {
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        terminate_resources: ?bool = null,
        force_terminate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
                .terminate_resources = "TerminateResources",
                .force_terminate = "ForceTerminate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_environment) } {
            return .{ .service_metadata = service_metadata, .action = terminate_environment };
        }
    },
    Response: type = struct {
        environment_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        application_name: ?[]const u8 = null,
        version_label: ?[]const u8 = null,
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        endpoint_url: ?[]const u8 = null,
        cname: ?[]const u8 = null,
        date_created: ?i64 = null,
        date_updated: ?i64 = null,
        status: ?[]const u8 = null,
        abortable_operation_in_progress: ?bool = null,
        health: ?[]const u8 = null,
        health_status: ?[]const u8 = null,
        resources: ?EnvironmentResourcesDescription = null,
        tier: ?EnvironmentTier = null,
        environment_links: ?[]EnvironmentLink = null,
        environment_arn: ?[]const u8 = null,
        operations_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .environment_id = "EnvironmentId",
                .application_name = "ApplicationName",
                .version_label = "VersionLabel",
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .template_name = "TemplateName",
                .description = "Description",
                .endpoint_url = "EndpointURL",
                .cname = "CNAME",
                .date_created = "DateCreated",
                .date_updated = "DateUpdated",
                .status = "Status",
                .abortable_operation_in_progress = "AbortableOperationInProgress",
                .health = "Health",
                .health_status = "HealthStatus",
                .resources = "Resources",
                .tier = "Tier",
                .environment_links = "EnvironmentLinks",
                .environment_arn = "EnvironmentArn",
                .operations_role = "OperationsRole",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
    },
} = .{};
pub const update_application: struct {
    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        application_name: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {
        application: ?ApplicationDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "Application",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_application_resource_lifecycle: struct {
    action_name: []const u8 = "UpdateApplicationResourceLifecycle",
    Request: type = struct {
        application_name: []const u8,
        resource_lifecycle_config: ApplicationResourceLifecycleConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .resource_lifecycle_config = "ResourceLifecycleConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application_resource_lifecycle) } {
            return .{ .service_metadata = service_metadata, .action = update_application_resource_lifecycle };
        }
    },
    Response: type = struct {
        application_name: ?[]const u8 = null,
        resource_lifecycle_config: ?ApplicationResourceLifecycleConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .resource_lifecycle_config = "ResourceLifecycleConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
    },
} = .{};
pub const update_application_version: struct {
    action_name: []const u8 = "UpdateApplicationVersion",
    Request: type = struct {
        application_name: []const u8,
        version_label: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .version_label = "VersionLabel",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application_version) } {
            return .{ .service_metadata = service_metadata, .action = update_application_version };
        }
    },
    Response: type = struct {
        application_version: ?ApplicationVersionDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_version = "ApplicationVersion",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_configuration_template: struct {
    action_name: []const u8 = "UpdateConfigurationTemplate",
    Request: type = struct {
        application_name: []const u8,
        template_name: []const u8,
        description: ?[]const u8 = null,
        option_settings: ?[]ConfigurationOptionSetting = null,
        options_to_remove: ?[]OptionSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .template_name = "TemplateName",
                .description = "Description",
                .option_settings = "OptionSettings",
                .options_to_remove = "OptionsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_template) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_template };
        }
    },
    Response: type = struct {
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        application_name: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        deployment_status: ?[]const u8 = null,
        date_created: ?i64 = null,
        date_updated: ?i64 = null,
        option_settings: ?[]ConfigurationOptionSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .application_name = "ApplicationName",
                .template_name = "TemplateName",
                .description = "Description",
                .environment_name = "EnvironmentName",
                .deployment_status = "DeploymentStatus",
                .date_created = "DateCreated",
                .date_updated = "DateUpdated",
                .option_settings = "OptionSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
        TooManyBuckets,
    },
} = .{};
pub const update_environment: struct {
    action_name: []const u8 = "UpdateEnvironment",
    Request: type = struct {
        application_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tier: ?EnvironmentTier = null,
        version_label: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        option_settings: ?[]ConfigurationOptionSetting = null,
        options_to_remove: ?[]OptionSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .environment_id = "EnvironmentId",
                .environment_name = "EnvironmentName",
                .group_name = "GroupName",
                .description = "Description",
                .tier = "Tier",
                .version_label = "VersionLabel",
                .template_name = "TemplateName",
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .option_settings = "OptionSettings",
                .options_to_remove = "OptionsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_environment };
        }
    },
    Response: type = struct {
        environment_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        application_name: ?[]const u8 = null,
        version_label: ?[]const u8 = null,
        solution_stack_name: ?[]const u8 = null,
        platform_arn: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        endpoint_url: ?[]const u8 = null,
        cname: ?[]const u8 = null,
        date_created: ?i64 = null,
        date_updated: ?i64 = null,
        status: ?[]const u8 = null,
        abortable_operation_in_progress: ?bool = null,
        health: ?[]const u8 = null,
        health_status: ?[]const u8 = null,
        resources: ?EnvironmentResourcesDescription = null,
        tier: ?EnvironmentTier = null,
        environment_links: ?[]EnvironmentLink = null,
        environment_arn: ?[]const u8 = null,
        operations_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .environment_id = "EnvironmentId",
                .application_name = "ApplicationName",
                .version_label = "VersionLabel",
                .solution_stack_name = "SolutionStackName",
                .platform_arn = "PlatformArn",
                .template_name = "TemplateName",
                .description = "Description",
                .endpoint_url = "EndpointURL",
                .cname = "CNAME",
                .date_created = "DateCreated",
                .date_updated = "DateUpdated",
                .status = "Status",
                .abortable_operation_in_progress = "AbortableOperationInProgress",
                .health = "Health",
                .health_status = "HealthStatus",
                .resources = "Resources",
                .tier = "Tier",
                .environment_links = "EnvironmentLinks",
                .environment_arn = "EnvironmentArn",
                .operations_role = "OperationsRole",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
        TooManyBuckets,
    },
} = .{};
pub const update_tags_for_resource: struct {
    action_name: []const u8 = "UpdateTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags_to_add: ?[]Tag = null,
        tags_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags_to_add = "TagsToAdd",
                .tags_to_remove = "TagsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_tags_for_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InsufficientPrivileges,
        OperationInProgress,
        ResourceNotFound,
        ResourceTypeNotSupported,
        TooManyTags,
    },
} = .{};
pub const validate_configuration_settings: struct {
    action_name: []const u8 = "ValidateConfigurationSettings",
    Request: type = struct {
        application_name: []const u8,
        template_name: ?[]const u8 = null,
        environment_name: ?[]const u8 = null,
        option_settings: []ConfigurationOptionSetting,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "ApplicationName",
                .template_name = "TemplateName",
                .environment_name = "EnvironmentName",
                .option_settings = "OptionSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_configuration_settings) } {
            return .{ .service_metadata = service_metadata, .action = validate_configuration_settings };
        }
    },
    Response: type = struct {
        messages: ?[]struct {
            message: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            namespace: ?[]const u8 = null,
            option_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "Message",
                    .severity = "Severity",
                    .namespace = "Namespace",
                    .option_name = "OptionName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .messages = "Messages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientPrivileges,
        TooManyBuckets,
    },
} = .{};

pub const ConfigurationOptionSetting = struct {
    resource_name: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    option_name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_name = "ResourceName",
            .namespace = "Namespace",
            .option_name = "OptionName",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const EnvironmentLink = struct {
    link_name: ?[]const u8 = null,
    environment_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .link_name = "LinkName",
            .environment_name = "EnvironmentName",
        };
        return @field(mappings, field_name);
    }
};

pub const EnvironmentTier = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const EnvironmentResourcesDescription = struct {
    load_balancer: ?LoadBalancerDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .load_balancer = "LoadBalancer",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancerDescription = struct {
    load_balancer_name: ?[]const u8 = null,
    domain: ?[]const u8 = null,
    listeners: ?[]Listener = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .load_balancer_name = "LoadBalancerName",
            .domain = "Domain",
            .listeners = "Listeners",
        };
        return @field(mappings, field_name);
    }
};

pub const Listener = struct {
    protocol: ?[]const u8 = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "Protocol",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const OptionSpecification = struct {
    resource_name: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    option_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_name = "ResourceName",
            .namespace = "Namespace",
            .option_name = "OptionName",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationVersionDescription = struct {
    application_version_arn: ?[]const u8 = null,
    application_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    version_label: ?[]const u8 = null,
    source_build_information: ?SourceBuildInformation = null,
    build_arn: ?[]const u8 = null,
    source_bundle: ?S3Location = null,
    date_created: ?i64 = null,
    date_updated: ?i64 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_version_arn = "ApplicationVersionArn",
            .application_name = "ApplicationName",
            .description = "Description",
            .version_label = "VersionLabel",
            .source_build_information = "SourceBuildInformation",
            .build_arn = "BuildArn",
            .source_bundle = "SourceBundle",
            .date_created = "DateCreated",
            .date_updated = "DateUpdated",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key = "S3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceBuildInformation = struct {
    source_type: []const u8,
    source_repository: []const u8,
    source_location: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_type = "SourceType",
            .source_repository = "SourceRepository",
            .source_location = "SourceLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationResourceLifecycleConfig = struct {
    service_role: ?[]const u8 = null,
    version_lifecycle_config: ?ApplicationVersionLifecycleConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_role = "ServiceRole",
            .version_lifecycle_config = "VersionLifecycleConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationVersionLifecycleConfig = struct {
    max_count_rule: ?MaxCountRule = null,
    max_age_rule: ?MaxAgeRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_count_rule = "MaxCountRule",
            .max_age_rule = "MaxAgeRule",
        };
        return @field(mappings, field_name);
    }
};

pub const MaxAgeRule = struct {
    enabled: bool,
    max_age_in_days: ?i64 = null,
    delete_source_from_s3: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .max_age_in_days = "MaxAgeInDays",
            .delete_source_from_s3 = "DeleteSourceFromS3",
        };
        return @field(mappings, field_name);
    }
};

pub const MaxCountRule = struct {
    enabled: bool,
    max_count: ?i64 = null,
    delete_source_from_s3: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .max_count = "MaxCount",
            .delete_source_from_s3 = "DeleteSourceFromS3",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationDescription = struct {
    application_arn: ?[]const u8 = null,
    application_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    date_created: ?i64 = null,
    date_updated: ?i64 = null,
    versions: ?[][]const u8 = null,
    configuration_templates: ?[][]const u8 = null,
    resource_lifecycle_config: ?ApplicationResourceLifecycleConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_arn = "ApplicationArn",
            .application_name = "ApplicationName",
            .description = "Description",
            .date_created = "DateCreated",
            .date_updated = "DateUpdated",
            .versions = "Versions",
            .configuration_templates = "ConfigurationTemplates",
            .resource_lifecycle_config = "ResourceLifecycleConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const PlatformSummary = struct {
    platform_arn: ?[]const u8 = null,
    platform_owner: ?[]const u8 = null,
    platform_status: ?[]const u8 = null,
    platform_category: ?[]const u8 = null,
    operating_system_name: ?[]const u8 = null,
    operating_system_version: ?[]const u8 = null,
    supported_tier_list: ?[][]const u8 = null,
    supported_addon_list: ?[][]const u8 = null,
    platform_lifecycle_state: ?[]const u8 = null,
    platform_version: ?[]const u8 = null,
    platform_branch_name: ?[]const u8 = null,
    platform_branch_lifecycle_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .platform_arn = "PlatformArn",
            .platform_owner = "PlatformOwner",
            .platform_status = "PlatformStatus",
            .platform_category = "PlatformCategory",
            .operating_system_name = "OperatingSystemName",
            .operating_system_version = "OperatingSystemVersion",
            .supported_tier_list = "SupportedTierList",
            .supported_addon_list = "SupportedAddonList",
            .platform_lifecycle_state = "PlatformLifecycleState",
            .platform_version = "PlatformVersion",
            .platform_branch_name = "PlatformBranchName",
            .platform_branch_lifecycle_state = "PlatformBranchLifecycleState",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationMetrics = struct {
    duration: ?i64 = null,
    request_count: ?i64 = null,
    status_codes: ?StatusCodes = null,
    latency: ?Latency = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "Duration",
            .request_count = "RequestCount",
            .status_codes = "StatusCodes",
            .latency = "Latency",
        };
        return @field(mappings, field_name);
    }
};

pub const Latency = struct {
    p999: ?f64 = null,
    p99: ?f64 = null,
    p95: ?f64 = null,
    p90: ?f64 = null,
    p85: ?f64 = null,
    p75: ?f64 = null,
    p50: ?f64 = null,
    p10: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .p999 = "P999",
            .p99 = "P99",
            .p95 = "P95",
            .p90 = "P90",
            .p85 = "P85",
            .p75 = "P75",
            .p50 = "P50",
            .p10 = "P10",
        };
        return @field(mappings, field_name);
    }
};

pub const StatusCodes = struct {
    status2xx: ?i64 = null,
    status3xx: ?i64 = null,
    status4xx: ?i64 = null,
    status5xx: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status2xx = "Status2xx",
            .status3xx = "Status3xx",
            .status4xx = "Status4xx",
            .status5xx = "Status5xx",
        };
        return @field(mappings, field_name);
    }
};

pub const EnvironmentDescription = struct {
    environment_name: ?[]const u8 = null,
    environment_id: ?[]const u8 = null,
    application_name: ?[]const u8 = null,
    version_label: ?[]const u8 = null,
    solution_stack_name: ?[]const u8 = null,
    platform_arn: ?[]const u8 = null,
    template_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    endpoint_url: ?[]const u8 = null,
    cname: ?[]const u8 = null,
    date_created: ?i64 = null,
    date_updated: ?i64 = null,
    status: ?[]const u8 = null,
    abortable_operation_in_progress: ?bool = null,
    health: ?[]const u8 = null,
    health_status: ?[]const u8 = null,
    resources: ?EnvironmentResourcesDescription = null,
    tier: ?EnvironmentTier = null,
    environment_links: ?[]EnvironmentLink = null,
    environment_arn: ?[]const u8 = null,
    operations_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .environment_name = "EnvironmentName",
            .environment_id = "EnvironmentId",
            .application_name = "ApplicationName",
            .version_label = "VersionLabel",
            .solution_stack_name = "SolutionStackName",
            .platform_arn = "PlatformArn",
            .template_name = "TemplateName",
            .description = "Description",
            .endpoint_url = "EndpointURL",
            .cname = "CNAME",
            .date_created = "DateCreated",
            .date_updated = "DateUpdated",
            .status = "Status",
            .abortable_operation_in_progress = "AbortableOperationInProgress",
            .health = "Health",
            .health_status = "HealthStatus",
            .resources = "Resources",
            .tier = "Tier",
            .environment_links = "EnvironmentLinks",
            .environment_arn = "EnvironmentArn",
            .operations_role = "OperationsRole",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationSettingsDescription = struct {
    solution_stack_name: ?[]const u8 = null,
    platform_arn: ?[]const u8 = null,
    application_name: ?[]const u8 = null,
    template_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    environment_name: ?[]const u8 = null,
    deployment_status: ?[]const u8 = null,
    date_created: ?i64 = null,
    date_updated: ?i64 = null,
    option_settings: ?[]ConfigurationOptionSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .solution_stack_name = "SolutionStackName",
            .platform_arn = "PlatformArn",
            .application_name = "ApplicationName",
            .template_name = "TemplateName",
            .description = "Description",
            .environment_name = "EnvironmentName",
            .deployment_status = "DeploymentStatus",
            .date_created = "DateCreated",
            .date_updated = "DateUpdated",
            .option_settings = "OptionSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceQuota = struct {
    maximum: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum = "Maximum",
        };
        return @field(mappings, field_name);
    }
};
