const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "Elastic Inference";
pub const arn_namespace: ?[]const u8 = "elastic-inference";
pub const endpoint_prefix: []const u8 = "api.elastic-inference";
pub const sigv4_name: []const u8 = "elastic-inference";
pub const name: []const u8 = "EC2MatterhornCfSoothsayerApiGatewayLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "Elastic Inference",
    arn_namespace: ?[]const u8 = "elastic-inference",
    endpoint_prefix: []const u8 = "api.elastic-inference",
    sigv4_name: []const u8 = "elastic-inference",
    name: []const u8 = "EC2MatterhornCfSoothsayerApiGatewayLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const describe_accelerator_offerings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-accelerator-offerings",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAcceleratorOfferings",
    Request: type = struct {
        location_type: []const u8,
        accelerator_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_type = "locationType",
                .accelerator_types = "acceleratorTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_accelerator_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_accelerator_offerings };
        }
    },
    Response: type = struct {
        accelerator_type_offerings: ?[]struct {
            accelerator_type: ?[]const u8 = null,
            location_type: ?[]const u8 = null,
            location: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .accelerator_type = "acceleratorType",
                    .location_type = "locationType",
                    .location = "location",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_type_offerings = "acceleratorTypeOfferings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const describe_accelerators: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-accelerators",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccelerators",
    Request: type = struct {
        accelerator_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_ids = "acceleratorIds",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_accelerators) } {
            return .{ .service_metadata = service_metadata, .action = describe_accelerators };
        }
    },
    Response: type = struct {
        accelerator_set: ?[]struct {
            accelerator_health: ?struct {
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            accelerator_type: ?[]const u8 = null,
            accelerator_id: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            attached_resource: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .accelerator_health = "acceleratorHealth",
                    .accelerator_type = "acceleratorType",
                    .accelerator_id = "acceleratorId",
                    .availability_zone = "availabilityZone",
                    .attached_resource = "attachedResource",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_set = "acceleratorSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const describe_accelerator_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/describe-accelerator-types",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAcceleratorTypes",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_accelerator_types) } {
            return .{ .service_metadata = service_metadata, .action = describe_accelerator_types };
        }
    },
    Response: type = struct {
        accelerator_types: ?[]struct {
            accelerator_type_name: ?[]const u8 = null,
            memory_info: ?struct {
                size_in_mib: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .size_in_mib = "sizeInMiB",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            throughput_info: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "key",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .accelerator_type_name = "acceleratorTypeName",
                    .memory_info = "memoryInfo",
                    .throughput_info = "throughputInfo",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_types = "acceleratorTypes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
