const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-06-01";
pub const sdk_id: []const u8 = "Elastic Load Balancing";
pub const arn_namespace: ?[]const u8 = "elasticloadbalancing";
pub const endpoint_prefix: []const u8 = "elasticloadbalancing";
pub const sigv4_name: []const u8 = "elasticloadbalancing";
pub const name: []const u8 = "ElasticLoadBalancing_v7";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2012-06-01",
    sdk_id: []const u8 = "Elastic Load Balancing",
    arn_namespace: ?[]const u8 = "elasticloadbalancing",
    endpoint_prefix: []const u8 = "elasticloadbalancing",
    sigv4_name: []const u8 = "elasticloadbalancing",
    name: []const u8 = "ElasticLoadBalancing_v7",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const add_tags: struct {
    action_name: []const u8 = "AddTags",
    Request: type = struct {
        load_balancer_names: [][]const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_names = "LoadBalancerNames",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        DuplicateTagKeys,
        TooManyTags,
    },
} = .{};
pub const apply_security_groups_to_load_balancer: struct {
    action_name: []const u8 = "ApplySecurityGroupsToLoadBalancer",
    Request: type = struct {
        load_balancer_name: []const u8,
        security_groups: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .security_groups = "SecurityGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_security_groups_to_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = apply_security_groups_to_load_balancer };
        }
    },
    Response: type = struct {
        security_groups: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_groups = "SecurityGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidConfigurationRequest,
        InvalidSecurityGroup,
    },
} = .{};
pub const attach_load_balancer_to_subnets: struct {
    action_name: []const u8 = "AttachLoadBalancerToSubnets",
    Request: type = struct {
        load_balancer_name: []const u8,
        subnets: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .subnets = "Subnets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_load_balancer_to_subnets) } {
            return .{ .service_metadata = service_metadata, .action = attach_load_balancer_to_subnets };
        }
    },
    Response: type = struct {
        subnets: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnets = "Subnets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidConfigurationRequest,
        InvalidSubnet,
        SubnetNotFound,
    },
} = .{};
pub const configure_health_check: struct {
    action_name: []const u8 = "ConfigureHealthCheck",
    Request: type = struct {
        load_balancer_name: []const u8,
        health_check: HealthCheck,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .health_check = "HealthCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(configure_health_check) } {
            return .{ .service_metadata = service_metadata, .action = configure_health_check };
        }
    },
    Response: type = struct {
        health_check: ?HealthCheck = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check = "HealthCheck",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
    },
} = .{};
pub const create_app_cookie_stickiness_policy: struct {
    action_name: []const u8 = "CreateAppCookieStickinessPolicy",
    Request: type = struct {
        load_balancer_name: []const u8,
        policy_name: []const u8,
        cookie_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .policy_name = "PolicyName",
                .cookie_name = "CookieName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_cookie_stickiness_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_app_cookie_stickiness_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        DuplicatePolicyName,
        InvalidConfigurationRequest,
        TooManyPolicies,
    },
} = .{};
pub const create_lb_cookie_stickiness_policy: struct {
    action_name: []const u8 = "CreateLBCookieStickinessPolicy",
    Request: type = struct {
        load_balancer_name: []const u8,
        policy_name: []const u8,
        cookie_expiration_period: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .policy_name = "PolicyName",
                .cookie_expiration_period = "CookieExpirationPeriod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lb_cookie_stickiness_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_lb_cookie_stickiness_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        DuplicatePolicyName,
        InvalidConfigurationRequest,
        TooManyPolicies,
    },
} = .{};
pub const create_load_balancer: struct {
    action_name: []const u8 = "CreateLoadBalancer",
    Request: type = struct {
        load_balancer_name: []const u8,
        listeners: []Listener,
        availability_zones: ?[][]const u8 = null,
        subnets: ?[][]const u8 = null,
        security_groups: ?[][]const u8 = null,
        scheme: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .listeners = "Listeners",
                .availability_zones = "AvailabilityZones",
                .subnets = "Subnets",
                .security_groups = "SecurityGroups",
                .scheme = "Scheme",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = create_load_balancer };
        }
    },
    Response: type = struct {
        dns_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dns_name = "DNSName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateNotFound,
        DuplicateAccessPointName,
        DuplicateTagKeys,
        InvalidConfigurationRequest,
        InvalidScheme,
        InvalidSecurityGroup,
        InvalidSubnet,
        OperationNotPermitted,
        SubnetNotFound,
        TooManyAccessPoints,
        TooManyTags,
        UnsupportedProtocol,
    },
} = .{};
pub const create_load_balancer_listeners: struct {
    action_name: []const u8 = "CreateLoadBalancerListeners",
    Request: type = struct {
        load_balancer_name: []const u8,
        listeners: []Listener,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .listeners = "Listeners",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_load_balancer_listeners) } {
            return .{ .service_metadata = service_metadata, .action = create_load_balancer_listeners };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        CertificateNotFound,
        DuplicateListener,
        InvalidConfigurationRequest,
        UnsupportedProtocol,
    },
} = .{};
pub const create_load_balancer_policy: struct {
    action_name: []const u8 = "CreateLoadBalancerPolicy",
    Request: type = struct {
        load_balancer_name: []const u8,
        policy_name: []const u8,
        policy_type_name: []const u8,
        policy_attributes: ?[]struct {
            attribute_name: ?[]const u8 = null,
            attribute_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "AttributeName",
                    .attribute_value = "AttributeValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .policy_name = "PolicyName",
                .policy_type_name = "PolicyTypeName",
                .policy_attributes = "PolicyAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_load_balancer_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_load_balancer_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        DuplicatePolicyName,
        InvalidConfigurationRequest,
        PolicyTypeNotFound,
        TooManyPolicies,
    },
} = .{};
pub const delete_load_balancer: struct {
    action_name: []const u8 = "DeleteLoadBalancer",
    Request: type = struct {
        load_balancer_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = delete_load_balancer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_load_balancer_listeners: struct {
    action_name: []const u8 = "DeleteLoadBalancerListeners",
    Request: type = struct {
        load_balancer_name: []const u8,
        load_balancer_ports: []i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .load_balancer_ports = "LoadBalancerPorts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_load_balancer_listeners) } {
            return .{ .service_metadata = service_metadata, .action = delete_load_balancer_listeners };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
    },
} = .{};
pub const delete_load_balancer_policy: struct {
    action_name: []const u8 = "DeleteLoadBalancerPolicy",
    Request: type = struct {
        load_balancer_name: []const u8,
        policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .policy_name = "PolicyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_load_balancer_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_load_balancer_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidConfigurationRequest,
    },
} = .{};
pub const deregister_instances_from_load_balancer: struct {
    action_name: []const u8 = "DeregisterInstancesFromLoadBalancer",
    Request: type = struct {
        load_balancer_name: []const u8,
        instances: []Instance,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .instances = "Instances",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_instances_from_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = deregister_instances_from_load_balancer };
        }
    },
    Response: type = struct {
        instances: ?[]Instance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidEndPoint,
    },
} = .{};
pub const describe_account_limits: struct {
    action_name: []const u8 = "DescribeAccountLimits",
    Request: type = struct {
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_limits };
        }
    },
    Response: type = struct {
        limits: ?[]struct {
            name: ?[]const u8 = null,
            max: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .max = "Max",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limits = "Limits",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_health: struct {
    action_name: []const u8 = "DescribeInstanceHealth",
    Request: type = struct {
        load_balancer_name: []const u8,
        instances: ?[]Instance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .instances = "Instances",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_health };
        }
    },
    Response: type = struct {
        instance_states: ?[]struct {
            instance_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            reason_code: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .state = "State",
                    .reason_code = "ReasonCode",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_states = "InstanceStates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidEndPoint,
    },
} = .{};
pub const describe_load_balancer_attributes: struct {
    action_name: []const u8 = "DescribeLoadBalancerAttributes",
    Request: type = struct {
        load_balancer_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_load_balancer_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_load_balancer_attributes };
        }
    },
    Response: type = struct {
        load_balancer_attributes: ?LoadBalancerAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_attributes = "LoadBalancerAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        LoadBalancerAttributeNotFound,
    },
} = .{};
pub const describe_load_balancer_policies: struct {
    action_name: []const u8 = "DescribeLoadBalancerPolicies",
    Request: type = struct {
        load_balancer_name: ?[]const u8 = null,
        policy_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .policy_names = "PolicyNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_load_balancer_policies) } {
            return .{ .service_metadata = service_metadata, .action = describe_load_balancer_policies };
        }
    },
    Response: type = struct {
        policy_descriptions: ?[]struct {
            policy_name: ?[]const u8 = null,
            policy_type_name: ?[]const u8 = null,
            policy_attribute_descriptions: ?[]struct {
                attribute_name: ?[]const u8 = null,
                attribute_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attribute_name = "AttributeName",
                        .attribute_value = "AttributeValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_name = "PolicyName",
                    .policy_type_name = "PolicyTypeName",
                    .policy_attribute_descriptions = "PolicyAttributeDescriptions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_descriptions = "PolicyDescriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        PolicyNotFound,
    },
} = .{};
pub const describe_load_balancer_policy_types: struct {
    action_name: []const u8 = "DescribeLoadBalancerPolicyTypes",
    Request: type = struct {
        policy_type_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_type_names = "PolicyTypeNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_load_balancer_policy_types) } {
            return .{ .service_metadata = service_metadata, .action = describe_load_balancer_policy_types };
        }
    },
    Response: type = struct {
        policy_type_descriptions: ?[]struct {
            policy_type_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            policy_attribute_type_descriptions: ?[]struct {
                attribute_name: ?[]const u8 = null,
                attribute_type: ?[]const u8 = null,
                description: ?[]const u8 = null,
                default_value: ?[]const u8 = null,
                cardinality: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attribute_name = "AttributeName",
                        .attribute_type = "AttributeType",
                        .description = "Description",
                        .default_value = "DefaultValue",
                        .cardinality = "Cardinality",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_type_name = "PolicyTypeName",
                    .description = "Description",
                    .policy_attribute_type_descriptions = "PolicyAttributeTypeDescriptions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_type_descriptions = "PolicyTypeDescriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        PolicyTypeNotFound,
    },
} = .{};
pub const describe_load_balancers: struct {
    action_name: []const u8 = "DescribeLoadBalancers",
    Request: type = struct {
        load_balancer_names: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_names = "LoadBalancerNames",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_load_balancers) } {
            return .{ .service_metadata = service_metadata, .action = describe_load_balancers };
        }
    },
    Response: type = struct {
        load_balancer_descriptions: ?[]struct {
            load_balancer_name: ?[]const u8 = null,
            dns_name: ?[]const u8 = null,
            canonical_hosted_zone_name: ?[]const u8 = null,
            canonical_hosted_zone_name_id: ?[]const u8 = null,
            listener_descriptions: ?[]struct {
                listener: ?Listener = null,
                policy_names: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .listener = "Listener",
                        .policy_names = "PolicyNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            policies: ?struct {
                app_cookie_stickiness_policies: ?[]struct {
                    policy_name: ?[]const u8 = null,
                    cookie_name: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .policy_name = "PolicyName",
                            .cookie_name = "CookieName",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                lb_cookie_stickiness_policies: ?[]struct {
                    policy_name: ?[]const u8 = null,
                    cookie_expiration_period: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .policy_name = "PolicyName",
                            .cookie_expiration_period = "CookieExpirationPeriod",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                other_policies: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .app_cookie_stickiness_policies = "AppCookieStickinessPolicies",
                        .lb_cookie_stickiness_policies = "LBCookieStickinessPolicies",
                        .other_policies = "OtherPolicies",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            backend_server_descriptions: ?[]struct {
                instance_port: ?i64 = null,
                policy_names: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .instance_port = "InstancePort",
                        .policy_names = "PolicyNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            availability_zones: ?[][]const u8 = null,
            subnets: ?[][]const u8 = null,
            vpc_id: ?[]const u8 = null,
            instances: ?[]Instance = null,
            health_check: ?HealthCheck = null,
            source_security_group: ?struct {
                owner_alias: ?[]const u8 = null,
                group_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .owner_alias = "OwnerAlias",
                        .group_name = "GroupName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            security_groups: ?[][]const u8 = null,
            created_time: ?i64 = null,
            scheme: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .load_balancer_name = "LoadBalancerName",
                    .dns_name = "DNSName",
                    .canonical_hosted_zone_name = "CanonicalHostedZoneName",
                    .canonical_hosted_zone_name_id = "CanonicalHostedZoneNameID",
                    .listener_descriptions = "ListenerDescriptions",
                    .policies = "Policies",
                    .backend_server_descriptions = "BackendServerDescriptions",
                    .availability_zones = "AvailabilityZones",
                    .subnets = "Subnets",
                    .vpc_id = "VPCId",
                    .instances = "Instances",
                    .health_check = "HealthCheck",
                    .source_security_group = "SourceSecurityGroup",
                    .security_groups = "SecurityGroups",
                    .created_time = "CreatedTime",
                    .scheme = "Scheme",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_descriptions = "LoadBalancerDescriptions",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        DependencyThrottle,
    },
} = .{};
pub const describe_tags: struct {
    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        load_balancer_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_names = "LoadBalancerNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        tag_descriptions: ?[]struct {
            load_balancer_name: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .load_balancer_name = "LoadBalancerName",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_descriptions = "TagDescriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
    },
} = .{};
pub const detach_load_balancer_from_subnets: struct {
    action_name: []const u8 = "DetachLoadBalancerFromSubnets",
    Request: type = struct {
        load_balancer_name: []const u8,
        subnets: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .subnets = "Subnets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_load_balancer_from_subnets) } {
            return .{ .service_metadata = service_metadata, .action = detach_load_balancer_from_subnets };
        }
    },
    Response: type = struct {
        subnets: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnets = "Subnets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidConfigurationRequest,
    },
} = .{};
pub const disable_availability_zones_for_load_balancer: struct {
    action_name: []const u8 = "DisableAvailabilityZonesForLoadBalancer",
    Request: type = struct {
        load_balancer_name: []const u8,
        availability_zones: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .availability_zones = "AvailabilityZones",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_availability_zones_for_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = disable_availability_zones_for_load_balancer };
        }
    },
    Response: type = struct {
        availability_zones: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZones",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidConfigurationRequest,
    },
} = .{};
pub const enable_availability_zones_for_load_balancer: struct {
    action_name: []const u8 = "EnableAvailabilityZonesForLoadBalancer",
    Request: type = struct {
        load_balancer_name: []const u8,
        availability_zones: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .availability_zones = "AvailabilityZones",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_availability_zones_for_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = enable_availability_zones_for_load_balancer };
        }
    },
    Response: type = struct {
        availability_zones: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZones",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
    },
} = .{};
pub const modify_load_balancer_attributes: struct {
    action_name: []const u8 = "ModifyLoadBalancerAttributes",
    Request: type = struct {
        load_balancer_name: []const u8,
        load_balancer_attributes: LoadBalancerAttributes,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .load_balancer_attributes = "LoadBalancerAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_load_balancer_attributes) } {
            return .{ .service_metadata = service_metadata, .action = modify_load_balancer_attributes };
        }
    },
    Response: type = struct {
        load_balancer_name: ?[]const u8 = null,
        load_balancer_attributes: ?LoadBalancerAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .load_balancer_attributes = "LoadBalancerAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidConfigurationRequest,
        LoadBalancerAttributeNotFound,
    },
} = .{};
pub const register_instances_with_load_balancer: struct {
    action_name: []const u8 = "RegisterInstancesWithLoadBalancer",
    Request: type = struct {
        load_balancer_name: []const u8,
        instances: []Instance,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .instances = "Instances",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_instances_with_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = register_instances_with_load_balancer };
        }
    },
    Response: type = struct {
        instances: ?[]Instance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidEndPoint,
    },
} = .{};
pub const remove_tags: struct {
    action_name: []const u8 = "RemoveTags",
    Request: type = struct {
        load_balancer_names: [][]const u8,
        tags: []struct {
            key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_names = "LoadBalancerNames",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
    },
} = .{};
pub const set_load_balancer_listener_ssl_certificate: struct {
    action_name: []const u8 = "SetLoadBalancerListenerSSLCertificate",
    Request: type = struct {
        load_balancer_name: []const u8,
        load_balancer_port: i64,
        ssl_certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .load_balancer_port = "LoadBalancerPort",
                .ssl_certificate_id = "SSLCertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_load_balancer_listener_ssl_certificate) } {
            return .{ .service_metadata = service_metadata, .action = set_load_balancer_listener_ssl_certificate };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        CertificateNotFound,
        InvalidConfigurationRequest,
        ListenerNotFound,
        UnsupportedProtocol,
    },
} = .{};
pub const set_load_balancer_policies_for_backend_server: struct {
    action_name: []const u8 = "SetLoadBalancerPoliciesForBackendServer",
    Request: type = struct {
        load_balancer_name: []const u8,
        instance_port: i64,
        policy_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .instance_port = "InstancePort",
                .policy_names = "PolicyNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_load_balancer_policies_for_backend_server) } {
            return .{ .service_metadata = service_metadata, .action = set_load_balancer_policies_for_backend_server };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidConfigurationRequest,
        PolicyNotFound,
    },
} = .{};
pub const set_load_balancer_policies_of_listener: struct {
    action_name: []const u8 = "SetLoadBalancerPoliciesOfListener",
    Request: type = struct {
        load_balancer_name: []const u8,
        load_balancer_port: i64,
        policy_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_name = "LoadBalancerName",
                .load_balancer_port = "LoadBalancerPort",
                .policy_names = "PolicyNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_load_balancer_policies_of_listener) } {
            return .{ .service_metadata = service_metadata, .action = set_load_balancer_policies_of_listener };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessPointNotFound,
        InvalidConfigurationRequest,
        ListenerNotFound,
        PolicyNotFound,
    },
} = .{};

pub const Instance = struct {
    instance_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancerAttributes = struct {
    cross_zone_load_balancing: ?CrossZoneLoadBalancing = null,
    access_log: ?AccessLog = null,
    connection_draining: ?ConnectionDraining = null,
    connection_settings: ?ConnectionSettings = null,
    additional_attributes: ?[]AdditionalAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cross_zone_load_balancing = "CrossZoneLoadBalancing",
            .access_log = "AccessLog",
            .connection_draining = "ConnectionDraining",
            .connection_settings = "ConnectionSettings",
            .additional_attributes = "AdditionalAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const AdditionalAttribute = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionSettings = struct {
    idle_timeout: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .idle_timeout = "IdleTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionDraining = struct {
    enabled: bool,
    timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .timeout = "Timeout",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessLog = struct {
    enabled: bool,
    s3_bucket_name: ?[]const u8 = null,
    emit_interval: ?i64 = null,
    s3_bucket_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .s3_bucket_name = "S3BucketName",
            .emit_interval = "EmitInterval",
            .s3_bucket_prefix = "S3BucketPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const CrossZoneLoadBalancing = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const HealthCheck = struct {
    target: []const u8,
    interval: i64,
    timeout: i64,
    unhealthy_threshold: i64,
    healthy_threshold: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target = "Target",
            .interval = "Interval",
            .timeout = "Timeout",
            .unhealthy_threshold = "UnhealthyThreshold",
            .healthy_threshold = "HealthyThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const Listener = struct {
    protocol: []const u8,
    load_balancer_port: i64,
    instance_protocol: ?[]const u8 = null,
    instance_port: i64,
    ssl_certificate_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "Protocol",
            .load_balancer_port = "LoadBalancerPort",
            .instance_protocol = "InstanceProtocol",
            .instance_port = "InstancePort",
            .ssl_certificate_id = "SSLCertificateId",
        };
        return @field(mappings, field_name);
    }
};
