const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-12-01";
pub const sdk_id: []const u8 = "Elastic Load Balancing v2";
pub const arn_namespace: ?[]const u8 = "elasticloadbalancing";
pub const endpoint_prefix: []const u8 = "elasticloadbalancing";
pub const sigv4_name: []const u8 = "elasticloadbalancing";
pub const name: []const u8 = "ElasticLoadBalancing_v10";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2015-12-01",
    sdk_id: []const u8 = "Elastic Load Balancing v2",
    arn_namespace: ?[]const u8 = "elasticloadbalancing",
    endpoint_prefix: []const u8 = "elasticloadbalancing",
    sigv4_name: []const u8 = "elasticloadbalancing",
    name: []const u8 = "ElasticLoadBalancing_v10",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const add_listener_certificates: struct {
    action_name: []const u8 = "AddListenerCertificates",
    Request: type = struct {
        listener_arn: []const u8,
        certificates: []Certificate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .certificates = "Certificates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_listener_certificates) } {
            return .{ .service_metadata = service_metadata, .action = add_listener_certificates };
        }
    },
    Response: type = struct {
        certificates: ?[]Certificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificates = "Certificates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateNotFound,
        ListenerNotFound,
        TooManyCertificates,
    },
} = .{};
pub const add_tags: struct {
    action_name: []const u8 = "AddTags",
    Request: type = struct {
        resource_arns: [][]const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "ResourceArns",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateTagKeys,
        ListenerNotFound,
        LoadBalancerNotFound,
        RuleNotFound,
        TargetGroupNotFound,
        TooManyTags,
        TrustStoreNotFound,
    },
} = .{};
pub const add_trust_store_revocations: struct {
    action_name: []const u8 = "AddTrustStoreRevocations",
    Request: type = struct {
        trust_store_arn: []const u8,
        revocation_contents: ?[]struct {
            s3_bucket: ?[]const u8 = null,
            s3_key: ?[]const u8 = null,
            s3_object_version: ?[]const u8 = null,
            revocation_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_bucket = "S3Bucket",
                    .s3_key = "S3Key",
                    .s3_object_version = "S3ObjectVersion",
                    .revocation_type = "RevocationType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arn = "TrustStoreArn",
                .revocation_contents = "RevocationContents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_trust_store_revocations) } {
            return .{ .service_metadata = service_metadata, .action = add_trust_store_revocations };
        }
    },
    Response: type = struct {
        trust_store_revocations: ?[]struct {
            trust_store_arn: ?[]const u8 = null,
            revocation_id: ?i64 = null,
            revocation_type: ?[]const u8 = null,
            number_of_revoked_entries: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trust_store_arn = "TrustStoreArn",
                    .revocation_id = "RevocationId",
                    .revocation_type = "RevocationType",
                    .number_of_revoked_entries = "NumberOfRevokedEntries",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_revocations = "TrustStoreRevocations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRevocationContent,
        RevocationContentNotFound,
        TooManyTrustStoreRevocationEntries,
        TrustStoreNotFound,
    },
} = .{};
pub const create_listener: struct {
    action_name: []const u8 = "CreateListener",
    Request: type = struct {
        load_balancer_arn: []const u8,
        protocol: ?[]const u8 = null,
        port: ?i64 = null,
        ssl_policy: ?[]const u8 = null,
        certificates: ?[]Certificate = null,
        default_actions: []Action,
        alpn_policy: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        mutual_authentication: ?MutualAuthenticationAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
                .protocol = "Protocol",
                .port = "Port",
                .ssl_policy = "SslPolicy",
                .certificates = "Certificates",
                .default_actions = "DefaultActions",
                .alpn_policy = "AlpnPolicy",
                .tags = "Tags",
                .mutual_authentication = "MutualAuthentication",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_listener) } {
            return .{ .service_metadata = service_metadata, .action = create_listener };
        }
    },
    Response: type = struct {
        listeners: ?[]Listener = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listeners = "Listeners",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ALPNPolicyNotSupported,
        CertificateNotFound,
        DuplicateListener,
        IncompatibleProtocols,
        InvalidConfigurationRequest,
        InvalidLoadBalancerAction,
        LoadBalancerNotFound,
        SSLPolicyNotFound,
        TargetGroupAssociationLimit,
        TargetGroupNotFound,
        TooManyActions,
        TooManyCertificates,
        TooManyListeners,
        TooManyRegistrationsForTargetId,
        TooManyTags,
        TooManyTargets,
        TooManyUniqueTargetGroupsPerLoadBalancer,
        TrustStoreNotFound,
        TrustStoreNotReady,
        UnsupportedProtocol,
    },
} = .{};
pub const create_load_balancer: struct {
    action_name: []const u8 = "CreateLoadBalancer",
    Request: type = struct {
        name: []const u8,
        subnets: ?[][]const u8 = null,
        subnet_mappings: ?[]SubnetMapping = null,
        security_groups: ?[][]const u8 = null,
        scheme: ?[]const u8 = null,
        tags: ?[]Tag = null,
        type: ?[]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        customer_owned_ipv4_pool: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .subnets = "Subnets",
                .subnet_mappings = "SubnetMappings",
                .security_groups = "SecurityGroups",
                .scheme = "Scheme",
                .tags = "Tags",
                .type = "Type",
                .ip_address_type = "IpAddressType",
                .customer_owned_ipv4_pool = "CustomerOwnedIpv4Pool",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = create_load_balancer };
        }
    },
    Response: type = struct {
        load_balancers: ?[]LoadBalancer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancers = "LoadBalancers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AllocationIdNotFound,
        AvailabilityZoneNotSupported,
        DuplicateLoadBalancerName,
        DuplicateTagKeys,
        InvalidConfigurationRequest,
        InvalidScheme,
        InvalidSecurityGroup,
        InvalidSubnet,
        OperationNotPermitted,
        ResourceInUse,
        SubnetNotFound,
        TooManyLoadBalancers,
        TooManyTags,
    },
} = .{};
pub const create_rule: struct {
    action_name: []const u8 = "CreateRule",
    Request: type = struct {
        listener_arn: []const u8,
        conditions: []RuleCondition,
        priority: i64,
        actions: []Action,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .conditions = "Conditions",
                .priority = "Priority",
                .actions = "Actions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_rule };
        }
    },
    Response: type = struct {
        rules: ?[]Rule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IncompatibleProtocols,
        InvalidConfigurationRequest,
        InvalidLoadBalancerAction,
        ListenerNotFound,
        PriorityInUse,
        TargetGroupAssociationLimit,
        TargetGroupNotFound,
        TooManyActions,
        TooManyRegistrationsForTargetId,
        TooManyRules,
        TooManyTags,
        TooManyTargetGroups,
        TooManyTargets,
        TooManyUniqueTargetGroupsPerLoadBalancer,
        UnsupportedProtocol,
    },
} = .{};
pub const create_target_group: struct {
    action_name: []const u8 = "CreateTargetGroup",
    Request: type = struct {
        name: []const u8,
        protocol: ?[]const u8 = null,
        protocol_version: ?[]const u8 = null,
        port: ?i64 = null,
        vpc_id: ?[]const u8 = null,
        health_check_protocol: ?[]const u8 = null,
        health_check_port: ?[]const u8 = null,
        health_check_enabled: ?bool = null,
        health_check_path: ?[]const u8 = null,
        health_check_interval_seconds: ?i64 = null,
        health_check_timeout_seconds: ?i64 = null,
        healthy_threshold_count: ?i64 = null,
        unhealthy_threshold_count: ?i64 = null,
        matcher: ?Matcher = null,
        target_type: ?[]const u8 = null,
        tags: ?[]Tag = null,
        ip_address_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .protocol = "Protocol",
                .protocol_version = "ProtocolVersion",
                .port = "Port",
                .vpc_id = "VpcId",
                .health_check_protocol = "HealthCheckProtocol",
                .health_check_port = "HealthCheckPort",
                .health_check_enabled = "HealthCheckEnabled",
                .health_check_path = "HealthCheckPath",
                .health_check_interval_seconds = "HealthCheckIntervalSeconds",
                .health_check_timeout_seconds = "HealthCheckTimeoutSeconds",
                .healthy_threshold_count = "HealthyThresholdCount",
                .unhealthy_threshold_count = "UnhealthyThresholdCount",
                .matcher = "Matcher",
                .target_type = "TargetType",
                .tags = "Tags",
                .ip_address_type = "IpAddressType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_target_group) } {
            return .{ .service_metadata = service_metadata, .action = create_target_group };
        }
    },
    Response: type = struct {
        target_groups: ?[]TargetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_groups = "TargetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateTargetGroupName,
        InvalidConfigurationRequest,
        TooManyTags,
        TooManyTargetGroups,
    },
} = .{};
pub const create_trust_store: struct {
    action_name: []const u8 = "CreateTrustStore",
    Request: type = struct {
        name: []const u8,
        ca_certificates_bundle_s3_bucket: []const u8,
        ca_certificates_bundle_s3_key: []const u8,
        ca_certificates_bundle_s3_object_version: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .ca_certificates_bundle_s3_bucket = "CaCertificatesBundleS3Bucket",
                .ca_certificates_bundle_s3_key = "CaCertificatesBundleS3Key",
                .ca_certificates_bundle_s3_object_version = "CaCertificatesBundleS3ObjectVersion",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trust_store) } {
            return .{ .service_metadata = service_metadata, .action = create_trust_store };
        }
    },
    Response: type = struct {
        trust_stores: ?[]TrustStore = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_stores = "TrustStores",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CaCertificatesBundleNotFound,
        DuplicateTagKeys,
        DuplicateTrustStoreName,
        InvalidCaCertificatesBundle,
        TooManyTags,
        TooManyTrustStores,
    },
} = .{};
pub const delete_listener: struct {
    action_name: []const u8 = "DeleteListener",
    Request: type = struct {
        listener_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_listener) } {
            return .{ .service_metadata = service_metadata, .action = delete_listener };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ListenerNotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_load_balancer: struct {
    action_name: []const u8 = "DeleteLoadBalancer",
    Request: type = struct {
        load_balancer_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_load_balancer) } {
            return .{ .service_metadata = service_metadata, .action = delete_load_balancer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LoadBalancerNotFound,
        OperationNotPermitted,
        ResourceInUse,
    },
} = .{};
pub const delete_rule: struct {
    action_name: []const u8 = "DeleteRule",
    Request: type = struct {
        rule_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_arn = "RuleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        RuleNotFound,
    },
} = .{};
pub const delete_target_group: struct {
    action_name: []const u8 = "DeleteTargetGroup",
    Request: type = struct {
        target_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_group_arn = "TargetGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_target_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_target_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
    },
} = .{};
pub const delete_trust_store: struct {
    action_name: []const u8 = "DeleteTrustStore",
    Request: type = struct {
        trust_store_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arn = "TrustStoreArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trust_store) } {
            return .{ .service_metadata = service_metadata, .action = delete_trust_store };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TrustStoreInUse,
        TrustStoreNotFound,
    },
} = .{};
pub const deregister_targets: struct {
    action_name: []const u8 = "DeregisterTargets",
    Request: type = struct {
        target_group_arn: []const u8,
        targets: []TargetDescription,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_group_arn = "TargetGroupArn",
                .targets = "Targets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_targets) } {
            return .{ .service_metadata = service_metadata, .action = deregister_targets };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTarget,
        TargetGroupNotFound,
    },
} = .{};
pub const describe_account_limits: struct {
    action_name: []const u8 = "DescribeAccountLimits",
    Request: type = struct {
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_limits };
        }
    },
    Response: type = struct {
        limits: ?[]struct {
            name: ?[]const u8 = null,
            max: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .max = "Max",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limits = "Limits",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_listener_certificates: struct {
    action_name: []const u8 = "DescribeListenerCertificates",
    Request: type = struct {
        listener_arn: []const u8,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_listener_certificates) } {
            return .{ .service_metadata = service_metadata, .action = describe_listener_certificates };
        }
    },
    Response: type = struct {
        certificates: ?[]Certificate = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificates = "Certificates",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ListenerNotFound,
    },
} = .{};
pub const describe_listeners: struct {
    action_name: []const u8 = "DescribeListeners",
    Request: type = struct {
        load_balancer_arn: ?[]const u8 = null,
        listener_arns: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
                .listener_arns = "ListenerArns",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_listeners) } {
            return .{ .service_metadata = service_metadata, .action = describe_listeners };
        }
    },
    Response: type = struct {
        listeners: ?[]Listener = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listeners = "Listeners",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ListenerNotFound,
        LoadBalancerNotFound,
        UnsupportedProtocol,
    },
} = .{};
pub const describe_load_balancer_attributes: struct {
    action_name: []const u8 = "DescribeLoadBalancerAttributes",
    Request: type = struct {
        load_balancer_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_load_balancer_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_load_balancer_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]LoadBalancerAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LoadBalancerNotFound,
    },
} = .{};
pub const describe_load_balancers: struct {
    action_name: []const u8 = "DescribeLoadBalancers",
    Request: type = struct {
        load_balancer_arns: ?[][]const u8 = null,
        names: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arns = "LoadBalancerArns",
                .names = "Names",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_load_balancers) } {
            return .{ .service_metadata = service_metadata, .action = describe_load_balancers };
        }
    },
    Response: type = struct {
        load_balancers: ?[]LoadBalancer = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancers = "LoadBalancers",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LoadBalancerNotFound,
    },
} = .{};
pub const describe_rules: struct {
    action_name: []const u8 = "DescribeRules",
    Request: type = struct {
        listener_arn: ?[]const u8 = null,
        rule_arns: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .rule_arns = "RuleArns",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_rules) } {
            return .{ .service_metadata = service_metadata, .action = describe_rules };
        }
    },
    Response: type = struct {
        rules: ?[]Rule = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ListenerNotFound,
        RuleNotFound,
        UnsupportedProtocol,
    },
} = .{};
pub const describe_ssl_policies: struct {
    action_name: []const u8 = "DescribeSSLPolicies",
    Request: type = struct {
        names: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,
        load_balancer_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .marker = "Marker",
                .page_size = "PageSize",
                .load_balancer_type = "LoadBalancerType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ssl_policies) } {
            return .{ .service_metadata = service_metadata, .action = describe_ssl_policies };
        }
    },
    Response: type = struct {
        ssl_policies: ?[]struct {
            ssl_protocols: ?[][]const u8 = null,
            ciphers: ?[]struct {
                name: ?[]const u8 = null,
                priority: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .priority = "Priority",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            name: ?[]const u8 = null,
            supported_load_balancer_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ssl_protocols = "SslProtocols",
                    .ciphers = "Ciphers",
                    .name = "Name",
                    .supported_load_balancer_types = "SupportedLoadBalancerTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ssl_policies = "SslPolicies",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        SSLPolicyNotFound,
    },
} = .{};
pub const describe_tags: struct {
    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        resource_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "ResourceArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        tag_descriptions: ?[]struct {
            resource_arn: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceArn",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_descriptions = "TagDescriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ListenerNotFound,
        LoadBalancerNotFound,
        RuleNotFound,
        TargetGroupNotFound,
        TrustStoreNotFound,
    },
} = .{};
pub const describe_target_group_attributes: struct {
    action_name: []const u8 = "DescribeTargetGroupAttributes",
    Request: type = struct {
        target_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_group_arn = "TargetGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_target_group_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_target_group_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]TargetGroupAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TargetGroupNotFound,
    },
} = .{};
pub const describe_target_groups: struct {
    action_name: []const u8 = "DescribeTargetGroups",
    Request: type = struct {
        load_balancer_arn: ?[]const u8 = null,
        target_group_arns: ?[][]const u8 = null,
        names: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
                .target_group_arns = "TargetGroupArns",
                .names = "Names",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_target_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_target_groups };
        }
    },
    Response: type = struct {
        target_groups: ?[]TargetGroup = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_groups = "TargetGroups",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LoadBalancerNotFound,
        TargetGroupNotFound,
    },
} = .{};
pub const describe_target_health: struct {
    action_name: []const u8 = "DescribeTargetHealth",
    Request: type = struct {
        target_group_arn: []const u8,
        targets: ?[]TargetDescription = null,
        include: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_group_arn = "TargetGroupArn",
                .targets = "Targets",
                .include = "Include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_target_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_target_health };
        }
    },
    Response: type = struct {
        target_health_descriptions: ?[]struct {
            target: ?TargetDescription = null,
            health_check_port: ?[]const u8 = null,
            target_health: ?struct {
                state: ?[]const u8 = null,
                reason: ?[]const u8 = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state = "State",
                        .reason = "Reason",
                        .description = "Description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            anomaly_detection: ?struct {
                result: ?[]const u8 = null,
                mitigation_in_effect: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .result = "Result",
                        .mitigation_in_effect = "MitigationInEffect",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .target = "Target",
                    .health_check_port = "HealthCheckPort",
                    .target_health = "TargetHealth",
                    .anomaly_detection = "AnomalyDetection",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_health_descriptions = "TargetHealthDescriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HealthUnavailable,
        InvalidTarget,
        TargetGroupNotFound,
    },
} = .{};
pub const describe_trust_store_associations: struct {
    action_name: []const u8 = "DescribeTrustStoreAssociations",
    Request: type = struct {
        trust_store_arn: []const u8,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arn = "TrustStoreArn",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trust_store_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_trust_store_associations };
        }
    },
    Response: type = struct {
        trust_store_associations: ?[]struct {
            resource_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_associations = "TrustStoreAssociations",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TrustStoreNotFound,
    },
} = .{};
pub const describe_trust_store_revocations: struct {
    action_name: []const u8 = "DescribeTrustStoreRevocations",
    Request: type = struct {
        trust_store_arn: []const u8,
        revocation_ids: ?[]i64 = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arn = "TrustStoreArn",
                .revocation_ids = "RevocationIds",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trust_store_revocations) } {
            return .{ .service_metadata = service_metadata, .action = describe_trust_store_revocations };
        }
    },
    Response: type = struct {
        trust_store_revocations: ?[]struct {
            trust_store_arn: ?[]const u8 = null,
            revocation_id: ?i64 = null,
            revocation_type: ?[]const u8 = null,
            number_of_revoked_entries: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trust_store_arn = "TrustStoreArn",
                    .revocation_id = "RevocationId",
                    .revocation_type = "RevocationType",
                    .number_of_revoked_entries = "NumberOfRevokedEntries",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_revocations = "TrustStoreRevocations",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RevocationIdNotFound,
        TrustStoreNotFound,
    },
} = .{};
pub const describe_trust_stores: struct {
    action_name: []const u8 = "DescribeTrustStores",
    Request: type = struct {
        trust_store_arns: ?[][]const u8 = null,
        names: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arns = "TrustStoreArns",
                .names = "Names",
                .marker = "Marker",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trust_stores) } {
            return .{ .service_metadata = service_metadata, .action = describe_trust_stores };
        }
    },
    Response: type = struct {
        trust_stores: ?[]TrustStore = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_stores = "TrustStores",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TrustStoreNotFound,
    },
} = .{};
pub const get_trust_store_ca_certificates_bundle: struct {
    action_name: []const u8 = "GetTrustStoreCaCertificatesBundle",
    Request: type = struct {
        trust_store_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arn = "TrustStoreArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trust_store_ca_certificates_bundle) } {
            return .{ .service_metadata = service_metadata, .action = get_trust_store_ca_certificates_bundle };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TrustStoreNotFound,
    },
} = .{};
pub const get_trust_store_revocation_content: struct {
    action_name: []const u8 = "GetTrustStoreRevocationContent",
    Request: type = struct {
        trust_store_arn: []const u8,
        revocation_id: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arn = "TrustStoreArn",
                .revocation_id = "RevocationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trust_store_revocation_content) } {
            return .{ .service_metadata = service_metadata, .action = get_trust_store_revocation_content };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RevocationIdNotFound,
        TrustStoreNotFound,
    },
} = .{};
pub const modify_listener: struct {
    action_name: []const u8 = "ModifyListener",
    Request: type = struct {
        listener_arn: []const u8,
        port: ?i64 = null,
        protocol: ?[]const u8 = null,
        ssl_policy: ?[]const u8 = null,
        certificates: ?[]Certificate = null,
        default_actions: ?[]Action = null,
        alpn_policy: ?[][]const u8 = null,
        mutual_authentication: ?MutualAuthenticationAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .port = "Port",
                .protocol = "Protocol",
                .ssl_policy = "SslPolicy",
                .certificates = "Certificates",
                .default_actions = "DefaultActions",
                .alpn_policy = "AlpnPolicy",
                .mutual_authentication = "MutualAuthentication",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_listener) } {
            return .{ .service_metadata = service_metadata, .action = modify_listener };
        }
    },
    Response: type = struct {
        listeners: ?[]Listener = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listeners = "Listeners",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ALPNPolicyNotSupported,
        CertificateNotFound,
        DuplicateListener,
        IncompatibleProtocols,
        InvalidConfigurationRequest,
        InvalidLoadBalancerAction,
        ListenerNotFound,
        SSLPolicyNotFound,
        TargetGroupAssociationLimit,
        TargetGroupNotFound,
        TooManyActions,
        TooManyCertificates,
        TooManyListeners,
        TooManyRegistrationsForTargetId,
        TooManyTargets,
        TooManyUniqueTargetGroupsPerLoadBalancer,
        TrustStoreNotFound,
        TrustStoreNotReady,
        UnsupportedProtocol,
    },
} = .{};
pub const modify_load_balancer_attributes: struct {
    action_name: []const u8 = "ModifyLoadBalancerAttributes",
    Request: type = struct {
        load_balancer_arn: []const u8,
        attributes: []LoadBalancerAttribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_load_balancer_attributes) } {
            return .{ .service_metadata = service_metadata, .action = modify_load_balancer_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]LoadBalancerAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidConfigurationRequest,
        LoadBalancerNotFound,
    },
} = .{};
pub const modify_rule: struct {
    action_name: []const u8 = "ModifyRule",
    Request: type = struct {
        rule_arn: []const u8,
        conditions: ?[]RuleCondition = null,
        actions: ?[]Action = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_arn = "RuleArn",
                .conditions = "Conditions",
                .actions = "Actions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_rule) } {
            return .{ .service_metadata = service_metadata, .action = modify_rule };
        }
    },
    Response: type = struct {
        rules: ?[]Rule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IncompatibleProtocols,
        InvalidLoadBalancerAction,
        OperationNotPermitted,
        RuleNotFound,
        TargetGroupAssociationLimit,
        TargetGroupNotFound,
        TooManyActions,
        TooManyRegistrationsForTargetId,
        TooManyTargets,
        TooManyUniqueTargetGroupsPerLoadBalancer,
        UnsupportedProtocol,
    },
} = .{};
pub const modify_target_group: struct {
    action_name: []const u8 = "ModifyTargetGroup",
    Request: type = struct {
        target_group_arn: []const u8,
        health_check_protocol: ?[]const u8 = null,
        health_check_port: ?[]const u8 = null,
        health_check_path: ?[]const u8 = null,
        health_check_enabled: ?bool = null,
        health_check_interval_seconds: ?i64 = null,
        health_check_timeout_seconds: ?i64 = null,
        healthy_threshold_count: ?i64 = null,
        unhealthy_threshold_count: ?i64 = null,
        matcher: ?Matcher = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_group_arn = "TargetGroupArn",
                .health_check_protocol = "HealthCheckProtocol",
                .health_check_port = "HealthCheckPort",
                .health_check_path = "HealthCheckPath",
                .health_check_enabled = "HealthCheckEnabled",
                .health_check_interval_seconds = "HealthCheckIntervalSeconds",
                .health_check_timeout_seconds = "HealthCheckTimeoutSeconds",
                .healthy_threshold_count = "HealthyThresholdCount",
                .unhealthy_threshold_count = "UnhealthyThresholdCount",
                .matcher = "Matcher",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_target_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_target_group };
        }
    },
    Response: type = struct {
        target_groups: ?[]TargetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_groups = "TargetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidConfigurationRequest,
        TargetGroupNotFound,
    },
} = .{};
pub const modify_target_group_attributes: struct {
    action_name: []const u8 = "ModifyTargetGroupAttributes",
    Request: type = struct {
        target_group_arn: []const u8,
        attributes: []TargetGroupAttribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_group_arn = "TargetGroupArn",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_target_group_attributes) } {
            return .{ .service_metadata = service_metadata, .action = modify_target_group_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]TargetGroupAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidConfigurationRequest,
        TargetGroupNotFound,
    },
} = .{};
pub const modify_trust_store: struct {
    action_name: []const u8 = "ModifyTrustStore",
    Request: type = struct {
        trust_store_arn: []const u8,
        ca_certificates_bundle_s3_bucket: []const u8,
        ca_certificates_bundle_s3_key: []const u8,
        ca_certificates_bundle_s3_object_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arn = "TrustStoreArn",
                .ca_certificates_bundle_s3_bucket = "CaCertificatesBundleS3Bucket",
                .ca_certificates_bundle_s3_key = "CaCertificatesBundleS3Key",
                .ca_certificates_bundle_s3_object_version = "CaCertificatesBundleS3ObjectVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_trust_store) } {
            return .{ .service_metadata = service_metadata, .action = modify_trust_store };
        }
    },
    Response: type = struct {
        trust_stores: ?[]TrustStore = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_stores = "TrustStores",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CaCertificatesBundleNotFound,
        InvalidCaCertificatesBundle,
        TrustStoreNotFound,
    },
} = .{};
pub const register_targets: struct {
    action_name: []const u8 = "RegisterTargets",
    Request: type = struct {
        target_group_arn: []const u8,
        targets: []TargetDescription,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_group_arn = "TargetGroupArn",
                .targets = "Targets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_targets) } {
            return .{ .service_metadata = service_metadata, .action = register_targets };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTarget,
        TargetGroupNotFound,
        TooManyRegistrationsForTargetId,
        TooManyTargets,
    },
} = .{};
pub const remove_listener_certificates: struct {
    action_name: []const u8 = "RemoveListenerCertificates",
    Request: type = struct {
        listener_arn: []const u8,
        certificates: []Certificate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .certificates = "Certificates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_listener_certificates) } {
            return .{ .service_metadata = service_metadata, .action = remove_listener_certificates };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ListenerNotFound,
        OperationNotPermitted,
    },
} = .{};
pub const remove_tags: struct {
    action_name: []const u8 = "RemoveTags",
    Request: type = struct {
        resource_arns: [][]const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "ResourceArns",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ListenerNotFound,
        LoadBalancerNotFound,
        RuleNotFound,
        TargetGroupNotFound,
        TooManyTags,
        TrustStoreNotFound,
    },
} = .{};
pub const remove_trust_store_revocations: struct {
    action_name: []const u8 = "RemoveTrustStoreRevocations",
    Request: type = struct {
        trust_store_arn: []const u8,
        revocation_ids: []i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_store_arn = "TrustStoreArn",
                .revocation_ids = "RevocationIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_trust_store_revocations) } {
            return .{ .service_metadata = service_metadata, .action = remove_trust_store_revocations };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RevocationIdNotFound,
        TrustStoreNotFound,
    },
} = .{};
pub const set_ip_address_type: struct {
    action_name: []const u8 = "SetIpAddressType",
    Request: type = struct {
        load_balancer_arn: []const u8,
        ip_address_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
                .ip_address_type = "IpAddressType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_ip_address_type) } {
            return .{ .service_metadata = service_metadata, .action = set_ip_address_type };
        }
    },
    Response: type = struct {
        ip_address_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_address_type = "IpAddressType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidConfigurationRequest,
        InvalidSubnet,
        LoadBalancerNotFound,
    },
} = .{};
pub const set_rule_priorities: struct {
    action_name: []const u8 = "SetRulePriorities",
    Request: type = struct {
        rule_priorities: []struct {
            rule_arn: ?[]const u8 = null,
            priority: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_arn = "RuleArn",
                    .priority = "Priority",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_priorities = "RulePriorities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_rule_priorities) } {
            return .{ .service_metadata = service_metadata, .action = set_rule_priorities };
        }
    },
    Response: type = struct {
        rules: ?[]Rule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        PriorityInUse,
        RuleNotFound,
    },
} = .{};
pub const set_security_groups: struct {
    action_name: []const u8 = "SetSecurityGroups",
    Request: type = struct {
        load_balancer_arn: []const u8,
        security_groups: [][]const u8,
        enforce_security_group_inbound_rules_on_private_link_traffic: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
                .security_groups = "SecurityGroups",
                .enforce_security_group_inbound_rules_on_private_link_traffic = "EnforceSecurityGroupInboundRulesOnPrivateLinkTraffic",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = set_security_groups };
        }
    },
    Response: type = struct {
        security_group_ids: ?[][]const u8 = null,
        enforce_security_group_inbound_rules_on_private_link_traffic: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_group_ids = "SecurityGroupIds",
                .enforce_security_group_inbound_rules_on_private_link_traffic = "EnforceSecurityGroupInboundRulesOnPrivateLinkTraffic",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidConfigurationRequest,
        InvalidSecurityGroup,
        LoadBalancerNotFound,
    },
} = .{};
pub const set_subnets: struct {
    action_name: []const u8 = "SetSubnets",
    Request: type = struct {
        load_balancer_arn: []const u8,
        subnets: ?[][]const u8 = null,
        subnet_mappings: ?[]SubnetMapping = null,
        ip_address_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_balancer_arn = "LoadBalancerArn",
                .subnets = "Subnets",
                .subnet_mappings = "SubnetMappings",
                .ip_address_type = "IpAddressType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_subnets) } {
            return .{ .service_metadata = service_metadata, .action = set_subnets };
        }
    },
    Response: type = struct {
        availability_zones: ?[]AvailabilityZone = null,
        ip_address_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZones",
                .ip_address_type = "IpAddressType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AllocationIdNotFound,
        AvailabilityZoneNotSupported,
        InvalidConfigurationRequest,
        InvalidSubnet,
        LoadBalancerNotFound,
        SubnetNotFound,
    },
} = .{};

pub const AvailabilityZone = struct {
    zone_name: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    outpost_id: ?[]const u8 = null,
    load_balancer_addresses: ?[]LoadBalancerAddress = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .zone_name = "ZoneName",
            .subnet_id = "SubnetId",
            .outpost_id = "OutpostId",
            .load_balancer_addresses = "LoadBalancerAddresses",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancerAddress = struct {
    ip_address: ?[]const u8 = null,
    allocation_id: ?[]const u8 = null,
    private_i_pv4_address: ?[]const u8 = null,
    i_pv6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "IpAddress",
            .allocation_id = "AllocationId",
            .private_i_pv4_address = "PrivateIPv4Address",
            .i_pv6_address = "IPv6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetMapping = struct {
    subnet_id: ?[]const u8 = null,
    allocation_id: ?[]const u8 = null,
    private_i_pv4_address: ?[]const u8 = null,
    i_pv6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "SubnetId",
            .allocation_id = "AllocationId",
            .private_i_pv4_address = "PrivateIPv4Address",
            .i_pv6_address = "IPv6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const Rule = struct {
    rule_arn: ?[]const u8 = null,
    priority: ?[]const u8 = null,
    conditions: ?[]RuleCondition = null,
    actions: ?[]Action = null,
    is_default: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_arn = "RuleArn",
            .priority = "Priority",
            .conditions = "Conditions",
            .actions = "Actions",
            .is_default = "IsDefault",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    type: []const u8,
    target_group_arn: ?[]const u8 = null,
    authenticate_oidc_config: ?AuthenticateOidcActionConfig = null,
    authenticate_cognito_config: ?AuthenticateCognitoActionConfig = null,
    order: ?i64 = null,
    redirect_config: ?RedirectActionConfig = null,
    fixed_response_config: ?FixedResponseActionConfig = null,
    forward_config: ?ForwardActionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .target_group_arn = "TargetGroupArn",
            .authenticate_oidc_config = "AuthenticateOidcConfig",
            .authenticate_cognito_config = "AuthenticateCognitoConfig",
            .order = "Order",
            .redirect_config = "RedirectConfig",
            .fixed_response_config = "FixedResponseConfig",
            .forward_config = "ForwardConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ForwardActionConfig = struct {
    target_groups: ?[]TargetGroupTuple = null,
    target_group_stickiness_config: ?TargetGroupStickinessConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_groups = "TargetGroups",
            .target_group_stickiness_config = "TargetGroupStickinessConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetGroupStickinessConfig = struct {
    enabled: ?bool = null,
    duration_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .duration_seconds = "DurationSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetGroupTuple = struct {
    target_group_arn: ?[]const u8 = null,
    weight: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_group_arn = "TargetGroupArn",
            .weight = "Weight",
        };
        return @field(mappings, field_name);
    }
};

pub const FixedResponseActionConfig = struct {
    message_body: ?[]const u8 = null,
    status_code: []const u8,
    content_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_body = "MessageBody",
            .status_code = "StatusCode",
            .content_type = "ContentType",
        };
        return @field(mappings, field_name);
    }
};

pub const RedirectActionConfig = struct {
    protocol: ?[]const u8 = null,
    port: ?[]const u8 = null,
    host: ?[]const u8 = null,
    path: ?[]const u8 = null,
    query: ?[]const u8 = null,
    status_code: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "Protocol",
            .port = "Port",
            .host = "Host",
            .path = "Path",
            .query = "Query",
            .status_code = "StatusCode",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthenticateCognitoActionConfig = struct {
    user_pool_arn: []const u8,
    user_pool_client_id: []const u8,
    user_pool_domain: []const u8,
    session_cookie_name: ?[]const u8 = null,
    scope: ?[]const u8 = null,
    session_timeout: ?i64 = null,
    authentication_request_extra_params: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    on_unauthenticated_request: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_arn = "UserPoolArn",
            .user_pool_client_id = "UserPoolClientId",
            .user_pool_domain = "UserPoolDomain",
            .session_cookie_name = "SessionCookieName",
            .scope = "Scope",
            .session_timeout = "SessionTimeout",
            .authentication_request_extra_params = "AuthenticationRequestExtraParams",
            .on_unauthenticated_request = "OnUnauthenticatedRequest",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "authentication_request_extra_params", field_name))
            return try serializeMap(self.authentication_request_extra_params, self.fieldNameFor("authentication_request_extra_params"), options, out_stream);
        return false;
    }
};

pub const AuthenticateOidcActionConfig = struct {
    issuer: []const u8,
    authorization_endpoint: []const u8,
    token_endpoint: []const u8,
    user_info_endpoint: []const u8,
    client_id: []const u8,
    client_secret: ?[]const u8 = null,
    session_cookie_name: ?[]const u8 = null,
    scope: ?[]const u8 = null,
    session_timeout: ?i64 = null,
    authentication_request_extra_params: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    on_unauthenticated_request: ?[]const u8 = null,
    use_existing_client_secret: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issuer = "Issuer",
            .authorization_endpoint = "AuthorizationEndpoint",
            .token_endpoint = "TokenEndpoint",
            .user_info_endpoint = "UserInfoEndpoint",
            .client_id = "ClientId",
            .client_secret = "ClientSecret",
            .session_cookie_name = "SessionCookieName",
            .scope = "Scope",
            .session_timeout = "SessionTimeout",
            .authentication_request_extra_params = "AuthenticationRequestExtraParams",
            .on_unauthenticated_request = "OnUnauthenticatedRequest",
            .use_existing_client_secret = "UseExistingClientSecret",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "authentication_request_extra_params", field_name))
            return try serializeMap(self.authentication_request_extra_params, self.fieldNameFor("authentication_request_extra_params"), options, out_stream);
        return false;
    }
};

pub const RuleCondition = struct {
    field: ?[]const u8 = null,
    values: ?[][]const u8 = null,
    host_header_config: ?HostHeaderConditionConfig = null,
    path_pattern_config: ?PathPatternConditionConfig = null,
    http_header_config: ?HttpHeaderConditionConfig = null,
    query_string_config: ?QueryStringConditionConfig = null,
    http_request_method_config: ?HttpRequestMethodConditionConfig = null,
    source_ip_config: ?SourceIpConditionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field = "Field",
            .values = "Values",
            .host_header_config = "HostHeaderConfig",
            .path_pattern_config = "PathPatternConfig",
            .http_header_config = "HttpHeaderConfig",
            .query_string_config = "QueryStringConfig",
            .http_request_method_config = "HttpRequestMethodConfig",
            .source_ip_config = "SourceIpConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceIpConditionConfig = struct {
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpRequestMethodConditionConfig = struct {
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryStringConditionConfig = struct {
    values: ?[]QueryStringKeyValuePair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryStringKeyValuePair = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpHeaderConditionConfig = struct {
    http_header_name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_header_name = "HttpHeaderName",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const PathPatternConditionConfig = struct {
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const HostHeaderConditionConfig = struct {
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const Certificate = struct {
    certificate_arn: ?[]const u8 = null,
    is_default: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "CertificateArn",
            .is_default = "IsDefault",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetDescription = struct {
    id: []const u8,
    port: ?i64 = null,
    availability_zone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .port = "Port",
            .availability_zone = "AvailabilityZone",
        };
        return @field(mappings, field_name);
    }
};

pub const TrustStore = struct {
    name: ?[]const u8 = null,
    trust_store_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    number_of_ca_certificates: ?i64 = null,
    total_revoked_entries: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .trust_store_arn = "TrustStoreArn",
            .status = "Status",
            .number_of_ca_certificates = "NumberOfCaCertificates",
            .total_revoked_entries = "TotalRevokedEntries",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetGroupAttribute = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetGroup = struct {
    target_group_arn: ?[]const u8 = null,
    target_group_name: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    port: ?i64 = null,
    vpc_id: ?[]const u8 = null,
    health_check_protocol: ?[]const u8 = null,
    health_check_port: ?[]const u8 = null,
    health_check_enabled: ?bool = null,
    health_check_interval_seconds: ?i64 = null,
    health_check_timeout_seconds: ?i64 = null,
    healthy_threshold_count: ?i64 = null,
    unhealthy_threshold_count: ?i64 = null,
    health_check_path: ?[]const u8 = null,
    matcher: ?Matcher = null,
    load_balancer_arns: ?[][]const u8 = null,
    target_type: ?[]const u8 = null,
    protocol_version: ?[]const u8 = null,
    ip_address_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_group_arn = "TargetGroupArn",
            .target_group_name = "TargetGroupName",
            .protocol = "Protocol",
            .port = "Port",
            .vpc_id = "VpcId",
            .health_check_protocol = "HealthCheckProtocol",
            .health_check_port = "HealthCheckPort",
            .health_check_enabled = "HealthCheckEnabled",
            .health_check_interval_seconds = "HealthCheckIntervalSeconds",
            .health_check_timeout_seconds = "HealthCheckTimeoutSeconds",
            .healthy_threshold_count = "HealthyThresholdCount",
            .unhealthy_threshold_count = "UnhealthyThresholdCount",
            .health_check_path = "HealthCheckPath",
            .matcher = "Matcher",
            .load_balancer_arns = "LoadBalancerArns",
            .target_type = "TargetType",
            .protocol_version = "ProtocolVersion",
            .ip_address_type = "IpAddressType",
        };
        return @field(mappings, field_name);
    }
};

pub const Matcher = struct {
    http_code: ?[]const u8 = null,
    grpc_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_code = "HttpCode",
            .grpc_code = "GrpcCode",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancerAttribute = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Listener = struct {
    listener_arn: ?[]const u8 = null,
    load_balancer_arn: ?[]const u8 = null,
    port: ?i64 = null,
    protocol: ?[]const u8 = null,
    certificates: ?[]Certificate = null,
    ssl_policy: ?[]const u8 = null,
    default_actions: ?[]Action = null,
    alpn_policy: ?[][]const u8 = null,
    mutual_authentication: ?MutualAuthenticationAttributes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .listener_arn = "ListenerArn",
            .load_balancer_arn = "LoadBalancerArn",
            .port = "Port",
            .protocol = "Protocol",
            .certificates = "Certificates",
            .ssl_policy = "SslPolicy",
            .default_actions = "DefaultActions",
            .alpn_policy = "AlpnPolicy",
            .mutual_authentication = "MutualAuthentication",
        };
        return @field(mappings, field_name);
    }
};

pub const MutualAuthenticationAttributes = struct {
    mode: ?[]const u8 = null,
    trust_store_arn: ?[]const u8 = null,
    ignore_client_certificate_expiry: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .trust_store_arn = "TrustStoreArn",
            .ignore_client_certificate_expiry = "IgnoreClientCertificateExpiry",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancer = struct {
    load_balancer_arn: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    canonical_hosted_zone_id: ?[]const u8 = null,
    created_time: ?i64 = null,
    load_balancer_name: ?[]const u8 = null,
    scheme: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    state: ?LoadBalancerState = null,
    type: ?[]const u8 = null,
    availability_zones: ?[]AvailabilityZone = null,
    security_groups: ?[][]const u8 = null,
    ip_address_type: ?[]const u8 = null,
    customer_owned_ipv4_pool: ?[]const u8 = null,
    enforce_security_group_inbound_rules_on_private_link_traffic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .load_balancer_arn = "LoadBalancerArn",
            .dns_name = "DNSName",
            .canonical_hosted_zone_id = "CanonicalHostedZoneId",
            .created_time = "CreatedTime",
            .load_balancer_name = "LoadBalancerName",
            .scheme = "Scheme",
            .vpc_id = "VpcId",
            .state = "State",
            .type = "Type",
            .availability_zones = "AvailabilityZones",
            .security_groups = "SecurityGroups",
            .ip_address_type = "IpAddressType",
            .customer_owned_ipv4_pool = "CustomerOwnedIpv4Pool",
            .enforce_security_group_inbound_rules_on_private_link_traffic = "EnforceSecurityGroupInboundRulesOnPrivateLinkTraffic",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancerState = struct {
    code: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};
