const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-09-25";
pub const sdk_id: []const u8 = "Elastic Transcoder";
pub const arn_namespace: ?[]const u8 = "elastictranscoder";
pub const endpoint_prefix: []const u8 = "elastictranscoder";
pub const sigv4_name: []const u8 = "elastictranscoder";
pub const name: []const u8 = "EtsCustomerService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2012-09-25",
    sdk_id: []const u8 = "Elastic Transcoder",
    arn_namespace: ?[]const u8 = "elastictranscoder",
    endpoint_prefix: []const u8 = "elastictranscoder",
    sigv4_name: []const u8 = "elastictranscoder",
    name: []const u8 = "EtsCustomerService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2012-09-25/jobs/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "CancelJob",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2012-09-25/jobs",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        pipeline_id: []const u8,
        input: ?JobInput = null,
        inputs: ?[]JobInput = null,
        output: ?CreateJobOutput = null,
        outputs: ?[]CreateJobOutput = null,
        output_key_prefix: ?[]const u8 = null,
        playlists: ?[]struct {
            name: ?[]const u8 = null,
            format: ?[]const u8 = null,
            output_keys: ?[][]const u8 = null,
            hls_content_protection: ?HlsContentProtection = null,
            play_ready_drm: ?PlayReadyDrm = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .format = "Format",
                    .output_keys = "OutputKeys",
                    .hls_content_protection = "HlsContentProtection",
                    .play_ready_drm = "PlayReadyDrm",
                };
                return @field(mappings, field_name);
            }
        } = null,
        user_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "PipelineId",
                .input = "Input",
                .inputs = "Inputs",
                .output = "Output",
                .outputs = "Outputs",
                .output_key_prefix = "OutputKeyPrefix",
                .playlists = "Playlists",
                .user_metadata = "UserMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "user_metadata", field_name))
                return try serializeMap(self.user_metadata, self.fieldNameFor("user_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        job: ?Job = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2012-09-25/pipelines",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePipeline",
    Request: type = struct {
        name: []const u8,
        input_bucket: []const u8,
        output_bucket: ?[]const u8 = null,
        role: []const u8,
        aws_kms_key_arn: ?[]const u8 = null,
        notifications: ?Notifications = null,
        content_config: ?PipelineOutputConfig = null,
        thumbnail_config: ?PipelineOutputConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .input_bucket = "InputBucket",
                .output_bucket = "OutputBucket",
                .role = "Role",
                .aws_kms_key_arn = "AwsKmsKeyArn",
                .notifications = "Notifications",
                .content_config = "ContentConfig",
                .thumbnail_config = "ThumbnailConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,
        warnings: ?[]Warning = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
                .warnings = "Warnings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_preset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2012-09-25/presets",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePreset",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        container: []const u8,
        video: ?VideoParameters = null,
        audio: ?AudioParameters = null,
        thumbnails: ?Thumbnails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .container = "Container",
                .video = "Video",
                .audio = "Audio",
                .thumbnails = "Thumbnails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_preset) } {
            return .{ .service_metadata = service_metadata, .action = create_preset };
        }
    },
    Response: type = struct {
        preset: ?Preset = null,
        warning: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preset = "Preset",
                .warning = "Warning",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const delete_pipeline: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2012-09-25/pipelines/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeletePipeline",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_pipeline };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_preset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2012-09-25/presets/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeletePreset",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_preset) } {
            return .{ .service_metadata = service_metadata, .action = delete_preset };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_jobs_by_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2012-09-25/jobsByPipeline/{PipelineId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobsByPipeline",
    Request: type = struct {
        pipeline_id: []const u8,
        ascending: ?[]const u8 = null,
        page_token: ?[]const u8 = null,

        pub const http_query = .{
            .ascending = "Ascending",
            .page_token = "PageToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_id = "PipelineId",
                .ascending = "Ascending",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs_by_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs_by_pipeline };
        }
    },
    Response: type = struct {
        jobs: ?[]Job = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_jobs_by_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2012-09-25/jobsByStatus/{Status}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobsByStatus",
    Request: type = struct {
        status: []const u8,
        ascending: ?[]const u8 = null,
        page_token: ?[]const u8 = null,

        pub const http_query = .{
            .ascending = "Ascending",
            .page_token = "PageToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .ascending = "Ascending",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs_by_status) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs_by_status };
        }
    },
    Response: type = struct {
        jobs: ?[]Job = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_pipelines: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2012-09-25/pipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPipelines",
    Request: type = struct {
        ascending: ?[]const u8 = null,
        page_token: ?[]const u8 = null,

        pub const http_query = .{
            .ascending = "Ascending",
            .page_token = "PageToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ascending = "Ascending",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_pipelines };
        }
    },
    Response: type = struct {
        pipelines: ?[]Pipeline = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipelines = "Pipelines",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        Validation,
    },
} = .{};
pub const list_presets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2012-09-25/presets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPresets",
    Request: type = struct {
        ascending: ?[]const u8 = null,
        page_token: ?[]const u8 = null,

        pub const http_query = .{
            .ascending = "Ascending",
            .page_token = "PageToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ascending = "Ascending",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_presets) } {
            return .{ .service_metadata = service_metadata, .action = list_presets };
        }
    },
    Response: type = struct {
        presets: ?[]Preset = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .presets = "Presets",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        Validation,
    },
} = .{};
pub const read_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2012-09-25/jobs/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "ReadJob",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(read_job) } {
            return .{ .service_metadata = service_metadata, .action = read_job };
        }
    },
    Response: type = struct {
        job: ?Job = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const read_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2012-09-25/pipelines/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "ReadPipeline",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(read_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = read_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,
        warnings: ?[]Warning = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
                .warnings = "Warnings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const read_preset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2012-09-25/presets/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "ReadPreset",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(read_preset) } {
            return .{ .service_metadata = service_metadata, .action = read_preset };
        }
    },
    Response: type = struct {
        preset: ?Preset = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preset = "Preset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const test_role: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2012-09-25/roleTests",
        .success_code = 200,
    };

    action_name: []const u8 = "TestRole",
    Request: type = struct {
        role: []const u8,
        input_bucket: []const u8,
        output_bucket: []const u8,
        topics: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role = "Role",
                .input_bucket = "InputBucket",
                .output_bucket = "OutputBucket",
                .topics = "Topics",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_role) } {
            return .{ .service_metadata = service_metadata, .action = test_role };
        }
    },
    Response: type = struct {
        success: ?[]const u8 = null,
        messages: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .success = "Success",
                .messages = "Messages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2012-09-25/pipelines/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePipeline",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        input_bucket: ?[]const u8 = null,
        role: ?[]const u8 = null,
        aws_kms_key_arn: ?[]const u8 = null,
        notifications: ?Notifications = null,
        content_config: ?PipelineOutputConfig = null,
        thumbnail_config: ?PipelineOutputConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .input_bucket = "InputBucket",
                .role = "Role",
                .aws_kms_key_arn = "AwsKmsKeyArn",
                .notifications = "Notifications",
                .content_config = "ContentConfig",
                .thumbnail_config = "ThumbnailConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = update_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,
        warnings: ?[]Warning = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
                .warnings = "Warnings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_pipeline_notifications: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2012-09-25/pipelines/{Id}/notifications",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePipelineNotifications",
    Request: type = struct {
        id: []const u8,
        notifications: Notifications,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .notifications = "Notifications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pipeline_notifications) } {
            return .{ .service_metadata = service_metadata, .action = update_pipeline_notifications };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_pipeline_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2012-09-25/pipelines/{Id}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePipelineStatus",
    Request: type = struct {
        id: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pipeline_status) } {
            return .{ .service_metadata = service_metadata, .action = update_pipeline_status };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleVersion,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const Pipeline = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    input_bucket: ?[]const u8 = null,
    output_bucket: ?[]const u8 = null,
    role: ?[]const u8 = null,
    aws_kms_key_arn: ?[]const u8 = null,
    notifications: ?Notifications = null,
    content_config: ?PipelineOutputConfig = null,
    thumbnail_config: ?PipelineOutputConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .status = "Status",
            .input_bucket = "InputBucket",
            .output_bucket = "OutputBucket",
            .role = "Role",
            .aws_kms_key_arn = "AwsKmsKeyArn",
            .notifications = "Notifications",
            .content_config = "ContentConfig",
            .thumbnail_config = "ThumbnailConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelineOutputConfig = struct {
    bucket: ?[]const u8 = null,
    storage_class: ?[]const u8 = null,
    permissions: ?[]Permission = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .storage_class = "StorageClass",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const Permission = struct {
    grantee_type: ?[]const u8 = null,
    grantee: ?[]const u8 = null,
    access: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grantee_type = "GranteeType",
            .grantee = "Grantee",
            .access = "Access",
        };
        return @field(mappings, field_name);
    }
};

pub const Notifications = struct {
    progressing: ?[]const u8 = null,
    completed: ?[]const u8 = null,
    warning: ?[]const u8 = null,
    @"error": ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .progressing = "Progressing",
            .completed = "Completed",
            .warning = "Warning",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const Warning = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Preset = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    container: ?[]const u8 = null,
    audio: ?AudioParameters = null,
    video: ?VideoParameters = null,
    thumbnails: ?Thumbnails = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .description = "Description",
            .container = "Container",
            .audio = "Audio",
            .video = "Video",
            .thumbnails = "Thumbnails",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const Thumbnails = struct {
    format: ?[]const u8 = null,
    interval: ?[]const u8 = null,
    resolution: ?[]const u8 = null,
    aspect_ratio: ?[]const u8 = null,
    max_width: ?[]const u8 = null,
    max_height: ?[]const u8 = null,
    sizing_policy: ?[]const u8 = null,
    padding_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .interval = "Interval",
            .resolution = "Resolution",
            .aspect_ratio = "AspectRatio",
            .max_width = "MaxWidth",
            .max_height = "MaxHeight",
            .sizing_policy = "SizingPolicy",
            .padding_policy = "PaddingPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoParameters = struct {
    codec: ?[]const u8 = null,
    codec_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    keyframes_max_dist: ?[]const u8 = null,
    fixed_gop: ?[]const u8 = null,
    bit_rate: ?[]const u8 = null,
    frame_rate: ?[]const u8 = null,
    max_frame_rate: ?[]const u8 = null,
    resolution: ?[]const u8 = null,
    aspect_ratio: ?[]const u8 = null,
    max_width: ?[]const u8 = null,
    max_height: ?[]const u8 = null,
    display_aspect_ratio: ?[]const u8 = null,
    sizing_policy: ?[]const u8 = null,
    padding_policy: ?[]const u8 = null,
    watermarks: ?[]PresetWatermark = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .codec = "Codec",
            .codec_options = "CodecOptions",
            .keyframes_max_dist = "KeyframesMaxDist",
            .fixed_gop = "FixedGOP",
            .bit_rate = "BitRate",
            .frame_rate = "FrameRate",
            .max_frame_rate = "MaxFrameRate",
            .resolution = "Resolution",
            .aspect_ratio = "AspectRatio",
            .max_width = "MaxWidth",
            .max_height = "MaxHeight",
            .display_aspect_ratio = "DisplayAspectRatio",
            .sizing_policy = "SizingPolicy",
            .padding_policy = "PaddingPolicy",
            .watermarks = "Watermarks",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "codec_options", field_name))
            return try serializeMap(self.codec_options, self.fieldNameFor("codec_options"), options, out_stream);
        return false;
    }
};

pub const PresetWatermark = struct {
    id: ?[]const u8 = null,
    max_width: ?[]const u8 = null,
    max_height: ?[]const u8 = null,
    sizing_policy: ?[]const u8 = null,
    horizontal_align: ?[]const u8 = null,
    horizontal_offset: ?[]const u8 = null,
    vertical_align: ?[]const u8 = null,
    vertical_offset: ?[]const u8 = null,
    opacity: ?[]const u8 = null,
    target: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .max_width = "MaxWidth",
            .max_height = "MaxHeight",
            .sizing_policy = "SizingPolicy",
            .horizontal_align = "HorizontalAlign",
            .horizontal_offset = "HorizontalOffset",
            .vertical_align = "VerticalAlign",
            .vertical_offset = "VerticalOffset",
            .opacity = "Opacity",
            .target = "Target",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioParameters = struct {
    codec: ?[]const u8 = null,
    sample_rate: ?[]const u8 = null,
    bit_rate: ?[]const u8 = null,
    channels: ?[]const u8 = null,
    audio_packing_mode: ?[]const u8 = null,
    codec_options: ?AudioCodecOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .codec = "Codec",
            .sample_rate = "SampleRate",
            .bit_rate = "BitRate",
            .channels = "Channels",
            .audio_packing_mode = "AudioPackingMode",
            .codec_options = "CodecOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioCodecOptions = struct {
    profile: ?[]const u8 = null,
    bit_depth: ?[]const u8 = null,
    bit_order: ?[]const u8 = null,
    signed: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .profile = "Profile",
            .bit_depth = "BitDepth",
            .bit_order = "BitOrder",
            .signed = "Signed",
        };
        return @field(mappings, field_name);
    }
};

pub const Job = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    pipeline_id: ?[]const u8 = null,
    input: ?JobInput = null,
    inputs: ?[]JobInput = null,
    output: ?JobOutput = null,
    outputs: ?[]JobOutput = null,
    output_key_prefix: ?[]const u8 = null,
    playlists: ?[]Playlist = null,
    status: ?[]const u8 = null,
    user_metadata: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    timing: ?Timing = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .pipeline_id = "PipelineId",
            .input = "Input",
            .inputs = "Inputs",
            .output = "Output",
            .outputs = "Outputs",
            .output_key_prefix = "OutputKeyPrefix",
            .playlists = "Playlists",
            .status = "Status",
            .user_metadata = "UserMetadata",
            .timing = "Timing",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_metadata", field_name))
            return try serializeMap(self.user_metadata, self.fieldNameFor("user_metadata"), options, out_stream);
        return false;
    }
};

pub const Timing = struct {
    submit_time_millis: ?i64 = null,
    start_time_millis: ?i64 = null,
    finish_time_millis: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .submit_time_millis = "SubmitTimeMillis",
            .start_time_millis = "StartTimeMillis",
            .finish_time_millis = "FinishTimeMillis",
        };
        return @field(mappings, field_name);
    }
};

pub const Playlist = struct {
    name: ?[]const u8 = null,
    format: ?[]const u8 = null,
    output_keys: ?[][]const u8 = null,
    hls_content_protection: ?HlsContentProtection = null,
    play_ready_drm: ?PlayReadyDrm = null,
    status: ?[]const u8 = null,
    status_detail: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .format = "Format",
            .output_keys = "OutputKeys",
            .hls_content_protection = "HlsContentProtection",
            .play_ready_drm = "PlayReadyDrm",
            .status = "Status",
            .status_detail = "StatusDetail",
        };
        return @field(mappings, field_name);
    }
};

pub const PlayReadyDrm = struct {
    format: ?[]const u8 = null,
    key: ?[]const u8 = null,
    key_md5: ?[]const u8 = null,
    key_id: ?[]const u8 = null,
    initialization_vector: ?[]const u8 = null,
    license_acquisition_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .key = "Key",
            .key_md5 = "KeyMd5",
            .key_id = "KeyId",
            .initialization_vector = "InitializationVector",
            .license_acquisition_url = "LicenseAcquisitionUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsContentProtection = struct {
    method: ?[]const u8 = null,
    key: ?[]const u8 = null,
    key_md5: ?[]const u8 = null,
    initialization_vector: ?[]const u8 = null,
    license_acquisition_url: ?[]const u8 = null,
    key_storage_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .method = "Method",
            .key = "Key",
            .key_md5 = "KeyMd5",
            .initialization_vector = "InitializationVector",
            .license_acquisition_url = "LicenseAcquisitionUrl",
            .key_storage_policy = "KeyStoragePolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const JobOutput = struct {
    id: ?[]const u8 = null,
    key: ?[]const u8 = null,
    thumbnail_pattern: ?[]const u8 = null,
    thumbnail_encryption: ?Encryption = null,
    rotate: ?[]const u8 = null,
    preset_id: ?[]const u8 = null,
    segment_duration: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_detail: ?[]const u8 = null,
    duration: ?i64 = null,
    width: ?i64 = null,
    height: ?i64 = null,
    frame_rate: ?[]const u8 = null,
    file_size: ?i64 = null,
    duration_millis: ?i64 = null,
    watermarks: ?[]JobWatermark = null,
    album_art: ?JobAlbumArt = null,
    composition: ?[]Clip = null,
    captions: ?Captions = null,
    encryption: ?Encryption = null,
    applied_color_space_conversion: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .key = "Key",
            .thumbnail_pattern = "ThumbnailPattern",
            .thumbnail_encryption = "ThumbnailEncryption",
            .rotate = "Rotate",
            .preset_id = "PresetId",
            .segment_duration = "SegmentDuration",
            .status = "Status",
            .status_detail = "StatusDetail",
            .duration = "Duration",
            .width = "Width",
            .height = "Height",
            .frame_rate = "FrameRate",
            .file_size = "FileSize",
            .duration_millis = "DurationMillis",
            .watermarks = "Watermarks",
            .album_art = "AlbumArt",
            .composition = "Composition",
            .captions = "Captions",
            .encryption = "Encryption",
            .applied_color_space_conversion = "AppliedColorSpaceConversion",
        };
        return @field(mappings, field_name);
    }
};

pub const Encryption = struct {
    mode: ?[]const u8 = null,
    key: ?[]const u8 = null,
    key_md5: ?[]const u8 = null,
    initialization_vector: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .key = "Key",
            .key_md5 = "KeyMd5",
            .initialization_vector = "InitializationVector",
        };
        return @field(mappings, field_name);
    }
};

pub const Captions = struct {
    merge_policy: ?[]const u8 = null,
    caption_sources: ?[]CaptionSource = null,
    caption_formats: ?[]CaptionFormat = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .merge_policy = "MergePolicy",
            .caption_sources = "CaptionSources",
            .caption_formats = "CaptionFormats",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionFormat = struct {
    format: ?[]const u8 = null,
    pattern: ?[]const u8 = null,
    encryption: ?Encryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .pattern = "Pattern",
            .encryption = "Encryption",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionSource = struct {
    key: ?[]const u8 = null,
    language: ?[]const u8 = null,
    time_offset: ?[]const u8 = null,
    label: ?[]const u8 = null,
    encryption: ?Encryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .language = "Language",
            .time_offset = "TimeOffset",
            .label = "Label",
            .encryption = "Encryption",
        };
        return @field(mappings, field_name);
    }
};

pub const Clip = struct {
    time_span: ?TimeSpan = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_span = "TimeSpan",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeSpan = struct {
    start_time: ?[]const u8 = null,
    duration: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .duration = "Duration",
        };
        return @field(mappings, field_name);
    }
};

pub const JobAlbumArt = struct {
    merge_policy: ?[]const u8 = null,
    artwork: ?[]Artwork = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .merge_policy = "MergePolicy",
            .artwork = "Artwork",
        };
        return @field(mappings, field_name);
    }
};

pub const Artwork = struct {
    input_key: ?[]const u8 = null,
    max_width: ?[]const u8 = null,
    max_height: ?[]const u8 = null,
    sizing_policy: ?[]const u8 = null,
    padding_policy: ?[]const u8 = null,
    album_art_format: ?[]const u8 = null,
    encryption: ?Encryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_key = "InputKey",
            .max_width = "MaxWidth",
            .max_height = "MaxHeight",
            .sizing_policy = "SizingPolicy",
            .padding_policy = "PaddingPolicy",
            .album_art_format = "AlbumArtFormat",
            .encryption = "Encryption",
        };
        return @field(mappings, field_name);
    }
};

pub const JobWatermark = struct {
    preset_watermark_id: ?[]const u8 = null,
    input_key: ?[]const u8 = null,
    encryption: ?Encryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .preset_watermark_id = "PresetWatermarkId",
            .input_key = "InputKey",
            .encryption = "Encryption",
        };
        return @field(mappings, field_name);
    }
};

pub const JobInput = struct {
    key: ?[]const u8 = null,
    frame_rate: ?[]const u8 = null,
    resolution: ?[]const u8 = null,
    aspect_ratio: ?[]const u8 = null,
    interlaced: ?[]const u8 = null,
    container: ?[]const u8 = null,
    encryption: ?Encryption = null,
    time_span: ?TimeSpan = null,
    input_captions: ?InputCaptions = null,
    detected_properties: ?DetectedProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .frame_rate = "FrameRate",
            .resolution = "Resolution",
            .aspect_ratio = "AspectRatio",
            .interlaced = "Interlaced",
            .container = "Container",
            .encryption = "Encryption",
            .time_span = "TimeSpan",
            .input_captions = "InputCaptions",
            .detected_properties = "DetectedProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectedProperties = struct {
    width: ?i64 = null,
    height: ?i64 = null,
    frame_rate: ?[]const u8 = null,
    file_size: ?i64 = null,
    duration_millis: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .width = "Width",
            .height = "Height",
            .frame_rate = "FrameRate",
            .file_size = "FileSize",
            .duration_millis = "DurationMillis",
        };
        return @field(mappings, field_name);
    }
};

pub const InputCaptions = struct {
    merge_policy: ?[]const u8 = null,
    caption_sources: ?[]CaptionSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .merge_policy = "MergePolicy",
            .caption_sources = "CaptionSources",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateJobOutput = struct {
    key: ?[]const u8 = null,
    thumbnail_pattern: ?[]const u8 = null,
    thumbnail_encryption: ?Encryption = null,
    rotate: ?[]const u8 = null,
    preset_id: ?[]const u8 = null,
    segment_duration: ?[]const u8 = null,
    watermarks: ?[]JobWatermark = null,
    album_art: ?JobAlbumArt = null,
    composition: ?[]Clip = null,
    captions: ?Captions = null,
    encryption: ?Encryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .thumbnail_pattern = "ThumbnailPattern",
            .thumbnail_encryption = "ThumbnailEncryption",
            .rotate = "Rotate",
            .preset_id = "PresetId",
            .segment_duration = "SegmentDuration",
            .watermarks = "Watermarks",
            .album_art = "AlbumArt",
            .composition = "Composition",
            .captions = "Captions",
            .encryption = "Encryption",
        };
        return @field(mappings, field_name);
    }
};
