const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-01-01";
pub const sdk_id: []const u8 = "Elasticsearch Service";
pub const arn_namespace: ?[]const u8 = "es";
pub const endpoint_prefix: []const u8 = "es";
pub const sigv4_name: []const u8 = "es";
pub const name: []const u8 = "AmazonElasticsearchService2015";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-01-01",
    sdk_id: []const u8 = "Elasticsearch Service",
    arn_namespace: ?[]const u8 = "es",
    endpoint_prefix: []const u8 = "es",
    sigv4_name: []const u8 = "es",
    name: []const u8 = "AmazonElasticsearchService2015",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_inbound_cross_cluster_search_connection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-01-01/es/ccs/inboundConnection/{CrossClusterSearchConnectionId}/accept",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptInboundCrossClusterSearchConnection",
    Request: type = struct {
        cross_cluster_search_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connection_id = "CrossClusterSearchConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_inbound_cross_cluster_search_connection) } {
            return .{ .service_metadata = service_metadata, .action = accept_inbound_cross_cluster_search_connection };
        }
    },
    Response: type = struct {
        cross_cluster_search_connection: ?InboundCrossClusterSearchConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connection = "CrossClusterSearchConnection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const add_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "AddTags",
    Request: type = struct {
        arn: []const u8,
        tag_list: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Base,
        Internal,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const associate_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/packages/associate/{PackageID}/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociatePackage",
    Request: type = struct {
        package_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_package) } {
            return .{ .service_metadata = service_metadata, .action = associate_package };
        }
    },
    Response: type = struct {
        domain_package_details: ?DomainPackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_package_details = "DomainPackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const authorize_vpc_endpoint_access: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/domain/{DomainName}/authorizeVpcEndpointAccess",
        .success_code = 200,
    };

    action_name: []const u8 = "AuthorizeVpcEndpointAccess",
    Request: type = struct {
        domain_name: []const u8,
        account: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .account = "Account",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_vpc_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = authorize_vpc_endpoint_access };
        }
    },
    Response: type = struct {
        authorized_principal: AuthorizedPrincipal,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorized_principal = "AuthorizedPrincipal",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const cancel_domain_config_change: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/domain/{DomainName}/config/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelDomainConfigChange",
    Request: type = struct {
        domain_name: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_domain_config_change) } {
            return .{ .service_metadata = service_metadata, .action = cancel_domain_config_change };
        }
    },
    Response: type = struct {
        dry_run: ?bool = null,
        cancelled_change_ids: ?[][]const u8 = null,
        cancelled_change_properties: ?[]struct {
            property_name: ?[]const u8 = null,
            cancelled_value: ?[]const u8 = null,
            active_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .property_name = "PropertyName",
                    .cancelled_value = "CancelledValue",
                    .active_value = "ActiveValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .cancelled_change_ids = "CancelledChangeIds",
                .cancelled_change_properties = "CancelledChangeProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const cancel_elasticsearch_service_software_update: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/serviceSoftwareUpdate/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelElasticsearchServiceSoftwareUpdate",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_elasticsearch_service_software_update) } {
            return .{ .service_metadata = service_metadata, .action = cancel_elasticsearch_service_software_update };
        }
    },
    Response: type = struct {
        service_software_options: ?ServiceSoftwareOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_software_options = "ServiceSoftwareOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_elasticsearch_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/domain",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateElasticsearchDomain",
    Request: type = struct {
        domain_name: []const u8,
        elasticsearch_version: ?[]const u8 = null,
        elasticsearch_cluster_config: ?ElasticsearchClusterConfig = null,
        ebs_options: ?EBSOptions = null,
        access_policies: ?[]const u8 = null,
        snapshot_options: ?SnapshotOptions = null,
        vpc_options: ?VPCOptions = null,
        cognito_options: ?CognitoOptions = null,
        encryption_at_rest_options: ?EncryptionAtRestOptions = null,
        node_to_node_encryption_options: ?NodeToNodeEncryptionOptions = null,
        advanced_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        log_publishing_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LogPublishingOption = null,
        } = null,
        domain_endpoint_options: ?DomainEndpointOptions = null,
        advanced_security_options: ?AdvancedSecurityOptionsInput = null,
        auto_tune_options: ?struct {
            desired_state: ?[]const u8 = null,
            maintenance_schedules: ?[]AutoTuneMaintenanceSchedule = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .desired_state = "DesiredState",
                    .maintenance_schedules = "MaintenanceSchedules",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .elasticsearch_version = "ElasticsearchVersion",
                .elasticsearch_cluster_config = "ElasticsearchClusterConfig",
                .ebs_options = "EBSOptions",
                .access_policies = "AccessPolicies",
                .snapshot_options = "SnapshotOptions",
                .vpc_options = "VPCOptions",
                .cognito_options = "CognitoOptions",
                .encryption_at_rest_options = "EncryptionAtRestOptions",
                .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
                .advanced_options = "AdvancedOptions",
                .log_publishing_options = "LogPublishingOptions",
                .domain_endpoint_options = "DomainEndpointOptions",
                .advanced_security_options = "AdvancedSecurityOptions",
                .auto_tune_options = "AutoTuneOptions",
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "advanced_options", field_name))
                return try serializeMap(self.advanced_options, self.fieldNameFor("advanced_options"), options, out_stream);
            if (std.mem.eql(u8, "log_publishing_options", field_name))
                return try serializeMap(self.log_publishing_options, self.fieldNameFor("log_publishing_options"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_elasticsearch_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_elasticsearch_domain };
        }
    },
    Response: type = struct {
        domain_status: ?ElasticsearchDomainStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_status = "DomainStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        InvalidType,
        LimitExceeded,
        ResourceAlreadyExists,
        Validation,
    },
} = .{};
pub const create_outbound_cross_cluster_search_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/ccs/outboundConnection",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateOutboundCrossClusterSearchConnection",
    Request: type = struct {
        source_domain_info: DomainInformation,
        destination_domain_info: DomainInformation,
        connection_alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_domain_info = "SourceDomainInfo",
                .destination_domain_info = "DestinationDomainInfo",
                .connection_alias = "ConnectionAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_outbound_cross_cluster_search_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_outbound_cross_cluster_search_connection };
        }
    },
    Response: type = struct {
        source_domain_info: ?DomainInformation = null,
        destination_domain_info: ?DomainInformation = null,
        connection_alias: ?[]const u8 = null,
        connection_status: ?OutboundCrossClusterSearchConnectionStatus = null,
        cross_cluster_search_connection_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_domain_info = "SourceDomainInfo",
                .destination_domain_info = "DestinationDomainInfo",
                .connection_alias = "ConnectionAlias",
                .connection_status = "ConnectionStatus",
                .cross_cluster_search_connection_id = "CrossClusterSearchConnectionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        Internal,
        LimitExceeded,
        ResourceAlreadyExists,
    },
} = .{};
pub const create_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/packages",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePackage",
    Request: type = struct {
        package_name: []const u8,
        package_type: []const u8,
        package_description: ?[]const u8 = null,
        package_source: PackageSource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "PackageName",
                .package_type = "PackageType",
                .package_description = "PackageDescription",
                .package_source = "PackageSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_package) } {
            return .{ .service_metadata = service_metadata, .action = create_package };
        }
    },
    Response: type = struct {
        package_details: ?PackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_details = "PackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        InvalidType,
        LimitExceeded,
        ResourceAlreadyExists,
        Validation,
    },
} = .{};
pub const create_vpc_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/vpcEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVpcEndpoint",
    Request: type = struct {
        domain_arn: []const u8,
        vpc_options: VPCOptions,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_arn = "DomainArn",
                .vpc_options = "VpcOptions",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_endpoint };
        }
    },
    Response: type = struct {
        vpc_endpoint: VpcEndpoint,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint = "VpcEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Conflict,
        DisabledOperation,
        Internal,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const delete_elasticsearch_domain: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-01-01/es/domain/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteElasticsearchDomain",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_elasticsearch_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_elasticsearch_domain };
        }
    },
    Response: type = struct {
        domain_status: ?ElasticsearchDomainStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_status = "DomainStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_elasticsearch_service_role: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-01-01/es/role",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteElasticsearchServiceRole",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_elasticsearch_service_role) } {
            return .{ .service_metadata = service_metadata, .action = delete_elasticsearch_service_role };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Base,
        Internal,
        Validation,
    },
} = .{};
pub const delete_inbound_cross_cluster_search_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-01-01/es/ccs/inboundConnection/{CrossClusterSearchConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInboundCrossClusterSearchConnection",
    Request: type = struct {
        cross_cluster_search_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connection_id = "CrossClusterSearchConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_inbound_cross_cluster_search_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_inbound_cross_cluster_search_connection };
        }
    },
    Response: type = struct {
        cross_cluster_search_connection: ?InboundCrossClusterSearchConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connection = "CrossClusterSearchConnection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        ResourceNotFound,
    },
} = .{};
pub const delete_outbound_cross_cluster_search_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-01-01/es/ccs/outboundConnection/{CrossClusterSearchConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteOutboundCrossClusterSearchConnection",
    Request: type = struct {
        cross_cluster_search_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connection_id = "CrossClusterSearchConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_outbound_cross_cluster_search_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_outbound_cross_cluster_search_connection };
        }
    },
    Response: type = struct {
        cross_cluster_search_connection: ?OutboundCrossClusterSearchConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connection = "CrossClusterSearchConnection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        ResourceNotFound,
    },
} = .{};
pub const delete_package: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-01-01/packages/{PackageID}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePackage",
    Request: type = struct {
        package_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_package) } {
            return .{ .service_metadata = service_metadata, .action = delete_package };
        }
    },
    Response: type = struct {
        package_details: ?PackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_details = "PackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_vpc_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-01-01/es/vpcEndpoints/{VpcEndpointId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteVpcEndpoint",
    Request: type = struct {
        vpc_endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_id = "VpcEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_endpoint };
        }
    },
    Response: type = struct {
        vpc_endpoint_summary: VpcEndpointSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_summary = "VpcEndpointSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const describe_domain_auto_tunes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/domain/{DomainName}/autoTunes",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomainAutoTunes",
    Request: type = struct {
        domain_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_auto_tunes) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_auto_tunes };
        }
    },
    Response: type = struct {
        auto_tunes: ?[]struct {
            auto_tune_type: ?[]const u8 = null,
            auto_tune_details: ?struct {
                scheduled_auto_tune_details: ?struct {
                    date: ?i64 = null,
                    action_type: ?[]const u8 = null,
                    action: ?[]const u8 = null,
                    severity: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date = "Date",
                            .action_type = "ActionType",
                            .action = "Action",
                            .severity = "Severity",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .scheduled_auto_tune_details = "ScheduledAutoTuneDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_tune_type = "AutoTuneType",
                    .auto_tune_details = "AutoTuneDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_tunes = "AutoTunes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_domain_change_progress: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/domain/{DomainName}/progress",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomainChangeProgress",
    Request: type = struct {
        domain_name: []const u8,
        change_id: ?[]const u8 = null,

        pub const http_query = .{
            .change_id = "changeid",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .change_id = "ChangeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_change_progress) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_change_progress };
        }
    },
    Response: type = struct {
        change_progress_status: ?struct {
            change_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            status: ?[]const u8 = null,
            pending_properties: ?[][]const u8 = null,
            completed_properties: ?[][]const u8 = null,
            total_number_of_stages: ?i64 = null,
            change_progress_stages: ?[]struct {
                name: ?[]const u8 = null,
                status: ?[]const u8 = null,
                description: ?[]const u8 = null,
                last_updated: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .status = "Status",
                        .description = "Description",
                        .last_updated = "LastUpdated",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            config_change_status: ?[]const u8 = null,
            last_updated_time: ?i64 = null,
            initiated_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .change_id = "ChangeId",
                    .start_time = "StartTime",
                    .status = "Status",
                    .pending_properties = "PendingProperties",
                    .completed_properties = "CompletedProperties",
                    .total_number_of_stages = "TotalNumberOfStages",
                    .change_progress_stages = "ChangeProgressStages",
                    .config_change_status = "ConfigChangeStatus",
                    .last_updated_time = "LastUpdatedTime",
                    .initiated_by = "InitiatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_progress_status = "ChangeProgressStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_elasticsearch_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/domain/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeElasticsearchDomain",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_elasticsearch_domain) } {
            return .{ .service_metadata = service_metadata, .action = describe_elasticsearch_domain };
        }
    },
    Response: type = struct {
        domain_status: ElasticsearchDomainStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_status = "DomainStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_elasticsearch_domain_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/domain/{DomainName}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeElasticsearchDomainConfig",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_elasticsearch_domain_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_elasticsearch_domain_config };
        }
    },
    Response: type = struct {
        domain_config: ElasticsearchDomainConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_config = "DomainConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_elasticsearch_domains: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/domain-info",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeElasticsearchDomains",
    Request: type = struct {
        domain_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_names = "DomainNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_elasticsearch_domains) } {
            return .{ .service_metadata = service_metadata, .action = describe_elasticsearch_domains };
        }
    },
    Response: type = struct {
        domain_status_list: []ElasticsearchDomainStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_status_list = "DomainStatusList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        Validation,
    },
} = .{};
pub const describe_elasticsearch_instance_type_limits: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/instanceTypeLimits/{ElasticsearchVersion}/{InstanceType}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeElasticsearchInstanceTypeLimits",
    Request: type = struct {
        domain_name: ?[]const u8 = null,
        instance_type: []const u8,
        elasticsearch_version: []const u8,

        pub const http_query = .{
            .domain_name = "domainName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .instance_type = "InstanceType",
                .elasticsearch_version = "ElasticsearchVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_elasticsearch_instance_type_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_elasticsearch_instance_type_limits };
        }
    },
    Response: type = struct {
        limits_by_role: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                storage_types: ?[]struct {
                    storage_type_name: ?[]const u8 = null,
                    storage_sub_type_name: ?[]const u8 = null,
                    storage_type_limits: ?[]struct {
                        limit_name: ?[]const u8 = null,
                        limit_values: ?[][]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .limit_name = "LimitName",
                                .limit_values = "LimitValues",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .storage_type_name = "StorageTypeName",
                            .storage_sub_type_name = "StorageSubTypeName",
                            .storage_type_limits = "StorageTypeLimits",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                instance_limits: ?struct {
                    instance_count_limits: ?struct {
                        minimum_instance_count: ?i64 = null,
                        maximum_instance_count: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .minimum_instance_count = "MinimumInstanceCount",
                                .maximum_instance_count = "MaximumInstanceCount",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .instance_count_limits = "InstanceCountLimits",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                additional_limits: ?[]struct {
                    limit_name: ?[]const u8 = null,
                    limit_values: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .limit_name = "LimitName",
                            .limit_values = "LimitValues",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .storage_types = "StorageTypes",
                        .instance_limits = "InstanceLimits",
                        .additional_limits = "AdditionalLimits",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limits_by_role = "LimitsByRole",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "limits_by_role", field_name))
                return try serializeMap(self.limits_by_role, self.fieldNameFor("limits_by_role"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        InvalidType,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_inbound_cross_cluster_search_connections: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/ccs/inboundConnection/search",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInboundCrossClusterSearchConnections",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_inbound_cross_cluster_search_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_inbound_cross_cluster_search_connections };
        }
    },
    Response: type = struct {
        cross_cluster_search_connections: ?[]InboundCrossClusterSearchConnection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connections = "CrossClusterSearchConnections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        InvalidPaginationToken,
    },
} = .{};
pub const describe_outbound_cross_cluster_search_connections: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/ccs/outboundConnection/search",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOutboundCrossClusterSearchConnections",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_outbound_cross_cluster_search_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_outbound_cross_cluster_search_connections };
        }
    },
    Response: type = struct {
        cross_cluster_search_connections: ?[]OutboundCrossClusterSearchConnection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connections = "CrossClusterSearchConnections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        InvalidPaginationToken,
    },
} = .{};
pub const describe_packages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/packages/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackages",
    Request: type = struct {
        filters: ?[]struct {
            name: ?[]const u8 = null,
            value: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_packages) } {
            return .{ .service_metadata = service_metadata, .action = describe_packages };
        }
    },
    Response: type = struct {
        package_details_list: ?[]PackageDetails = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_details_list = "PackageDetailsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_reserved_elasticsearch_instance_offerings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/reservedInstanceOfferings",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReservedElasticsearchInstanceOfferings",
    Request: type = struct {
        reserved_elasticsearch_instance_offering_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .reserved_elasticsearch_instance_offering_id = "offeringId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_elasticsearch_instance_offering_id = "ReservedElasticsearchInstanceOfferingId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_elasticsearch_instance_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_elasticsearch_instance_offerings };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reserved_elasticsearch_instance_offerings: ?[]struct {
            reserved_elasticsearch_instance_offering_id: ?[]const u8 = null,
            elasticsearch_instance_type: ?[]const u8 = null,
            duration: ?i64 = null,
            fixed_price: ?f64 = null,
            usage_price: ?f64 = null,
            currency_code: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            recurring_charges: ?[]RecurringCharge = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reserved_elasticsearch_instance_offering_id = "ReservedElasticsearchInstanceOfferingId",
                    .elasticsearch_instance_type = "ElasticsearchInstanceType",
                    .duration = "Duration",
                    .fixed_price = "FixedPrice",
                    .usage_price = "UsagePrice",
                    .currency_code = "CurrencyCode",
                    .payment_option = "PaymentOption",
                    .recurring_charges = "RecurringCharges",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .reserved_elasticsearch_instance_offerings = "ReservedElasticsearchInstanceOfferings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_reserved_elasticsearch_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/reservedInstances",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReservedElasticsearchInstances",
    Request: type = struct {
        reserved_elasticsearch_instance_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .reserved_elasticsearch_instance_id = "reservationId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_elasticsearch_instance_id = "ReservedElasticsearchInstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_elasticsearch_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_elasticsearch_instances };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reserved_elasticsearch_instances: ?[]struct {
            reservation_name: ?[]const u8 = null,
            reserved_elasticsearch_instance_id: ?[]const u8 = null,
            reserved_elasticsearch_instance_offering_id: ?[]const u8 = null,
            elasticsearch_instance_type: ?[]const u8 = null,
            start_time: ?i64 = null,
            duration: ?i64 = null,
            fixed_price: ?f64 = null,
            usage_price: ?f64 = null,
            currency_code: ?[]const u8 = null,
            elasticsearch_instance_count: ?i64 = null,
            state: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            recurring_charges: ?[]RecurringCharge = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reservation_name = "ReservationName",
                    .reserved_elasticsearch_instance_id = "ReservedElasticsearchInstanceId",
                    .reserved_elasticsearch_instance_offering_id = "ReservedElasticsearchInstanceOfferingId",
                    .elasticsearch_instance_type = "ElasticsearchInstanceType",
                    .start_time = "StartTime",
                    .duration = "Duration",
                    .fixed_price = "FixedPrice",
                    .usage_price = "UsagePrice",
                    .currency_code = "CurrencyCode",
                    .elasticsearch_instance_count = "ElasticsearchInstanceCount",
                    .state = "State",
                    .payment_option = "PaymentOption",
                    .recurring_charges = "RecurringCharges",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .reserved_elasticsearch_instances = "ReservedElasticsearchInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_vpc_endpoints: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/vpcEndpoints/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeVpcEndpoints",
    Request: type = struct {
        vpc_endpoint_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_ids = "VpcEndpointIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_endpoints };
        }
    },
    Response: type = struct {
        vpc_endpoints: []VpcEndpoint,
        vpc_endpoint_errors: []struct {
            vpc_endpoint_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpc_endpoint_id = "VpcEndpointId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoints = "VpcEndpoints",
                .vpc_endpoint_errors = "VpcEndpointErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        Validation,
    },
} = .{};
pub const dissociate_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/packages/dissociate/{PackageID}/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DissociatePackage",
    Request: type = struct {
        package_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(dissociate_package) } {
            return .{ .service_metadata = service_metadata, .action = dissociate_package };
        }
    },
    Response: type = struct {
        domain_package_details: ?DomainPackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_package_details = "DomainPackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_compatible_elasticsearch_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/compatibleVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCompatibleElasticsearchVersions",
    Request: type = struct {
        domain_name: ?[]const u8 = null,

        pub const http_query = .{
            .domain_name = "domainName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compatible_elasticsearch_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_compatible_elasticsearch_versions };
        }
    },
    Response: type = struct {
        compatible_elasticsearch_versions: ?[]struct {
            source_version: ?[]const u8 = null,
            target_versions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_version = "SourceVersion",
                    .target_versions = "TargetVersions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compatible_elasticsearch_versions = "CompatibleElasticsearchVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_package_version_history: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/packages/{PackageID}/history",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPackageVersionHistory",
    Request: type = struct {
        package_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_package_version_history) } {
            return .{ .service_metadata = service_metadata, .action = get_package_version_history };
        }
    },
    Response: type = struct {
        package_id: ?[]const u8 = null,
        package_version_history_list: ?[]struct {
            package_version: ?[]const u8 = null,
            commit_message: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .package_version = "PackageVersion",
                    .commit_message = "CommitMessage",
                    .created_at = "CreatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .package_version_history_list = "PackageVersionHistoryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_upgrade_history: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/upgradeDomain/{DomainName}/history",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUpgradeHistory",
    Request: type = struct {
        domain_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_upgrade_history) } {
            return .{ .service_metadata = service_metadata, .action = get_upgrade_history };
        }
    },
    Response: type = struct {
        upgrade_histories: ?[]struct {
            upgrade_name: ?[]const u8 = null,
            start_timestamp: ?i64 = null,
            upgrade_status: ?[]const u8 = null,
            steps_list: ?[]struct {
                upgrade_step: ?[]const u8 = null,
                upgrade_step_status: ?[]const u8 = null,
                issues: ?[][]const u8 = null,
                progress_percent: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .upgrade_step = "UpgradeStep",
                        .upgrade_step_status = "UpgradeStepStatus",
                        .issues = "Issues",
                        .progress_percent = "ProgressPercent",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .upgrade_name = "UpgradeName",
                    .start_timestamp = "StartTimestamp",
                    .upgrade_status = "UpgradeStatus",
                    .steps_list = "StepsList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upgrade_histories = "UpgradeHistories",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_upgrade_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/upgradeDomain/{DomainName}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUpgradeStatus",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_upgrade_status) } {
            return .{ .service_metadata = service_metadata, .action = get_upgrade_status };
        }
    },
    Response: type = struct {
        upgrade_step: ?[]const u8 = null,
        step_status: ?[]const u8 = null,
        upgrade_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upgrade_step = "UpgradeStep",
                .step_status = "StepStatus",
                .upgrade_name = "UpgradeName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_domain_names: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/domain",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainNames",
    Request: type = struct {
        engine_type: ?[]const u8 = null,

        pub const http_query = .{
            .engine_type = "engineType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_type = "EngineType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domain_names) } {
            return .{ .service_metadata = service_metadata, .action = list_domain_names };
        }
    },
    Response: type = struct {
        domain_names: ?[]struct {
            domain_name: ?[]const u8 = null,
            engine_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .engine_type = "EngineType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_names = "DomainNames",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Validation,
    },
} = .{};
pub const list_domains_for_package: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/packages/{PackageID}/domains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainsForPackage",
    Request: type = struct {
        package_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domains_for_package) } {
            return .{ .service_metadata = service_metadata, .action = list_domains_for_package };
        }
    },
    Response: type = struct {
        domain_package_details_list: ?[]DomainPackageDetails = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_package_details_list = "DomainPackageDetailsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_elasticsearch_instance_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/instanceTypes/{ElasticsearchVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListElasticsearchInstanceTypes",
    Request: type = struct {
        elasticsearch_version: []const u8,
        domain_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .domain_name = "domainName",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .elasticsearch_version = "ElasticsearchVersion",
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_elasticsearch_instance_types) } {
            return .{ .service_metadata = service_metadata, .action = list_elasticsearch_instance_types };
        }
    },
    Response: type = struct {
        elasticsearch_instance_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .elasticsearch_instance_types = "ElasticsearchInstanceTypes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_elasticsearch_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListElasticsearchVersions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_elasticsearch_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_elasticsearch_versions };
        }
    },
    Response: type = struct {
        elasticsearch_versions: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .elasticsearch_versions = "ElasticsearchVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_packages_for_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/domain/{DomainName}/packages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackagesForDomain",
    Request: type = struct {
        domain_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_packages_for_domain) } {
            return .{ .service_metadata = service_metadata, .action = list_packages_for_domain };
        }
    },
    Response: type = struct {
        domain_package_details_list: ?[]DomainPackageDetails = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_package_details_list = "DomainPackageDetailsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTags",
    Request: type = struct {
        arn: []const u8,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_vpc_endpoint_access: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/domain/{DomainName}/listVpcEndpointAccess",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVpcEndpointAccess",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_endpoint_access };
        }
    },
    Response: type = struct {
        authorized_principal_list: []AuthorizedPrincipal,
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorized_principal_list = "AuthorizedPrincipalList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const list_vpc_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/vpcEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVpcEndpoints",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_endpoints };
        }
    },
    Response: type = struct {
        vpc_endpoint_summary_list: []VpcEndpointSummary,
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_summary_list = "VpcEndpointSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
    },
} = .{};
pub const list_vpc_endpoints_for_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-01-01/es/domain/{DomainName}/vpcEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVpcEndpointsForDomain",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_endpoints_for_domain) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_endpoints_for_domain };
        }
    },
    Response: type = struct {
        vpc_endpoint_summary_list: []VpcEndpointSummary,
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_summary_list = "VpcEndpointSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const purchase_reserved_elasticsearch_instance_offering: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/purchaseReservedInstanceOffering",
        .success_code = 200,
    };

    action_name: []const u8 = "PurchaseReservedElasticsearchInstanceOffering",
    Request: type = struct {
        reserved_elasticsearch_instance_offering_id: []const u8,
        reservation_name: []const u8,
        instance_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_elasticsearch_instance_offering_id = "ReservedElasticsearchInstanceOfferingId",
                .reservation_name = "ReservationName",
                .instance_count = "InstanceCount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_reserved_elasticsearch_instance_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_reserved_elasticsearch_instance_offering };
        }
    },
    Response: type = struct {
        reserved_elasticsearch_instance_id: ?[]const u8 = null,
        reservation_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_elasticsearch_instance_id = "ReservedElasticsearchInstanceId",
                .reservation_name = "ReservationName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        Internal,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const reject_inbound_cross_cluster_search_connection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-01-01/es/ccs/inboundConnection/{CrossClusterSearchConnectionId}/reject",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectInboundCrossClusterSearchConnection",
    Request: type = struct {
        cross_cluster_search_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connection_id = "CrossClusterSearchConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_inbound_cross_cluster_search_connection) } {
            return .{ .service_metadata = service_metadata, .action = reject_inbound_cross_cluster_search_connection };
        }
    },
    Response: type = struct {
        cross_cluster_search_connection: ?InboundCrossClusterSearchConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_cluster_search_connection = "CrossClusterSearchConnection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        ResourceNotFound,
    },
} = .{};
pub const remove_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/tags-removal",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveTags",
    Request: type = struct {
        arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Base,
        Internal,
        Validation,
    },
} = .{};
pub const revoke_vpc_endpoint_access: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/domain/{DomainName}/revokeVpcEndpointAccess",
        .success_code = 200,
    };

    action_name: []const u8 = "RevokeVpcEndpointAccess",
    Request: type = struct {
        domain_name: []const u8,
        account: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .account = "Account",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_vpc_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = revoke_vpc_endpoint_access };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_elasticsearch_service_software_update: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/serviceSoftwareUpdate/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartElasticsearchServiceSoftwareUpdate",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_elasticsearch_service_software_update) } {
            return .{ .service_metadata = service_metadata, .action = start_elasticsearch_service_software_update };
        }
    },
    Response: type = struct {
        service_software_options: ?ServiceSoftwareOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_software_options = "ServiceSoftwareOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_elasticsearch_domain_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/domain/{DomainName}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateElasticsearchDomainConfig",
    Request: type = struct {
        domain_name: []const u8,
        elasticsearch_cluster_config: ?ElasticsearchClusterConfig = null,
        ebs_options: ?EBSOptions = null,
        snapshot_options: ?SnapshotOptions = null,
        vpc_options: ?VPCOptions = null,
        cognito_options: ?CognitoOptions = null,
        advanced_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        access_policies: ?[]const u8 = null,
        log_publishing_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LogPublishingOption = null,
        } = null,
        domain_endpoint_options: ?DomainEndpointOptions = null,
        advanced_security_options: ?AdvancedSecurityOptionsInput = null,
        node_to_node_encryption_options: ?NodeToNodeEncryptionOptions = null,
        encryption_at_rest_options: ?EncryptionAtRestOptions = null,
        auto_tune_options: ?AutoTuneOptions = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .elasticsearch_cluster_config = "ElasticsearchClusterConfig",
                .ebs_options = "EBSOptions",
                .snapshot_options = "SnapshotOptions",
                .vpc_options = "VPCOptions",
                .cognito_options = "CognitoOptions",
                .advanced_options = "AdvancedOptions",
                .access_policies = "AccessPolicies",
                .log_publishing_options = "LogPublishingOptions",
                .domain_endpoint_options = "DomainEndpointOptions",
                .advanced_security_options = "AdvancedSecurityOptions",
                .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
                .encryption_at_rest_options = "EncryptionAtRestOptions",
                .auto_tune_options = "AutoTuneOptions",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "advanced_options", field_name))
                return try serializeMap(self.advanced_options, self.fieldNameFor("advanced_options"), options, out_stream);
            if (std.mem.eql(u8, "log_publishing_options", field_name))
                return try serializeMap(self.log_publishing_options, self.fieldNameFor("log_publishing_options"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_elasticsearch_domain_config) } {
            return .{ .service_metadata = service_metadata, .action = update_elasticsearch_domain_config };
        }
    },
    Response: type = struct {
        domain_config: ElasticsearchDomainConfig,
        dry_run_results: ?struct {
            deployment_type: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .deployment_type = "DeploymentType",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_config = "DomainConfig",
                .dry_run_results = "DryRunResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        InvalidType,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/packages/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePackage",
    Request: type = struct {
        package_id: []const u8,
        package_source: PackageSource,
        package_description: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .package_source = "PackageSource",
                .package_description = "PackageDescription",
                .commit_message = "CommitMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_package) } {
            return .{ .service_metadata = service_metadata, .action = update_package };
        }
    },
    Response: type = struct {
        package_details: ?PackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_details = "PackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_vpc_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/vpcEndpoints/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVpcEndpoint",
    Request: type = struct {
        vpc_endpoint_id: []const u8,
        vpc_options: VPCOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_id = "VpcEndpointId",
                .vpc_options = "VpcOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_vpc_endpoint };
        }
    },
    Response: type = struct {
        vpc_endpoint: VpcEndpoint,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint = "VpcEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Conflict,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const upgrade_elasticsearch_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-01-01/es/upgradeDomain",
        .success_code = 200,
    };

    action_name: []const u8 = "UpgradeElasticsearchDomain",
    Request: type = struct {
        domain_name: []const u8,
        target_version: []const u8,
        perform_check_only: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .target_version = "TargetVersion",
                .perform_check_only = "PerformCheckOnly",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upgrade_elasticsearch_domain) } {
            return .{ .service_metadata = service_metadata, .action = upgrade_elasticsearch_domain };
        }
    },
    Response: type = struct {
        domain_name: ?[]const u8 = null,
        target_version: ?[]const u8 = null,
        perform_check_only: ?bool = null,
        change_progress_details: ?ChangeProgressDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .target_version = "TargetVersion",
                .perform_check_only = "PerformCheckOnly",
                .change_progress_details = "ChangeProgressDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceAlreadyExists,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const ChangeProgressDetails = struct {
    change_id: ?[]const u8 = null,
    message: ?[]const u8 = null,
    config_change_status: ?[]const u8 = null,
    start_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    initiated_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .change_id = "ChangeId",
            .message = "Message",
            .config_change_status = "ConfigChangeStatus",
            .start_time = "StartTime",
            .last_updated_time = "LastUpdatedTime",
            .initiated_by = "InitiatedBy",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcEndpoint = struct {
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_endpoint_owner: ?[]const u8 = null,
    domain_arn: ?[]const u8 = null,
    vpc_options: ?VPCDerivedInfo = null,
    status: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_endpoint_id = "VpcEndpointId",
            .vpc_endpoint_owner = "VpcEndpointOwner",
            .domain_arn = "DomainArn",
            .vpc_options = "VpcOptions",
            .status = "Status",
            .endpoint = "Endpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const VPCDerivedInfo = struct {
    vpc_id: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    availability_zones: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VPCId",
            .subnet_ids = "SubnetIds",
            .availability_zones = "AvailabilityZones",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const VPCOptions = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageDetails = struct {
    package_id: ?[]const u8 = null,
    package_name: ?[]const u8 = null,
    package_type: ?[]const u8 = null,
    package_description: ?[]const u8 = null,
    package_status: ?[]const u8 = null,
    created_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    available_package_version: ?[]const u8 = null,
    error_details: ?ErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_id = "PackageID",
            .package_name = "PackageName",
            .package_type = "PackageType",
            .package_description = "PackageDescription",
            .package_status = "PackageStatus",
            .created_at = "CreatedAt",
            .last_updated_at = "LastUpdatedAt",
            .available_package_version = "AvailablePackageVersion",
            .error_details = "ErrorDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetails = struct {
    error_type: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_type = "ErrorType",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageSource = struct {
    s3_bucket_name: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "S3BucketName",
            .s3_key = "S3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchDomainConfig = struct {
    elasticsearch_version: ?ElasticsearchVersionStatus = null,
    elasticsearch_cluster_config: ?ElasticsearchClusterConfigStatus = null,
    ebs_options: ?EBSOptionsStatus = null,
    access_policies: ?AccessPoliciesStatus = null,
    snapshot_options: ?SnapshotOptionsStatus = null,
    vpc_options: ?VPCDerivedInfoStatus = null,
    cognito_options: ?CognitoOptionsStatus = null,
    encryption_at_rest_options: ?EncryptionAtRestOptionsStatus = null,
    node_to_node_encryption_options: ?NodeToNodeEncryptionOptionsStatus = null,
    advanced_options: ?AdvancedOptionsStatus = null,
    log_publishing_options: ?LogPublishingOptionsStatus = null,
    domain_endpoint_options: ?DomainEndpointOptionsStatus = null,
    advanced_security_options: ?AdvancedSecurityOptionsStatus = null,
    auto_tune_options: ?AutoTuneOptionsStatus = null,
    change_progress_details: ?ChangeProgressDetails = null,
    modifying_properties: ?[]ModifyingProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elasticsearch_version = "ElasticsearchVersion",
            .elasticsearch_cluster_config = "ElasticsearchClusterConfig",
            .ebs_options = "EBSOptions",
            .access_policies = "AccessPolicies",
            .snapshot_options = "SnapshotOptions",
            .vpc_options = "VPCOptions",
            .cognito_options = "CognitoOptions",
            .encryption_at_rest_options = "EncryptionAtRestOptions",
            .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
            .advanced_options = "AdvancedOptions",
            .log_publishing_options = "LogPublishingOptions",
            .domain_endpoint_options = "DomainEndpointOptions",
            .advanced_security_options = "AdvancedSecurityOptions",
            .auto_tune_options = "AutoTuneOptions",
            .change_progress_details = "ChangeProgressDetails",
            .modifying_properties = "ModifyingProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const ModifyingProperties = struct {
    name: ?[]const u8 = null,
    active_value: ?[]const u8 = null,
    pending_value: ?[]const u8 = null,
    value_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .active_value = "ActiveValue",
            .pending_value = "PendingValue",
            .value_type = "ValueType",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTuneOptionsStatus = struct {
    options: ?AutoTuneOptions = null,
    status: ?AutoTuneStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTuneStatus = struct {
    creation_date: i64,
    update_date: i64,
    update_version: ?i64 = null,
    state: []const u8,
    error_message: ?[]const u8 = null,
    pending_deletion: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_date = "CreationDate",
            .update_date = "UpdateDate",
            .update_version = "UpdateVersion",
            .state = "State",
            .error_message = "ErrorMessage",
            .pending_deletion = "PendingDeletion",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTuneOptions = struct {
    desired_state: ?[]const u8 = null,
    rollback_on_disable: ?[]const u8 = null,
    maintenance_schedules: ?[]AutoTuneMaintenanceSchedule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .desired_state = "DesiredState",
            .rollback_on_disable = "RollbackOnDisable",
            .maintenance_schedules = "MaintenanceSchedules",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTuneMaintenanceSchedule = struct {
    start_at: ?i64 = null,
    duration: ?Duration = null,
    cron_expression_for_recurrence: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_at = "StartAt",
            .duration = "Duration",
            .cron_expression_for_recurrence = "CronExpressionForRecurrence",
        };
        return @field(mappings, field_name);
    }
};

pub const Duration = struct {
    value: ?i64 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedSecurityOptionsStatus = struct {
    options: AdvancedSecurityOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const OptionStatus = struct {
    creation_date: i64,
    update_date: i64,
    update_version: ?i64 = null,
    state: []const u8,
    pending_deletion: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_date = "CreationDate",
            .update_date = "UpdateDate",
            .update_version = "UpdateVersion",
            .state = "State",
            .pending_deletion = "PendingDeletion",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedSecurityOptions = struct {
    enabled: ?bool = null,
    internal_user_database_enabled: ?bool = null,
    saml_options: ?SAMLOptionsOutput = null,
    anonymous_auth_disable_date: ?i64 = null,
    anonymous_auth_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .internal_user_database_enabled = "InternalUserDatabaseEnabled",
            .saml_options = "SAMLOptions",
            .anonymous_auth_disable_date = "AnonymousAuthDisableDate",
            .anonymous_auth_enabled = "AnonymousAuthEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SAMLOptionsOutput = struct {
    enabled: ?bool = null,
    idp: ?SAMLIdp = null,
    subject_key: ?[]const u8 = null,
    roles_key: ?[]const u8 = null,
    session_timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .idp = "Idp",
            .subject_key = "SubjectKey",
            .roles_key = "RolesKey",
            .session_timeout_minutes = "SessionTimeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const SAMLIdp = struct {
    metadata_content: []const u8,
    entity_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metadata_content = "MetadataContent",
            .entity_id = "EntityId",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainEndpointOptionsStatus = struct {
    options: DomainEndpointOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainEndpointOptions = struct {
    enforce_https: ?bool = null,
    tls_security_policy: ?[]const u8 = null,
    custom_endpoint_enabled: ?bool = null,
    custom_endpoint: ?[]const u8 = null,
    custom_endpoint_certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enforce_https = "EnforceHTTPS",
            .tls_security_policy = "TLSSecurityPolicy",
            .custom_endpoint_enabled = "CustomEndpointEnabled",
            .custom_endpoint = "CustomEndpoint",
            .custom_endpoint_certificate_arn = "CustomEndpointCertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LogPublishingOptionsStatus = struct {
    options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?LogPublishingOption = null,
    } = null,
    status: ?OptionStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const LogPublishingOption = struct {
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedOptionsStatus = struct {
    options: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const NodeToNodeEncryptionOptionsStatus = struct {
    options: NodeToNodeEncryptionOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeToNodeEncryptionOptions = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAtRestOptionsStatus = struct {
    options: EncryptionAtRestOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAtRestOptions = struct {
    enabled: ?bool = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const CognitoOptionsStatus = struct {
    options: CognitoOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const CognitoOptions = struct {
    enabled: ?bool = null,
    user_pool_id: ?[]const u8 = null,
    identity_pool_id: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .user_pool_id = "UserPoolId",
            .identity_pool_id = "IdentityPoolId",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VPCDerivedInfoStatus = struct {
    options: VPCDerivedInfo,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotOptionsStatus = struct {
    options: SnapshotOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotOptions = struct {
    automated_snapshot_start_hour: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automated_snapshot_start_hour = "AutomatedSnapshotStartHour",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessPoliciesStatus = struct {
    options: []const u8,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSOptionsStatus = struct {
    options: EBSOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSOptions = struct {
    ebs_enabled: ?bool = null,
    volume_type: ?[]const u8 = null,
    volume_size: ?i64 = null,
    iops: ?i64 = null,
    throughput: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_enabled = "EBSEnabled",
            .volume_type = "VolumeType",
            .volume_size = "VolumeSize",
            .iops = "Iops",
            .throughput = "Throughput",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchClusterConfigStatus = struct {
    options: ElasticsearchClusterConfig,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchClusterConfig = struct {
    instance_type: ?[]const u8 = null,
    instance_count: ?i64 = null,
    dedicated_master_enabled: ?bool = null,
    zone_awareness_enabled: ?bool = null,
    zone_awareness_config: ?ZoneAwarenessConfig = null,
    dedicated_master_type: ?[]const u8 = null,
    dedicated_master_count: ?i64 = null,
    warm_enabled: ?bool = null,
    warm_type: ?[]const u8 = null,
    warm_count: ?i64 = null,
    cold_storage_options: ?ColdStorageOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "InstanceType",
            .instance_count = "InstanceCount",
            .dedicated_master_enabled = "DedicatedMasterEnabled",
            .zone_awareness_enabled = "ZoneAwarenessEnabled",
            .zone_awareness_config = "ZoneAwarenessConfig",
            .dedicated_master_type = "DedicatedMasterType",
            .dedicated_master_count = "DedicatedMasterCount",
            .warm_enabled = "WarmEnabled",
            .warm_type = "WarmType",
            .warm_count = "WarmCount",
            .cold_storage_options = "ColdStorageOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const ColdStorageOptions = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ZoneAwarenessConfig = struct {
    availability_zone_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone_count = "AvailabilityZoneCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchVersionStatus = struct {
    options: []const u8,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedSecurityOptionsInput = struct {
    enabled: ?bool = null,
    internal_user_database_enabled: ?bool = null,
    master_user_options: ?MasterUserOptions = null,
    saml_options: ?SAMLOptionsInput = null,
    anonymous_auth_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .internal_user_database_enabled = "InternalUserDatabaseEnabled",
            .master_user_options = "MasterUserOptions",
            .saml_options = "SAMLOptions",
            .anonymous_auth_enabled = "AnonymousAuthEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SAMLOptionsInput = struct {
    enabled: ?bool = null,
    idp: ?SAMLIdp = null,
    master_user_name: ?[]const u8 = null,
    master_backend_role: ?[]const u8 = null,
    subject_key: ?[]const u8 = null,
    roles_key: ?[]const u8 = null,
    session_timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .idp = "Idp",
            .master_user_name = "MasterUserName",
            .master_backend_role = "MasterBackendRole",
            .subject_key = "SubjectKey",
            .roles_key = "RolesKey",
            .session_timeout_minutes = "SessionTimeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const MasterUserOptions = struct {
    master_user_arn: ?[]const u8 = null,
    master_user_name: ?[]const u8 = null,
    master_user_password: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .master_user_arn = "MasterUserARN",
            .master_user_name = "MasterUserName",
            .master_user_password = "MasterUserPassword",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceSoftwareOptions = struct {
    current_version: ?[]const u8 = null,
    new_version: ?[]const u8 = null,
    update_available: ?bool = null,
    cancellable: ?bool = null,
    update_status: ?[]const u8 = null,
    description: ?[]const u8 = null,
    automated_update_date: ?i64 = null,
    optional_deployment: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .current_version = "CurrentVersion",
            .new_version = "NewVersion",
            .update_available = "UpdateAvailable",
            .cancellable = "Cancellable",
            .update_status = "UpdateStatus",
            .description = "Description",
            .automated_update_date = "AutomatedUpdateDate",
            .optional_deployment = "OptionalDeployment",
        };
        return @field(mappings, field_name);
    }
};

pub const InboundCrossClusterSearchConnection = struct {
    source_domain_info: ?DomainInformation = null,
    destination_domain_info: ?DomainInformation = null,
    cross_cluster_search_connection_id: ?[]const u8 = null,
    connection_status: ?InboundCrossClusterSearchConnectionStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_domain_info = "SourceDomainInfo",
            .destination_domain_info = "DestinationDomainInfo",
            .cross_cluster_search_connection_id = "CrossClusterSearchConnectionId",
            .connection_status = "ConnectionStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const InboundCrossClusterSearchConnectionStatus = struct {
    status_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "StatusCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainInformation = struct {
    owner_id: ?[]const u8 = null,
    domain_name: []const u8,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .domain_name = "DomainName",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcEndpointSummary = struct {
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_endpoint_owner: ?[]const u8 = null,
    domain_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_endpoint_id = "VpcEndpointId",
            .vpc_endpoint_owner = "VpcEndpointOwner",
            .domain_arn = "DomainArn",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthorizedPrincipal = struct {
    principal_type: ?[]const u8 = null,
    principal: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal_type = "PrincipalType",
            .principal = "Principal",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainPackageDetails = struct {
    package_id: ?[]const u8 = null,
    package_name: ?[]const u8 = null,
    package_type: ?[]const u8 = null,
    last_updated: ?i64 = null,
    domain_name: ?[]const u8 = null,
    domain_package_status: ?[]const u8 = null,
    package_version: ?[]const u8 = null,
    reference_path: ?[]const u8 = null,
    error_details: ?ErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_id = "PackageID",
            .package_name = "PackageName",
            .package_type = "PackageType",
            .last_updated = "LastUpdated",
            .domain_name = "DomainName",
            .domain_package_status = "DomainPackageStatus",
            .package_version = "PackageVersion",
            .reference_path = "ReferencePath",
            .error_details = "ErrorDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const RecurringCharge = struct {
    recurring_charge_amount: ?f64 = null,
    recurring_charge_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recurring_charge_amount = "RecurringChargeAmount",
            .recurring_charge_frequency = "RecurringChargeFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const OutboundCrossClusterSearchConnection = struct {
    source_domain_info: ?DomainInformation = null,
    destination_domain_info: ?DomainInformation = null,
    cross_cluster_search_connection_id: ?[]const u8 = null,
    connection_alias: ?[]const u8 = null,
    connection_status: ?OutboundCrossClusterSearchConnectionStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_domain_info = "SourceDomainInfo",
            .destination_domain_info = "DestinationDomainInfo",
            .cross_cluster_search_connection_id = "CrossClusterSearchConnectionId",
            .connection_alias = "ConnectionAlias",
            .connection_status = "ConnectionStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const OutboundCrossClusterSearchConnectionStatus = struct {
    status_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "StatusCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchDomainStatus = struct {
    domain_id: []const u8,
    domain_name: []const u8,
    arn: []const u8,
    created: ?bool = null,
    deleted: ?bool = null,
    endpoint: ?[]const u8 = null,
    endpoints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    processing: ?bool = null,
    upgrade_processing: ?bool = null,
    elasticsearch_version: ?[]const u8 = null,
    elasticsearch_cluster_config: ElasticsearchClusterConfig,
    ebs_options: ?EBSOptions = null,
    access_policies: ?[]const u8 = null,
    snapshot_options: ?SnapshotOptions = null,
    vpc_options: ?VPCDerivedInfo = null,
    cognito_options: ?CognitoOptions = null,
    encryption_at_rest_options: ?EncryptionAtRestOptions = null,
    node_to_node_encryption_options: ?NodeToNodeEncryptionOptions = null,
    advanced_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    log_publishing_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?LogPublishingOption = null,
    } = null,
    service_software_options: ?ServiceSoftwareOptions = null,
    domain_endpoint_options: ?DomainEndpointOptions = null,
    advanced_security_options: ?AdvancedSecurityOptions = null,
    auto_tune_options: ?AutoTuneOptionsOutput = null,
    change_progress_details: ?ChangeProgressDetails = null,
    domain_processing_status: ?[]const u8 = null,
    modifying_properties: ?[]ModifyingProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_id = "DomainId",
            .domain_name = "DomainName",
            .arn = "ARN",
            .created = "Created",
            .deleted = "Deleted",
            .endpoint = "Endpoint",
            .endpoints = "Endpoints",
            .processing = "Processing",
            .upgrade_processing = "UpgradeProcessing",
            .elasticsearch_version = "ElasticsearchVersion",
            .elasticsearch_cluster_config = "ElasticsearchClusterConfig",
            .ebs_options = "EBSOptions",
            .access_policies = "AccessPolicies",
            .snapshot_options = "SnapshotOptions",
            .vpc_options = "VPCOptions",
            .cognito_options = "CognitoOptions",
            .encryption_at_rest_options = "EncryptionAtRestOptions",
            .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
            .advanced_options = "AdvancedOptions",
            .log_publishing_options = "LogPublishingOptions",
            .service_software_options = "ServiceSoftwareOptions",
            .domain_endpoint_options = "DomainEndpointOptions",
            .advanced_security_options = "AdvancedSecurityOptions",
            .auto_tune_options = "AutoTuneOptions",
            .change_progress_details = "ChangeProgressDetails",
            .domain_processing_status = "DomainProcessingStatus",
            .modifying_properties = "ModifyingProperties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "endpoints", field_name))
            return try serializeMap(self.endpoints, self.fieldNameFor("endpoints"), options, out_stream);
        if (std.mem.eql(u8, "advanced_options", field_name))
            return try serializeMap(self.advanced_options, self.fieldNameFor("advanced_options"), options, out_stream);
        if (std.mem.eql(u8, "log_publishing_options", field_name))
            return try serializeMap(self.log_publishing_options, self.fieldNameFor("log_publishing_options"), options, out_stream);
        return false;
    }
};

pub const AutoTuneOptionsOutput = struct {
    state: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};
