const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2009-03-31";
pub const sdk_id: []const u8 = "EMR";
pub const arn_namespace: ?[]const u8 = "elasticmapreduce";
pub const endpoint_prefix: []const u8 = "elasticmapreduce";
pub const sigv4_name: []const u8 = "elasticmapreduce";
pub const name: []const u8 = "ElasticMapReduce";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2009-03-31",
    sdk_id: []const u8 = "EMR",
    arn_namespace: ?[]const u8 = "elasticmapreduce",
    endpoint_prefix: []const u8 = "elasticmapreduce",
    sigv4_name: []const u8 = "elasticmapreduce",
    name: []const u8 = "ElasticMapReduce",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_instance_fleet: struct {
    action_name: []const u8 = "AddInstanceFleet",
    Request: type = struct {
        cluster_id: []const u8,
        instance_fleet: InstanceFleetConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .instance_fleet = "InstanceFleet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_instance_fleet) } {
            return .{ .service_metadata = service_metadata, .action = add_instance_fleet };
        }
    },
    Response: type = struct {
        cluster_id: ?[]const u8 = null,
        instance_fleet_id: ?[]const u8 = null,
        cluster_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .instance_fleet_id = "InstanceFleetId",
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const add_instance_groups: struct {
    action_name: []const u8 = "AddInstanceGroups",
    Request: type = struct {
        instance_groups: []InstanceGroupConfig,
        job_flow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_groups = "InstanceGroups",
                .job_flow_id = "JobFlowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_instance_groups) } {
            return .{ .service_metadata = service_metadata, .action = add_instance_groups };
        }
    },
    Response: type = struct {
        job_flow_id: ?[]const u8 = null,
        instance_group_ids: ?[][]const u8 = null,
        cluster_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flow_id = "JobFlowId",
                .instance_group_ids = "InstanceGroupIds",
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const add_job_flow_steps: struct {
    action_name: []const u8 = "AddJobFlowSteps",
    Request: type = struct {
        job_flow_id: []const u8,
        steps: []StepConfig,
        execution_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flow_id = "JobFlowId",
                .steps = "Steps",
                .execution_role_arn = "ExecutionRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_job_flow_steps) } {
            return .{ .service_metadata = service_metadata, .action = add_job_flow_steps };
        }
    },
    Response: type = struct {
        step_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .step_ids = "StepIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const add_tags: struct {
    action_name: []const u8 = "AddTags",
    Request: type = struct {
        resource_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const cancel_steps: struct {
    action_name: []const u8 = "CancelSteps",
    Request: type = struct {
        cluster_id: []const u8,
        step_ids: [][]const u8,
        step_cancellation_option: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .step_ids = "StepIds",
                .step_cancellation_option = "StepCancellationOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_steps) } {
            return .{ .service_metadata = service_metadata, .action = cancel_steps };
        }
    },
    Response: type = struct {
        cancel_steps_info_list: ?[]struct {
            step_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .step_id = "StepId",
                    .status = "Status",
                    .reason = "Reason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cancel_steps_info_list = "CancelStepsInfoList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const create_security_configuration: struct {
    action_name: []const u8 = "CreateSecurityConfiguration",
    Request: type = struct {
        name: []const u8,
        security_configuration: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .security_configuration = "SecurityConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_security_configuration };
        }
    },
    Response: type = struct {
        name: []const u8,
        creation_date_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .creation_date_time = "CreationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_studio: struct {
    action_name: []const u8 = "CreateStudio",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        auth_mode: []const u8,
        vpc_id: []const u8,
        subnet_ids: [][]const u8,
        service_role: []const u8,
        user_role: ?[]const u8 = null,
        workspace_security_group_id: []const u8,
        engine_security_group_id: []const u8,
        default_s3_location: []const u8,
        idp_auth_url: ?[]const u8 = null,
        idp_relay_state_parameter_name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        trusted_identity_propagation_enabled: ?bool = null,
        idc_user_assignment: ?[]const u8 = null,
        idc_instance_arn: ?[]const u8 = null,
        encryption_key_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .auth_mode = "AuthMode",
                .vpc_id = "VpcId",
                .subnet_ids = "SubnetIds",
                .service_role = "ServiceRole",
                .user_role = "UserRole",
                .workspace_security_group_id = "WorkspaceSecurityGroupId",
                .engine_security_group_id = "EngineSecurityGroupId",
                .default_s3_location = "DefaultS3Location",
                .idp_auth_url = "IdpAuthUrl",
                .idp_relay_state_parameter_name = "IdpRelayStateParameterName",
                .tags = "Tags",
                .trusted_identity_propagation_enabled = "TrustedIdentityPropagationEnabled",
                .idc_user_assignment = "IdcUserAssignment",
                .idc_instance_arn = "IdcInstanceArn",
                .encryption_key_arn = "EncryptionKeyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_studio) } {
            return .{ .service_metadata = service_metadata, .action = create_studio };
        }
    },
    Response: type = struct {
        studio_id: ?[]const u8 = null,
        url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
                .url = "Url",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_studio_session_mapping: struct {
    action_name: []const u8 = "CreateStudioSessionMapping",
    Request: type = struct {
        studio_id: []const u8,
        identity_id: ?[]const u8 = null,
        identity_name: ?[]const u8 = null,
        identity_type: []const u8,
        session_policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
                .identity_id = "IdentityId",
                .identity_name = "IdentityName",
                .identity_type = "IdentityType",
                .session_policy_arn = "SessionPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_studio_session_mapping) } {
            return .{ .service_metadata = service_metadata, .action = create_studio_session_mapping };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const delete_security_configuration: struct {
    action_name: []const u8 = "DeleteSecurityConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_security_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_studio: struct {
    action_name: []const u8 = "DeleteStudio",
    Request: type = struct {
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_studio) } {
            return .{ .service_metadata = service_metadata, .action = delete_studio };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_studio_session_mapping: struct {
    action_name: []const u8 = "DeleteStudioSessionMapping",
    Request: type = struct {
        studio_id: []const u8,
        identity_id: ?[]const u8 = null,
        identity_name: ?[]const u8 = null,
        identity_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
                .identity_id = "IdentityId",
                .identity_name = "IdentityName",
                .identity_type = "IdentityType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_studio_session_mapping) } {
            return .{ .service_metadata = service_metadata, .action = delete_studio_session_mapping };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const describe_cluster: struct {
    action_name: []const u8 = "DescribeCluster",
    Request: type = struct {
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster };
        }
    },
    Response: type = struct {
        cluster: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?ClusterStatus = null,
            ec2_instance_attributes: ?struct {
                ec2_key_name: ?[]const u8 = null,
                ec2_subnet_id: ?[]const u8 = null,
                requested_ec2_subnet_ids: ?[][]const u8 = null,
                ec2_availability_zone: ?[]const u8 = null,
                requested_ec2_availability_zones: ?[][]const u8 = null,
                iam_instance_profile: ?[]const u8 = null,
                emr_managed_master_security_group: ?[]const u8 = null,
                emr_managed_slave_security_group: ?[]const u8 = null,
                service_access_security_group: ?[]const u8 = null,
                additional_master_security_groups: ?[][]const u8 = null,
                additional_slave_security_groups: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ec2_key_name = "Ec2KeyName",
                        .ec2_subnet_id = "Ec2SubnetId",
                        .requested_ec2_subnet_ids = "RequestedEc2SubnetIds",
                        .ec2_availability_zone = "Ec2AvailabilityZone",
                        .requested_ec2_availability_zones = "RequestedEc2AvailabilityZones",
                        .iam_instance_profile = "IamInstanceProfile",
                        .emr_managed_master_security_group = "EmrManagedMasterSecurityGroup",
                        .emr_managed_slave_security_group = "EmrManagedSlaveSecurityGroup",
                        .service_access_security_group = "ServiceAccessSecurityGroup",
                        .additional_master_security_groups = "AdditionalMasterSecurityGroups",
                        .additional_slave_security_groups = "AdditionalSlaveSecurityGroups",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instance_collection_type: ?[]const u8 = null,
            log_uri: ?[]const u8 = null,
            log_encryption_kms_key_id: ?[]const u8 = null,
            requested_ami_version: ?[]const u8 = null,
            running_ami_version: ?[]const u8 = null,
            release_label: ?[]const u8 = null,
            auto_terminate: ?bool = null,
            termination_protected: ?bool = null,
            unhealthy_node_replacement: ?bool = null,
            visible_to_all_users: ?bool = null,
            applications: ?[]Application = null,
            tags: ?[]Tag = null,
            service_role: ?[]const u8 = null,
            normalized_instance_hours: ?i64 = null,
            master_public_dns_name: ?[]const u8 = null,
            configurations: ?[]Configuration = null,
            security_configuration: ?[]const u8 = null,
            auto_scaling_role: ?[]const u8 = null,
            scale_down_behavior: ?[]const u8 = null,
            custom_ami_id: ?[]const u8 = null,
            ebs_root_volume_size: ?i64 = null,
            repo_upgrade_on_boot: ?[]const u8 = null,
            kerberos_attributes: ?KerberosAttributes = null,
            cluster_arn: ?[]const u8 = null,
            outpost_arn: ?[]const u8 = null,
            step_concurrency_level: ?i64 = null,
            placement_groups: ?[]PlacementGroupConfig = null,
            os_release_label: ?[]const u8 = null,
            ebs_root_volume_iops: ?i64 = null,
            ebs_root_volume_throughput: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .status = "Status",
                    .ec2_instance_attributes = "Ec2InstanceAttributes",
                    .instance_collection_type = "InstanceCollectionType",
                    .log_uri = "LogUri",
                    .log_encryption_kms_key_id = "LogEncryptionKmsKeyId",
                    .requested_ami_version = "RequestedAmiVersion",
                    .running_ami_version = "RunningAmiVersion",
                    .release_label = "ReleaseLabel",
                    .auto_terminate = "AutoTerminate",
                    .termination_protected = "TerminationProtected",
                    .unhealthy_node_replacement = "UnhealthyNodeReplacement",
                    .visible_to_all_users = "VisibleToAllUsers",
                    .applications = "Applications",
                    .tags = "Tags",
                    .service_role = "ServiceRole",
                    .normalized_instance_hours = "NormalizedInstanceHours",
                    .master_public_dns_name = "MasterPublicDnsName",
                    .configurations = "Configurations",
                    .security_configuration = "SecurityConfiguration",
                    .auto_scaling_role = "AutoScalingRole",
                    .scale_down_behavior = "ScaleDownBehavior",
                    .custom_ami_id = "CustomAmiId",
                    .ebs_root_volume_size = "EbsRootVolumeSize",
                    .repo_upgrade_on_boot = "RepoUpgradeOnBoot",
                    .kerberos_attributes = "KerberosAttributes",
                    .cluster_arn = "ClusterArn",
                    .outpost_arn = "OutpostArn",
                    .step_concurrency_level = "StepConcurrencyLevel",
                    .placement_groups = "PlacementGroups",
                    .os_release_label = "OSReleaseLabel",
                    .ebs_root_volume_iops = "EbsRootVolumeIops",
                    .ebs_root_volume_throughput = "EbsRootVolumeThroughput",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const describe_job_flows: struct {
    action_name: []const u8 = "DescribeJobFlows",
    Request: type = struct {
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        job_flow_ids: ?[][]const u8 = null,
        job_flow_states: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .job_flow_ids = "JobFlowIds",
                .job_flow_states = "JobFlowStates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_flows) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_flows };
        }
    },
    Response: type = struct {
        job_flows: ?[]struct {
            job_flow_id: []const u8,
            name: []const u8,
            log_uri: ?[]const u8 = null,
            log_encryption_kms_key_id: ?[]const u8 = null,
            ami_version: ?[]const u8 = null,
            execution_status_detail: struct {
                state: []const u8,
                creation_date_time: i64,
                start_date_time: ?i64 = null,
                ready_date_time: ?i64 = null,
                end_date_time: ?i64 = null,
                last_state_change_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state = "State",
                        .creation_date_time = "CreationDateTime",
                        .start_date_time = "StartDateTime",
                        .ready_date_time = "ReadyDateTime",
                        .end_date_time = "EndDateTime",
                        .last_state_change_reason = "LastStateChangeReason",
                    };
                    return @field(mappings, field_name);
                }
            },
            instances: struct {
                master_instance_type: []const u8,
                master_public_dns_name: ?[]const u8 = null,
                master_instance_id: ?[]const u8 = null,
                slave_instance_type: []const u8,
                instance_count: i64,
                instance_groups: ?[]struct {
                    instance_group_id: ?[]const u8 = null,
                    name: ?[]const u8 = null,
                    market: []const u8,
                    instance_role: []const u8,
                    bid_price: ?[]const u8 = null,
                    instance_type: []const u8,
                    instance_request_count: i64,
                    instance_running_count: i64,
                    state: []const u8,
                    last_state_change_reason: ?[]const u8 = null,
                    creation_date_time: i64,
                    start_date_time: ?i64 = null,
                    ready_date_time: ?i64 = null,
                    end_date_time: ?i64 = null,
                    custom_ami_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .instance_group_id = "InstanceGroupId",
                            .name = "Name",
                            .market = "Market",
                            .instance_role = "InstanceRole",
                            .bid_price = "BidPrice",
                            .instance_type = "InstanceType",
                            .instance_request_count = "InstanceRequestCount",
                            .instance_running_count = "InstanceRunningCount",
                            .state = "State",
                            .last_state_change_reason = "LastStateChangeReason",
                            .creation_date_time = "CreationDateTime",
                            .start_date_time = "StartDateTime",
                            .ready_date_time = "ReadyDateTime",
                            .end_date_time = "EndDateTime",
                            .custom_ami_id = "CustomAmiId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                normalized_instance_hours: ?i64 = null,
                ec2_key_name: ?[]const u8 = null,
                ec2_subnet_id: ?[]const u8 = null,
                placement: ?PlacementType = null,
                keep_job_flow_alive_when_no_steps: ?bool = null,
                termination_protected: ?bool = null,
                unhealthy_node_replacement: ?bool = null,
                hadoop_version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .master_instance_type = "MasterInstanceType",
                        .master_public_dns_name = "MasterPublicDnsName",
                        .master_instance_id = "MasterInstanceId",
                        .slave_instance_type = "SlaveInstanceType",
                        .instance_count = "InstanceCount",
                        .instance_groups = "InstanceGroups",
                        .normalized_instance_hours = "NormalizedInstanceHours",
                        .ec2_key_name = "Ec2KeyName",
                        .ec2_subnet_id = "Ec2SubnetId",
                        .placement = "Placement",
                        .keep_job_flow_alive_when_no_steps = "KeepJobFlowAliveWhenNoSteps",
                        .termination_protected = "TerminationProtected",
                        .unhealthy_node_replacement = "UnhealthyNodeReplacement",
                        .hadoop_version = "HadoopVersion",
                    };
                    return @field(mappings, field_name);
                }
            },
            steps: ?[]struct {
                step_config: StepConfig,
                execution_status_detail: struct {
                    state: []const u8,
                    creation_date_time: i64,
                    start_date_time: ?i64 = null,
                    end_date_time: ?i64 = null,
                    last_state_change_reason: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .state = "State",
                            .creation_date_time = "CreationDateTime",
                            .start_date_time = "StartDateTime",
                            .end_date_time = "EndDateTime",
                            .last_state_change_reason = "LastStateChangeReason",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .step_config = "StepConfig",
                        .execution_status_detail = "ExecutionStatusDetail",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            bootstrap_actions: ?[]struct {
                bootstrap_action_config: ?BootstrapActionConfig = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bootstrap_action_config = "BootstrapActionConfig",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            supported_products: ?[][]const u8 = null,
            visible_to_all_users: ?bool = null,
            job_flow_role: ?[]const u8 = null,
            service_role: ?[]const u8 = null,
            auto_scaling_role: ?[]const u8 = null,
            scale_down_behavior: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_flow_id = "JobFlowId",
                    .name = "Name",
                    .log_uri = "LogUri",
                    .log_encryption_kms_key_id = "LogEncryptionKmsKeyId",
                    .ami_version = "AmiVersion",
                    .execution_status_detail = "ExecutionStatusDetail",
                    .instances = "Instances",
                    .steps = "Steps",
                    .bootstrap_actions = "BootstrapActions",
                    .supported_products = "SupportedProducts",
                    .visible_to_all_users = "VisibleToAllUsers",
                    .job_flow_role = "JobFlowRole",
                    .service_role = "ServiceRole",
                    .auto_scaling_role = "AutoScalingRole",
                    .scale_down_behavior = "ScaleDownBehavior",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flows = "JobFlows",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_notebook_execution: struct {
    action_name: []const u8 = "DescribeNotebookExecution",
    Request: type = struct {
        notebook_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_execution_id = "NotebookExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_notebook_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_notebook_execution };
        }
    },
    Response: type = struct {
        notebook_execution: ?struct {
            notebook_execution_id: ?[]const u8 = null,
            editor_id: ?[]const u8 = null,
            execution_engine: ?ExecutionEngineConfig = null,
            notebook_execution_name: ?[]const u8 = null,
            notebook_params: ?[]const u8 = null,
            status: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            arn: ?[]const u8 = null,
            output_notebook_uri: ?[]const u8 = null,
            last_state_change_reason: ?[]const u8 = null,
            notebook_instance_security_group_id: ?[]const u8 = null,
            tags: ?[]Tag = null,
            notebook_s3_location: ?NotebookS3LocationForOutput = null,
            output_notebook_s3_location: ?struct {
                bucket: ?[]const u8 = null,
                key: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bucket = "Bucket",
                        .key = "Key",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            output_notebook_format: ?[]const u8 = null,
            environment_variables: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .notebook_execution_id = "NotebookExecutionId",
                    .editor_id = "EditorId",
                    .execution_engine = "ExecutionEngine",
                    .notebook_execution_name = "NotebookExecutionName",
                    .notebook_params = "NotebookParams",
                    .status = "Status",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .arn = "Arn",
                    .output_notebook_uri = "OutputNotebookURI",
                    .last_state_change_reason = "LastStateChangeReason",
                    .notebook_instance_security_group_id = "NotebookInstanceSecurityGroupId",
                    .tags = "Tags",
                    .notebook_s3_location = "NotebookS3Location",
                    .output_notebook_s3_location = "OutputNotebookS3Location",
                    .output_notebook_format = "OutputNotebookFormat",
                    .environment_variables = "EnvironmentVariables",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "environment_variables", field_name))
                    return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_execution = "NotebookExecution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const describe_release_label: struct {
    action_name: []const u8 = "DescribeReleaseLabel",
    Request: type = struct {
        release_label: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .release_label = "ReleaseLabel",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_release_label) } {
            return .{ .service_metadata = service_metadata, .action = describe_release_label };
        }
    },
    Response: type = struct {
        release_label: ?[]const u8 = null,
        applications: ?[]struct {
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        available_os_releases: ?[]struct {
            label: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .label = "Label",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .release_label = "ReleaseLabel",
                .applications = "Applications",
                .next_token = "NextToken",
                .available_os_releases = "AvailableOSReleases",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const describe_security_configuration: struct {
    action_name: []const u8 = "DescribeSecurityConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_security_configuration };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        security_configuration: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .security_configuration = "SecurityConfiguration",
                .creation_date_time = "CreationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const describe_step: struct {
    action_name: []const u8 = "DescribeStep",
    Request: type = struct {
        cluster_id: []const u8,
        step_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .step_id = "StepId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_step) } {
            return .{ .service_metadata = service_metadata, .action = describe_step };
        }
    },
    Response: type = struct {
        step: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            config: ?HadoopStepConfig = null,
            action_on_failure: ?[]const u8 = null,
            status: ?StepStatus = null,
            execution_role_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .config = "Config",
                    .action_on_failure = "ActionOnFailure",
                    .status = "Status",
                    .execution_role_arn = "ExecutionRoleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .step = "Step",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const describe_studio: struct {
    action_name: []const u8 = "DescribeStudio",
    Request: type = struct {
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_studio) } {
            return .{ .service_metadata = service_metadata, .action = describe_studio };
        }
    },
    Response: type = struct {
        studio: ?struct {
            studio_id: ?[]const u8 = null,
            studio_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            auth_mode: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            subnet_ids: ?[][]const u8 = null,
            service_role: ?[]const u8 = null,
            user_role: ?[]const u8 = null,
            workspace_security_group_id: ?[]const u8 = null,
            engine_security_group_id: ?[]const u8 = null,
            url: ?[]const u8 = null,
            creation_time: ?i64 = null,
            default_s3_location: ?[]const u8 = null,
            idp_auth_url: ?[]const u8 = null,
            idp_relay_state_parameter_name: ?[]const u8 = null,
            tags: ?[]Tag = null,
            idc_instance_arn: ?[]const u8 = null,
            trusted_identity_propagation_enabled: ?bool = null,
            idc_user_assignment: ?[]const u8 = null,
            encryption_key_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .studio_id = "StudioId",
                    .studio_arn = "StudioArn",
                    .name = "Name",
                    .description = "Description",
                    .auth_mode = "AuthMode",
                    .vpc_id = "VpcId",
                    .subnet_ids = "SubnetIds",
                    .service_role = "ServiceRole",
                    .user_role = "UserRole",
                    .workspace_security_group_id = "WorkspaceSecurityGroupId",
                    .engine_security_group_id = "EngineSecurityGroupId",
                    .url = "Url",
                    .creation_time = "CreationTime",
                    .default_s3_location = "DefaultS3Location",
                    .idp_auth_url = "IdpAuthUrl",
                    .idp_relay_state_parameter_name = "IdpRelayStateParameterName",
                    .tags = "Tags",
                    .idc_instance_arn = "IdcInstanceArn",
                    .trusted_identity_propagation_enabled = "TrustedIdentityPropagationEnabled",
                    .idc_user_assignment = "IdcUserAssignment",
                    .encryption_key_arn = "EncryptionKeyArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio = "Studio",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_auto_termination_policy: struct {
    action_name: []const u8 = "GetAutoTerminationPolicy",
    Request: type = struct {
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_auto_termination_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_auto_termination_policy };
        }
    },
    Response: type = struct {
        auto_termination_policy: ?AutoTerminationPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_termination_policy = "AutoTerminationPolicy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_block_public_access_configuration: struct {
    action_name: []const u8 = "GetBlockPublicAccessConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_block_public_access_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_block_public_access_configuration };
        }
    },
    Response: type = struct {
        block_public_access_configuration: BlockPublicAccessConfiguration,
        block_public_access_configuration_metadata: struct {
            creation_date_time: i64,
            created_by_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_date_time = "CreationDateTime",
                    .created_by_arn = "CreatedByArn",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .block_public_access_configuration = "BlockPublicAccessConfiguration",
                .block_public_access_configuration_metadata = "BlockPublicAccessConfigurationMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_cluster_session_credentials: struct {
    action_name: []const u8 = "GetClusterSessionCredentials",
    Request: type = struct {
        cluster_id: []const u8,
        execution_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .execution_role_arn = "ExecutionRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cluster_session_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_cluster_session_credentials };
        }
    },
    Response: type = struct {
        credentials: ?union {
            username_password: ?struct {
                username: ?[]const u8 = null,
                password: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .username = "Username",
                        .password = "Password",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .username_password = "UsernamePassword",
                };
                return @field(mappings, field_name);
            }
        } = null,
        expires_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
                .expires_at = "ExpiresAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const get_managed_scaling_policy: struct {
    action_name: []const u8 = "GetManagedScalingPolicy",
    Request: type = struct {
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_managed_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_managed_scaling_policy };
        }
    },
    Response: type = struct {
        managed_scaling_policy: ?ManagedScalingPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_scaling_policy = "ManagedScalingPolicy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_studio_session_mapping: struct {
    action_name: []const u8 = "GetStudioSessionMapping",
    Request: type = struct {
        studio_id: []const u8,
        identity_id: ?[]const u8 = null,
        identity_name: ?[]const u8 = null,
        identity_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
                .identity_id = "IdentityId",
                .identity_name = "IdentityName",
                .identity_type = "IdentityType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_studio_session_mapping) } {
            return .{ .service_metadata = service_metadata, .action = get_studio_session_mapping };
        }
    },
    Response: type = struct {
        session_mapping: ?struct {
            studio_id: ?[]const u8 = null,
            identity_id: ?[]const u8 = null,
            identity_name: ?[]const u8 = null,
            identity_type: ?[]const u8 = null,
            session_policy_arn: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .studio_id = "StudioId",
                    .identity_id = "IdentityId",
                    .identity_name = "IdentityName",
                    .identity_type = "IdentityType",
                    .session_policy_arn = "SessionPolicyArn",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_mapping = "SessionMapping",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const list_bootstrap_actions: struct {
    action_name: []const u8 = "ListBootstrapActions",
    Request: type = struct {
        cluster_id: []const u8,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bootstrap_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_bootstrap_actions };
        }
    },
    Response: type = struct {
        bootstrap_actions: ?[]struct {
            name: ?[]const u8 = null,
            script_path: ?[]const u8 = null,
            args: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .script_path = "ScriptPath",
                    .args = "Args",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bootstrap_actions = "BootstrapActions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_clusters: struct {
    action_name: []const u8 = "ListClusters",
    Request: type = struct {
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        cluster_states: ?[][]const u8 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .cluster_states = "ClusterStates",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_clusters };
        }
    },
    Response: type = struct {
        clusters: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?ClusterStatus = null,
            normalized_instance_hours: ?i64 = null,
            cluster_arn: ?[]const u8 = null,
            outpost_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .status = "Status",
                    .normalized_instance_hours = "NormalizedInstanceHours",
                    .cluster_arn = "ClusterArn",
                    .outpost_arn = "OutpostArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .clusters = "Clusters",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_instance_fleets: struct {
    action_name: []const u8 = "ListInstanceFleets",
    Request: type = struct {
        cluster_id: []const u8,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instance_fleets) } {
            return .{ .service_metadata = service_metadata, .action = list_instance_fleets };
        }
    },
    Response: type = struct {
        instance_fleets: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?struct {
                state: ?[]const u8 = null,
                state_change_reason: ?struct {
                    code: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .code = "Code",
                            .message = "Message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                timeline: ?struct {
                    creation_date_time: ?i64 = null,
                    ready_date_time: ?i64 = null,
                    end_date_time: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .creation_date_time = "CreationDateTime",
                            .ready_date_time = "ReadyDateTime",
                            .end_date_time = "EndDateTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state = "State",
                        .state_change_reason = "StateChangeReason",
                        .timeline = "Timeline",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instance_fleet_type: ?[]const u8 = null,
            target_on_demand_capacity: ?i64 = null,
            target_spot_capacity: ?i64 = null,
            provisioned_on_demand_capacity: ?i64 = null,
            provisioned_spot_capacity: ?i64 = null,
            instance_type_specifications: ?[]struct {
                instance_type: ?[]const u8 = null,
                weighted_capacity: ?i64 = null,
                bid_price: ?[]const u8 = null,
                bid_price_as_percentage_of_on_demand_price: ?f64 = null,
                configurations: ?[]Configuration = null,
                ebs_block_devices: ?[]EbsBlockDevice = null,
                ebs_optimized: ?bool = null,
                custom_ami_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .instance_type = "InstanceType",
                        .weighted_capacity = "WeightedCapacity",
                        .bid_price = "BidPrice",
                        .bid_price_as_percentage_of_on_demand_price = "BidPriceAsPercentageOfOnDemandPrice",
                        .configurations = "Configurations",
                        .ebs_block_devices = "EbsBlockDevices",
                        .ebs_optimized = "EbsOptimized",
                        .custom_ami_id = "CustomAmiId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            launch_specifications: ?InstanceFleetProvisioningSpecifications = null,
            resize_specifications: ?InstanceFleetResizingSpecifications = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .status = "Status",
                    .instance_fleet_type = "InstanceFleetType",
                    .target_on_demand_capacity = "TargetOnDemandCapacity",
                    .target_spot_capacity = "TargetSpotCapacity",
                    .provisioned_on_demand_capacity = "ProvisionedOnDemandCapacity",
                    .provisioned_spot_capacity = "ProvisionedSpotCapacity",
                    .instance_type_specifications = "InstanceTypeSpecifications",
                    .launch_specifications = "LaunchSpecifications",
                    .resize_specifications = "ResizeSpecifications",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_fleets = "InstanceFleets",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_instance_groups: struct {
    action_name: []const u8 = "ListInstanceGroups",
    Request: type = struct {
        cluster_id: []const u8,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instance_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_instance_groups };
        }
    },
    Response: type = struct {
        instance_groups: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            market: ?[]const u8 = null,
            instance_group_type: ?[]const u8 = null,
            bid_price: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            requested_instance_count: ?i64 = null,
            running_instance_count: ?i64 = null,
            status: ?struct {
                state: ?[]const u8 = null,
                state_change_reason: ?struct {
                    code: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .code = "Code",
                            .message = "Message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                timeline: ?struct {
                    creation_date_time: ?i64 = null,
                    ready_date_time: ?i64 = null,
                    end_date_time: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .creation_date_time = "CreationDateTime",
                            .ready_date_time = "ReadyDateTime",
                            .end_date_time = "EndDateTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state = "State",
                        .state_change_reason = "StateChangeReason",
                        .timeline = "Timeline",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            configurations: ?[]Configuration = null,
            configurations_version: ?i64 = null,
            last_successfully_applied_configurations: ?[]Configuration = null,
            last_successfully_applied_configurations_version: ?i64 = null,
            ebs_block_devices: ?[]EbsBlockDevice = null,
            ebs_optimized: ?bool = null,
            shrink_policy: ?ShrinkPolicy = null,
            auto_scaling_policy: ?AutoScalingPolicyDescription = null,
            custom_ami_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .market = "Market",
                    .instance_group_type = "InstanceGroupType",
                    .bid_price = "BidPrice",
                    .instance_type = "InstanceType",
                    .requested_instance_count = "RequestedInstanceCount",
                    .running_instance_count = "RunningInstanceCount",
                    .status = "Status",
                    .configurations = "Configurations",
                    .configurations_version = "ConfigurationsVersion",
                    .last_successfully_applied_configurations = "LastSuccessfullyAppliedConfigurations",
                    .last_successfully_applied_configurations_version = "LastSuccessfullyAppliedConfigurationsVersion",
                    .ebs_block_devices = "EbsBlockDevices",
                    .ebs_optimized = "EbsOptimized",
                    .shrink_policy = "ShrinkPolicy",
                    .auto_scaling_policy = "AutoScalingPolicy",
                    .custom_ami_id = "CustomAmiId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_groups = "InstanceGroups",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_instances: struct {
    action_name: []const u8 = "ListInstances",
    Request: type = struct {
        cluster_id: []const u8,
        instance_group_id: ?[]const u8 = null,
        instance_group_types: ?[][]const u8 = null,
        instance_fleet_id: ?[]const u8 = null,
        instance_fleet_type: ?[]const u8 = null,
        instance_states: ?[][]const u8 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .instance_group_id = "InstanceGroupId",
                .instance_group_types = "InstanceGroupTypes",
                .instance_fleet_id = "InstanceFleetId",
                .instance_fleet_type = "InstanceFleetType",
                .instance_states = "InstanceStates",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            id: ?[]const u8 = null,
            ec2_instance_id: ?[]const u8 = null,
            public_dns_name: ?[]const u8 = null,
            public_ip_address: ?[]const u8 = null,
            private_dns_name: ?[]const u8 = null,
            private_ip_address: ?[]const u8 = null,
            status: ?struct {
                state: ?[]const u8 = null,
                state_change_reason: ?struct {
                    code: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .code = "Code",
                            .message = "Message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                timeline: ?struct {
                    creation_date_time: ?i64 = null,
                    ready_date_time: ?i64 = null,
                    end_date_time: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .creation_date_time = "CreationDateTime",
                            .ready_date_time = "ReadyDateTime",
                            .end_date_time = "EndDateTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state = "State",
                        .state_change_reason = "StateChangeReason",
                        .timeline = "Timeline",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instance_group_id: ?[]const u8 = null,
            instance_fleet_id: ?[]const u8 = null,
            market: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            ebs_volumes: ?[]struct {
                device: ?[]const u8 = null,
                volume_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .device = "Device",
                        .volume_id = "VolumeId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .ec2_instance_id = "Ec2InstanceId",
                    .public_dns_name = "PublicDnsName",
                    .public_ip_address = "PublicIpAddress",
                    .private_dns_name = "PrivateDnsName",
                    .private_ip_address = "PrivateIpAddress",
                    .status = "Status",
                    .instance_group_id = "InstanceGroupId",
                    .instance_fleet_id = "InstanceFleetId",
                    .market = "Market",
                    .instance_type = "InstanceType",
                    .ebs_volumes = "EbsVolumes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_notebook_executions: struct {
    action_name: []const u8 = "ListNotebookExecutions",
    Request: type = struct {
        editor_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        from: ?i64 = null,
        to: ?i64 = null,
        marker: ?[]const u8 = null,
        execution_engine_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .editor_id = "EditorId",
                .status = "Status",
                .from = "From",
                .to = "To",
                .marker = "Marker",
                .execution_engine_id = "ExecutionEngineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notebook_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_notebook_executions };
        }
    },
    Response: type = struct {
        notebook_executions: ?[]struct {
            notebook_execution_id: ?[]const u8 = null,
            editor_id: ?[]const u8 = null,
            notebook_execution_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            notebook_s3_location: ?NotebookS3LocationForOutput = null,
            execution_engine_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .notebook_execution_id = "NotebookExecutionId",
                    .editor_id = "EditorId",
                    .notebook_execution_name = "NotebookExecutionName",
                    .status = "Status",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .notebook_s3_location = "NotebookS3Location",
                    .execution_engine_id = "ExecutionEngineId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_executions = "NotebookExecutions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const list_release_labels: struct {
    action_name: []const u8 = "ListReleaseLabels",
    Request: type = struct {
        filters: ?struct {
            prefix: ?[]const u8 = null,
            application: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .prefix = "Prefix",
                    .application = "Application",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_release_labels) } {
            return .{ .service_metadata = service_metadata, .action = list_release_labels };
        }
    },
    Response: type = struct {
        release_labels: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .release_labels = "ReleaseLabels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_security_configurations: struct {
    action_name: []const u8 = "ListSecurityConfigurations",
    Request: type = struct {
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_security_configurations };
        }
    },
    Response: type = struct {
        security_configurations: ?[]struct {
            name: ?[]const u8 = null,
            creation_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .creation_date_time = "CreationDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_configurations = "SecurityConfigurations",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_steps: struct {
    action_name: []const u8 = "ListSteps",
    Request: type = struct {
        cluster_id: []const u8,
        step_states: ?[][]const u8 = null,
        step_ids: ?[][]const u8 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .step_states = "StepStates",
                .step_ids = "StepIds",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_steps) } {
            return .{ .service_metadata = service_metadata, .action = list_steps };
        }
    },
    Response: type = struct {
        steps: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            config: ?HadoopStepConfig = null,
            action_on_failure: ?[]const u8 = null,
            status: ?StepStatus = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .config = "Config",
                    .action_on_failure = "ActionOnFailure",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .steps = "Steps",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_studios: struct {
    action_name: []const u8 = "ListStudios",
    Request: type = struct {
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_studios) } {
            return .{ .service_metadata = service_metadata, .action = list_studios };
        }
    },
    Response: type = struct {
        studios: ?[]struct {
            studio_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            url: ?[]const u8 = null,
            auth_mode: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .studio_id = "StudioId",
                    .name = "Name",
                    .vpc_id = "VpcId",
                    .description = "Description",
                    .url = "Url",
                    .auth_mode = "AuthMode",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studios = "Studios",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_studio_session_mappings: struct {
    action_name: []const u8 = "ListStudioSessionMappings",
    Request: type = struct {
        studio_id: ?[]const u8 = null,
        identity_type: ?[]const u8 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
                .identity_type = "IdentityType",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_studio_session_mappings) } {
            return .{ .service_metadata = service_metadata, .action = list_studio_session_mappings };
        }
    },
    Response: type = struct {
        session_mappings: ?[]struct {
            studio_id: ?[]const u8 = null,
            identity_id: ?[]const u8 = null,
            identity_name: ?[]const u8 = null,
            identity_type: ?[]const u8 = null,
            session_policy_arn: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .studio_id = "StudioId",
                    .identity_id = "IdentityId",
                    .identity_name = "IdentityName",
                    .identity_type = "IdentityType",
                    .session_policy_arn = "SessionPolicyArn",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_mappings = "SessionMappings",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const list_supported_instance_types: struct {
    action_name: []const u8 = "ListSupportedInstanceTypes",
    Request: type = struct {
        release_label: []const u8,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .release_label = "ReleaseLabel",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_supported_instance_types) } {
            return .{ .service_metadata = service_metadata, .action = list_supported_instance_types };
        }
    },
    Response: type = struct {
        supported_instance_types: ?[]struct {
            type: ?[]const u8 = null,
            memory_gb: ?f32 = null,
            storage_gb: ?i64 = null,
            vcpu: ?i64 = null,
            is64_bits_only: ?bool = null,
            instance_family_id: ?[]const u8 = null,
            ebs_optimized_available: ?bool = null,
            ebs_optimized_by_default: ?bool = null,
            number_of_disks: ?i64 = null,
            ebs_storage_only: ?bool = null,
            architecture: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .memory_gb = "MemoryGB",
                    .storage_gb = "StorageGB",
                    .vcpu = "VCPU",
                    .is64_bits_only = "Is64BitsOnly",
                    .instance_family_id = "InstanceFamilyId",
                    .ebs_optimized_available = "EbsOptimizedAvailable",
                    .ebs_optimized_by_default = "EbsOptimizedByDefault",
                    .number_of_disks = "NumberOfDisks",
                    .ebs_storage_only = "EbsStorageOnly",
                    .architecture = "Architecture",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .supported_instance_types = "SupportedInstanceTypes",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const modify_cluster: struct {
    action_name: []const u8 = "ModifyCluster",
    Request: type = struct {
        cluster_id: []const u8,
        step_concurrency_level: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .step_concurrency_level = "StepConcurrencyLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster };
        }
    },
    Response: type = struct {
        step_concurrency_level: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .step_concurrency_level = "StepConcurrencyLevel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const modify_instance_fleet: struct {
    action_name: []const u8 = "ModifyInstanceFleet",
    Request: type = struct {
        cluster_id: []const u8,
        instance_fleet: struct {
            instance_fleet_id: []const u8,
            target_on_demand_capacity: ?i64 = null,
            target_spot_capacity: ?i64 = null,
            resize_specifications: ?InstanceFleetResizingSpecifications = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_fleet_id = "InstanceFleetId",
                    .target_on_demand_capacity = "TargetOnDemandCapacity",
                    .target_spot_capacity = "TargetSpotCapacity",
                    .resize_specifications = "ResizeSpecifications",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .instance_fleet = "InstanceFleet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_fleet) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_fleet };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const modify_instance_groups: struct {
    action_name: []const u8 = "ModifyInstanceGroups",
    Request: type = struct {
        cluster_id: ?[]const u8 = null,
        instance_groups: ?[]struct {
            instance_group_id: []const u8,
            instance_count: ?i64 = null,
            ec2_instance_ids_to_terminate: ?[][]const u8 = null,
            shrink_policy: ?ShrinkPolicy = null,
            reconfiguration_type: ?[]const u8 = null,
            configurations: ?[]Configuration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_group_id = "InstanceGroupId",
                    .instance_count = "InstanceCount",
                    .ec2_instance_ids_to_terminate = "EC2InstanceIdsToTerminate",
                    .shrink_policy = "ShrinkPolicy",
                    .reconfiguration_type = "ReconfigurationType",
                    .configurations = "Configurations",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .instance_groups = "InstanceGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_groups) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_groups };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const put_auto_scaling_policy: struct {
    action_name: []const u8 = "PutAutoScalingPolicy",
    Request: type = struct {
        cluster_id: []const u8,
        instance_group_id: []const u8,
        auto_scaling_policy: AutoScalingPolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .instance_group_id = "InstanceGroupId",
                .auto_scaling_policy = "AutoScalingPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_auto_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_auto_scaling_policy };
        }
    },
    Response: type = struct {
        cluster_id: ?[]const u8 = null,
        instance_group_id: ?[]const u8 = null,
        auto_scaling_policy: ?AutoScalingPolicyDescription = null,
        cluster_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .instance_group_id = "InstanceGroupId",
                .auto_scaling_policy = "AutoScalingPolicy",
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_auto_termination_policy: struct {
    action_name: []const u8 = "PutAutoTerminationPolicy",
    Request: type = struct {
        cluster_id: []const u8,
        auto_termination_policy: ?AutoTerminationPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .auto_termination_policy = "AutoTerminationPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_auto_termination_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_auto_termination_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_block_public_access_configuration: struct {
    action_name: []const u8 = "PutBlockPublicAccessConfiguration",
    Request: type = struct {
        block_public_access_configuration: BlockPublicAccessConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .block_public_access_configuration = "BlockPublicAccessConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_block_public_access_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_block_public_access_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const put_managed_scaling_policy: struct {
    action_name: []const u8 = "PutManagedScalingPolicy",
    Request: type = struct {
        cluster_id: []const u8,
        managed_scaling_policy: ManagedScalingPolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .managed_scaling_policy = "ManagedScalingPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_managed_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_managed_scaling_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const remove_auto_scaling_policy: struct {
    action_name: []const u8 = "RemoveAutoScalingPolicy",
    Request: type = struct {
        cluster_id: []const u8,
        instance_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .instance_group_id = "InstanceGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_auto_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = remove_auto_scaling_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const remove_auto_termination_policy: struct {
    action_name: []const u8 = "RemoveAutoTerminationPolicy",
    Request: type = struct {
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_auto_termination_policy) } {
            return .{ .service_metadata = service_metadata, .action = remove_auto_termination_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const remove_managed_scaling_policy: struct {
    action_name: []const u8 = "RemoveManagedScalingPolicy",
    Request: type = struct {
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_managed_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = remove_managed_scaling_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const remove_tags: struct {
    action_name: []const u8 = "RemoveTags",
    Request: type = struct {
        resource_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const run_job_flow: struct {
    action_name: []const u8 = "RunJobFlow",
    Request: type = struct {
        name: []const u8,
        log_uri: ?[]const u8 = null,
        log_encryption_kms_key_id: ?[]const u8 = null,
        additional_info: ?[]const u8 = null,
        ami_version: ?[]const u8 = null,
        release_label: ?[]const u8 = null,
        instances: struct {
            master_instance_type: ?[]const u8 = null,
            slave_instance_type: ?[]const u8 = null,
            instance_count: ?i64 = null,
            instance_groups: ?[]InstanceGroupConfig = null,
            instance_fleets: ?[]InstanceFleetConfig = null,
            ec2_key_name: ?[]const u8 = null,
            placement: ?PlacementType = null,
            keep_job_flow_alive_when_no_steps: ?bool = null,
            termination_protected: ?bool = null,
            unhealthy_node_replacement: ?bool = null,
            hadoop_version: ?[]const u8 = null,
            ec2_subnet_id: ?[]const u8 = null,
            ec2_subnet_ids: ?[][]const u8 = null,
            emr_managed_master_security_group: ?[]const u8 = null,
            emr_managed_slave_security_group: ?[]const u8 = null,
            service_access_security_group: ?[]const u8 = null,
            additional_master_security_groups: ?[][]const u8 = null,
            additional_slave_security_groups: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .master_instance_type = "MasterInstanceType",
                    .slave_instance_type = "SlaveInstanceType",
                    .instance_count = "InstanceCount",
                    .instance_groups = "InstanceGroups",
                    .instance_fleets = "InstanceFleets",
                    .ec2_key_name = "Ec2KeyName",
                    .placement = "Placement",
                    .keep_job_flow_alive_when_no_steps = "KeepJobFlowAliveWhenNoSteps",
                    .termination_protected = "TerminationProtected",
                    .unhealthy_node_replacement = "UnhealthyNodeReplacement",
                    .hadoop_version = "HadoopVersion",
                    .ec2_subnet_id = "Ec2SubnetId",
                    .ec2_subnet_ids = "Ec2SubnetIds",
                    .emr_managed_master_security_group = "EmrManagedMasterSecurityGroup",
                    .emr_managed_slave_security_group = "EmrManagedSlaveSecurityGroup",
                    .service_access_security_group = "ServiceAccessSecurityGroup",
                    .additional_master_security_groups = "AdditionalMasterSecurityGroups",
                    .additional_slave_security_groups = "AdditionalSlaveSecurityGroups",
                };
                return @field(mappings, field_name);
            }
        },
        steps: ?[]StepConfig = null,
        bootstrap_actions: ?[]BootstrapActionConfig = null,
        supported_products: ?[][]const u8 = null,
        new_supported_products: ?[]struct {
            name: ?[]const u8 = null,
            args: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .args = "Args",
                };
                return @field(mappings, field_name);
            }
        } = null,
        applications: ?[]Application = null,
        configurations: ?[]Configuration = null,
        visible_to_all_users: ?bool = null,
        job_flow_role: ?[]const u8 = null,
        service_role: ?[]const u8 = null,
        tags: ?[]Tag = null,
        security_configuration: ?[]const u8 = null,
        auto_scaling_role: ?[]const u8 = null,
        scale_down_behavior: ?[]const u8 = null,
        custom_ami_id: ?[]const u8 = null,
        ebs_root_volume_size: ?i64 = null,
        repo_upgrade_on_boot: ?[]const u8 = null,
        kerberos_attributes: ?KerberosAttributes = null,
        step_concurrency_level: ?i64 = null,
        managed_scaling_policy: ?ManagedScalingPolicy = null,
        placement_group_configs: ?[]PlacementGroupConfig = null,
        auto_termination_policy: ?AutoTerminationPolicy = null,
        os_release_label: ?[]const u8 = null,
        ebs_root_volume_iops: ?i64 = null,
        ebs_root_volume_throughput: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .log_uri = "LogUri",
                .log_encryption_kms_key_id = "LogEncryptionKmsKeyId",
                .additional_info = "AdditionalInfo",
                .ami_version = "AmiVersion",
                .release_label = "ReleaseLabel",
                .instances = "Instances",
                .steps = "Steps",
                .bootstrap_actions = "BootstrapActions",
                .supported_products = "SupportedProducts",
                .new_supported_products = "NewSupportedProducts",
                .applications = "Applications",
                .configurations = "Configurations",
                .visible_to_all_users = "VisibleToAllUsers",
                .job_flow_role = "JobFlowRole",
                .service_role = "ServiceRole",
                .tags = "Tags",
                .security_configuration = "SecurityConfiguration",
                .auto_scaling_role = "AutoScalingRole",
                .scale_down_behavior = "ScaleDownBehavior",
                .custom_ami_id = "CustomAmiId",
                .ebs_root_volume_size = "EbsRootVolumeSize",
                .repo_upgrade_on_boot = "RepoUpgradeOnBoot",
                .kerberos_attributes = "KerberosAttributes",
                .step_concurrency_level = "StepConcurrencyLevel",
                .managed_scaling_policy = "ManagedScalingPolicy",
                .placement_group_configs = "PlacementGroupConfigs",
                .auto_termination_policy = "AutoTerminationPolicy",
                .os_release_label = "OSReleaseLabel",
                .ebs_root_volume_iops = "EbsRootVolumeIops",
                .ebs_root_volume_throughput = "EbsRootVolumeThroughput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(run_job_flow) } {
            return .{ .service_metadata = service_metadata, .action = run_job_flow };
        }
    },
    Response: type = struct {
        job_flow_id: ?[]const u8 = null,
        cluster_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flow_id = "JobFlowId",
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const set_keep_job_flow_alive_when_no_steps: struct {
    action_name: []const u8 = "SetKeepJobFlowAliveWhenNoSteps",
    Request: type = struct {
        job_flow_ids: [][]const u8,
        keep_job_flow_alive_when_no_steps: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flow_ids = "JobFlowIds",
                .keep_job_flow_alive_when_no_steps = "KeepJobFlowAliveWhenNoSteps",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_keep_job_flow_alive_when_no_steps) } {
            return .{ .service_metadata = service_metadata, .action = set_keep_job_flow_alive_when_no_steps };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const set_termination_protection: struct {
    action_name: []const u8 = "SetTerminationProtection",
    Request: type = struct {
        job_flow_ids: [][]const u8,
        termination_protected: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flow_ids = "JobFlowIds",
                .termination_protected = "TerminationProtected",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_termination_protection) } {
            return .{ .service_metadata = service_metadata, .action = set_termination_protection };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const set_unhealthy_node_replacement: struct {
    action_name: []const u8 = "SetUnhealthyNodeReplacement",
    Request: type = struct {
        job_flow_ids: [][]const u8,
        unhealthy_node_replacement: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flow_ids = "JobFlowIds",
                .unhealthy_node_replacement = "UnhealthyNodeReplacement",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_unhealthy_node_replacement) } {
            return .{ .service_metadata = service_metadata, .action = set_unhealthy_node_replacement };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const set_visible_to_all_users: struct {
    action_name: []const u8 = "SetVisibleToAllUsers",
    Request: type = struct {
        job_flow_ids: [][]const u8,
        visible_to_all_users: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flow_ids = "JobFlowIds",
                .visible_to_all_users = "VisibleToAllUsers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_visible_to_all_users) } {
            return .{ .service_metadata = service_metadata, .action = set_visible_to_all_users };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const start_notebook_execution: struct {
    action_name: []const u8 = "StartNotebookExecution",
    Request: type = struct {
        editor_id: ?[]const u8 = null,
        relative_path: ?[]const u8 = null,
        notebook_execution_name: ?[]const u8 = null,
        notebook_params: ?[]const u8 = null,
        execution_engine: ExecutionEngineConfig,
        service_role: []const u8,
        notebook_instance_security_group_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        notebook_s3_location: ?struct {
            bucket: ?[]const u8 = null,
            key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket = "Bucket",
                    .key = "Key",
                };
                return @field(mappings, field_name);
            }
        } = null,
        output_notebook_s3_location: ?struct {
            bucket: ?[]const u8 = null,
            key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket = "Bucket",
                    .key = "Key",
                };
                return @field(mappings, field_name);
            }
        } = null,
        output_notebook_format: ?[]const u8 = null,
        environment_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .editor_id = "EditorId",
                .relative_path = "RelativePath",
                .notebook_execution_name = "NotebookExecutionName",
                .notebook_params = "NotebookParams",
                .execution_engine = "ExecutionEngine",
                .service_role = "ServiceRole",
                .notebook_instance_security_group_id = "NotebookInstanceSecurityGroupId",
                .tags = "Tags",
                .notebook_s3_location = "NotebookS3Location",
                .output_notebook_s3_location = "OutputNotebookS3Location",
                .output_notebook_format = "OutputNotebookFormat",
                .environment_variables = "EnvironmentVariables",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment_variables", field_name))
                return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_notebook_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_notebook_execution };
        }
    },
    Response: type = struct {
        notebook_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_execution_id = "NotebookExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const stop_notebook_execution: struct {
    action_name: []const u8 = "StopNotebookExecution",
    Request: type = struct {
        notebook_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_execution_id = "NotebookExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_notebook_execution) } {
            return .{ .service_metadata = service_metadata, .action = stop_notebook_execution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};
pub const terminate_job_flows: struct {
    action_name: []const u8 = "TerminateJobFlows",
    Request: type = struct {
        job_flow_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_flow_ids = "JobFlowIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_job_flows) } {
            return .{ .service_metadata = service_metadata, .action = terminate_job_flows };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const update_studio: struct {
    action_name: []const u8 = "UpdateStudio",
    Request: type = struct {
        studio_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        default_s3_location: ?[]const u8 = null,
        encryption_key_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
                .name = "Name",
                .description = "Description",
                .subnet_ids = "SubnetIds",
                .default_s3_location = "DefaultS3Location",
                .encryption_key_arn = "EncryptionKeyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_studio) } {
            return .{ .service_metadata = service_metadata, .action = update_studio };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const update_studio_session_mapping: struct {
    action_name: []const u8 = "UpdateStudioSessionMapping",
    Request: type = struct {
        studio_id: []const u8,
        identity_id: ?[]const u8 = null,
        identity_name: ?[]const u8 = null,
        identity_type: []const u8,
        session_policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "StudioId",
                .identity_id = "IdentityId",
                .identity_name = "IdentityName",
                .identity_type = "IdentityType",
                .session_policy_arn = "SessionPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_studio_session_mapping) } {
            return .{ .service_metadata = service_metadata, .action = update_studio_session_mapping };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
    },
} = .{};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionEngineConfig = struct {
    id: []const u8,
    type: ?[]const u8 = null,
    master_instance_security_group_id: ?[]const u8 = null,
    execution_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .type = "Type",
            .master_instance_security_group_id = "MasterInstanceSecurityGroupId",
            .execution_role_arn = "ExecutionRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTerminationPolicy = struct {
    idle_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .idle_timeout = "IdleTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementGroupConfig = struct {
    instance_role: []const u8,
    placement_strategy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_role = "InstanceRole",
            .placement_strategy = "PlacementStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedScalingPolicy = struct {
    compute_limits: ?ComputeLimits = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compute_limits = "ComputeLimits",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeLimits = struct {
    unit_type: []const u8,
    minimum_capacity_units: i64,
    maximum_capacity_units: i64,
    maximum_on_demand_capacity_units: ?i64 = null,
    maximum_core_capacity_units: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unit_type = "UnitType",
            .minimum_capacity_units = "MinimumCapacityUnits",
            .maximum_capacity_units = "MaximumCapacityUnits",
            .maximum_on_demand_capacity_units = "MaximumOnDemandCapacityUnits",
            .maximum_core_capacity_units = "MaximumCoreCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const KerberosAttributes = struct {
    realm: []const u8,
    kdc_admin_password: []const u8,
    cross_realm_trust_principal_password: ?[]const u8 = null,
    ad_domain_join_user: ?[]const u8 = null,
    ad_domain_join_password: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .realm = "Realm",
            .kdc_admin_password = "KdcAdminPassword",
            .cross_realm_trust_principal_password = "CrossRealmTrustPrincipalPassword",
            .ad_domain_join_user = "ADDomainJoinUser",
            .ad_domain_join_password = "ADDomainJoinPassword",
        };
        return @field(mappings, field_name);
    }
};

pub const Configuration = struct {
    classification: ?[]const u8 = null,
    configurations: ?[]Configuration = null,
    properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .classification = "Classification",
            .configurations = "Configurations",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "properties", field_name))
            return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
        return false;
    }
};

pub const Application = struct {
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,
    args: ?[][]const u8 = null,
    additional_info: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .version = "Version",
            .args = "Args",
            .additional_info = "AdditionalInfo",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_info", field_name))
            return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
        return false;
    }
};

pub const BootstrapActionConfig = struct {
    name: []const u8,
    script_bootstrap_action: ScriptBootstrapActionConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .script_bootstrap_action = "ScriptBootstrapAction",
        };
        return @field(mappings, field_name);
    }
};

pub const ScriptBootstrapActionConfig = struct {
    path: []const u8,
    args: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .args = "Args",
        };
        return @field(mappings, field_name);
    }
};

pub const StepConfig = struct {
    name: []const u8,
    action_on_failure: ?[]const u8 = null,
    hadoop_jar_step: HadoopJarStepConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .action_on_failure = "ActionOnFailure",
            .hadoop_jar_step = "HadoopJarStep",
        };
        return @field(mappings, field_name);
    }
};

pub const HadoopJarStepConfig = struct {
    properties: ?[]KeyValue = null,
    jar: []const u8,
    main_class: ?[]const u8 = null,
    args: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .properties = "Properties",
            .jar = "Jar",
            .main_class = "MainClass",
            .args = "Args",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyValue = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementType = struct {
    availability_zone: ?[]const u8 = null,
    availability_zones: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "AvailabilityZone",
            .availability_zones = "AvailabilityZones",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceFleetConfig = struct {
    name: ?[]const u8 = null,
    instance_fleet_type: []const u8,
    target_on_demand_capacity: ?i64 = null,
    target_spot_capacity: ?i64 = null,
    instance_type_configs: ?[]InstanceTypeConfig = null,
    launch_specifications: ?InstanceFleetProvisioningSpecifications = null,
    resize_specifications: ?InstanceFleetResizingSpecifications = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .instance_fleet_type = "InstanceFleetType",
            .target_on_demand_capacity = "TargetOnDemandCapacity",
            .target_spot_capacity = "TargetSpotCapacity",
            .instance_type_configs = "InstanceTypeConfigs",
            .launch_specifications = "LaunchSpecifications",
            .resize_specifications = "ResizeSpecifications",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceFleetResizingSpecifications = struct {
    spot_resize_specification: ?SpotResizingSpecification = null,
    on_demand_resize_specification: ?OnDemandResizingSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .spot_resize_specification = "SpotResizeSpecification",
            .on_demand_resize_specification = "OnDemandResizeSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const OnDemandResizingSpecification = struct {
    timeout_duration_minutes: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_duration_minutes = "TimeoutDurationMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotResizingSpecification = struct {
    timeout_duration_minutes: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_duration_minutes = "TimeoutDurationMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceFleetProvisioningSpecifications = struct {
    spot_specification: ?SpotProvisioningSpecification = null,
    on_demand_specification: ?OnDemandProvisioningSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .spot_specification = "SpotSpecification",
            .on_demand_specification = "OnDemandSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const OnDemandProvisioningSpecification = struct {
    allocation_strategy: []const u8,
    capacity_reservation_options: ?OnDemandCapacityReservationOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocation_strategy = "AllocationStrategy",
            .capacity_reservation_options = "CapacityReservationOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const OnDemandCapacityReservationOptions = struct {
    usage_strategy: ?[]const u8 = null,
    capacity_reservation_preference: ?[]const u8 = null,
    capacity_reservation_resource_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .usage_strategy = "UsageStrategy",
            .capacity_reservation_preference = "CapacityReservationPreference",
            .capacity_reservation_resource_group_arn = "CapacityReservationResourceGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotProvisioningSpecification = struct {
    timeout_duration_minutes: i64,
    timeout_action: []const u8,
    block_duration_minutes: ?i64 = null,
    allocation_strategy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_duration_minutes = "TimeoutDurationMinutes",
            .timeout_action = "TimeoutAction",
            .block_duration_minutes = "BlockDurationMinutes",
            .allocation_strategy = "AllocationStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceTypeConfig = struct {
    instance_type: []const u8,
    weighted_capacity: ?i64 = null,
    bid_price: ?[]const u8 = null,
    bid_price_as_percentage_of_on_demand_price: ?f64 = null,
    ebs_configuration: ?EbsConfiguration = null,
    configurations: ?[]Configuration = null,
    custom_ami_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "InstanceType",
            .weighted_capacity = "WeightedCapacity",
            .bid_price = "BidPrice",
            .bid_price_as_percentage_of_on_demand_price = "BidPriceAsPercentageOfOnDemandPrice",
            .ebs_configuration = "EbsConfiguration",
            .configurations = "Configurations",
            .custom_ami_id = "CustomAmiId",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsConfiguration = struct {
    ebs_block_device_configs: ?[]EbsBlockDeviceConfig = null,
    ebs_optimized: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_block_device_configs = "EbsBlockDeviceConfigs",
            .ebs_optimized = "EbsOptimized",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsBlockDeviceConfig = struct {
    volume_specification: VolumeSpecification,
    volumes_per_instance: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_specification = "VolumeSpecification",
            .volumes_per_instance = "VolumesPerInstance",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeSpecification = struct {
    volume_type: []const u8,
    iops: ?i64 = null,
    size_in_gb: i64,
    throughput: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_type = "VolumeType",
            .iops = "Iops",
            .size_in_gb = "SizeInGB",
            .throughput = "Throughput",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceGroupConfig = struct {
    name: ?[]const u8 = null,
    market: ?[]const u8 = null,
    instance_role: []const u8,
    bid_price: ?[]const u8 = null,
    instance_type: []const u8,
    instance_count: i64,
    configurations: ?[]Configuration = null,
    ebs_configuration: ?EbsConfiguration = null,
    auto_scaling_policy: ?AutoScalingPolicy = null,
    custom_ami_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .market = "Market",
            .instance_role = "InstanceRole",
            .bid_price = "BidPrice",
            .instance_type = "InstanceType",
            .instance_count = "InstanceCount",
            .configurations = "Configurations",
            .ebs_configuration = "EbsConfiguration",
            .auto_scaling_policy = "AutoScalingPolicy",
            .custom_ami_id = "CustomAmiId",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingPolicy = struct {
    constraints: ScalingConstraints,
    rules: []ScalingRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constraints = "Constraints",
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const ScalingRule = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    action: ScalingAction,
    trigger: ScalingTrigger,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .action = "Action",
            .trigger = "Trigger",
        };
        return @field(mappings, field_name);
    }
};

pub const ScalingTrigger = struct {
    cloud_watch_alarm_definition: CloudWatchAlarmDefinition,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_alarm_definition = "CloudWatchAlarmDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchAlarmDefinition = struct {
    comparison_operator: []const u8,
    evaluation_periods: ?i64 = null,
    metric_name: []const u8,
    namespace: ?[]const u8 = null,
    period: i64,
    statistic: ?[]const u8 = null,
    threshold: f64,
    unit: ?[]const u8 = null,
    dimensions: ?[]MetricDimension = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison_operator = "ComparisonOperator",
            .evaluation_periods = "EvaluationPeriods",
            .metric_name = "MetricName",
            .namespace = "Namespace",
            .period = "Period",
            .statistic = "Statistic",
            .threshold = "Threshold",
            .unit = "Unit",
            .dimensions = "Dimensions",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricDimension = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ScalingAction = struct {
    market: ?[]const u8 = null,
    simple_scaling_policy_configuration: SimpleScalingPolicyConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .market = "Market",
            .simple_scaling_policy_configuration = "SimpleScalingPolicyConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SimpleScalingPolicyConfiguration = struct {
    adjustment_type: ?[]const u8 = null,
    scaling_adjustment: i64,
    cool_down: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adjustment_type = "AdjustmentType",
            .scaling_adjustment = "ScalingAdjustment",
            .cool_down = "CoolDown",
        };
        return @field(mappings, field_name);
    }
};

pub const ScalingConstraints = struct {
    min_capacity: i64,
    max_capacity: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_capacity = "MinCapacity",
            .max_capacity = "MaxCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const BlockPublicAccessConfiguration = struct {
    block_public_security_group_rules: bool,
    permitted_public_security_group_rule_ranges: ?[]PortRange = null,
    classification: ?[]const u8 = null,
    configurations: ?[]Configuration = null,
    properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_public_security_group_rules = "BlockPublicSecurityGroupRules",
            .permitted_public_security_group_rule_ranges = "PermittedPublicSecurityGroupRuleRanges",
            .classification = "Classification",
            .configurations = "Configurations",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "properties", field_name))
            return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
        return false;
    }
};

pub const PortRange = struct {
    min_range: i64,
    max_range: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_range = "MinRange",
            .max_range = "MaxRange",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingPolicyDescription = struct {
    status: ?AutoScalingPolicyStatus = null,
    constraints: ?ScalingConstraints = null,
    rules: ?[]ScalingRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .constraints = "Constraints",
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingPolicyStatus = struct {
    state: ?[]const u8 = null,
    state_change_reason: ?AutoScalingPolicyStateChangeReason = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .state_change_reason = "StateChangeReason",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingPolicyStateChangeReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ShrinkPolicy = struct {
    decommission_timeout: ?i64 = null,
    instance_resize_policy: ?InstanceResizePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .decommission_timeout = "DecommissionTimeout",
            .instance_resize_policy = "InstanceResizePolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceResizePolicy = struct {
    instances_to_terminate: ?[][]const u8 = null,
    instances_to_protect: ?[][]const u8 = null,
    instance_termination_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instances_to_terminate = "InstancesToTerminate",
            .instances_to_protect = "InstancesToProtect",
            .instance_termination_timeout = "InstanceTerminationTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const StepStatus = struct {
    state: ?[]const u8 = null,
    state_change_reason: ?StepStateChangeReason = null,
    failure_details: ?FailureDetails = null,
    timeline: ?StepTimeline = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .state_change_reason = "StateChangeReason",
            .failure_details = "FailureDetails",
            .timeline = "Timeline",
        };
        return @field(mappings, field_name);
    }
};

pub const StepTimeline = struct {
    creation_date_time: ?i64 = null,
    start_date_time: ?i64 = null,
    end_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_date_time = "CreationDateTime",
            .start_date_time = "StartDateTime",
            .end_date_time = "EndDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const FailureDetails = struct {
    reason: ?[]const u8 = null,
    message: ?[]const u8 = null,
    log_file: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reason = "Reason",
            .message = "Message",
            .log_file = "LogFile",
        };
        return @field(mappings, field_name);
    }
};

pub const StepStateChangeReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const HadoopStepConfig = struct {
    jar: ?[]const u8 = null,
    properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    main_class: ?[]const u8 = null,
    args: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .jar = "Jar",
            .properties = "Properties",
            .main_class = "MainClass",
            .args = "Args",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "properties", field_name))
            return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
        return false;
    }
};

pub const NotebookS3LocationForOutput = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsBlockDevice = struct {
    volume_specification: ?VolumeSpecification = null,
    device: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_specification = "VolumeSpecification",
            .device = "Device",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterStatus = struct {
    state: ?[]const u8 = null,
    state_change_reason: ?ClusterStateChangeReason = null,
    timeline: ?ClusterTimeline = null,
    error_details: ?[]ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .state_change_reason = "StateChangeReason",
            .timeline = "Timeline",
            .error_details = "ErrorDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetail = struct {
    error_code: ?[]const u8 = null,
    error_data: ?[][]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_data = "ErrorData",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "error_data", field_name))
            return try serializeMap(self.error_data, self.fieldNameFor("error_data"), options, out_stream);
        return false;
    }
};

pub const ClusterTimeline = struct {
    creation_date_time: ?i64 = null,
    ready_date_time: ?i64 = null,
    end_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_date_time = "CreationDateTime",
            .ready_date_time = "ReadyDateTime",
            .end_date_time = "EndDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterStateChangeReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};
