const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-10-01";
pub const sdk_id: []const u8 = "EMR containers";
pub const arn_namespace: ?[]const u8 = "emr-containers";
pub const endpoint_prefix: []const u8 = "emr-containers";
pub const sigv4_name: []const u8 = "emr-containers";
pub const name: []const u8 = "AwsChicagoWebService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-10-01",
    sdk_id: []const u8 = "EMR containers",
    arn_namespace: ?[]const u8 = "emr-containers",
    endpoint_prefix: []const u8 = "emr-containers",
    sigv4_name: []const u8 = "emr-containers",
    name: []const u8 = "AwsChicagoWebService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_job_run: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/virtualclusters/{virtualClusterId}/jobruns/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelJobRun",
    Request: type = struct {
        id: []const u8,
        virtual_cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .virtual_cluster_id = "virtualClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job_run) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job_run };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        virtual_cluster_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .virtual_cluster_id = "virtualClusterId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const create_job_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/jobtemplates",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateJobTemplate",
    Request: type = struct {
        name: []const u8,
        client_token: []const u8,
        job_template_data: JobTemplateData,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        kms_key_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .client_token = "clientToken",
                .job_template_data = "jobTemplateData",
                .tags = "tags",
                .kms_key_arn = "kmsKeyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job_template) } {
            return .{ .service_metadata = service_metadata, .action = create_job_template };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .arn = "arn",
                .created_at = "createdAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_managed_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/virtualclusters/{virtualClusterId}/endpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateManagedEndpoint",
    Request: type = struct {
        name: []const u8,
        virtual_cluster_id: []const u8,
        type: []const u8,
        release_label: []const u8,
        execution_role_arn: []const u8,
        certificate_arn: ?[]const u8 = null,
        configuration_overrides: ?ConfigurationOverrides = null,
        client_token: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .virtual_cluster_id = "virtualClusterId",
                .type = "type",
                .release_label = "releaseLabel",
                .execution_role_arn = "executionRoleArn",
                .certificate_arn = "certificateArn",
                .configuration_overrides = "configurationOverrides",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_managed_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_managed_endpoint };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        virtual_cluster_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .arn = "arn",
                .virtual_cluster_id = "virtualClusterId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_virtual_cluster: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/virtualclusters",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVirtualCluster",
    Request: type = struct {
        name: []const u8,
        container_provider: ContainerProvider,
        client_token: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .container_provider = "containerProvider",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_virtual_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_virtual_cluster };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_job_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/jobtemplates/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJobTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_job_template };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const delete_managed_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/virtualclusters/{virtualClusterId}/endpoints/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteManagedEndpoint",
    Request: type = struct {
        id: []const u8,
        virtual_cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .virtual_cluster_id = "virtualClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_managed_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_managed_endpoint };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        virtual_cluster_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .virtual_cluster_id = "virtualClusterId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const delete_virtual_cluster: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/virtualclusters/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteVirtualCluster",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_virtual_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_virtual_cluster };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_job_run: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/virtualclusters/{virtualClusterId}/jobruns/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobRun",
    Request: type = struct {
        id: []const u8,
        virtual_cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .virtual_cluster_id = "virtualClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_run) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_run };
        }
    },
    Response: type = struct {
        job_run: ?JobRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_run = "jobRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_job_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobtemplates/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_template) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_template };
        }
    },
    Response: type = struct {
        job_template: ?JobTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template = "jobTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_managed_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/virtualclusters/{virtualClusterId}/endpoints/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeManagedEndpoint",
    Request: type = struct {
        id: []const u8,
        virtual_cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .virtual_cluster_id = "virtualClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_managed_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = describe_managed_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_virtual_cluster: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/virtualclusters/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeVirtualCluster",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_virtual_cluster) } {
            return .{ .service_metadata = service_metadata, .action = describe_virtual_cluster };
        }
    },
    Response: type = struct {
        virtual_cluster: ?VirtualCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_cluster = "virtualCluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_managed_endpoint_session_credentials: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/virtualclusters/{virtualClusterIdentifier}/endpoints/{endpointIdentifier}/credentials",
        .success_code = 200,
    };

    action_name: []const u8 = "GetManagedEndpointSessionCredentials",
    Request: type = struct {
        endpoint_identifier: []const u8,
        virtual_cluster_identifier: []const u8,
        execution_role_arn: []const u8,
        credential_type: []const u8,
        duration_in_seconds: ?i64 = null,
        log_context: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_identifier = "endpointIdentifier",
                .virtual_cluster_identifier = "virtualClusterIdentifier",
                .execution_role_arn = "executionRoleArn",
                .credential_type = "credentialType",
                .duration_in_seconds = "durationInSeconds",
                .log_context = "logContext",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_managed_endpoint_session_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_managed_endpoint_session_credentials };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        credentials: ?union {
            token: ?[]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .token = "token",
                };
                return @field(mappings, field_name);
            }
        } = null,
        expires_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .credentials = "credentials",
                .expires_at = "expiresAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        RequestThrottled,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_job_runs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/virtualclusters/{virtualClusterId}/jobruns",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobRuns",
    Request: type = struct {
        virtual_cluster_id: []const u8,
        created_before: ?i64 = null,
        created_after: ?i64 = null,
        name: ?[]const u8 = null,
        states: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .created_before = "createdBefore",
            .created_after = "createdAfter",
            .name = "name",
            .states = "states",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_cluster_id = "virtualClusterId",
                .created_before = "createdBefore",
                .created_after = "createdAfter",
                .name = "name",
                .states = "states",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_job_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_job_runs };
        }
    },
    Response: type = struct {
        job_runs: ?[]JobRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_runs = "jobRuns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_job_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobtemplates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobTemplates",
    Request: type = struct {
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .created_after = "createdAfter",
            .created_before = "createdBefore",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_after = "createdAfter",
                .created_before = "createdBefore",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_job_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_job_templates };
        }
    },
    Response: type = struct {
        templates: ?[]JobTemplate = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .templates = "templates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_managed_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/virtualclusters/{virtualClusterId}/endpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListManagedEndpoints",
    Request: type = struct {
        virtual_cluster_id: []const u8,
        created_before: ?i64 = null,
        created_after: ?i64 = null,
        types: ?[][]const u8 = null,
        states: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .created_before = "createdBefore",
            .created_after = "createdAfter",
            .types = "types",
            .states = "states",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_cluster_id = "virtualClusterId",
                .created_before = "createdBefore",
                .created_after = "createdAfter",
                .types = "types",
                .states = "states",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_managed_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_managed_endpoints };
        }
    },
    Response: type = struct {
        endpoints: ?[]Endpoint = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "endpoints",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_virtual_clusters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/virtualclusters",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVirtualClusters",
    Request: type = struct {
        container_provider_id: ?[]const u8 = null,
        container_provider_type: ?[]const u8 = null,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        states: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .container_provider_id = "containerProviderId",
            .container_provider_type = "containerProviderType",
            .created_after = "createdAfter",
            .created_before = "createdBefore",
            .states = "states",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_provider_id = "containerProviderId",
                .container_provider_type = "containerProviderType",
                .created_after = "createdAfter",
                .created_before = "createdBefore",
                .states = "states",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_virtual_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_virtual_clusters };
        }
    },
    Response: type = struct {
        virtual_clusters: ?[]VirtualCluster = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .virtual_clusters = "virtualClusters",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const start_job_run: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/virtualclusters/{virtualClusterId}/jobruns",
        .success_code = 200,
    };

    action_name: []const u8 = "StartJobRun",
    Request: type = struct {
        name: ?[]const u8 = null,
        virtual_cluster_id: []const u8,
        client_token: []const u8,
        execution_role_arn: ?[]const u8 = null,
        release_label: ?[]const u8 = null,
        job_driver: ?JobDriver = null,
        configuration_overrides: ?ConfigurationOverrides = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        job_template_id: ?[]const u8 = null,
        job_template_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        retry_policy_configuration: ?RetryPolicyConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .virtual_cluster_id = "virtualClusterId",
                .client_token = "clientToken",
                .execution_role_arn = "executionRoleArn",
                .release_label = "releaseLabel",
                .job_driver = "jobDriver",
                .configuration_overrides = "configurationOverrides",
                .tags = "tags",
                .job_template_id = "jobTemplateId",
                .job_template_parameters = "jobTemplateParameters",
                .retry_policy_configuration = "retryPolicyConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "job_template_parameters", field_name))
                return try serializeMap(self.job_template_parameters, self.fieldNameFor("job_template_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_job_run) } {
            return .{ .service_metadata = service_metadata, .action = start_job_run };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        virtual_cluster_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .arn = "arn",
                .virtual_cluster_id = "virtualClusterId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const RetryPolicyConfiguration = struct {
    max_attempts: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_attempts = "maxAttempts",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationOverrides = struct {
    application_configuration: ?[]Configuration = null,
    monitoring_configuration: ?MonitoringConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_configuration = "applicationConfiguration",
            .monitoring_configuration = "monitoringConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringConfiguration = struct {
    persistent_app_ui: ?[]const u8 = null,
    cloud_watch_monitoring_configuration: ?CloudWatchMonitoringConfiguration = null,
    s3_monitoring_configuration: ?S3MonitoringConfiguration = null,
    container_log_rotation_configuration: ?ContainerLogRotationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .persistent_app_ui = "persistentAppUI",
            .cloud_watch_monitoring_configuration = "cloudWatchMonitoringConfiguration",
            .s3_monitoring_configuration = "s3MonitoringConfiguration",
            .container_log_rotation_configuration = "containerLogRotationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerLogRotationConfiguration = struct {
    rotation_size: []const u8,
    max_files_to_keep: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rotation_size = "rotationSize",
            .max_files_to_keep = "maxFilesToKeep",
        };
        return @field(mappings, field_name);
    }
};

pub const S3MonitoringConfiguration = struct {
    log_uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_uri = "logUri",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchMonitoringConfiguration = struct {
    log_group_name: []const u8,
    log_stream_name_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_name = "logGroupName",
            .log_stream_name_prefix = "logStreamNamePrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Configuration = struct {
    classification: []const u8,
    properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    configurations: ?[]Configuration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .classification = "classification",
            .properties = "properties",
            .configurations = "configurations",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "properties", field_name))
            return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
        return false;
    }
};

pub const JobDriver = struct {
    spark_submit_job_driver: ?SparkSubmitJobDriver = null,
    spark_sql_job_driver: ?SparkSqlJobDriver = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .spark_submit_job_driver = "sparkSubmitJobDriver",
            .spark_sql_job_driver = "sparkSqlJobDriver",
        };
        return @field(mappings, field_name);
    }
};

pub const SparkSqlJobDriver = struct {
    entry_point: ?[]const u8 = null,
    spark_sql_parameters: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entry_point = "entryPoint",
            .spark_sql_parameters = "sparkSqlParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const SparkSubmitJobDriver = struct {
    entry_point: []const u8,
    entry_point_arguments: ?[][]const u8 = null,
    spark_submit_parameters: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entry_point = "entryPoint",
            .entry_point_arguments = "entryPointArguments",
            .spark_submit_parameters = "sparkSubmitParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const VirtualCluster = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    container_provider: ?ContainerProvider = null,
    created_at: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .arn = "arn",
            .state = "state",
            .container_provider = "containerProvider",
            .created_at = "createdAt",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ContainerProvider = struct {
    type: []const u8,
    id: []const u8,
    info: ?ContainerInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .id = "id",
            .info = "info",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerInfo = union {
    eks_info: ?EksInfo,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eks_info = "eksInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const EksInfo = struct {
    namespace: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "namespace",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    virtual_cluster_id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    release_label: ?[]const u8 = null,
    execution_role_arn: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    certificate_authority: ?Certificate = null,
    configuration_overrides: ?ConfigurationOverrides = null,
    server_url: ?[]const u8 = null,
    created_at: ?i64 = null,
    security_group: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    state_details: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .arn = "arn",
            .virtual_cluster_id = "virtualClusterId",
            .type = "type",
            .state = "state",
            .release_label = "releaseLabel",
            .execution_role_arn = "executionRoleArn",
            .certificate_arn = "certificateArn",
            .certificate_authority = "certificateAuthority",
            .configuration_overrides = "configurationOverrides",
            .server_url = "serverUrl",
            .created_at = "createdAt",
            .security_group = "securityGroup",
            .subnet_ids = "subnetIds",
            .state_details = "stateDetails",
            .failure_reason = "failureReason",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Certificate = struct {
    certificate_arn: ?[]const u8 = null,
    certificate_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "certificateArn",
            .certificate_data = "certificateData",
        };
        return @field(mappings, field_name);
    }
};

pub const JobTemplate = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    created_by: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    job_template_data: JobTemplateData,
    kms_key_arn: ?[]const u8 = null,
    decryption_error: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .id = "id",
            .arn = "arn",
            .created_at = "createdAt",
            .created_by = "createdBy",
            .tags = "tags",
            .job_template_data = "jobTemplateData",
            .kms_key_arn = "kmsKeyArn",
            .decryption_error = "decryptionError",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const JobTemplateData = struct {
    execution_role_arn: []const u8,
    release_label: []const u8,
    configuration_overrides: ?ParametricConfigurationOverrides = null,
    job_driver: JobDriver,
    parameter_configuration: ?[]struct {
        key: ?[]const u8 = null,
        value: ?TemplateParameterConfiguration = null,
    } = null,
    job_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execution_role_arn = "executionRoleArn",
            .release_label = "releaseLabel",
            .configuration_overrides = "configurationOverrides",
            .job_driver = "jobDriver",
            .parameter_configuration = "parameterConfiguration",
            .job_tags = "jobTags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameter_configuration", field_name))
            return try serializeMap(self.parameter_configuration, self.fieldNameFor("parameter_configuration"), options, out_stream);
        if (std.mem.eql(u8, "job_tags", field_name))
            return try serializeMap(self.job_tags, self.fieldNameFor("job_tags"), options, out_stream);
        return false;
    }
};

pub const TemplateParameterConfiguration = struct {
    type: ?[]const u8 = null,
    default_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ParametricConfigurationOverrides = struct {
    application_configuration: ?[]Configuration = null,
    monitoring_configuration: ?ParametricMonitoringConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_configuration = "applicationConfiguration",
            .monitoring_configuration = "monitoringConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ParametricMonitoringConfiguration = struct {
    persistent_app_ui: ?[]const u8 = null,
    cloud_watch_monitoring_configuration: ?ParametricCloudWatchMonitoringConfiguration = null,
    s3_monitoring_configuration: ?ParametricS3MonitoringConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .persistent_app_ui = "persistentAppUI",
            .cloud_watch_monitoring_configuration = "cloudWatchMonitoringConfiguration",
            .s3_monitoring_configuration = "s3MonitoringConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ParametricS3MonitoringConfiguration = struct {
    log_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_uri = "logUri",
        };
        return @field(mappings, field_name);
    }
};

pub const ParametricCloudWatchMonitoringConfiguration = struct {
    log_group_name: ?[]const u8 = null,
    log_stream_name_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_name = "logGroupName",
            .log_stream_name_prefix = "logStreamNamePrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const JobRun = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    virtual_cluster_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    client_token: ?[]const u8 = null,
    execution_role_arn: ?[]const u8 = null,
    release_label: ?[]const u8 = null,
    configuration_overrides: ?ConfigurationOverrides = null,
    job_driver: ?JobDriver = null,
    created_at: ?i64 = null,
    created_by: ?[]const u8 = null,
    finished_at: ?i64 = null,
    state_details: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    retry_policy_configuration: ?RetryPolicyConfiguration = null,
    retry_policy_execution: ?RetryPolicyExecution = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .virtual_cluster_id = "virtualClusterId",
            .arn = "arn",
            .state = "state",
            .client_token = "clientToken",
            .execution_role_arn = "executionRoleArn",
            .release_label = "releaseLabel",
            .configuration_overrides = "configurationOverrides",
            .job_driver = "jobDriver",
            .created_at = "createdAt",
            .created_by = "createdBy",
            .finished_at = "finishedAt",
            .state_details = "stateDetails",
            .failure_reason = "failureReason",
            .tags = "tags",
            .retry_policy_configuration = "retryPolicyConfiguration",
            .retry_policy_execution = "retryPolicyExecution",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const RetryPolicyExecution = struct {
    current_attempt_count: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .current_attempt_count = "currentAttemptCount",
        };
        return @field(mappings, field_name);
    }
};
