const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "EntityResolution";
pub const arn_namespace: ?[]const u8 = "entityresolution";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "entityresolution";
pub const name: []const u8 = "AWSVeniceService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "EntityResolution",
    arn_namespace: ?[]const u8 = "entityresolution",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "entityresolution",
    name: []const u8 = "AWSVeniceService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_id_mapping_workflow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/idmappingworkflows",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIdMappingWorkflow",
    Request: type = struct {
        workflow_name: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []IdMappingWorkflowInputSource,
        output_source_config: []IdMappingWorkflowOutputSource,
        id_mapping_techniques: IdMappingTechniques,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .id_mapping_techniques = "idMappingTechniques",
                .role_arn = "roleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_id_mapping_workflow) } {
            return .{ .service_metadata = service_metadata, .action = create_id_mapping_workflow };
        }
    },
    Response: type = struct {
        workflow_name: []const u8,
        workflow_arn: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []IdMappingWorkflowInputSource,
        output_source_config: []IdMappingWorkflowOutputSource,
        id_mapping_techniques: IdMappingTechniques,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .workflow_arn = "workflowArn",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .id_mapping_techniques = "idMappingTechniques",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ExceedsLimit,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_matching_workflow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/matchingworkflows",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMatchingWorkflow",
    Request: type = struct {
        workflow_name: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []InputSource,
        output_source_config: []OutputSource,
        resolution_techniques: ResolutionTechniques,
        incremental_run_config: ?IncrementalRunConfig = null,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .resolution_techniques = "resolutionTechniques",
                .incremental_run_config = "incrementalRunConfig",
                .role_arn = "roleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_matching_workflow) } {
            return .{ .service_metadata = service_metadata, .action = create_matching_workflow };
        }
    },
    Response: type = struct {
        workflow_name: []const u8,
        workflow_arn: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []InputSource,
        output_source_config: []OutputSource,
        resolution_techniques: ResolutionTechniques,
        incremental_run_config: ?IncrementalRunConfig = null,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .workflow_arn = "workflowArn",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .resolution_techniques = "resolutionTechniques",
                .incremental_run_config = "incrementalRunConfig",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ExceedsLimit,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_schema_mapping: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/schemas",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSchemaMapping",
    Request: type = struct {
        schema_name: []const u8,
        description: ?[]const u8 = null,
        mapped_input_fields: []SchemaInputAttribute,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_name = "schemaName",
                .description = "description",
                .mapped_input_fields = "mappedInputFields",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_schema_mapping) } {
            return .{ .service_metadata = service_metadata, .action = create_schema_mapping };
        }
    },
    Response: type = struct {
        schema_name: []const u8,
        schema_arn: []const u8,
        description: []const u8,
        mapped_input_fields: []SchemaInputAttribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_name = "schemaName",
                .schema_arn = "schemaArn",
                .description = "description",
                .mapped_input_fields = "mappedInputFields",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ExceedsLimit,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_id_mapping_workflow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/idmappingworkflows/{workflowName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIdMappingWorkflow",
    Request: type = struct {
        workflow_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_id_mapping_workflow) } {
            return .{ .service_metadata = service_metadata, .action = delete_id_mapping_workflow };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_matching_workflow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/matchingworkflows/{workflowName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMatchingWorkflow",
    Request: type = struct {
        workflow_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_matching_workflow) } {
            return .{ .service_metadata = service_metadata, .action = delete_matching_workflow };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_schema_mapping: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/schemas/{schemaName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSchemaMapping",
    Request: type = struct {
        schema_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_name = "schemaName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema_mapping) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema_mapping };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_id_mapping_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/idmappingworkflows/{workflowName}/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIdMappingJob",
    Request: type = struct {
        workflow_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_id_mapping_job) } {
            return .{ .service_metadata = service_metadata, .action = get_id_mapping_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        status: []const u8,
        start_time: i64,
        end_time: ?i64 = null,
        metrics: ?struct {
            input_records: ?i64 = null,
            total_records_processed: ?i64 = null,
            records_not_processed: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .input_records = "inputRecords",
                    .total_records_processed = "totalRecordsProcessed",
                    .records_not_processed = "recordsNotProcessed",
                };
                return @field(mappings, field_name);
            }
        } = null,
        error_details: ?ErrorDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .status = "status",
                .start_time = "startTime",
                .end_time = "endTime",
                .metrics = "metrics",
                .error_details = "errorDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_id_mapping_workflow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/idmappingworkflows/{workflowName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIdMappingWorkflow",
    Request: type = struct {
        workflow_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_id_mapping_workflow) } {
            return .{ .service_metadata = service_metadata, .action = get_id_mapping_workflow };
        }
    },
    Response: type = struct {
        workflow_name: []const u8,
        workflow_arn: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []IdMappingWorkflowInputSource,
        output_source_config: []IdMappingWorkflowOutputSource,
        id_mapping_techniques: IdMappingTechniques,
        created_at: i64,
        updated_at: i64,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .workflow_arn = "workflowArn",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .id_mapping_techniques = "idMappingTechniques",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .role_arn = "roleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_match_id: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/matchingworkflows/{workflowName}/matches",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMatchId",
    Request: type = struct {
        workflow_name: []const u8,
        record: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .record = "record",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "record", field_name))
                return try serializeMap(self.record, self.fieldNameFor("record"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_match_id) } {
            return .{ .service_metadata = service_metadata, .action = get_match_id };
        }
    },
    Response: type = struct {
        match_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .match_id = "matchId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_matching_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/matchingworkflows/{workflowName}/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMatchingJob",
    Request: type = struct {
        workflow_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_matching_job) } {
            return .{ .service_metadata = service_metadata, .action = get_matching_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        status: []const u8,
        start_time: i64,
        end_time: ?i64 = null,
        metrics: ?struct {
            input_records: ?i64 = null,
            total_records_processed: ?i64 = null,
            records_not_processed: ?i64 = null,
            match_i_ds: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .input_records = "inputRecords",
                    .total_records_processed = "totalRecordsProcessed",
                    .records_not_processed = "recordsNotProcessed",
                    .match_i_ds = "matchIDs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        error_details: ?ErrorDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .status = "status",
                .start_time = "startTime",
                .end_time = "endTime",
                .metrics = "metrics",
                .error_details = "errorDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_matching_workflow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/matchingworkflows/{workflowName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMatchingWorkflow",
    Request: type = struct {
        workflow_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_matching_workflow) } {
            return .{ .service_metadata = service_metadata, .action = get_matching_workflow };
        }
    },
    Response: type = struct {
        workflow_name: []const u8,
        workflow_arn: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []InputSource,
        output_source_config: []OutputSource,
        resolution_techniques: ResolutionTechniques,
        created_at: i64,
        updated_at: i64,
        incremental_run_config: ?IncrementalRunConfig = null,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .workflow_arn = "workflowArn",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .resolution_techniques = "resolutionTechniques",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .incremental_run_config = "incrementalRunConfig",
                .role_arn = "roleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_provider_service: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/providerservices/{providerName}/{providerServiceName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProviderService",
    Request: type = struct {
        provider_name: []const u8,
        provider_service_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_name = "providerName",
                .provider_service_name = "providerServiceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_provider_service) } {
            return .{ .service_metadata = service_metadata, .action = get_provider_service };
        }
    },
    Response: type = struct {
        provider_name: []const u8,
        provider_service_name: []const u8,
        provider_service_display_name: []const u8,
        provider_service_type: []const u8,
        provider_service_arn: []const u8,
        provider_configuration_definition: ?[]const u8 = null,
        provider_endpoint_configuration: union {
            marketplace_configuration: ?struct {
                data_set_id: []const u8,
                revision_id: []const u8,
                asset_id: []const u8,
                listing_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .data_set_id = "dataSetId",
                        .revision_id = "revisionId",
                        .asset_id = "assetId",
                        .listing_id = "listingId",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .marketplace_configuration = "marketplaceConfiguration",
                };
                return @field(mappings, field_name);
            }
        },
        anonymized_output: bool,
        provider_entity_output_definition: []const u8,
        provider_intermediate_data_access_configuration: ?struct {
            aws_account_ids: ?[][]const u8 = null,
            required_bucket_actions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_account_ids = "awsAccountIds",
                    .required_bucket_actions = "requiredBucketActions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_name = "providerName",
                .provider_service_name = "providerServiceName",
                .provider_service_display_name = "providerServiceDisplayName",
                .provider_service_type = "providerServiceType",
                .provider_service_arn = "providerServiceArn",
                .provider_configuration_definition = "providerConfigurationDefinition",
                .provider_endpoint_configuration = "providerEndpointConfiguration",
                .anonymized_output = "anonymizedOutput",
                .provider_entity_output_definition = "providerEntityOutputDefinition",
                .provider_intermediate_data_access_configuration = "providerIntermediateDataAccessConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_schema_mapping: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/schemas/{schemaName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSchemaMapping",
    Request: type = struct {
        schema_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_name = "schemaName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_mapping) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_mapping };
        }
    },
    Response: type = struct {
        schema_name: []const u8,
        schema_arn: []const u8,
        description: ?[]const u8 = null,
        mapped_input_fields: []SchemaInputAttribute,
        created_at: i64,
        updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        has_workflows: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_name = "schemaName",
                .schema_arn = "schemaArn",
                .description = "description",
                .mapped_input_fields = "mappedInputFields",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .tags = "tags",
                .has_workflows = "hasWorkflows",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_id_mapping_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/idmappingworkflows/{workflowName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIdMappingJobs",
    Request: type = struct {
        workflow_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_id_mapping_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_id_mapping_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]JobSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_id_mapping_workflows: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/idmappingworkflows",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIdMappingWorkflows",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_id_mapping_workflows) } {
            return .{ .service_metadata = service_metadata, .action = list_id_mapping_workflows };
        }
    },
    Response: type = struct {
        workflow_summaries: ?[]struct {
            workflow_name: []const u8,
            workflow_arn: []const u8,
            created_at: i64,
            updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workflow_name = "workflowName",
                    .workflow_arn = "workflowArn",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_summaries = "workflowSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_matching_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/matchingworkflows/{workflowName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMatchingJobs",
    Request: type = struct {
        workflow_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_matching_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_matching_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]JobSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_matching_workflows: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/matchingworkflows",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMatchingWorkflows",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_matching_workflows) } {
            return .{ .service_metadata = service_metadata, .action = list_matching_workflows };
        }
    },
    Response: type = struct {
        workflow_summaries: ?[]struct {
            workflow_name: []const u8,
            workflow_arn: []const u8,
            created_at: i64,
            updated_at: i64,
            resolution_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workflow_name = "workflowName",
                    .workflow_arn = "workflowArn",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .resolution_type = "resolutionType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_summaries = "workflowSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_provider_services: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/providerservices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProviderServices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        provider_name: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .provider_name = "providerName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .provider_name = "providerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_provider_services) } {
            return .{ .service_metadata = service_metadata, .action = list_provider_services };
        }
    },
    Response: type = struct {
        provider_service_summaries: ?[]struct {
            provider_service_arn: []const u8,
            provider_name: []const u8,
            provider_service_display_name: []const u8,
            provider_service_name: []const u8,
            provider_service_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .provider_service_arn = "providerServiceArn",
                    .provider_name = "providerName",
                    .provider_service_display_name = "providerServiceDisplayName",
                    .provider_service_name = "providerServiceName",
                    .provider_service_type = "providerServiceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_service_summaries = "providerServiceSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_schema_mappings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/schemas",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSchemaMappings",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schema_mappings) } {
            return .{ .service_metadata = service_metadata, .action = list_schema_mappings };
        }
    },
    Response: type = struct {
        schema_list: ?[]struct {
            schema_name: []const u8,
            schema_arn: []const u8,
            created_at: i64,
            updated_at: i64,
            has_workflows: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schema_name = "schemaName",
                    .schema_arn = "schemaArn",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .has_workflows = "hasWorkflows",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_list = "schemaList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_id_mapping_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/idmappingworkflows/{workflowName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartIdMappingJob",
    Request: type = struct {
        workflow_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_id_mapping_job) } {
            return .{ .service_metadata = service_metadata, .action = start_id_mapping_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ExceedsLimit,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_matching_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/matchingworkflows/{workflowName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMatchingJob",
    Request: type = struct {
        workflow_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_matching_job) } {
            return .{ .service_metadata = service_metadata, .action = start_matching_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ExceedsLimit,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_id_mapping_workflow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/idmappingworkflows/{workflowName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIdMappingWorkflow",
    Request: type = struct {
        workflow_name: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []IdMappingWorkflowInputSource,
        output_source_config: []IdMappingWorkflowOutputSource,
        id_mapping_techniques: IdMappingTechniques,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .id_mapping_techniques = "idMappingTechniques",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_id_mapping_workflow) } {
            return .{ .service_metadata = service_metadata, .action = update_id_mapping_workflow };
        }
    },
    Response: type = struct {
        workflow_name: []const u8,
        workflow_arn: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []IdMappingWorkflowInputSource,
        output_source_config: []IdMappingWorkflowOutputSource,
        id_mapping_techniques: IdMappingTechniques,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .workflow_arn = "workflowArn",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .id_mapping_techniques = "idMappingTechniques",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_matching_workflow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/matchingworkflows/{workflowName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMatchingWorkflow",
    Request: type = struct {
        workflow_name: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []InputSource,
        output_source_config: []OutputSource,
        resolution_techniques: ResolutionTechniques,
        incremental_run_config: ?IncrementalRunConfig = null,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .resolution_techniques = "resolutionTechniques",
                .incremental_run_config = "incrementalRunConfig",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_matching_workflow) } {
            return .{ .service_metadata = service_metadata, .action = update_matching_workflow };
        }
    },
    Response: type = struct {
        workflow_name: []const u8,
        description: ?[]const u8 = null,
        input_source_config: []InputSource,
        output_source_config: []OutputSource,
        resolution_techniques: ResolutionTechniques,
        incremental_run_config: ?IncrementalRunConfig = null,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_name = "workflowName",
                .description = "description",
                .input_source_config = "inputSourceConfig",
                .output_source_config = "outputSourceConfig",
                .resolution_techniques = "resolutionTechniques",
                .incremental_run_config = "incrementalRunConfig",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_schema_mapping: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/schemas/{schemaName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSchemaMapping",
    Request: type = struct {
        schema_name: []const u8,
        description: ?[]const u8 = null,
        mapped_input_fields: []SchemaInputAttribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_name = "schemaName",
                .description = "description",
                .mapped_input_fields = "mappedInputFields",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_schema_mapping) } {
            return .{ .service_metadata = service_metadata, .action = update_schema_mapping };
        }
    },
    Response: type = struct {
        schema_name: []const u8,
        schema_arn: []const u8,
        description: ?[]const u8 = null,
        mapped_input_fields: []SchemaInputAttribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_name = "schemaName",
                .schema_arn = "schemaArn",
                .description = "description",
                .mapped_input_fields = "mappedInputFields",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const SchemaInputAttribute = struct {
    field_name: []const u8,
    type: []const u8,
    group_name: ?[]const u8 = null,
    match_key: ?[]const u8 = null,
    sub_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_name = "fieldName",
            .type = "type",
            .group_name = "groupName",
            .match_key = "matchKey",
            .sub_type = "subType",
        };
        return @field(mappings, field_name);
    }
};

pub const IncrementalRunConfig = struct {
    incremental_run_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .incremental_run_type = "incrementalRunType",
        };
        return @field(mappings, field_name);
    }
};

pub const ResolutionTechniques = struct {
    resolution_type: []const u8,
    rule_based_properties: ?RuleBasedProperties = null,
    provider_properties: ?ProviderProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resolution_type = "resolutionType",
            .rule_based_properties = "ruleBasedProperties",
            .provider_properties = "providerProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const ProviderProperties = struct {
    provider_service_arn: []const u8,
    provider_configuration: ?[]const u8 = null,
    intermediate_source_configuration: ?IntermediateSourceConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provider_service_arn = "providerServiceArn",
            .provider_configuration = "providerConfiguration",
            .intermediate_source_configuration = "intermediateSourceConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IntermediateSourceConfiguration = struct {
    intermediate_s3_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .intermediate_s3_path = "intermediateS3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleBasedProperties = struct {
    rules: []Rule,
    attribute_matching_model: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "rules",
            .attribute_matching_model = "attributeMatchingModel",
        };
        return @field(mappings, field_name);
    }
};

pub const Rule = struct {
    rule_name: []const u8,
    matching_keys: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_name = "ruleName",
            .matching_keys = "matchingKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputSource = struct {
    output_s3_path: []const u8,
    kms_arn: ?[]const u8 = null,
    output: []OutputAttribute,
    apply_normalization: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_s3_path = "outputS3Path",
            .kms_arn = "KMSArn",
            .output = "output",
            .apply_normalization = "applyNormalization",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputAttribute = struct {
    name: []const u8,
    hashed: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .hashed = "hashed",
        };
        return @field(mappings, field_name);
    }
};

pub const InputSource = struct {
    input_source_arn: []const u8,
    schema_name: []const u8,
    apply_normalization: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_source_arn = "inputSourceARN",
            .schema_name = "schemaName",
            .apply_normalization = "applyNormalization",
        };
        return @field(mappings, field_name);
    }
};

pub const IdMappingTechniques = struct {
    id_mapping_type: []const u8,
    provider_properties: ProviderProperties,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id_mapping_type = "idMappingType",
            .provider_properties = "providerProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const IdMappingWorkflowOutputSource = struct {
    output_s3_path: []const u8,
    kms_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_s3_path = "outputS3Path",
            .kms_arn = "KMSArn",
        };
        return @field(mappings, field_name);
    }
};

pub const IdMappingWorkflowInputSource = struct {
    input_source_arn: []const u8,
    schema_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_source_arn = "inputSourceARN",
            .schema_name = "schemaName",
        };
        return @field(mappings, field_name);
    }
};

pub const JobSummary = struct {
    job_id: []const u8,
    status: []const u8,
    start_time: i64,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "jobId",
            .status = "status",
            .start_time = "startTime",
            .end_time = "endTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetails = struct {
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};
