const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-03-12";
pub const sdk_id: []const u8 = "finspace";
pub const arn_namespace: ?[]const u8 = "finspace";
pub const endpoint_prefix: []const u8 = "finspace";
pub const sigv4_name: []const u8 = "finspace";
pub const name: []const u8 = "AWSHabaneroManagementService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-03-12",
    sdk_id: []const u8 = "finspace",
    arn_namespace: ?[]const u8 = "finspace",
    endpoint_prefix: []const u8 = "finspace",
    sigv4_name: []const u8 = "finspace",
    name: []const u8 = "AWSHabaneroManagementService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/environment",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEnvironment",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        federation_mode: ?[]const u8 = null,
        federation_parameters: ?FederationParameters = null,
        superuser_parameters: ?struct {
            email_address: []const u8,
            first_name: []const u8,
            last_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .email_address = "emailAddress",
                    .first_name = "firstName",
                    .last_name = "lastName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        data_bundles: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
                .federation_mode = "federationMode",
                .federation_parameters = "federationParameters",
                .superuser_parameters = "superuserParameters",
                .data_bundles = "dataBundles",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_environment };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,
        environment_arn: ?[]const u8 = null,
        environment_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .environment_arn = "environmentArn",
                .environment_url = "environmentUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        LimitExceeded,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_kx_changeset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}/changesets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKxChangeset",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        change_requests: []ChangeRequest,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .change_requests = "changeRequests",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_kx_changeset) } {
            return .{ .service_metadata = service_metadata, .action = create_kx_changeset };
        }
    },
    Response: type = struct {
        changeset_id: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        change_requests: ?[]ChangeRequest = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,
        status: ?[]const u8 = null,
        error_info: ?ErrorInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .changeset_id = "changesetId",
                .database_name = "databaseName",
                .environment_id = "environmentId",
                .change_requests = "changeRequests",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .status = "status",
                .error_info = "errorInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_kx_cluster: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/kx/environments/{environmentId}/clusters",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKxCluster",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        environment_id: []const u8,
        cluster_name: []const u8,
        cluster_type: []const u8,
        tickerplant_log_configuration: ?TickerplantLogConfiguration = null,
        databases: ?[]KxDatabaseConfiguration = null,
        cache_storage_configurations: ?[]KxCacheStorageConfiguration = null,
        auto_scaling_configuration: ?AutoScalingConfiguration = null,
        cluster_description: ?[]const u8 = null,
        capacity_configuration: ?CapacityConfiguration = null,
        release_label: []const u8,
        vpc_configuration: VpcConfiguration,
        initialization_script: ?[]const u8 = null,
        command_line_arguments: ?[]KxCommandLineArgument = null,
        code: ?CodeConfiguration = null,
        execution_role: ?[]const u8 = null,
        savedown_storage_configuration: ?KxSavedownStorageConfiguration = null,
        az_mode: []const u8,
        availability_zone_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        scaling_group_configuration: ?KxScalingGroupConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .environment_id = "environmentId",
                .cluster_name = "clusterName",
                .cluster_type = "clusterType",
                .tickerplant_log_configuration = "tickerplantLogConfiguration",
                .databases = "databases",
                .cache_storage_configurations = "cacheStorageConfigurations",
                .auto_scaling_configuration = "autoScalingConfiguration",
                .cluster_description = "clusterDescription",
                .capacity_configuration = "capacityConfiguration",
                .release_label = "releaseLabel",
                .vpc_configuration = "vpcConfiguration",
                .initialization_script = "initializationScript",
                .command_line_arguments = "commandLineArguments",
                .code = "code",
                .execution_role = "executionRole",
                .savedown_storage_configuration = "savedownStorageConfiguration",
                .az_mode = "azMode",
                .availability_zone_id = "availabilityZoneId",
                .tags = "tags",
                .scaling_group_configuration = "scalingGroupConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_kx_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_kx_cluster };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        cluster_name: ?[]const u8 = null,
        cluster_type: ?[]const u8 = null,
        tickerplant_log_configuration: ?TickerplantLogConfiguration = null,
        volumes: ?[]Volume = null,
        databases: ?[]KxDatabaseConfiguration = null,
        cache_storage_configurations: ?[]KxCacheStorageConfiguration = null,
        auto_scaling_configuration: ?AutoScalingConfiguration = null,
        cluster_description: ?[]const u8 = null,
        capacity_configuration: ?CapacityConfiguration = null,
        release_label: ?[]const u8 = null,
        vpc_configuration: ?VpcConfiguration = null,
        initialization_script: ?[]const u8 = null,
        command_line_arguments: ?[]KxCommandLineArgument = null,
        code: ?CodeConfiguration = null,
        execution_role: ?[]const u8 = null,
        last_modified_timestamp: ?i64 = null,
        savedown_storage_configuration: ?KxSavedownStorageConfiguration = null,
        az_mode: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        scaling_group_configuration: ?KxScalingGroupConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .status = "status",
                .status_reason = "statusReason",
                .cluster_name = "clusterName",
                .cluster_type = "clusterType",
                .tickerplant_log_configuration = "tickerplantLogConfiguration",
                .volumes = "volumes",
                .databases = "databases",
                .cache_storage_configurations = "cacheStorageConfigurations",
                .auto_scaling_configuration = "autoScalingConfiguration",
                .cluster_description = "clusterDescription",
                .capacity_configuration = "capacityConfiguration",
                .release_label = "releaseLabel",
                .vpc_configuration = "vpcConfiguration",
                .initialization_script = "initializationScript",
                .command_line_arguments = "commandLineArguments",
                .code = "code",
                .execution_role = "executionRole",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .savedown_storage_configuration = "savedownStorageConfiguration",
                .az_mode = "azMode",
                .availability_zone_id = "availabilityZoneId",
                .created_timestamp = "createdTimestamp",
                .scaling_group_configuration = "scalingGroupConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_kx_database: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/kx/environments/{environmentId}/databases",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKxDatabase",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .description = "description",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_kx_database) } {
            return .{ .service_metadata = service_metadata, .action = create_kx_database };
        }
    },
    Response: type = struct {
        database_name: ?[]const u8 = null,
        database_arn: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "databaseName",
                .database_arn = "databaseArn",
                .environment_id = "environmentId",
                .description = "description",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_kx_dataview: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}/dataviews",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKxDataview",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        dataview_name: []const u8,
        az_mode: []const u8,
        availability_zone_id: ?[]const u8 = null,
        changeset_id: ?[]const u8 = null,
        segment_configurations: ?[]KxDataviewSegmentConfiguration = null,
        auto_update: ?bool = null,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .dataview_name = "dataviewName",
                .az_mode = "azMode",
                .availability_zone_id = "availabilityZoneId",
                .changeset_id = "changesetId",
                .segment_configurations = "segmentConfigurations",
                .auto_update = "autoUpdate",
                .description = "description",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_kx_dataview) } {
            return .{ .service_metadata = service_metadata, .action = create_kx_dataview };
        }
    },
    Response: type = struct {
        dataview_name: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        az_mode: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        changeset_id: ?[]const u8 = null,
        segment_configurations: ?[]KxDataviewSegmentConfiguration = null,
        description: ?[]const u8 = null,
        auto_update: ?bool = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataview_name = "dataviewName",
                .database_name = "databaseName",
                .environment_id = "environmentId",
                .az_mode = "azMode",
                .availability_zone_id = "availabilityZoneId",
                .changeset_id = "changesetId",
                .segment_configurations = "segmentConfigurations",
                .description = "description",
                .auto_update = "autoUpdate",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_kx_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/kx/environments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKxEnvironment",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        kms_key_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_kx_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_kx_environment };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        creation_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .status = "status",
                .environment_id = "environmentId",
                .description = "description",
                .environment_arn = "environmentArn",
                .kms_key_id = "kmsKeyId",
                .creation_timestamp = "creationTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_kx_scaling_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/kx/environments/{environmentId}/scalingGroups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKxScalingGroup",
    Request: type = struct {
        client_token: []const u8,
        environment_id: []const u8,
        scaling_group_name: []const u8,
        host_type: []const u8,
        availability_zone_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .environment_id = "environmentId",
                .scaling_group_name = "scalingGroupName",
                .host_type = "hostType",
                .availability_zone_id = "availabilityZoneId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_kx_scaling_group) } {
            return .{ .service_metadata = service_metadata, .action = create_kx_scaling_group };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,
        scaling_group_name: ?[]const u8 = null,
        host_type: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_modified_timestamp: ?i64 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .scaling_group_name = "scalingGroupName",
                .host_type = "hostType",
                .availability_zone_id = "availabilityZoneId",
                .status = "status",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .created_timestamp = "createdTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_kx_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/kx/environments/{environmentId}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKxUser",
    Request: type = struct {
        environment_id: []const u8,
        user_name: []const u8,
        iam_role: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .user_name = "userName",
                .iam_role = "iamRole",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_kx_user) } {
            return .{ .service_metadata = service_metadata, .action = create_kx_user };
        }
    },
    Response: type = struct {
        user_name: ?[]const u8 = null,
        user_arn: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        iam_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "userName",
                .user_arn = "userArn",
                .environment_id = "environmentId",
                .iam_role = "iamRole",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_kx_volume: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/kx/environments/{environmentId}/kxvolumes",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKxVolume",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        environment_id: []const u8,
        volume_type: []const u8,
        volume_name: []const u8,
        description: ?[]const u8 = null,
        nas1_configuration: ?KxNAS1Configuration = null,
        az_mode: []const u8,
        availability_zone_ids: [][]const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .environment_id = "environmentId",
                .volume_type = "volumeType",
                .volume_name = "volumeName",
                .description = "description",
                .nas1_configuration = "nas1Configuration",
                .az_mode = "azMode",
                .availability_zone_ids = "availabilityZoneIds",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_kx_volume) } {
            return .{ .service_metadata = service_metadata, .action = create_kx_volume };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,
        volume_name: ?[]const u8 = null,
        volume_type: ?[]const u8 = null,
        volume_arn: ?[]const u8 = null,
        nas1_configuration: ?KxNAS1Configuration = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        az_mode: ?[]const u8 = null,
        description: ?[]const u8 = null,
        availability_zone_ids: ?[][]const u8 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .volume_name = "volumeName",
                .volume_type = "volumeType",
                .volume_arn = "volumeArn",
                .nas1_configuration = "nas1Configuration",
                .status = "status",
                .status_reason = "statusReason",
                .az_mode = "azMode",
                .description = "description",
                .availability_zone_ids = "availabilityZoneIds",
                .created_timestamp = "createdTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/environment/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEnvironment",
    Request: type = struct {
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_kx_cluster: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/kx/environments/{environmentId}/clusters/{clusterName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKxCluster",
    Request: type = struct {
        environment_id: []const u8,
        cluster_name: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .cluster_name = "clusterName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_kx_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_kx_cluster };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_kx_database: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKxDatabase",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        client_token: []const u8,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_kx_database) } {
            return .{ .service_metadata = service_metadata, .action = delete_kx_database };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_kx_dataview: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}/dataviews/{dataviewName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKxDataview",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        dataview_name: []const u8,
        client_token: []const u8,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .dataview_name = "dataviewName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_kx_dataview) } {
            return .{ .service_metadata = service_metadata, .action = delete_kx_dataview };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_kx_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/kx/environments/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKxEnvironment",
    Request: type = struct {
        environment_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_kx_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_kx_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_kx_scaling_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/kx/environments/{environmentId}/scalingGroups/{scalingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKxScalingGroup",
    Request: type = struct {
        environment_id: []const u8,
        scaling_group_name: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .scaling_group_name = "scalingGroupName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_kx_scaling_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_kx_scaling_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_kx_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/kx/environments/{environmentId}/users/{userName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKxUser",
    Request: type = struct {
        user_name: []const u8,
        environment_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "userName",
                .environment_id = "environmentId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_kx_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_kx_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_kx_volume: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/kx/environments/{environmentId}/kxvolumes/{volumeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKxVolume",
    Request: type = struct {
        environment_id: []const u8,
        volume_name: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .volume_name = "volumeName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_kx_volume) } {
            return .{ .service_metadata = service_metadata, .action = delete_kx_volume };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environment/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironment",
    Request: type = struct {
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_environment };
        }
    },
    Response: type = struct {
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_kx_changeset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}/changesets/{changesetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxChangeset",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        changeset_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .changeset_id = "changesetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_changeset) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_changeset };
        }
    },
    Response: type = struct {
        changeset_id: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        change_requests: ?[]ChangeRequest = null,
        created_timestamp: ?i64 = null,
        active_from_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,
        status: ?[]const u8 = null,
        error_info: ?ErrorInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .changeset_id = "changesetId",
                .database_name = "databaseName",
                .environment_id = "environmentId",
                .change_requests = "changeRequests",
                .created_timestamp = "createdTimestamp",
                .active_from_timestamp = "activeFromTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .status = "status",
                .error_info = "errorInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_kx_cluster: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/clusters/{clusterName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxCluster",
    Request: type = struct {
        environment_id: []const u8,
        cluster_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .cluster_name = "clusterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_cluster) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_cluster };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        cluster_name: ?[]const u8 = null,
        cluster_type: ?[]const u8 = null,
        tickerplant_log_configuration: ?TickerplantLogConfiguration = null,
        volumes: ?[]Volume = null,
        databases: ?[]KxDatabaseConfiguration = null,
        cache_storage_configurations: ?[]KxCacheStorageConfiguration = null,
        auto_scaling_configuration: ?AutoScalingConfiguration = null,
        cluster_description: ?[]const u8 = null,
        capacity_configuration: ?CapacityConfiguration = null,
        release_label: ?[]const u8 = null,
        vpc_configuration: ?VpcConfiguration = null,
        initialization_script: ?[]const u8 = null,
        command_line_arguments: ?[]KxCommandLineArgument = null,
        code: ?CodeConfiguration = null,
        execution_role: ?[]const u8 = null,
        last_modified_timestamp: ?i64 = null,
        savedown_storage_configuration: ?KxSavedownStorageConfiguration = null,
        az_mode: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        scaling_group_configuration: ?KxScalingGroupConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .status_reason = "statusReason",
                .cluster_name = "clusterName",
                .cluster_type = "clusterType",
                .tickerplant_log_configuration = "tickerplantLogConfiguration",
                .volumes = "volumes",
                .databases = "databases",
                .cache_storage_configurations = "cacheStorageConfigurations",
                .auto_scaling_configuration = "autoScalingConfiguration",
                .cluster_description = "clusterDescription",
                .capacity_configuration = "capacityConfiguration",
                .release_label = "releaseLabel",
                .vpc_configuration = "vpcConfiguration",
                .initialization_script = "initializationScript",
                .command_line_arguments = "commandLineArguments",
                .code = "code",
                .execution_role = "executionRole",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .savedown_storage_configuration = "savedownStorageConfiguration",
                .az_mode = "azMode",
                .availability_zone_id = "availabilityZoneId",
                .created_timestamp = "createdTimestamp",
                .scaling_group_configuration = "scalingGroupConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_kx_connection_string: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/connectionString",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxConnectionString",
    Request: type = struct {
        user_arn: []const u8,
        environment_id: []const u8,
        cluster_name: []const u8,

        pub const http_query = .{
            .user_arn = "userArn",
            .cluster_name = "clusterName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_arn = "userArn",
                .environment_id = "environmentId",
                .cluster_name = "clusterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_connection_string) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_connection_string };
        }
    },
    Response: type = struct {
        signed_connection_string: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .signed_connection_string = "signedConnectionString",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_kx_database: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxDatabase",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_database) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_database };
        }
    },
    Response: type = struct {
        database_name: ?[]const u8 = null,
        database_arn: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,
        last_completed_changeset_id: ?[]const u8 = null,
        num_bytes: ?i64 = null,
        num_changesets: ?i64 = null,
        num_files: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "databaseName",
                .database_arn = "databaseArn",
                .environment_id = "environmentId",
                .description = "description",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .last_completed_changeset_id = "lastCompletedChangesetId",
                .num_bytes = "numBytes",
                .num_changesets = "numChangesets",
                .num_files = "numFiles",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_kx_dataview: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}/dataviews/{dataviewName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxDataview",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        dataview_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .dataview_name = "dataviewName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_dataview) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_dataview };
        }
    },
    Response: type = struct {
        database_name: ?[]const u8 = null,
        dataview_name: ?[]const u8 = null,
        az_mode: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        changeset_id: ?[]const u8 = null,
        segment_configurations: ?[]KxDataviewSegmentConfiguration = null,
        active_versions: ?[]KxDataviewActiveVersion = null,
        description: ?[]const u8 = null,
        auto_update: ?bool = null,
        environment_id: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "databaseName",
                .dataview_name = "dataviewName",
                .az_mode = "azMode",
                .availability_zone_id = "availabilityZoneId",
                .changeset_id = "changesetId",
                .segment_configurations = "segmentConfigurations",
                .active_versions = "activeVersions",
                .description = "description",
                .auto_update = "autoUpdate",
                .environment_id = "environmentId",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .status = "status",
                .status_reason = "statusReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_kx_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxEnvironment",
    Request: type = struct {
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_environment };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        tgw_status: ?[]const u8 = null,
        dns_status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        dedicated_service_account_id: ?[]const u8 = null,
        transit_gateway_configuration: ?TransitGatewayConfiguration = null,
        custom_dns_configuration: ?[]CustomDNSServer = null,
        creation_timestamp: ?i64 = null,
        update_timestamp: ?i64 = null,
        availability_zone_ids: ?[][]const u8 = null,
        certificate_authority_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .environment_id = "environmentId",
                .aws_account_id = "awsAccountId",
                .status = "status",
                .tgw_status = "tgwStatus",
                .dns_status = "dnsStatus",
                .error_message = "errorMessage",
                .description = "description",
                .environment_arn = "environmentArn",
                .kms_key_id = "kmsKeyId",
                .dedicated_service_account_id = "dedicatedServiceAccountId",
                .transit_gateway_configuration = "transitGatewayConfiguration",
                .custom_dns_configuration = "customDNSConfiguration",
                .creation_timestamp = "creationTimestamp",
                .update_timestamp = "updateTimestamp",
                .availability_zone_ids = "availabilityZoneIds",
                .certificate_authority_arn = "certificateAuthorityArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_kx_scaling_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/scalingGroups/{scalingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxScalingGroup",
    Request: type = struct {
        environment_id: []const u8,
        scaling_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .scaling_group_name = "scalingGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_scaling_group) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_scaling_group };
        }
    },
    Response: type = struct {
        scaling_group_name: ?[]const u8 = null,
        scaling_group_arn: ?[]const u8 = null,
        host_type: ?[]const u8 = null,
        clusters: ?[][]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        last_modified_timestamp: ?i64 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_group_name = "scalingGroupName",
                .scaling_group_arn = "scalingGroupArn",
                .host_type = "hostType",
                .clusters = "clusters",
                .availability_zone_id = "availabilityZoneId",
                .status = "status",
                .status_reason = "statusReason",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .created_timestamp = "createdTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_kx_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/users/{userName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxUser",
    Request: type = struct {
        user_name: []const u8,
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "userName",
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_user) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_user };
        }
    },
    Response: type = struct {
        user_name: ?[]const u8 = null,
        user_arn: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        iam_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "userName",
                .user_arn = "userArn",
                .environment_id = "environmentId",
                .iam_role = "iamRole",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_kx_volume: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/kxvolumes/{volumeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetKxVolume",
    Request: type = struct {
        environment_id: []const u8,
        volume_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .volume_name = "volumeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_kx_volume) } {
            return .{ .service_metadata = service_metadata, .action = get_kx_volume };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,
        volume_name: ?[]const u8 = null,
        volume_type: ?[]const u8 = null,
        volume_arn: ?[]const u8 = null,
        nas1_configuration: ?KxNAS1Configuration = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        description: ?[]const u8 = null,
        az_mode: ?[]const u8 = null,
        availability_zone_ids: ?[][]const u8 = null,
        last_modified_timestamp: ?i64 = null,
        attached_clusters: ?[]KxAttachedCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .volume_name = "volumeName",
                .volume_type = "volumeType",
                .volume_arn = "volumeArn",
                .nas1_configuration = "nas1Configuration",
                .status = "status",
                .status_reason = "statusReason",
                .created_timestamp = "createdTimestamp",
                .description = "description",
                .az_mode = "azMode",
                .availability_zone_ids = "availabilityZoneIds",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .attached_clusters = "attachedClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environment",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironments",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_environments };
        }
    },
    Response: type = struct {
        environments: ?[]Environment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environments = "environments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_kx_changesets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}/changesets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxChangesets",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_changesets) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_changesets };
        }
    },
    Response: type = struct {
        kx_changesets: ?[]struct {
            changeset_id: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            active_from_timestamp: ?i64 = null,
            last_modified_timestamp: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .changeset_id = "changesetId",
                    .created_timestamp = "createdTimestamp",
                    .active_from_timestamp = "activeFromTimestamp",
                    .last_modified_timestamp = "lastModifiedTimestamp",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kx_changesets = "kxChangesets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_kx_cluster_nodes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/clusters/{clusterName}/nodes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxClusterNodes",
    Request: type = struct {
        environment_id: []const u8,
        cluster_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .cluster_name = "clusterName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_cluster_nodes) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_cluster_nodes };
        }
    },
    Response: type = struct {
        nodes: ?[]struct {
            node_id: ?[]const u8 = null,
            availability_zone_id: ?[]const u8 = null,
            launch_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .node_id = "nodeId",
                    .availability_zone_id = "availabilityZoneId",
                    .launch_time = "launchTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nodes = "nodes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_kx_clusters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/clusters",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxClusters",
    Request: type = struct {
        environment_id: []const u8,
        cluster_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .cluster_type = "clusterType",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .cluster_type = "clusterType",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_clusters };
        }
    },
    Response: type = struct {
        kx_cluster_summaries: ?[]struct {
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            cluster_name: ?[]const u8 = null,
            cluster_type: ?[]const u8 = null,
            cluster_description: ?[]const u8 = null,
            release_label: ?[]const u8 = null,
            volumes: ?[]Volume = null,
            initialization_script: ?[]const u8 = null,
            execution_role: ?[]const u8 = null,
            az_mode: ?[]const u8 = null,
            availability_zone_id: ?[]const u8 = null,
            last_modified_timestamp: ?i64 = null,
            created_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "status",
                    .status_reason = "statusReason",
                    .cluster_name = "clusterName",
                    .cluster_type = "clusterType",
                    .cluster_description = "clusterDescription",
                    .release_label = "releaseLabel",
                    .volumes = "volumes",
                    .initialization_script = "initializationScript",
                    .execution_role = "executionRole",
                    .az_mode = "azMode",
                    .availability_zone_id = "availabilityZoneId",
                    .last_modified_timestamp = "lastModifiedTimestamp",
                    .created_timestamp = "createdTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kx_cluster_summaries = "kxClusterSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_kx_databases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/databases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxDatabases",
    Request: type = struct {
        environment_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_databases) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_databases };
        }
    },
    Response: type = struct {
        kx_databases: ?[]struct {
            database_name: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_modified_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_name = "databaseName",
                    .created_timestamp = "createdTimestamp",
                    .last_modified_timestamp = "lastModifiedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kx_databases = "kxDatabases",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_kx_dataviews: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}/dataviews",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxDataviews",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_dataviews) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_dataviews };
        }
    },
    Response: type = struct {
        kx_dataviews: ?[]struct {
            environment_id: ?[]const u8 = null,
            database_name: ?[]const u8 = null,
            dataview_name: ?[]const u8 = null,
            az_mode: ?[]const u8 = null,
            availability_zone_id: ?[]const u8 = null,
            changeset_id: ?[]const u8 = null,
            segment_configurations: ?[]KxDataviewSegmentConfiguration = null,
            active_versions: ?[]KxDataviewActiveVersion = null,
            status: ?[]const u8 = null,
            description: ?[]const u8 = null,
            auto_update: ?bool = null,
            created_timestamp: ?i64 = null,
            last_modified_timestamp: ?i64 = null,
            status_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .environment_id = "environmentId",
                    .database_name = "databaseName",
                    .dataview_name = "dataviewName",
                    .az_mode = "azMode",
                    .availability_zone_id = "availabilityZoneId",
                    .changeset_id = "changesetId",
                    .segment_configurations = "segmentConfigurations",
                    .active_versions = "activeVersions",
                    .status = "status",
                    .description = "description",
                    .auto_update = "autoUpdate",
                    .created_timestamp = "createdTimestamp",
                    .last_modified_timestamp = "lastModifiedTimestamp",
                    .status_reason = "statusReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kx_dataviews = "kxDataviews",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_kx_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxEnvironments",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_environments };
        }
    },
    Response: type = struct {
        environments: ?[]struct {
            name: ?[]const u8 = null,
            environment_id: ?[]const u8 = null,
            aws_account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            tgw_status: ?[]const u8 = null,
            dns_status: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            description: ?[]const u8 = null,
            environment_arn: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            dedicated_service_account_id: ?[]const u8 = null,
            transit_gateway_configuration: ?TransitGatewayConfiguration = null,
            custom_dns_configuration: ?[]CustomDNSServer = null,
            creation_timestamp: ?i64 = null,
            update_timestamp: ?i64 = null,
            availability_zone_ids: ?[][]const u8 = null,
            certificate_authority_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .environment_id = "environmentId",
                    .aws_account_id = "awsAccountId",
                    .status = "status",
                    .tgw_status = "tgwStatus",
                    .dns_status = "dnsStatus",
                    .error_message = "errorMessage",
                    .description = "description",
                    .environment_arn = "environmentArn",
                    .kms_key_id = "kmsKeyId",
                    .dedicated_service_account_id = "dedicatedServiceAccountId",
                    .transit_gateway_configuration = "transitGatewayConfiguration",
                    .custom_dns_configuration = "customDNSConfiguration",
                    .creation_timestamp = "creationTimestamp",
                    .update_timestamp = "updateTimestamp",
                    .availability_zone_ids = "availabilityZoneIds",
                    .certificate_authority_arn = "certificateAuthorityArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environments = "environments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_kx_scaling_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/scalingGroups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxScalingGroups",
    Request: type = struct {
        environment_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_scaling_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_scaling_groups };
        }
    },
    Response: type = struct {
        scaling_groups: ?[]struct {
            scaling_group_name: ?[]const u8 = null,
            host_type: ?[]const u8 = null,
            clusters: ?[][]const u8 = null,
            availability_zone_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            last_modified_timestamp: ?i64 = null,
            created_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scaling_group_name = "scalingGroupName",
                    .host_type = "hostType",
                    .clusters = "clusters",
                    .availability_zone_id = "availabilityZoneId",
                    .status = "status",
                    .status_reason = "statusReason",
                    .last_modified_timestamp = "lastModifiedTimestamp",
                    .created_timestamp = "createdTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_groups = "scalingGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_kx_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxUsers",
    Request: type = struct {
        environment_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_users) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_users };
        }
    },
    Response: type = struct {
        users: ?[]struct {
            user_arn: ?[]const u8 = null,
            user_name: ?[]const u8 = null,
            iam_role: ?[]const u8 = null,
            create_timestamp: ?i64 = null,
            update_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_arn = "userArn",
                    .user_name = "userName",
                    .iam_role = "iamRole",
                    .create_timestamp = "createTimestamp",
                    .update_timestamp = "updateTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "users",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_kx_volumes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/kx/environments/{environmentId}/kxvolumes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKxVolumes",
    Request: type = struct {
        environment_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        volume_type: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .volume_type = "volumeType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .volume_type = "volumeType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kx_volumes) } {
            return .{ .service_metadata = service_metadata, .action = list_kx_volumes };
        }
    },
    Response: type = struct {
        kx_volume_summaries: ?[]struct {
            volume_name: ?[]const u8 = null,
            volume_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            az_mode: ?[]const u8 = null,
            availability_zone_ids: ?[][]const u8 = null,
            created_timestamp: ?i64 = null,
            last_modified_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_name = "volumeName",
                    .volume_type = "volumeType",
                    .status = "status",
                    .description = "description",
                    .status_reason = "statusReason",
                    .az_mode = "azMode",
                    .availability_zone_ids = "availabilityZoneIds",
                    .created_timestamp = "createdTimestamp",
                    .last_modified_timestamp = "lastModifiedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kx_volume_summaries = "kxVolumeSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_environment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/environment/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEnvironment",
    Request: type = struct {
        environment_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        federation_mode: ?[]const u8 = null,
        federation_parameters: ?FederationParameters = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .name = "name",
                .description = "description",
                .federation_mode = "federationMode",
                .federation_parameters = "federationParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_environment };
        }
    },
    Response: type = struct {
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_kx_cluster_code_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/kx/environments/{environmentId}/clusters/{clusterName}/configuration/code",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKxClusterCodeConfiguration",
    Request: type = struct {
        environment_id: []const u8,
        cluster_name: []const u8,
        client_token: ?[]const u8 = null,
        code: CodeConfiguration,
        initialization_script: ?[]const u8 = null,
        command_line_arguments: ?[]KxCommandLineArgument = null,
        deployment_configuration: ?struct {
            deployment_strategy: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .deployment_strategy = "deploymentStrategy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .cluster_name = "clusterName",
                .client_token = "clientToken",
                .code = "code",
                .initialization_script = "initializationScript",
                .command_line_arguments = "commandLineArguments",
                .deployment_configuration = "deploymentConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kx_cluster_code_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_kx_cluster_code_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_kx_cluster_databases: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/kx/environments/{environmentId}/clusters/{clusterName}/configuration/databases",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKxClusterDatabases",
    Request: type = struct {
        environment_id: []const u8,
        cluster_name: []const u8,
        client_token: ?[]const u8 = null,
        databases: []KxDatabaseConfiguration,
        deployment_configuration: ?struct {
            deployment_strategy: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .deployment_strategy = "deploymentStrategy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .cluster_name = "clusterName",
                .client_token = "clientToken",
                .databases = "databases",
                .deployment_configuration = "deploymentConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kx_cluster_databases) } {
            return .{ .service_metadata = service_metadata, .action = update_kx_cluster_databases };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_kx_database: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKxDatabase",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        description: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .description = "description",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kx_database) } {
            return .{ .service_metadata = service_metadata, .action = update_kx_database };
        }
    },
    Response: type = struct {
        database_name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        last_modified_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "databaseName",
                .environment_id = "environmentId",
                .description = "description",
                .last_modified_timestamp = "lastModifiedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_kx_dataview: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/kx/environments/{environmentId}/databases/{databaseName}/dataviews/{dataviewName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKxDataview",
    Request: type = struct {
        environment_id: []const u8,
        database_name: []const u8,
        dataview_name: []const u8,
        description: ?[]const u8 = null,
        changeset_id: ?[]const u8 = null,
        segment_configurations: ?[]KxDataviewSegmentConfiguration = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .dataview_name = "dataviewName",
                .description = "description",
                .changeset_id = "changesetId",
                .segment_configurations = "segmentConfigurations",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kx_dataview) } {
            return .{ .service_metadata = service_metadata, .action = update_kx_dataview };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        dataview_name: ?[]const u8 = null,
        az_mode: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        changeset_id: ?[]const u8 = null,
        segment_configurations: ?[]KxDataviewSegmentConfiguration = null,
        active_versions: ?[]KxDataviewActiveVersion = null,
        status: ?[]const u8 = null,
        auto_update: ?bool = null,
        description: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_modified_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .database_name = "databaseName",
                .dataview_name = "dataviewName",
                .az_mode = "azMode",
                .availability_zone_id = "availabilityZoneId",
                .changeset_id = "changesetId",
                .segment_configurations = "segmentConfigurations",
                .active_versions = "activeVersions",
                .status = "status",
                .auto_update = "autoUpdate",
                .description = "description",
                .created_timestamp = "createdTimestamp",
                .last_modified_timestamp = "lastModifiedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_kx_environment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/kx/environments/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKxEnvironment",
    Request: type = struct {
        environment_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .name = "name",
                .description = "description",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kx_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_kx_environment };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        tgw_status: ?[]const u8 = null,
        dns_status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        dedicated_service_account_id: ?[]const u8 = null,
        transit_gateway_configuration: ?TransitGatewayConfiguration = null,
        custom_dns_configuration: ?[]CustomDNSServer = null,
        creation_timestamp: ?i64 = null,
        update_timestamp: ?i64 = null,
        availability_zone_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .environment_id = "environmentId",
                .aws_account_id = "awsAccountId",
                .status = "status",
                .tgw_status = "tgwStatus",
                .dns_status = "dnsStatus",
                .error_message = "errorMessage",
                .description = "description",
                .environment_arn = "environmentArn",
                .kms_key_id = "kmsKeyId",
                .dedicated_service_account_id = "dedicatedServiceAccountId",
                .transit_gateway_configuration = "transitGatewayConfiguration",
                .custom_dns_configuration = "customDNSConfiguration",
                .creation_timestamp = "creationTimestamp",
                .update_timestamp = "updateTimestamp",
                .availability_zone_ids = "availabilityZoneIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_kx_environment_network: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/kx/environments/{environmentId}/network",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKxEnvironmentNetwork",
    Request: type = struct {
        environment_id: []const u8,
        transit_gateway_configuration: ?TransitGatewayConfiguration = null,
        custom_dns_configuration: ?[]CustomDNSServer = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .transit_gateway_configuration = "transitGatewayConfiguration",
                .custom_dns_configuration = "customDNSConfiguration",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kx_environment_network) } {
            return .{ .service_metadata = service_metadata, .action = update_kx_environment_network };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        tgw_status: ?[]const u8 = null,
        dns_status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        dedicated_service_account_id: ?[]const u8 = null,
        transit_gateway_configuration: ?TransitGatewayConfiguration = null,
        custom_dns_configuration: ?[]CustomDNSServer = null,
        creation_timestamp: ?i64 = null,
        update_timestamp: ?i64 = null,
        availability_zone_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .environment_id = "environmentId",
                .aws_account_id = "awsAccountId",
                .status = "status",
                .tgw_status = "tgwStatus",
                .dns_status = "dnsStatus",
                .error_message = "errorMessage",
                .description = "description",
                .environment_arn = "environmentArn",
                .kms_key_id = "kmsKeyId",
                .dedicated_service_account_id = "dedicatedServiceAccountId",
                .transit_gateway_configuration = "transitGatewayConfiguration",
                .custom_dns_configuration = "customDNSConfiguration",
                .creation_timestamp = "creationTimestamp",
                .update_timestamp = "updateTimestamp",
                .availability_zone_ids = "availabilityZoneIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_kx_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/kx/environments/{environmentId}/users/{userName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKxUser",
    Request: type = struct {
        environment_id: []const u8,
        user_name: []const u8,
        iam_role: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .user_name = "userName",
                .iam_role = "iamRole",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kx_user) } {
            return .{ .service_metadata = service_metadata, .action = update_kx_user };
        }
    },
    Response: type = struct {
        user_name: ?[]const u8 = null,
        user_arn: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        iam_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "userName",
                .user_arn = "userArn",
                .environment_id = "environmentId",
                .iam_role = "iamRole",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_kx_volume: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/kx/environments/{environmentId}/kxvolumes/{volumeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateKxVolume",
    Request: type = struct {
        environment_id: []const u8,
        volume_name: []const u8,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        nas1_configuration: ?KxNAS1Configuration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .volume_name = "volumeName",
                .description = "description",
                .client_token = "clientToken",
                .nas1_configuration = "nas1Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_kx_volume) } {
            return .{ .service_metadata = service_metadata, .action = update_kx_volume };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,
        volume_name: ?[]const u8 = null,
        volume_type: ?[]const u8 = null,
        volume_arn: ?[]const u8 = null,
        nas1_configuration: ?KxNAS1Configuration = null,
        status: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        az_mode: ?[]const u8 = null,
        availability_zone_ids: ?[][]const u8 = null,
        last_modified_timestamp: ?i64 = null,
        attached_clusters: ?[]KxAttachedCluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .volume_name = "volumeName",
                .volume_type = "volumeType",
                .volume_arn = "volumeArn",
                .nas1_configuration = "nas1Configuration",
                .status = "status",
                .description = "description",
                .status_reason = "statusReason",
                .created_timestamp = "createdTimestamp",
                .az_mode = "azMode",
                .availability_zone_ids = "availabilityZoneIds",
                .last_modified_timestamp = "lastModifiedTimestamp",
                .attached_clusters = "attachedClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const KxAttachedCluster = struct {
    cluster_name: ?[]const u8 = null,
    cluster_type: ?[]const u8 = null,
    cluster_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_name = "clusterName",
            .cluster_type = "clusterType",
            .cluster_status = "clusterStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const KxNAS1Configuration = struct {
    type: ?[]const u8 = null,
    size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .size = "size",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomDNSServer = struct {
    custom_dns_server_name: []const u8,
    custom_dns_server_ip: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_dns_server_name = "customDNSServerName",
            .custom_dns_server_ip = "customDNSServerIP",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayConfiguration = struct {
    transit_gateway_id: []const u8,
    routable_cidr_space: []const u8,
    attachment_network_acl_configuration: ?[]NetworkACLEntry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_id = "transitGatewayID",
            .routable_cidr_space = "routableCIDRSpace",
            .attachment_network_acl_configuration = "attachmentNetworkAclConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkACLEntry = struct {
    rule_number: i64,
    protocol: []const u8,
    rule_action: []const u8,
    port_range: ?PortRange = null,
    icmp_type_code: ?IcmpTypeCode = null,
    cidr_block: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_number = "ruleNumber",
            .protocol = "protocol",
            .rule_action = "ruleAction",
            .port_range = "portRange",
            .icmp_type_code = "icmpTypeCode",
            .cidr_block = "cidrBlock",
        };
        return @field(mappings, field_name);
    }
};

pub const IcmpTypeCode = struct {
    type: i64,
    code: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .code = "code",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRange = struct {
    from: i64,
    to: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "from",
            .to = "to",
        };
        return @field(mappings, field_name);
    }
};

pub const KxDataviewActiveVersion = struct {
    changeset_id: ?[]const u8 = null,
    segment_configurations: ?[]KxDataviewSegmentConfiguration = null,
    attached_clusters: ?[][]const u8 = null,
    created_timestamp: ?i64 = null,
    version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .changeset_id = "changesetId",
            .segment_configurations = "segmentConfigurations",
            .attached_clusters = "attachedClusters",
            .created_timestamp = "createdTimestamp",
            .version_id = "versionId",
        };
        return @field(mappings, field_name);
    }
};

pub const KxDataviewSegmentConfiguration = struct {
    db_paths: [][]const u8,
    volume_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_paths = "dbPaths",
            .volume_name = "volumeName",
        };
        return @field(mappings, field_name);
    }
};

pub const KxDatabaseConfiguration = struct {
    database_name: []const u8,
    cache_configurations: ?[]KxDatabaseCacheConfiguration = null,
    changeset_id: ?[]const u8 = null,
    dataview_name: ?[]const u8 = null,
    dataview_configuration: ?KxDataviewConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "databaseName",
            .cache_configurations = "cacheConfigurations",
            .changeset_id = "changesetId",
            .dataview_name = "dataviewName",
            .dataview_configuration = "dataviewConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const KxDataviewConfiguration = struct {
    dataview_name: ?[]const u8 = null,
    dataview_version_id: ?[]const u8 = null,
    changeset_id: ?[]const u8 = null,
    segment_configurations: ?[]KxDataviewSegmentConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dataview_name = "dataviewName",
            .dataview_version_id = "dataviewVersionId",
            .changeset_id = "changesetId",
            .segment_configurations = "segmentConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const KxDatabaseCacheConfiguration = struct {
    cache_type: []const u8,
    db_paths: [][]const u8,
    dataview_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_type = "cacheType",
            .db_paths = "dbPaths",
            .dataview_name = "dataviewName",
        };
        return @field(mappings, field_name);
    }
};

pub const KxCommandLineArgument = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeConfiguration = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,
    s3_object_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .s3_key = "s3Key",
            .s3_object_version = "s3ObjectVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const Environment = struct {
    name: ?[]const u8 = null,
    environment_id: ?[]const u8 = null,
    aws_account_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    environment_url: ?[]const u8 = null,
    description: ?[]const u8 = null,
    environment_arn: ?[]const u8 = null,
    sage_maker_studio_domain_url: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    dedicated_service_account_id: ?[]const u8 = null,
    federation_mode: ?[]const u8 = null,
    federation_parameters: ?FederationParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .environment_id = "environmentId",
            .aws_account_id = "awsAccountId",
            .status = "status",
            .environment_url = "environmentUrl",
            .description = "description",
            .environment_arn = "environmentArn",
            .sage_maker_studio_domain_url = "sageMakerStudioDomainUrl",
            .kms_key_id = "kmsKeyId",
            .dedicated_service_account_id = "dedicatedServiceAccountId",
            .federation_mode = "federationMode",
            .federation_parameters = "federationParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const FederationParameters = struct {
    saml_metadata_document: ?[]const u8 = null,
    saml_metadata_url: ?[]const u8 = null,
    application_call_back_url: ?[]const u8 = null,
    federation_urn: ?[]const u8 = null,
    federation_provider_name: ?[]const u8 = null,
    attribute_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .saml_metadata_document = "samlMetadataDocument",
            .saml_metadata_url = "samlMetadataURL",
            .application_call_back_url = "applicationCallBackURL",
            .federation_urn = "federationURN",
            .federation_provider_name = "federationProviderName",
            .attribute_map = "attributeMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attribute_map", field_name))
            return try serializeMap(self.attribute_map, self.fieldNameFor("attribute_map"), options, out_stream);
        return false;
    }
};

pub const Volume = struct {
    volume_name: ?[]const u8 = null,
    volume_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_name = "volumeName",
            .volume_type = "volumeType",
        };
        return @field(mappings, field_name);
    }
};

pub const KxScalingGroupConfiguration = struct {
    scaling_group_name: []const u8,
    memory_limit: ?i64 = null,
    memory_reservation: i64,
    node_count: i64,
    cpu: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scaling_group_name = "scalingGroupName",
            .memory_limit = "memoryLimit",
            .memory_reservation = "memoryReservation",
            .node_count = "nodeCount",
            .cpu = "cpu",
        };
        return @field(mappings, field_name);
    }
};

pub const KxSavedownStorageConfiguration = struct {
    type: ?[]const u8 = null,
    size: ?i64 = null,
    volume_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .size = "size",
            .volume_name = "volumeName",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfiguration = struct {
    vpc_id: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    ip_address_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "vpcId",
            .security_group_ids = "securityGroupIds",
            .subnet_ids = "subnetIds",
            .ip_address_type = "ipAddressType",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityConfiguration = struct {
    node_type: ?[]const u8 = null,
    node_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_type = "nodeType",
            .node_count = "nodeCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingConfiguration = struct {
    min_node_count: ?i64 = null,
    max_node_count: ?i64 = null,
    auto_scaling_metric: ?[]const u8 = null,
    metric_target: ?f64 = null,
    scale_in_cooldown_seconds: ?f64 = null,
    scale_out_cooldown_seconds: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_node_count = "minNodeCount",
            .max_node_count = "maxNodeCount",
            .auto_scaling_metric = "autoScalingMetric",
            .metric_target = "metricTarget",
            .scale_in_cooldown_seconds = "scaleInCooldownSeconds",
            .scale_out_cooldown_seconds = "scaleOutCooldownSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const KxCacheStorageConfiguration = struct {
    type: []const u8,
    size: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .size = "size",
        };
        return @field(mappings, field_name);
    }
};

pub const TickerplantLogConfiguration = struct {
    tickerplant_log_volumes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tickerplant_log_volumes = "tickerplantLogVolumes",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorInfo = struct {
    error_message: ?[]const u8 = null,
    error_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_message = "errorMessage",
            .error_type = "errorType",
        };
        return @field(mappings, field_name);
    }
};

pub const ChangeRequest = struct {
    change_type: []const u8,
    s3_path: ?[]const u8 = null,
    db_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .change_type = "changeType",
            .s3_path = "s3Path",
            .db_path = "dbPath",
        };
        return @field(mappings, field_name);
    }
};
