const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-13";
pub const sdk_id: []const u8 = "finspace data";
pub const arn_namespace: ?[]const u8 = "finspace-api";
pub const endpoint_prefix: []const u8 = "finspace-api";
pub const sigv4_name: []const u8 = "finspace-api";
pub const name: []const u8 = "AWSHabaneroPublicAPI";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-13",
    sdk_id: []const u8 = "finspace data",
    arn_namespace: ?[]const u8 = "finspace-api",
    endpoint_prefix: []const u8 = "finspace-api",
    sigv4_name: []const u8 = "finspace-api",
    name: []const u8 = "AWSHabaneroPublicAPI",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_user_to_permission_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/permission-group/{permissionGroupId}/users/{userId}",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateUserToPermissionGroup",
    Request: type = struct {
        permission_group_id: []const u8,
        user_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
                .user_id = "userId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_user_to_permission_group) } {
            return .{ .service_metadata = service_metadata, .action = associate_user_to_permission_group };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_changeset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasets/{datasetId}/changesetsv2",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateChangeset",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dataset_id: []const u8,
        change_type: []const u8,
        source_params: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        format_params: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .dataset_id = "datasetId",
                .change_type = "changeType",
                .source_params = "sourceParams",
                .format_params = "formatParams",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "source_params", field_name))
                return try serializeMap(self.source_params, self.fieldNameFor("source_params"), options, out_stream);
            if (std.mem.eql(u8, "format_params", field_name))
                return try serializeMap(self.format_params, self.fieldNameFor("format_params"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_changeset) } {
            return .{ .service_metadata = service_metadata, .action = create_changeset };
        }
    },
    Response: type = struct {
        dataset_id: ?[]const u8 = null,
        changeset_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
                .changeset_id = "changesetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_dataset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasetsv2",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dataset_title: []const u8,
        kind: []const u8,
        dataset_description: ?[]const u8 = null,
        owner_info: ?DatasetOwnerInfo = null,
        permission_group_params: struct {
            permission_group_id: ?[]const u8 = null,
            dataset_permissions: ?[]struct {
                permission: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .permission = "permission",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .permission_group_id = "permissionGroupId",
                    .dataset_permissions = "datasetPermissions",
                };
                return @field(mappings, field_name);
            }
        },
        alias: ?[]const u8 = null,
        schema_definition: ?SchemaUnion = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .dataset_title = "datasetTitle",
                .kind = "kind",
                .dataset_description = "datasetDescription",
                .owner_info = "ownerInfo",
                .permission_group_params = "permissionGroupParams",
                .alias = "alias",
                .schema_definition = "schemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        dataset_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_data_view: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasets/{datasetId}/dataviewsv2",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataView",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dataset_id: []const u8,
        auto_update: ?bool = null,
        sort_columns: ?[][]const u8 = null,
        partition_columns: ?[][]const u8 = null,
        as_of_timestamp: ?i64 = null,
        destination_type_params: DataViewDestinationTypeParams,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .dataset_id = "datasetId",
                .auto_update = "autoUpdate",
                .sort_columns = "sortColumns",
                .partition_columns = "partitionColumns",
                .as_of_timestamp = "asOfTimestamp",
                .destination_type_params = "destinationTypeParams",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_view) } {
            return .{ .service_metadata = service_metadata, .action = create_data_view };
        }
    },
    Response: type = struct {
        dataset_id: ?[]const u8 = null,
        data_view_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
                .data_view_id = "dataViewId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_permission_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/permission-group",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePermissionGroup",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        application_permissions: [][]const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .application_permissions = "applicationPermissions",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_permission_group) } {
            return .{ .service_metadata = service_metadata, .action = create_permission_group };
        }
    },
    Response: type = struct {
        permission_group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        email_address: []const u8,
        type: []const u8,
        first_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        api_access: ?[]const u8 = null,
        api_access_principal_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "emailAddress",
                .type = "type",
                .first_name = "firstName",
                .last_name = "lastName",
                .api_access = "apiAccess",
                .api_access_principal_arn = "apiAccessPrincipalArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_dataset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/datasetsv2/{datasetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dataset_id: []const u8,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .dataset_id = "datasetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {
        dataset_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_permission_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/permission-group/{permissionGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePermissionGroup",
    Request: type = struct {
        permission_group_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission_group };
        }
    },
    Response: type = struct {
        permission_group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disable_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/{userId}/disable",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableUser",
    Request: type = struct {
        user_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_user) } {
            return .{ .service_metadata = service_metadata, .action = disable_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_user_from_permission_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/permission-group/{permissionGroupId}/users/{userId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateUserFromPermissionGroup",
    Request: type = struct {
        permission_group_id: []const u8,
        user_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
                .user_id = "userId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_user_from_permission_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_user_from_permission_group };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const enable_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/{userId}/enable",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableUser",
    Request: type = struct {
        user_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_user) } {
            return .{ .service_metadata = service_metadata, .action = enable_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_changeset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets/{datasetId}/changesetsv2/{changesetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChangeset",
    Request: type = struct {
        dataset_id: []const u8,
        changeset_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
                .changeset_id = "changesetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_changeset) } {
            return .{ .service_metadata = service_metadata, .action = get_changeset };
        }
    },
    Response: type = struct {
        changeset_id: ?[]const u8 = null,
        changeset_arn: ?[]const u8 = null,
        dataset_id: ?[]const u8 = null,
        change_type: ?[]const u8 = null,
        source_params: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        format_params: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        create_time: ?i64 = null,
        status: ?[]const u8 = null,
        error_info: ?ChangesetErrorInfo = null,
        active_until_timestamp: ?i64 = null,
        active_from_timestamp: ?i64 = null,
        updates_changeset_id: ?[]const u8 = null,
        updated_by_changeset_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .changeset_id = "changesetId",
                .changeset_arn = "changesetArn",
                .dataset_id = "datasetId",
                .change_type = "changeType",
                .source_params = "sourceParams",
                .format_params = "formatParams",
                .create_time = "createTime",
                .status = "status",
                .error_info = "errorInfo",
                .active_until_timestamp = "activeUntilTimestamp",
                .active_from_timestamp = "activeFromTimestamp",
                .updates_changeset_id = "updatesChangesetId",
                .updated_by_changeset_id = "updatedByChangesetId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "source_params", field_name))
                return try serializeMap(self.source_params, self.fieldNameFor("source_params"), options, out_stream);
            if (std.mem.eql(u8, "format_params", field_name))
                return try serializeMap(self.format_params, self.fieldNameFor("format_params"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_dataset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasetsv2/{datasetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataset",
    Request: type = struct {
        dataset_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dataset) } {
            return .{ .service_metadata = service_metadata, .action = get_dataset };
        }
    },
    Response: type = struct {
        dataset_id: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        dataset_title: ?[]const u8 = null,
        kind: ?[]const u8 = null,
        dataset_description: ?[]const u8 = null,
        create_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        schema_definition: ?SchemaUnion = null,
        alias: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
                .dataset_arn = "datasetArn",
                .dataset_title = "datasetTitle",
                .kind = "kind",
                .dataset_description = "datasetDescription",
                .create_time = "createTime",
                .last_modified_time = "lastModifiedTime",
                .schema_definition = "schemaDefinition",
                .alias = "alias",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_data_view: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets/{datasetId}/dataviewsv2/{dataViewId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataView",
    Request: type = struct {
        data_view_id: []const u8,
        dataset_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_view_id = "dataViewId",
                .dataset_id = "datasetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_view) } {
            return .{ .service_metadata = service_metadata, .action = get_data_view };
        }
    },
    Response: type = struct {
        auto_update: ?bool = null,
        partition_columns: ?[][]const u8 = null,
        dataset_id: ?[]const u8 = null,
        as_of_timestamp: ?i64 = null,
        error_info: ?DataViewErrorInfo = null,
        last_modified_time: ?i64 = null,
        create_time: ?i64 = null,
        sort_columns: ?[][]const u8 = null,
        data_view_id: ?[]const u8 = null,
        data_view_arn: ?[]const u8 = null,
        destination_type_params: ?DataViewDestinationTypeParams = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_update = "autoUpdate",
                .partition_columns = "partitionColumns",
                .dataset_id = "datasetId",
                .as_of_timestamp = "asOfTimestamp",
                .error_info = "errorInfo",
                .last_modified_time = "lastModifiedTime",
                .create_time = "createTime",
                .sort_columns = "sortColumns",
                .data_view_id = "dataViewId",
                .data_view_arn = "dataViewArn",
                .destination_type_params = "destinationTypeParams",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_external_data_view_access_details: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasets/{datasetId}/dataviewsv2/{dataViewId}/external-access-details",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExternalDataViewAccessDetails",
    Request: type = struct {
        data_view_id: []const u8,
        dataset_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_view_id = "dataViewId",
                .dataset_id = "datasetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_external_data_view_access_details) } {
            return .{ .service_metadata = service_metadata, .action = get_external_data_view_access_details };
        }
    },
    Response: type = struct {
        credentials: ?struct {
            access_key_id: ?[]const u8 = null,
            secret_access_key: ?[]const u8 = null,
            session_token: ?[]const u8 = null,
            expiration: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_key_id = "accessKeyId",
                    .secret_access_key = "secretAccessKey",
                    .session_token = "sessionToken",
                    .expiration = "expiration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        s3_location: ?struct {
            bucket: []const u8,
            key: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket = "bucket",
                    .key = "key",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "credentials",
                .s3_location = "s3Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_permission_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/permission-group/{permissionGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPermissionGroup",
    Request: type = struct {
        permission_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_permission_group) } {
            return .{ .service_metadata = service_metadata, .action = get_permission_group };
        }
    },
    Response: type = struct {
        permission_group: ?PermissionGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group = "permissionGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_programmatic_access_credentials: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/credentials/programmatic",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProgrammaticAccessCredentials",
    Request: type = struct {
        duration_in_minutes: ?i64 = null,
        environment_id: []const u8,

        pub const http_query = .{
            .duration_in_minutes = "durationInMinutes",
            .environment_id = "environmentId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .duration_in_minutes = "durationInMinutes",
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_programmatic_access_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_programmatic_access_credentials };
        }
    },
    Response: type = struct {
        credentials: ?struct {
            access_key_id: ?[]const u8 = null,
            secret_access_key: ?[]const u8 = null,
            session_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_key_id = "accessKeyId",
                    .secret_access_key = "secretAccessKey",
                    .session_token = "sessionToken",
                };
                return @field(mappings, field_name);
            }
        } = null,
        duration_in_minutes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "credentials",
                .duration_in_minutes = "durationInMinutes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user/{userId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUser",
    Request: type = struct {
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user) } {
            return .{ .service_metadata = service_metadata, .action = get_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        type: ?[]const u8 = null,
        api_access: ?[]const u8 = null,
        api_access_principal_arn: ?[]const u8 = null,
        create_time: ?i64 = null,
        last_enabled_time: ?i64 = null,
        last_disabled_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        last_login_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
                .status = "status",
                .first_name = "firstName",
                .last_name = "lastName",
                .email_address = "emailAddress",
                .type = "type",
                .api_access = "apiAccess",
                .api_access_principal_arn = "apiAccessPrincipalArn",
                .create_time = "createTime",
                .last_enabled_time = "lastEnabledTime",
                .last_disabled_time = "lastDisabledTime",
                .last_modified_time = "lastModifiedTime",
                .last_login_time = "lastLoginTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_working_location: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workingLocationV1",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkingLocation",
    Request: type = struct {
        location_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_type = "locationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_working_location) } {
            return .{ .service_metadata = service_metadata, .action = get_working_location };
        }
    },
    Response: type = struct {
        s3_uri: ?[]const u8 = null,
        s3_path: ?[]const u8 = null,
        s3_bucket: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_uri = "s3Uri",
                .s3_path = "s3Path",
                .s3_bucket = "s3Bucket",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_changesets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets/{datasetId}/changesetsv2",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChangesets",
    Request: type = struct {
        dataset_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_changesets) } {
            return .{ .service_metadata = service_metadata, .action = list_changesets };
        }
    },
    Response: type = struct {
        changesets: ?[]struct {
            changeset_id: ?[]const u8 = null,
            changeset_arn: ?[]const u8 = null,
            dataset_id: ?[]const u8 = null,
            change_type: ?[]const u8 = null,
            source_params: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            format_params: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            create_time: ?i64 = null,
            status: ?[]const u8 = null,
            error_info: ?ChangesetErrorInfo = null,
            active_until_timestamp: ?i64 = null,
            active_from_timestamp: ?i64 = null,
            updates_changeset_id: ?[]const u8 = null,
            updated_by_changeset_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .changeset_id = "changesetId",
                    .changeset_arn = "changesetArn",
                    .dataset_id = "datasetId",
                    .change_type = "changeType",
                    .source_params = "sourceParams",
                    .format_params = "formatParams",
                    .create_time = "createTime",
                    .status = "status",
                    .error_info = "errorInfo",
                    .active_until_timestamp = "activeUntilTimestamp",
                    .active_from_timestamp = "activeFromTimestamp",
                    .updates_changeset_id = "updatesChangesetId",
                    .updated_by_changeset_id = "updatedByChangesetId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "source_params", field_name))
                    return try serializeMap(self.source_params, self.fieldNameFor("source_params"), options, out_stream);
                if (std.mem.eql(u8, "format_params", field_name))
                    return try serializeMap(self.format_params, self.fieldNameFor("format_params"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .changesets = "changesets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_datasets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasetsv2",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatasets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasets) } {
            return .{ .service_metadata = service_metadata, .action = list_datasets };
        }
    },
    Response: type = struct {
        datasets: ?[]struct {
            dataset_id: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            dataset_title: ?[]const u8 = null,
            kind: ?[]const u8 = null,
            dataset_description: ?[]const u8 = null,
            owner_info: ?DatasetOwnerInfo = null,
            create_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            schema_definition: ?SchemaUnion = null,
            alias: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_id = "datasetId",
                    .dataset_arn = "datasetArn",
                    .dataset_title = "datasetTitle",
                    .kind = "kind",
                    .dataset_description = "datasetDescription",
                    .owner_info = "ownerInfo",
                    .create_time = "createTime",
                    .last_modified_time = "lastModifiedTime",
                    .schema_definition = "schemaDefinition",
                    .alias = "alias",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datasets = "datasets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_views: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets/{datasetId}/dataviewsv2",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataViews",
    Request: type = struct {
        dataset_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_views) } {
            return .{ .service_metadata = service_metadata, .action = list_data_views };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        data_views: ?[]struct {
            data_view_id: ?[]const u8 = null,
            data_view_arn: ?[]const u8 = null,
            dataset_id: ?[]const u8 = null,
            as_of_timestamp: ?i64 = null,
            partition_columns: ?[][]const u8 = null,
            sort_columns: ?[][]const u8 = null,
            status: ?[]const u8 = null,
            error_info: ?DataViewErrorInfo = null,
            destination_type_properties: ?DataViewDestinationTypeParams = null,
            auto_update: ?bool = null,
            create_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_view_id = "dataViewId",
                    .data_view_arn = "dataViewArn",
                    .dataset_id = "datasetId",
                    .as_of_timestamp = "asOfTimestamp",
                    .partition_columns = "partitionColumns",
                    .sort_columns = "sortColumns",
                    .status = "status",
                    .error_info = "errorInfo",
                    .destination_type_properties = "destinationTypeProperties",
                    .auto_update = "autoUpdate",
                    .create_time = "createTime",
                    .last_modified_time = "lastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .data_views = "dataViews",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_permission_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/permission-group",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPermissionGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: i64,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_groups };
        }
    },
    Response: type = struct {
        permission_groups: ?[]PermissionGroup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_groups = "permissionGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_permission_groups_by_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user/{userId}/permission-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPermissionGroupsByUser",
    Request: type = struct {
        user_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: i64,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_groups_by_user) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_groups_by_user };
        }
    },
    Response: type = struct {
        permission_groups: ?[]struct {
            permission_group_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            membership_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .permission_group_id = "permissionGroupId",
                    .name = "name",
                    .membership_status = "membershipStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_groups = "permissionGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: i64,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        users: ?[]struct {
            user_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            first_name: ?[]const u8 = null,
            last_name: ?[]const u8 = null,
            email_address: ?[]const u8 = null,
            type: ?[]const u8 = null,
            api_access: ?[]const u8 = null,
            api_access_principal_arn: ?[]const u8 = null,
            create_time: ?i64 = null,
            last_enabled_time: ?i64 = null,
            last_disabled_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            last_login_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_id = "userId",
                    .status = "status",
                    .first_name = "firstName",
                    .last_name = "lastName",
                    .email_address = "emailAddress",
                    .type = "type",
                    .api_access = "apiAccess",
                    .api_access_principal_arn = "apiAccessPrincipalArn",
                    .create_time = "createTime",
                    .last_enabled_time = "lastEnabledTime",
                    .last_disabled_time = "lastDisabledTime",
                    .last_modified_time = "lastModifiedTime",
                    .last_login_time = "lastLoginTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "users",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_users_by_permission_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/permission-group/{permissionGroupId}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsersByPermissionGroup",
    Request: type = struct {
        permission_group_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: i64,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users_by_permission_group) } {
            return .{ .service_metadata = service_metadata, .action = list_users_by_permission_group };
        }
    },
    Response: type = struct {
        users: ?[]struct {
            user_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            first_name: ?[]const u8 = null,
            last_name: ?[]const u8 = null,
            email_address: ?[]const u8 = null,
            type: ?[]const u8 = null,
            api_access: ?[]const u8 = null,
            api_access_principal_arn: ?[]const u8 = null,
            membership_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_id = "userId",
                    .status = "status",
                    .first_name = "firstName",
                    .last_name = "lastName",
                    .email_address = "emailAddress",
                    .type = "type",
                    .api_access = "apiAccess",
                    .api_access_principal_arn = "apiAccessPrincipalArn",
                    .membership_status = "membershipStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "users",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const reset_user_password: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/{userId}/password",
        .success_code = 200,
    };

    action_name: []const u8 = "ResetUserPassword",
    Request: type = struct {
        user_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_user_password) } {
            return .{ .service_metadata = service_metadata, .action = reset_user_password };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        temporary_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
                .temporary_password = "temporaryPassword",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_changeset: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/datasets/{datasetId}/changesetsv2/{changesetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChangeset",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dataset_id: []const u8,
        changeset_id: []const u8,
        source_params: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        format_params: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .dataset_id = "datasetId",
                .changeset_id = "changesetId",
                .source_params = "sourceParams",
                .format_params = "formatParams",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "source_params", field_name))
                return try serializeMap(self.source_params, self.fieldNameFor("source_params"), options, out_stream);
            if (std.mem.eql(u8, "format_params", field_name))
                return try serializeMap(self.format_params, self.fieldNameFor("format_params"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_changeset) } {
            return .{ .service_metadata = service_metadata, .action = update_changeset };
        }
    },
    Response: type = struct {
        changeset_id: ?[]const u8 = null,
        dataset_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .changeset_id = "changesetId",
                .dataset_id = "datasetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_dataset: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/datasetsv2/{datasetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataset",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dataset_id: []const u8,
        dataset_title: []const u8,
        kind: []const u8,
        dataset_description: ?[]const u8 = null,
        alias: ?[]const u8 = null,
        schema_definition: ?SchemaUnion = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .dataset_id = "datasetId",
                .dataset_title = "datasetTitle",
                .kind = "kind",
                .dataset_description = "datasetDescription",
                .alias = "alias",
                .schema_definition = "schemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dataset) } {
            return .{ .service_metadata = service_metadata, .action = update_dataset };
        }
    },
    Response: type = struct {
        dataset_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_id = "datasetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_permission_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/permission-group/{permissionGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePermissionGroup",
    Request: type = struct {
        permission_group_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        application_permissions: ?[][]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
                .name = "name",
                .description = "description",
                .application_permissions = "applicationPermissions",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_permission_group) } {
            return .{ .service_metadata = service_metadata, .action = update_permission_group };
        }
    },
    Response: type = struct {
        permission_group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_group_id = "permissionGroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/user/{userId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        user_id: []const u8,
        type: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        api_access: ?[]const u8 = null,
        api_access_principal_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
                .type = "type",
                .first_name = "firstName",
                .last_name = "lastName",
                .api_access = "apiAccess",
                .api_access_principal_arn = "apiAccessPrincipalArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const SchemaUnion = struct {
    tabular_schema_config: ?SchemaDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tabular_schema_config = "tabularSchemaConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaDefinition = struct {
    columns: ?[]ColumnDefinition = null,
    primary_key_columns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .columns = "columns",
            .primary_key_columns = "primaryKeyColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnDefinition = struct {
    data_type: ?[]const u8 = null,
    column_name: ?[]const u8 = null,
    column_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_type = "dataType",
            .column_name = "columnName",
            .column_description = "columnDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const PermissionGroup = struct {
    permission_group_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    application_permissions: ?[][]const u8 = null,
    create_time: ?i64 = null,
    last_modified_time: ?i64 = null,
    membership_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .permission_group_id = "permissionGroupId",
            .name = "name",
            .description = "description",
            .application_permissions = "applicationPermissions",
            .create_time = "createTime",
            .last_modified_time = "lastModifiedTime",
            .membership_status = "membershipStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const DataViewDestinationTypeParams = struct {
    destination_type: []const u8,
    s3_destination_export_file_format: ?[]const u8 = null,
    s3_destination_export_file_format_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_type = "destinationType",
            .s3_destination_export_file_format = "s3DestinationExportFileFormat",
            .s3_destination_export_file_format_options = "s3DestinationExportFileFormatOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "s3_destination_export_file_format_options", field_name))
            return try serializeMap(self.s3_destination_export_file_format_options, self.fieldNameFor("s3_destination_export_file_format_options"), options, out_stream);
        return false;
    }
};

pub const DataViewErrorInfo = struct {
    error_message: ?[]const u8 = null,
    error_category: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_message = "errorMessage",
            .error_category = "errorCategory",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetOwnerInfo = struct {
    name: ?[]const u8 = null,
    phone_number: ?[]const u8 = null,
    email: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .phone_number = "phoneNumber",
            .email = "email",
        };
        return @field(mappings, field_name);
    }
};

pub const ChangesetErrorInfo = struct {
    error_message: ?[]const u8 = null,
    error_category: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_message = "errorMessage",
            .error_category = "errorCategory",
        };
        return @field(mappings, field_name);
    }
};
