const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-06-26";
pub const sdk_id: []const u8 = "forecastquery";
pub const arn_namespace: ?[]const u8 = "forecast";
pub const endpoint_prefix: []const u8 = "forecastquery";
pub const sigv4_name: []const u8 = "forecast";
pub const name: []const u8 = "AmazonForecastRuntime";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-06-26",
    sdk_id: []const u8 = "forecastquery",
    arn_namespace: ?[]const u8 = "forecast",
    endpoint_prefix: []const u8 = "forecastquery",
    sigv4_name: []const u8 = "forecast",
    name: []const u8 = "AmazonForecastRuntime",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const query_forecast: struct {
    action_name: []const u8 = "QueryForecast",
    Request: type = struct {
        forecast_arn: []const u8,
        start_date: ?[]const u8 = null,
        end_date: ?[]const u8 = null,
        filters: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_arn = "ForecastArn",
                .start_date = "StartDate",
                .end_date = "EndDate",
                .filters = "Filters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query_forecast) } {
            return .{ .service_metadata = service_metadata, .action = query_forecast };
        }
    },
    Response: type = struct {
        forecast: ?Forecast = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast = "Forecast",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const query_what_if_forecast: struct {
    action_name: []const u8 = "QueryWhatIfForecast",
    Request: type = struct {
        what_if_forecast_arn: []const u8,
        start_date: ?[]const u8 = null,
        end_date: ?[]const u8 = null,
        filters: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .what_if_forecast_arn = "WhatIfForecastArn",
                .start_date = "StartDate",
                .end_date = "EndDate",
                .filters = "Filters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query_what_if_forecast) } {
            return .{ .service_metadata = service_metadata, .action = query_what_if_forecast };
        }
    },
    Response: type = struct {
        forecast: ?Forecast = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast = "Forecast",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};

pub const Forecast = struct {
    predictions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]DataPoint = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .predictions = "Predictions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "predictions", field_name))
            return try serializeMap(self.predictions, self.fieldNameFor("predictions"), options, out_stream);
        return false;
    }
};

pub const DataPoint = struct {
    timestamp: ?[]const u8 = null,
    value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp = "Timestamp",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
