const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-09-07";
pub const sdk_id: []const u8 = "FreeTier";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "freetier";
pub const sigv4_name: []const u8 = "freetier";
pub const name: []const u8 = "AWSFreeTierService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2023-09-07",
    sdk_id: []const u8 = "FreeTier",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "freetier",
    sigv4_name: []const u8 = "freetier",
    name: []const u8 = "AWSFreeTierService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const get_free_tier_usage: struct {
    action_name: []const u8 = "GetFreeTierUsage",
    Request: type = struct {
        filter: ?Expression = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_free_tier_usage) } {
            return .{ .service_metadata = service_metadata, .action = get_free_tier_usage };
        }
    },
    Response: type = struct {
        free_tier_usages: []struct {
            service: ?[]const u8 = null,
            operation: ?[]const u8 = null,
            usage_type: ?[]const u8 = null,
            region: ?[]const u8 = null,
            actual_usage_amount: ?f64 = null,
            forecasted_usage_amount: ?f64 = null,
            limit: ?f64 = null,
            unit: ?[]const u8 = null,
            description: ?[]const u8 = null,
            free_tier_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service = "service",
                    .operation = "operation",
                    .usage_type = "usageType",
                    .region = "region",
                    .actual_usage_amount = "actualUsageAmount",
                    .forecasted_usage_amount = "forecastedUsageAmount",
                    .limit = "limit",
                    .unit = "unit",
                    .description = "description",
                    .free_tier_type = "freeTierType",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .free_tier_usages = "freeTierUsages",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const Expression = struct {
    @"or": ?[]Expression = null,
    @"and": ?[]Expression = null,
    @"not": ?Expression = null,
    dimensions: ?struct {
        key: []const u8,
        values: [][]const u8,
        match_options: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key = "Key",
                .values = "Values",
                .match_options = "MatchOptions",
            };
            return @field(mappings, field_name);
        }
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .@"or" = "Or",
            .@"and" = "And",
            .@"not" = "Not",
            .dimensions = "Dimensions",
        };
        return @field(mappings, field_name);
    }
};
