const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-03-01";
pub const sdk_id: []const u8 = "FSx";
pub const arn_namespace: ?[]const u8 = "fsx";
pub const endpoint_prefix: []const u8 = "fsx";
pub const sigv4_name: []const u8 = "fsx";
pub const name: []const u8 = "AWSSimbaAPIService_v20180301";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-03-01",
    sdk_id: []const u8 = "FSx",
    arn_namespace: ?[]const u8 = "fsx",
    endpoint_prefix: []const u8 = "fsx",
    sigv4_name: []const u8 = "fsx",
    name: []const u8 = "AWSSimbaAPIService_v20180301",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_file_system_aliases: struct {
    action_name: []const u8 = "AssociateFileSystemAliases",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_id: []const u8,
        aliases: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_id = "FileSystemId",
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_file_system_aliases) } {
            return .{ .service_metadata = service_metadata, .action = associate_file_system_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[]Alias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const cancel_data_repository_task: struct {
    action_name: []const u8 = "CancelDataRepositoryTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_data_repository_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_data_repository_task };
        }
    },
    Response: type = struct {
        lifecycle: ?[]const u8 = null,
        task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle = "Lifecycle",
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryTaskEnded,
        DataRepositoryTaskNotFound,
        InternalServerError,
        UnsupportedOperation,
    },
} = .{};
pub const copy_backup: struct {
    action_name: []const u8 = "CopyBackup",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        source_backup_id: []const u8,
        source_region: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        copy_tags: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .source_backup_id = "SourceBackupId",
                .source_region = "SourceRegion",
                .kms_key_id = "KmsKeyId",
                .copy_tags = "CopyTags",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_backup) } {
            return .{ .service_metadata = service_metadata, .action = copy_backup };
        }
    },
    Response: type = struct {
        backup: ?Backup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup = "Backup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupNotFound,
        BadRequest,
        IncompatibleParameterError,
        IncompatibleRegionForMultiAZ,
        InternalServerError,
        InvalidDestinationKmsKey,
        InvalidRegion,
        InvalidSourceKmsKey,
        ServiceLimitExceeded,
        SourceBackupUnavailable,
        UnsupportedOperation,
    },
} = .{};
pub const copy_snapshot_and_update_volume: struct {
    action_name: []const u8 = "CopySnapshotAndUpdateVolume",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        volume_id: []const u8,
        source_snapshot_arn: []const u8,
        copy_strategy: ?[]const u8 = null,
        options: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .volume_id = "VolumeId",
                .source_snapshot_arn = "SourceSnapshotARN",
                .copy_strategy = "CopyStrategy",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_snapshot_and_update_volume) } {
            return .{ .service_metadata = service_metadata, .action = copy_snapshot_and_update_volume };
        }
    },
    Response: type = struct {
        volume_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,
        administrative_actions: ?[]AdministrativeAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_id = "VolumeId",
                .lifecycle = "Lifecycle",
                .administrative_actions = "AdministrativeActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
    },
} = .{};
pub const create_backup: struct {
    action_name: []const u8 = "CreateBackup",
    Request: type = struct {
        file_system_id: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,
        volume_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .volume_id = "VolumeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backup) } {
            return .{ .service_metadata = service_metadata, .action = create_backup };
        }
    },
    Response: type = struct {
        backup: ?Backup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup = "Backup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupInProgress,
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
        UnsupportedOperation,
        VolumeNotFound,
    },
} = .{};
pub const create_data_repository_association: struct {
    action_name: []const u8 = "CreateDataRepositoryAssociation",
    Request: type = struct {
        file_system_id: []const u8,
        file_system_path: ?[]const u8 = null,
        data_repository_path: []const u8,
        batch_import_meta_data_on_create: ?bool = null,
        imported_file_chunk_size: ?i64 = null,
        s3: ?S3DataRepositoryConfiguration = null,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .file_system_path = "FileSystemPath",
                .data_repository_path = "DataRepositoryPath",
                .batch_import_meta_data_on_create = "BatchImportMetaDataOnCreate",
                .imported_file_chunk_size = "ImportedFileChunkSize",
                .s3 = "S3",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_repository_association) } {
            return .{ .service_metadata = service_metadata, .action = create_data_repository_association };
        }
    },
    Response: type = struct {
        association: ?DataRepositoryAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "Association",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const create_data_repository_task: struct {
    action_name: []const u8 = "CreateDataRepositoryTask",
    Request: type = struct {
        type: []const u8,
        paths: ?[][]const u8 = null,
        file_system_id: []const u8,
        report: CompletionReport,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,
        capacity_to_release: ?i64 = null,
        release_configuration: ?ReleaseConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .paths = "Paths",
                .file_system_id = "FileSystemId",
                .report = "Report",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .capacity_to_release = "CapacityToRelease",
                .release_configuration = "ReleaseConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_repository_task) } {
            return .{ .service_metadata = service_metadata, .action = create_data_repository_task };
        }
    },
    Response: type = struct {
        data_repository_task: ?DataRepositoryTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_repository_task = "DataRepositoryTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryTaskExecuting,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const create_file_cache: struct {
    action_name: []const u8 = "CreateFileCache",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_cache_type: []const u8,
        file_cache_type_version: []const u8,
        storage_capacity: i64,
        subnet_ids: [][]const u8,
        security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        copy_tags_to_data_repository_associations: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        lustre_configuration: ?struct {
            per_unit_storage_throughput: i64,
            deployment_type: []const u8,
            weekly_maintenance_start_time: ?[]const u8 = null,
            metadata_configuration: FileCacheLustreMetadataConfiguration,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .per_unit_storage_throughput = "PerUnitStorageThroughput",
                    .deployment_type = "DeploymentType",
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                    .metadata_configuration = "MetadataConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        data_repository_associations: ?[]struct {
            file_cache_path: []const u8,
            data_repository_path: []const u8,
            data_repository_subdirectories: ?[][]const u8 = null,
            nfs: ?struct {
                version: []const u8,
                dns_ips: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .version = "Version",
                        .dns_ips = "DnsIps",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_cache_path = "FileCachePath",
                    .data_repository_path = "DataRepositoryPath",
                    .data_repository_subdirectories = "DataRepositorySubdirectories",
                    .nfs = "NFS",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_cache_type = "FileCacheType",
                .file_cache_type_version = "FileCacheTypeVersion",
                .storage_capacity = "StorageCapacity",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
                .tags = "Tags",
                .copy_tags_to_data_repository_associations = "CopyTagsToDataRepositoryAssociations",
                .kms_key_id = "KmsKeyId",
                .lustre_configuration = "LustreConfiguration",
                .data_repository_associations = "DataRepositoryAssociations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_file_cache) } {
            return .{ .service_metadata = service_metadata, .action = create_file_cache };
        }
    },
    Response: type = struct {
        file_cache: ?struct {
            owner_id: ?[]const u8 = null,
            creation_time: ?i64 = null,
            file_cache_id: ?[]const u8 = null,
            file_cache_type: ?[]const u8 = null,
            file_cache_type_version: ?[]const u8 = null,
            lifecycle: ?[]const u8 = null,
            failure_details: ?FileCacheFailureDetails = null,
            storage_capacity: ?i64 = null,
            vpc_id: ?[]const u8 = null,
            subnet_ids: ?[][]const u8 = null,
            network_interface_ids: ?[][]const u8 = null,
            dns_name: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            tags: ?[]Tag = null,
            copy_tags_to_data_repository_associations: ?bool = null,
            lustre_configuration: ?FileCacheLustreConfiguration = null,
            data_repository_association_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .owner_id = "OwnerId",
                    .creation_time = "CreationTime",
                    .file_cache_id = "FileCacheId",
                    .file_cache_type = "FileCacheType",
                    .file_cache_type_version = "FileCacheTypeVersion",
                    .lifecycle = "Lifecycle",
                    .failure_details = "FailureDetails",
                    .storage_capacity = "StorageCapacity",
                    .vpc_id = "VpcId",
                    .subnet_ids = "SubnetIds",
                    .network_interface_ids = "NetworkInterfaceIds",
                    .dns_name = "DNSName",
                    .kms_key_id = "KmsKeyId",
                    .resource_arn = "ResourceARN",
                    .tags = "Tags",
                    .copy_tags_to_data_repository_associations = "CopyTagsToDataRepositoryAssociations",
                    .lustre_configuration = "LustreConfiguration",
                    .data_repository_association_ids = "DataRepositoryAssociationIds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_cache = "FileCache",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        InvalidNetworkSettings,
        InvalidPerUnitStorageThroughput,
        MissingFileCacheConfiguration,
        ServiceLimitExceeded,
    },
} = .{};
pub const create_file_system: struct {
    action_name: []const u8 = "CreateFileSystem",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_type: []const u8,
        storage_capacity: i64,
        storage_type: ?[]const u8 = null,
        subnet_ids: [][]const u8,
        security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        windows_configuration: ?CreateFileSystemWindowsConfiguration = null,
        lustre_configuration: ?CreateFileSystemLustreConfiguration = null,
        ontap_configuration: ?struct {
            automatic_backup_retention_days: ?i64 = null,
            daily_automatic_backup_start_time: ?[]const u8 = null,
            deployment_type: []const u8,
            endpoint_ip_address_range: ?[]const u8 = null,
            fsx_admin_password: ?[]const u8 = null,
            disk_iops_configuration: ?DiskIopsConfiguration = null,
            preferred_subnet_id: ?[]const u8 = null,
            route_table_ids: ?[][]const u8 = null,
            throughput_capacity: ?i64 = null,
            weekly_maintenance_start_time: ?[]const u8 = null,
            ha_pairs: ?i64 = null,
            throughput_capacity_per_ha_pair: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
                    .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
                    .deployment_type = "DeploymentType",
                    .endpoint_ip_address_range = "EndpointIpAddressRange",
                    .fsx_admin_password = "FsxAdminPassword",
                    .disk_iops_configuration = "DiskIopsConfiguration",
                    .preferred_subnet_id = "PreferredSubnetId",
                    .route_table_ids = "RouteTableIds",
                    .throughput_capacity = "ThroughputCapacity",
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                    .ha_pairs = "HAPairs",
                    .throughput_capacity_per_ha_pair = "ThroughputCapacityPerHAPair",
                };
                return @field(mappings, field_name);
            }
        } = null,
        file_system_type_version: ?[]const u8 = null,
        open_zfs_configuration: ?CreateFileSystemOpenZFSConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_type = "FileSystemType",
                .storage_capacity = "StorageCapacity",
                .storage_type = "StorageType",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .windows_configuration = "WindowsConfiguration",
                .lustre_configuration = "LustreConfiguration",
                .ontap_configuration = "OntapConfiguration",
                .file_system_type_version = "FileSystemTypeVersion",
                .open_zfs_configuration = "OpenZFSConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_file_system) } {
            return .{ .service_metadata = service_metadata, .action = create_file_system };
        }
    },
    Response: type = struct {
        file_system: ?FileSystem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system = "FileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActiveDirectoryError,
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        InvalidExportPath,
        InvalidImportPath,
        InvalidNetworkSettings,
        InvalidPerUnitStorageThroughput,
        MissingFileSystemConfiguration,
        ServiceLimitExceeded,
    },
} = .{};
pub const create_file_system_from_backup: struct {
    action_name: []const u8 = "CreateFileSystemFromBackup",
    Request: type = struct {
        backup_id: []const u8,
        client_request_token: ?[]const u8 = null,
        subnet_ids: [][]const u8,
        security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        windows_configuration: ?CreateFileSystemWindowsConfiguration = null,
        lustre_configuration: ?CreateFileSystemLustreConfiguration = null,
        storage_type: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        file_system_type_version: ?[]const u8 = null,
        open_zfs_configuration: ?CreateFileSystemOpenZFSConfiguration = null,
        storage_capacity: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .client_request_token = "ClientRequestToken",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
                .tags = "Tags",
                .windows_configuration = "WindowsConfiguration",
                .lustre_configuration = "LustreConfiguration",
                .storage_type = "StorageType",
                .kms_key_id = "KmsKeyId",
                .file_system_type_version = "FileSystemTypeVersion",
                .open_zfs_configuration = "OpenZFSConfiguration",
                .storage_capacity = "StorageCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_file_system_from_backup) } {
            return .{ .service_metadata = service_metadata, .action = create_file_system_from_backup };
        }
    },
    Response: type = struct {
        file_system: ?FileSystem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system = "FileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActiveDirectoryError,
        BackupNotFound,
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        InvalidNetworkSettings,
        InvalidPerUnitStorageThroughput,
        MissingFileSystemConfiguration,
        ServiceLimitExceeded,
    },
} = .{};
pub const create_snapshot: struct {
    action_name: []const u8 = "CreateSnapshot",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        name: []const u8,
        volume_id: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .name = "Name",
                .volume_id = "VolumeId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        ServiceLimitExceeded,
        VolumeNotFound,
    },
} = .{};
pub const create_storage_virtual_machine: struct {
    action_name: []const u8 = "CreateStorageVirtualMachine",
    Request: type = struct {
        active_directory_configuration: ?struct {
            net_bios_name: []const u8,
            self_managed_active_directory_configuration: ?SelfManagedActiveDirectoryConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .net_bios_name = "NetBiosName",
                    .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_request_token: ?[]const u8 = null,
        file_system_id: []const u8,
        name: []const u8,
        svm_admin_password: ?[]const u8 = null,
        tags: ?[]Tag = null,
        root_volume_security_style: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .active_directory_configuration = "ActiveDirectoryConfiguration",
                .client_request_token = "ClientRequestToken",
                .file_system_id = "FileSystemId",
                .name = "Name",
                .svm_admin_password = "SvmAdminPassword",
                .tags = "Tags",
                .root_volume_security_style = "RootVolumeSecurityStyle",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_storage_virtual_machine) } {
            return .{ .service_metadata = service_metadata, .action = create_storage_virtual_machine };
        }
    },
    Response: type = struct {
        storage_virtual_machine: ?StorageVirtualMachine = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_virtual_machine = "StorageVirtualMachine",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActiveDirectoryError,
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const create_volume: struct {
    action_name: []const u8 = "CreateVolume",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        volume_type: []const u8,
        name: []const u8,
        ontap_configuration: ?CreateOntapVolumeConfiguration = null,
        tags: ?[]Tag = null,
        open_zfs_configuration: ?struct {
            parent_volume_id: []const u8,
            storage_capacity_reservation_gib: ?i64 = null,
            storage_capacity_quota_gib: ?i64 = null,
            record_size_kib: ?i64 = null,
            data_compression_type: ?[]const u8 = null,
            copy_tags_to_snapshots: ?bool = null,
            origin_snapshot: ?struct {
                snapshot_arn: []const u8,
                copy_strategy: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .snapshot_arn = "SnapshotARN",
                        .copy_strategy = "CopyStrategy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            read_only: ?bool = null,
            nfs_exports: ?[]OpenZFSNfsExport = null,
            user_and_group_quotas: ?[]OpenZFSUserOrGroupQuota = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .parent_volume_id = "ParentVolumeId",
                    .storage_capacity_reservation_gib = "StorageCapacityReservationGiB",
                    .storage_capacity_quota_gib = "StorageCapacityQuotaGiB",
                    .record_size_kib = "RecordSizeKiB",
                    .data_compression_type = "DataCompressionType",
                    .copy_tags_to_snapshots = "CopyTagsToSnapshots",
                    .origin_snapshot = "OriginSnapshot",
                    .read_only = "ReadOnly",
                    .nfs_exports = "NfsExports",
                    .user_and_group_quotas = "UserAndGroupQuotas",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .volume_type = "VolumeType",
                .name = "Name",
                .ontap_configuration = "OntapConfiguration",
                .tags = "Tags",
                .open_zfs_configuration = "OpenZFSConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_volume) } {
            return .{ .service_metadata = service_metadata, .action = create_volume };
        }
    },
    Response: type = struct {
        volume: ?Volume = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume = "Volume",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        MissingVolumeConfiguration,
        ServiceLimitExceeded,
        StorageVirtualMachineNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const create_volume_from_backup: struct {
    action_name: []const u8 = "CreateVolumeFromBackup",
    Request: type = struct {
        backup_id: []const u8,
        client_request_token: ?[]const u8 = null,
        name: []const u8,
        ontap_configuration: ?CreateOntapVolumeConfiguration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .client_request_token = "ClientRequestToken",
                .name = "Name",
                .ontap_configuration = "OntapConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_volume_from_backup) } {
            return .{ .service_metadata = service_metadata, .action = create_volume_from_backup };
        }
    },
    Response: type = struct {
        volume: ?Volume = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume = "Volume",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupNotFound,
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        MissingVolumeConfiguration,
        ServiceLimitExceeded,
        StorageVirtualMachineNotFound,
    },
} = .{};
pub const delete_backup: struct {
    action_name: []const u8 = "DeleteBackup",
    Request: type = struct {
        backup_id: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup };
        }
    },
    Response: type = struct {
        backup_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .lifecycle = "Lifecycle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupBeingCopied,
        BackupInProgress,
        BackupNotFound,
        BackupRestoring,
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
    },
} = .{};
pub const delete_data_repository_association: struct {
    action_name: []const u8 = "DeleteDataRepositoryAssociation",
    Request: type = struct {
        association_id: []const u8,
        client_request_token: ?[]const u8 = null,
        delete_data_in_file_system: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .client_request_token = "ClientRequestToken",
                .delete_data_in_file_system = "DeleteDataInFileSystem",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_repository_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_repository_association };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,
        delete_data_in_file_system: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .lifecycle = "Lifecycle",
                .delete_data_in_file_system = "DeleteDataInFileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryAssociationNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
    },
} = .{};
pub const delete_file_cache: struct {
    action_name: []const u8 = "DeleteFileCache",
    Request: type = struct {
        file_cache_id: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_cache_id = "FileCacheId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_file_cache) } {
            return .{ .service_metadata = service_metadata, .action = delete_file_cache };
        }
    },
    Response: type = struct {
        file_cache_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_cache_id = "FileCacheId",
                .lifecycle = "Lifecycle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileCacheNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
    },
} = .{};
pub const delete_file_system: struct {
    action_name: []const u8 = "DeleteFileSystem",
    Request: type = struct {
        file_system_id: []const u8,
        client_request_token: ?[]const u8 = null,
        windows_configuration: ?struct {
            skip_final_backup: ?bool = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .skip_final_backup = "SkipFinalBackup",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lustre_configuration: ?struct {
            skip_final_backup: ?bool = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .skip_final_backup = "SkipFinalBackup",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        open_zfs_configuration: ?struct {
            skip_final_backup: ?bool = null,
            final_backup_tags: ?[]Tag = null,
            options: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .skip_final_backup = "SkipFinalBackup",
                    .final_backup_tags = "FinalBackupTags",
                    .options = "Options",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .client_request_token = "ClientRequestToken",
                .windows_configuration = "WindowsConfiguration",
                .lustre_configuration = "LustreConfiguration",
                .open_zfs_configuration = "OpenZFSConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_file_system) } {
            return .{ .service_metadata = service_metadata, .action = delete_file_system };
        }
    },
    Response: type = struct {
        file_system_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,
        windows_response: ?struct {
            final_backup_id: ?[]const u8 = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .final_backup_id = "FinalBackupId",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lustre_response: ?struct {
            final_backup_id: ?[]const u8 = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .final_backup_id = "FinalBackupId",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        open_zfs_response: ?struct {
            final_backup_id: ?[]const u8 = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .final_backup_id = "FinalBackupId",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .lifecycle = "Lifecycle",
                .windows_response = "WindowsResponse",
                .lustre_response = "LustreResponse",
                .open_zfs_response = "OpenZFSResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
    },
} = .{};
pub const delete_snapshot: struct {
    action_name: []const u8 = "DeleteSnapshot",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        snapshot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .snapshot_id = "SnapshotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_snapshot };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .lifecycle = "Lifecycle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        SnapshotNotFound,
    },
} = .{};
pub const delete_storage_virtual_machine: struct {
    action_name: []const u8 = "DeleteStorageVirtualMachine",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        storage_virtual_machine_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .storage_virtual_machine_id = "StorageVirtualMachineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_storage_virtual_machine) } {
            return .{ .service_metadata = service_metadata, .action = delete_storage_virtual_machine };
        }
    },
    Response: type = struct {
        storage_virtual_machine_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_virtual_machine_id = "StorageVirtualMachineId",
                .lifecycle = "Lifecycle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        StorageVirtualMachineNotFound,
    },
} = .{};
pub const delete_volume: struct {
    action_name: []const u8 = "DeleteVolume",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        volume_id: []const u8,
        ontap_configuration: ?struct {
            skip_final_backup: ?bool = null,
            final_backup_tags: ?[]Tag = null,
            bypass_snaplock_enterprise_retention: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .skip_final_backup = "SkipFinalBackup",
                    .final_backup_tags = "FinalBackupTags",
                    .bypass_snaplock_enterprise_retention = "BypassSnaplockEnterpriseRetention",
                };
                return @field(mappings, field_name);
            }
        } = null,
        open_zfs_configuration: ?struct {
            options: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .options = "Options",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .volume_id = "VolumeId",
                .ontap_configuration = "OntapConfiguration",
                .open_zfs_configuration = "OpenZFSConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_volume) } {
            return .{ .service_metadata = service_metadata, .action = delete_volume };
        }
    },
    Response: type = struct {
        volume_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,
        ontap_response: ?struct {
            final_backup_id: ?[]const u8 = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .final_backup_id = "FinalBackupId",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_id = "VolumeId",
                .lifecycle = "Lifecycle",
                .ontap_response = "OntapResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
        VolumeNotFound,
    },
} = .{};
pub const describe_backups: struct {
    action_name: []const u8 = "DescribeBackups",
    Request: type = struct {
        backup_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_ids = "BackupIds",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_backups) } {
            return .{ .service_metadata = service_metadata, .action = describe_backups };
        }
    },
    Response: type = struct {
        backups: ?[]Backup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backups = "Backups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupNotFound,
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
        VolumeNotFound,
    },
} = .{};
pub const describe_data_repository_associations: struct {
    action_name: []const u8 = "DescribeDataRepositoryAssociations",
    Request: type = struct {
        association_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_ids = "AssociationIds",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_repository_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_repository_associations };
        }
    },
    Response: type = struct {
        associations: ?[]DataRepositoryAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "Associations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryAssociationNotFound,
        FileSystemNotFound,
        InternalServerError,
        InvalidDataRepositoryType,
    },
} = .{};
pub const describe_data_repository_tasks: struct {
    action_name: []const u8 = "DescribeDataRepositoryTasks",
    Request: type = struct {
        task_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_ids = "TaskIds",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_repository_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_repository_tasks };
        }
    },
    Response: type = struct {
        data_repository_tasks: ?[]DataRepositoryTask = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_repository_tasks = "DataRepositoryTasks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryTaskNotFound,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_file_caches: struct {
    action_name: []const u8 = "DescribeFileCaches",
    Request: type = struct {
        file_cache_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_cache_ids = "FileCacheIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_file_caches) } {
            return .{ .service_metadata = service_metadata, .action = describe_file_caches };
        }
    },
    Response: type = struct {
        file_caches: ?[]FileCache = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_caches = "FileCaches",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileCacheNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_file_system_aliases: struct {
    action_name: []const u8 = "DescribeFileSystemAliases",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_id = "FileSystemId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_file_system_aliases) } {
            return .{ .service_metadata = service_metadata, .action = describe_file_system_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[]Alias = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_file_systems: struct {
    action_name: []const u8 = "DescribeFileSystems",
    Request: type = struct {
        file_system_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_ids = "FileSystemIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_file_systems) } {
            return .{ .service_metadata = service_metadata, .action = describe_file_systems };
        }
    },
    Response: type = struct {
        file_systems: ?[]FileSystem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_systems = "FileSystems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_shared_vpc_configuration: struct {
    action_name: []const u8 = "DescribeSharedVpcConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_shared_vpc_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_shared_vpc_configuration };
        }
    },
    Response: type = struct {
        enable_fsx_route_table_updates_from_participant_accounts: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enable_fsx_route_table_updates_from_participant_accounts = "EnableFsxRouteTableUpdatesFromParticipantAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const describe_snapshots: struct {
    action_name: []const u8 = "DescribeSnapshots",
    Request: type = struct {
        snapshot_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        include_shared: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_ids = "SnapshotIds",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .include_shared = "IncludeShared",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshots };
        }
    },
    Response: type = struct {
        snapshots: ?[]Snapshot = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshots = "Snapshots",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        SnapshotNotFound,
    },
} = .{};
pub const describe_storage_virtual_machines: struct {
    action_name: []const u8 = "DescribeStorageVirtualMachines",
    Request: type = struct {
        storage_virtual_machine_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_virtual_machine_ids = "StorageVirtualMachineIds",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_storage_virtual_machines) } {
            return .{ .service_metadata = service_metadata, .action = describe_storage_virtual_machines };
        }
    },
    Response: type = struct {
        storage_virtual_machines: ?[]StorageVirtualMachine = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_virtual_machines = "StorageVirtualMachines",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        StorageVirtualMachineNotFound,
    },
} = .{};
pub const describe_volumes: struct {
    action_name: []const u8 = "DescribeVolumes",
    Request: type = struct {
        volume_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_ids = "VolumeIds",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_volumes) } {
            return .{ .service_metadata = service_metadata, .action = describe_volumes };
        }
    },
    Response: type = struct {
        volumes: ?[]Volume = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volumes = "Volumes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        VolumeNotFound,
    },
} = .{};
pub const disassociate_file_system_aliases: struct {
    action_name: []const u8 = "DisassociateFileSystemAliases",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_id: []const u8,
        aliases: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_id = "FileSystemId",
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_file_system_aliases) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_file_system_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[]Alias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotServiceResourceError,
        ResourceDoesNotSupportTagging,
        ResourceNotFound,
    },
} = .{};
pub const release_file_system_nfs_v3_locks: struct {
    action_name: []const u8 = "ReleaseFileSystemNfsV3Locks",
    Request: type = struct {
        file_system_id: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(release_file_system_nfs_v3_locks) } {
            return .{ .service_metadata = service_metadata, .action = release_file_system_nfs_v3_locks };
        }
    },
    Response: type = struct {
        file_system: ?FileSystem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system = "FileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
    },
} = .{};
pub const restore_volume_from_snapshot: struct {
    action_name: []const u8 = "RestoreVolumeFromSnapshot",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        volume_id: []const u8,
        snapshot_id: []const u8,
        options: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .volume_id = "VolumeId",
                .snapshot_id = "SnapshotId",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_volume_from_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = restore_volume_from_snapshot };
        }
    },
    Response: type = struct {
        volume_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,
        administrative_actions: ?[]AdministrativeAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_id = "VolumeId",
                .lifecycle = "Lifecycle",
                .administrative_actions = "AdministrativeActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        VolumeNotFound,
    },
} = .{};
pub const start_misconfigured_state_recovery: struct {
    action_name: []const u8 = "StartMisconfiguredStateRecovery",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_id = "FileSystemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_misconfigured_state_recovery) } {
            return .{ .service_metadata = service_metadata, .action = start_misconfigured_state_recovery };
        }
    },
    Response: type = struct {
        file_system: ?FileSystem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system = "FileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotServiceResourceError,
        ResourceDoesNotSupportTagging,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotServiceResourceError,
        ResourceDoesNotSupportTagging,
        ResourceNotFound,
    },
} = .{};
pub const update_data_repository_association: struct {
    action_name: []const u8 = "UpdateDataRepositoryAssociation",
    Request: type = struct {
        association_id: []const u8,
        client_request_token: ?[]const u8 = null,
        imported_file_chunk_size: ?i64 = null,
        s3: ?S3DataRepositoryConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .client_request_token = "ClientRequestToken",
                .imported_file_chunk_size = "ImportedFileChunkSize",
                .s3 = "S3",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_repository_association) } {
            return .{ .service_metadata = service_metadata, .action = update_data_repository_association };
        }
    },
    Response: type = struct {
        association: ?DataRepositoryAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "Association",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryAssociationNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
    },
} = .{};
pub const update_file_cache: struct {
    action_name: []const u8 = "UpdateFileCache",
    Request: type = struct {
        file_cache_id: []const u8,
        client_request_token: ?[]const u8 = null,
        lustre_configuration: ?struct {
            weekly_maintenance_start_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_cache_id = "FileCacheId",
                .client_request_token = "ClientRequestToken",
                .lustre_configuration = "LustreConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_file_cache) } {
            return .{ .service_metadata = service_metadata, .action = update_file_cache };
        }
    },
    Response: type = struct {
        file_cache: ?FileCache = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_cache = "FileCache",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileCacheNotFound,
        IncompatibleParameterError,
        InternalServerError,
        MissingFileCacheConfiguration,
        ServiceLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const update_file_system: struct {
    action_name: []const u8 = "UpdateFileSystem",
    Request: type = struct {
        file_system_id: []const u8,
        client_request_token: ?[]const u8 = null,
        storage_capacity: ?i64 = null,
        windows_configuration: ?struct {
            weekly_maintenance_start_time: ?[]const u8 = null,
            daily_automatic_backup_start_time: ?[]const u8 = null,
            automatic_backup_retention_days: ?i64 = null,
            throughput_capacity: ?i64 = null,
            self_managed_active_directory_configuration: ?SelfManagedActiveDirectoryConfigurationUpdates = null,
            audit_log_configuration: ?WindowsAuditLogCreateConfiguration = null,
            disk_iops_configuration: ?DiskIopsConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                    .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
                    .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
                    .throughput_capacity = "ThroughputCapacity",
                    .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
                    .audit_log_configuration = "AuditLogConfiguration",
                    .disk_iops_configuration = "DiskIopsConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lustre_configuration: ?struct {
            weekly_maintenance_start_time: ?[]const u8 = null,
            daily_automatic_backup_start_time: ?[]const u8 = null,
            automatic_backup_retention_days: ?i64 = null,
            auto_import_policy: ?[]const u8 = null,
            data_compression_type: ?[]const u8 = null,
            log_configuration: ?LustreLogCreateConfiguration = null,
            root_squash_configuration: ?LustreRootSquashConfiguration = null,
            per_unit_storage_throughput: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                    .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
                    .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
                    .auto_import_policy = "AutoImportPolicy",
                    .data_compression_type = "DataCompressionType",
                    .log_configuration = "LogConfiguration",
                    .root_squash_configuration = "RootSquashConfiguration",
                    .per_unit_storage_throughput = "PerUnitStorageThroughput",
                };
                return @field(mappings, field_name);
            }
        } = null,
        ontap_configuration: ?struct {
            automatic_backup_retention_days: ?i64 = null,
            daily_automatic_backup_start_time: ?[]const u8 = null,
            fsx_admin_password: ?[]const u8 = null,
            weekly_maintenance_start_time: ?[]const u8 = null,
            disk_iops_configuration: ?DiskIopsConfiguration = null,
            throughput_capacity: ?i64 = null,
            add_route_table_ids: ?[][]const u8 = null,
            remove_route_table_ids: ?[][]const u8 = null,
            throughput_capacity_per_ha_pair: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
                    .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
                    .fsx_admin_password = "FsxAdminPassword",
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                    .disk_iops_configuration = "DiskIopsConfiguration",
                    .throughput_capacity = "ThroughputCapacity",
                    .add_route_table_ids = "AddRouteTableIds",
                    .remove_route_table_ids = "RemoveRouteTableIds",
                    .throughput_capacity_per_ha_pair = "ThroughputCapacityPerHAPair",
                };
                return @field(mappings, field_name);
            }
        } = null,
        open_zfs_configuration: ?struct {
            automatic_backup_retention_days: ?i64 = null,
            copy_tags_to_backups: ?bool = null,
            copy_tags_to_volumes: ?bool = null,
            daily_automatic_backup_start_time: ?[]const u8 = null,
            throughput_capacity: ?i64 = null,
            weekly_maintenance_start_time: ?[]const u8 = null,
            disk_iops_configuration: ?DiskIopsConfiguration = null,
            add_route_table_ids: ?[][]const u8 = null,
            remove_route_table_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
                    .copy_tags_to_backups = "CopyTagsToBackups",
                    .copy_tags_to_volumes = "CopyTagsToVolumes",
                    .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
                    .throughput_capacity = "ThroughputCapacity",
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                    .disk_iops_configuration = "DiskIopsConfiguration",
                    .add_route_table_ids = "AddRouteTableIds",
                    .remove_route_table_ids = "RemoveRouteTableIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        storage_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .client_request_token = "ClientRequestToken",
                .storage_capacity = "StorageCapacity",
                .windows_configuration = "WindowsConfiguration",
                .lustre_configuration = "LustreConfiguration",
                .ontap_configuration = "OntapConfiguration",
                .open_zfs_configuration = "OpenZFSConfiguration",
                .storage_type = "StorageType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_file_system) } {
            return .{ .service_metadata = service_metadata, .action = update_file_system };
        }
    },
    Response: type = struct {
        file_system: ?FileSystem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system = "FileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        InvalidNetworkSettings,
        MissingFileSystemConfiguration,
        ServiceLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const update_shared_vpc_configuration: struct {
    action_name: []const u8 = "UpdateSharedVpcConfiguration",
    Request: type = struct {
        enable_fsx_route_table_updates_from_participant_accounts: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enable_fsx_route_table_updates_from_participant_accounts = "EnableFsxRouteTableUpdatesFromParticipantAccounts",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_shared_vpc_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_shared_vpc_configuration };
        }
    },
    Response: type = struct {
        enable_fsx_route_table_updates_from_participant_accounts: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enable_fsx_route_table_updates_from_participant_accounts = "EnableFsxRouteTableUpdatesFromParticipantAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
    },
} = .{};
pub const update_snapshot: struct {
    action_name: []const u8 = "UpdateSnapshot",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        name: []const u8,
        snapshot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .name = "Name",
                .snapshot_id = "SnapshotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = update_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        SnapshotNotFound,
    },
} = .{};
pub const update_storage_virtual_machine: struct {
    action_name: []const u8 = "UpdateStorageVirtualMachine",
    Request: type = struct {
        active_directory_configuration: ?struct {
            self_managed_active_directory_configuration: ?SelfManagedActiveDirectoryConfigurationUpdates = null,
            net_bios_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
                    .net_bios_name = "NetBiosName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_request_token: ?[]const u8 = null,
        storage_virtual_machine_id: []const u8,
        svm_admin_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .active_directory_configuration = "ActiveDirectoryConfiguration",
                .client_request_token = "ClientRequestToken",
                .storage_virtual_machine_id = "StorageVirtualMachineId",
                .svm_admin_password = "SvmAdminPassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_storage_virtual_machine) } {
            return .{ .service_metadata = service_metadata, .action = update_storage_virtual_machine };
        }
    },
    Response: type = struct {
        storage_virtual_machine: ?StorageVirtualMachine = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_virtual_machine = "StorageVirtualMachine",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        StorageVirtualMachineNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const update_volume: struct {
    action_name: []const u8 = "UpdateVolume",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        volume_id: []const u8,
        ontap_configuration: ?struct {
            junction_path: ?[]const u8 = null,
            security_style: ?[]const u8 = null,
            size_in_megabytes: ?i64 = null,
            storage_efficiency_enabled: ?bool = null,
            tiering_policy: ?TieringPolicy = null,
            snapshot_policy: ?[]const u8 = null,
            copy_tags_to_backups: ?bool = null,
            snaplock_configuration: ?struct {
                audit_log_volume: ?bool = null,
                autocommit_period: ?AutocommitPeriod = null,
                privileged_delete: ?[]const u8 = null,
                retention_period: ?SnaplockRetentionPeriod = null,
                volume_append_mode_enabled: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .audit_log_volume = "AuditLogVolume",
                        .autocommit_period = "AutocommitPeriod",
                        .privileged_delete = "PrivilegedDelete",
                        .retention_period = "RetentionPeriod",
                        .volume_append_mode_enabled = "VolumeAppendModeEnabled",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            size_in_bytes: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .junction_path = "JunctionPath",
                    .security_style = "SecurityStyle",
                    .size_in_megabytes = "SizeInMegabytes",
                    .storage_efficiency_enabled = "StorageEfficiencyEnabled",
                    .tiering_policy = "TieringPolicy",
                    .snapshot_policy = "SnapshotPolicy",
                    .copy_tags_to_backups = "CopyTagsToBackups",
                    .snaplock_configuration = "SnaplockConfiguration",
                    .size_in_bytes = "SizeInBytes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        name: ?[]const u8 = null,
        open_zfs_configuration: ?struct {
            storage_capacity_reservation_gib: ?i64 = null,
            storage_capacity_quota_gib: ?i64 = null,
            record_size_kib: ?i64 = null,
            data_compression_type: ?[]const u8 = null,
            nfs_exports: ?[]OpenZFSNfsExport = null,
            user_and_group_quotas: ?[]OpenZFSUserOrGroupQuota = null,
            read_only: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .storage_capacity_reservation_gib = "StorageCapacityReservationGiB",
                    .storage_capacity_quota_gib = "StorageCapacityQuotaGiB",
                    .record_size_kib = "RecordSizeKiB",
                    .data_compression_type = "DataCompressionType",
                    .nfs_exports = "NfsExports",
                    .user_and_group_quotas = "UserAndGroupQuotas",
                    .read_only = "ReadOnly",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .volume_id = "VolumeId",
                .ontap_configuration = "OntapConfiguration",
                .name = "Name",
                .open_zfs_configuration = "OpenZFSConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_volume) } {
            return .{ .service_metadata = service_metadata, .action = update_volume };
        }
    },
    Response: type = struct {
        volume: ?Volume = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume = "Volume",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        MissingVolumeConfiguration,
        VolumeNotFound,
    },
} = .{};

pub const Volume = struct {
    creation_time: ?i64 = null,
    file_system_id: ?[]const u8 = null,
    lifecycle: ?[]const u8 = null,
    name: ?[]const u8 = null,
    ontap_configuration: ?OntapVolumeConfiguration = null,
    resource_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    volume_id: ?[]const u8 = null,
    volume_type: ?[]const u8 = null,
    lifecycle_transition_reason: ?LifecycleTransitionReason = null,
    administrative_actions: ?[]AdministrativeAction = null,
    open_zfs_configuration: ?OpenZFSVolumeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_time = "CreationTime",
            .file_system_id = "FileSystemId",
            .lifecycle = "Lifecycle",
            .name = "Name",
            .ontap_configuration = "OntapConfiguration",
            .resource_arn = "ResourceARN",
            .tags = "Tags",
            .volume_id = "VolumeId",
            .volume_type = "VolumeType",
            .lifecycle_transition_reason = "LifecycleTransitionReason",
            .administrative_actions = "AdministrativeActions",
            .open_zfs_configuration = "OpenZFSConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenZFSVolumeConfiguration = struct {
    parent_volume_id: ?[]const u8 = null,
    volume_path: ?[]const u8 = null,
    storage_capacity_reservation_gib: ?i64 = null,
    storage_capacity_quota_gib: ?i64 = null,
    record_size_kib: ?i64 = null,
    data_compression_type: ?[]const u8 = null,
    copy_tags_to_snapshots: ?bool = null,
    origin_snapshot: ?OpenZFSOriginSnapshotConfiguration = null,
    read_only: ?bool = null,
    nfs_exports: ?[]OpenZFSNfsExport = null,
    user_and_group_quotas: ?[]OpenZFSUserOrGroupQuota = null,
    restore_to_snapshot: ?[]const u8 = null,
    delete_intermediate_snaphots: ?bool = null,
    delete_cloned_volumes: ?bool = null,
    delete_intermediate_data: ?bool = null,
    source_snapshot_arn: ?[]const u8 = null,
    destination_snapshot: ?[]const u8 = null,
    copy_strategy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parent_volume_id = "ParentVolumeId",
            .volume_path = "VolumePath",
            .storage_capacity_reservation_gib = "StorageCapacityReservationGiB",
            .storage_capacity_quota_gib = "StorageCapacityQuotaGiB",
            .record_size_kib = "RecordSizeKiB",
            .data_compression_type = "DataCompressionType",
            .copy_tags_to_snapshots = "CopyTagsToSnapshots",
            .origin_snapshot = "OriginSnapshot",
            .read_only = "ReadOnly",
            .nfs_exports = "NfsExports",
            .user_and_group_quotas = "UserAndGroupQuotas",
            .restore_to_snapshot = "RestoreToSnapshot",
            .delete_intermediate_snaphots = "DeleteIntermediateSnaphots",
            .delete_cloned_volumes = "DeleteClonedVolumes",
            .delete_intermediate_data = "DeleteIntermediateData",
            .source_snapshot_arn = "SourceSnapshotARN",
            .destination_snapshot = "DestinationSnapshot",
            .copy_strategy = "CopyStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenZFSUserOrGroupQuota = struct {
    type: []const u8,
    id: i64,
    storage_capacity_quota_gib: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .id = "Id",
            .storage_capacity_quota_gib = "StorageCapacityQuotaGiB",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenZFSNfsExport = struct {
    client_configurations: []OpenZFSClientConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_configurations = "ClientConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenZFSClientConfiguration = struct {
    clients: []const u8,
    options: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .clients = "Clients",
            .options = "Options",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenZFSOriginSnapshotConfiguration = struct {
    snapshot_arn: ?[]const u8 = null,
    copy_strategy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snapshot_arn = "SnapshotARN",
            .copy_strategy = "CopyStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const AdministrativeAction = struct {
    administrative_action_type: ?[]const u8 = null,
    progress_percent: ?i64 = null,
    request_time: ?i64 = null,
    status: ?[]const u8 = null,
    target_file_system_values: ?FileSystem = null,
    failure_details: ?AdministrativeActionFailureDetails = null,
    target_volume_values: ?Volume = null,
    target_snapshot_values: ?Snapshot = null,
    total_transfer_bytes: ?i64 = null,
    remaining_transfer_bytes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .administrative_action_type = "AdministrativeActionType",
            .progress_percent = "ProgressPercent",
            .request_time = "RequestTime",
            .status = "Status",
            .target_file_system_values = "TargetFileSystemValues",
            .failure_details = "FailureDetails",
            .target_volume_values = "TargetVolumeValues",
            .target_snapshot_values = "TargetSnapshotValues",
            .total_transfer_bytes = "TotalTransferBytes",
            .remaining_transfer_bytes = "RemainingTransferBytes",
        };
        return @field(mappings, field_name);
    }
};

pub const Snapshot = struct {
    resource_arn: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    volume_id: ?[]const u8 = null,
    creation_time: ?i64 = null,
    lifecycle: ?[]const u8 = null,
    lifecycle_transition_reason: ?LifecycleTransitionReason = null,
    tags: ?[]Tag = null,
    administrative_actions: ?[]AdministrativeAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceARN",
            .snapshot_id = "SnapshotId",
            .name = "Name",
            .volume_id = "VolumeId",
            .creation_time = "CreationTime",
            .lifecycle = "Lifecycle",
            .lifecycle_transition_reason = "LifecycleTransitionReason",
            .tags = "Tags",
            .administrative_actions = "AdministrativeActions",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleTransitionReason = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AdministrativeActionFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystem = struct {
    owner_id: ?[]const u8 = null,
    creation_time: ?i64 = null,
    file_system_id: ?[]const u8 = null,
    file_system_type: ?[]const u8 = null,
    lifecycle: ?[]const u8 = null,
    failure_details: ?FileSystemFailureDetails = null,
    storage_capacity: ?i64 = null,
    storage_type: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    network_interface_ids: ?[][]const u8 = null,
    dns_name: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    windows_configuration: ?WindowsFileSystemConfiguration = null,
    lustre_configuration: ?LustreFileSystemConfiguration = null,
    administrative_actions: ?[]AdministrativeAction = null,
    ontap_configuration: ?OntapFileSystemConfiguration = null,
    file_system_type_version: ?[]const u8 = null,
    open_zfs_configuration: ?OpenZFSFileSystemConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .creation_time = "CreationTime",
            .file_system_id = "FileSystemId",
            .file_system_type = "FileSystemType",
            .lifecycle = "Lifecycle",
            .failure_details = "FailureDetails",
            .storage_capacity = "StorageCapacity",
            .storage_type = "StorageType",
            .vpc_id = "VpcId",
            .subnet_ids = "SubnetIds",
            .network_interface_ids = "NetworkInterfaceIds",
            .dns_name = "DNSName",
            .kms_key_id = "KmsKeyId",
            .resource_arn = "ResourceARN",
            .tags = "Tags",
            .windows_configuration = "WindowsConfiguration",
            .lustre_configuration = "LustreConfiguration",
            .administrative_actions = "AdministrativeActions",
            .ontap_configuration = "OntapConfiguration",
            .file_system_type_version = "FileSystemTypeVersion",
            .open_zfs_configuration = "OpenZFSConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenZFSFileSystemConfiguration = struct {
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    copy_tags_to_volumes: ?bool = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    deployment_type: ?[]const u8 = null,
    throughput_capacity: ?i64 = null,
    weekly_maintenance_start_time: ?[]const u8 = null,
    disk_iops_configuration: ?DiskIopsConfiguration = null,
    root_volume_id: ?[]const u8 = null,
    preferred_subnet_id: ?[]const u8 = null,
    endpoint_ip_address_range: ?[]const u8 = null,
    route_table_ids: ?[][]const u8 = null,
    endpoint_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .copy_tags_to_volumes = "CopyTagsToVolumes",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .deployment_type = "DeploymentType",
            .throughput_capacity = "ThroughputCapacity",
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .disk_iops_configuration = "DiskIopsConfiguration",
            .root_volume_id = "RootVolumeId",
            .preferred_subnet_id = "PreferredSubnetId",
            .endpoint_ip_address_range = "EndpointIpAddressRange",
            .route_table_ids = "RouteTableIds",
            .endpoint_ip_address = "EndpointIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const DiskIopsConfiguration = struct {
    mode: ?[]const u8 = null,
    iops: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .iops = "Iops",
        };
        return @field(mappings, field_name);
    }
};

pub const OntapFileSystemConfiguration = struct {
    automatic_backup_retention_days: ?i64 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    deployment_type: ?[]const u8 = null,
    endpoint_ip_address_range: ?[]const u8 = null,
    endpoints: ?FileSystemEndpoints = null,
    disk_iops_configuration: ?DiskIopsConfiguration = null,
    preferred_subnet_id: ?[]const u8 = null,
    route_table_ids: ?[][]const u8 = null,
    throughput_capacity: ?i64 = null,
    weekly_maintenance_start_time: ?[]const u8 = null,
    fsx_admin_password: ?[]const u8 = null,
    ha_pairs: ?i64 = null,
    throughput_capacity_per_ha_pair: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .deployment_type = "DeploymentType",
            .endpoint_ip_address_range = "EndpointIpAddressRange",
            .endpoints = "Endpoints",
            .disk_iops_configuration = "DiskIopsConfiguration",
            .preferred_subnet_id = "PreferredSubnetId",
            .route_table_ids = "RouteTableIds",
            .throughput_capacity = "ThroughputCapacity",
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .fsx_admin_password = "FsxAdminPassword",
            .ha_pairs = "HAPairs",
            .throughput_capacity_per_ha_pair = "ThroughputCapacityPerHAPair",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemEndpoints = struct {
    intercluster: ?FileSystemEndpoint = null,
    management: ?FileSystemEndpoint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .intercluster = "Intercluster",
            .management = "Management",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemEndpoint = struct {
    dns_name: ?[]const u8 = null,
    ip_addresses: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dns_name = "DNSName",
            .ip_addresses = "IpAddresses",
        };
        return @field(mappings, field_name);
    }
};

pub const LustreFileSystemConfiguration = struct {
    weekly_maintenance_start_time: ?[]const u8 = null,
    data_repository_configuration: ?DataRepositoryConfiguration = null,
    deployment_type: ?[]const u8 = null,
    per_unit_storage_throughput: ?i64 = null,
    mount_name: ?[]const u8 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    drive_cache_type: ?[]const u8 = null,
    data_compression_type: ?[]const u8 = null,
    log_configuration: ?LustreLogConfiguration = null,
    root_squash_configuration: ?LustreRootSquashConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .data_repository_configuration = "DataRepositoryConfiguration",
            .deployment_type = "DeploymentType",
            .per_unit_storage_throughput = "PerUnitStorageThroughput",
            .mount_name = "MountName",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .drive_cache_type = "DriveCacheType",
            .data_compression_type = "DataCompressionType",
            .log_configuration = "LogConfiguration",
            .root_squash_configuration = "RootSquashConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LustreRootSquashConfiguration = struct {
    root_squash: ?[]const u8 = null,
    no_squash_nids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .root_squash = "RootSquash",
            .no_squash_nids = "NoSquashNids",
        };
        return @field(mappings, field_name);
    }
};

pub const LustreLogConfiguration = struct {
    level: []const u8,
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .level = "Level",
            .destination = "Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryConfiguration = struct {
    lifecycle: ?[]const u8 = null,
    import_path: ?[]const u8 = null,
    export_path: ?[]const u8 = null,
    imported_file_chunk_size: ?i64 = null,
    auto_import_policy: ?[]const u8 = null,
    failure_details: ?DataRepositoryFailureDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lifecycle = "Lifecycle",
            .import_path = "ImportPath",
            .export_path = "ExportPath",
            .imported_file_chunk_size = "ImportedFileChunkSize",
            .auto_import_policy = "AutoImportPolicy",
            .failure_details = "FailureDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const WindowsFileSystemConfiguration = struct {
    active_directory_id: ?[]const u8 = null,
    self_managed_active_directory_configuration: ?SelfManagedActiveDirectoryAttributes = null,
    deployment_type: ?[]const u8 = null,
    remote_administration_endpoint: ?[]const u8 = null,
    preferred_subnet_id: ?[]const u8 = null,
    preferred_file_server_ip: ?[]const u8 = null,
    throughput_capacity: ?i64 = null,
    maintenance_operations_in_progress: ?[][]const u8 = null,
    weekly_maintenance_start_time: ?[]const u8 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    aliases: ?[]Alias = null,
    audit_log_configuration: ?WindowsAuditLogConfiguration = null,
    disk_iops_configuration: ?DiskIopsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_directory_id = "ActiveDirectoryId",
            .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
            .deployment_type = "DeploymentType",
            .remote_administration_endpoint = "RemoteAdministrationEndpoint",
            .preferred_subnet_id = "PreferredSubnetId",
            .preferred_file_server_ip = "PreferredFileServerIp",
            .throughput_capacity = "ThroughputCapacity",
            .maintenance_operations_in_progress = "MaintenanceOperationsInProgress",
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .aliases = "Aliases",
            .audit_log_configuration = "AuditLogConfiguration",
            .disk_iops_configuration = "DiskIopsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const WindowsAuditLogConfiguration = struct {
    file_access_audit_log_level: []const u8,
    file_share_access_audit_log_level: []const u8,
    audit_log_destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_access_audit_log_level = "FileAccessAuditLogLevel",
            .file_share_access_audit_log_level = "FileShareAccessAuditLogLevel",
            .audit_log_destination = "AuditLogDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const Alias = struct {
    name: ?[]const u8 = null,
    lifecycle: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .lifecycle = "Lifecycle",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfManagedActiveDirectoryAttributes = struct {
    domain_name: ?[]const u8 = null,
    organizational_unit_distinguished_name: ?[]const u8 = null,
    file_system_administrators_group: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    dns_ips: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .organizational_unit_distinguished_name = "OrganizationalUnitDistinguishedName",
            .file_system_administrators_group = "FileSystemAdministratorsGroup",
            .user_name = "UserName",
            .dns_ips = "DnsIps",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const OntapVolumeConfiguration = struct {
    flex_cache_endpoint_type: ?[]const u8 = null,
    junction_path: ?[]const u8 = null,
    security_style: ?[]const u8 = null,
    size_in_megabytes: ?i64 = null,
    storage_efficiency_enabled: ?bool = null,
    storage_virtual_machine_id: ?[]const u8 = null,
    storage_virtual_machine_root: ?bool = null,
    tiering_policy: ?TieringPolicy = null,
    uuid: ?[]const u8 = null,
    ontap_volume_type: ?[]const u8 = null,
    snapshot_policy: ?[]const u8 = null,
    copy_tags_to_backups: ?bool = null,
    snaplock_configuration: ?SnaplockConfiguration = null,
    volume_style: ?[]const u8 = null,
    aggregate_configuration: ?AggregateConfiguration = null,
    size_in_bytes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flex_cache_endpoint_type = "FlexCacheEndpointType",
            .junction_path = "JunctionPath",
            .security_style = "SecurityStyle",
            .size_in_megabytes = "SizeInMegabytes",
            .storage_efficiency_enabled = "StorageEfficiencyEnabled",
            .storage_virtual_machine_id = "StorageVirtualMachineId",
            .storage_virtual_machine_root = "StorageVirtualMachineRoot",
            .tiering_policy = "TieringPolicy",
            .uuid = "UUID",
            .ontap_volume_type = "OntapVolumeType",
            .snapshot_policy = "SnapshotPolicy",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .snaplock_configuration = "SnaplockConfiguration",
            .volume_style = "VolumeStyle",
            .aggregate_configuration = "AggregateConfiguration",
            .size_in_bytes = "SizeInBytes",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregateConfiguration = struct {
    aggregates: ?[][]const u8 = null,
    total_constituents: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aggregates = "Aggregates",
            .total_constituents = "TotalConstituents",
        };
        return @field(mappings, field_name);
    }
};

pub const SnaplockConfiguration = struct {
    audit_log_volume: ?bool = null,
    autocommit_period: ?AutocommitPeriod = null,
    privileged_delete: ?[]const u8 = null,
    retention_period: ?SnaplockRetentionPeriod = null,
    snaplock_type: ?[]const u8 = null,
    volume_append_mode_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit_log_volume = "AuditLogVolume",
            .autocommit_period = "AutocommitPeriod",
            .privileged_delete = "PrivilegedDelete",
            .retention_period = "RetentionPeriod",
            .snaplock_type = "SnaplockType",
            .volume_append_mode_enabled = "VolumeAppendModeEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SnaplockRetentionPeriod = struct {
    default_retention: RetentionPeriod,
    minimum_retention: RetentionPeriod,
    maximum_retention: RetentionPeriod,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_retention = "DefaultRetention",
            .minimum_retention = "MinimumRetention",
            .maximum_retention = "MaximumRetention",
        };
        return @field(mappings, field_name);
    }
};

pub const RetentionPeriod = struct {
    type: []const u8,
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AutocommitPeriod = struct {
    type: []const u8,
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TieringPolicy = struct {
    cooling_period: ?i64 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cooling_period = "CoolingPeriod",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageVirtualMachine = struct {
    active_directory_configuration: ?SvmActiveDirectoryConfiguration = null,
    creation_time: ?i64 = null,
    endpoints: ?SvmEndpoints = null,
    file_system_id: ?[]const u8 = null,
    lifecycle: ?[]const u8 = null,
    name: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    storage_virtual_machine_id: ?[]const u8 = null,
    subtype: ?[]const u8 = null,
    uuid: ?[]const u8 = null,
    tags: ?[]Tag = null,
    lifecycle_transition_reason: ?LifecycleTransitionReason = null,
    root_volume_security_style: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_directory_configuration = "ActiveDirectoryConfiguration",
            .creation_time = "CreationTime",
            .endpoints = "Endpoints",
            .file_system_id = "FileSystemId",
            .lifecycle = "Lifecycle",
            .name = "Name",
            .resource_arn = "ResourceARN",
            .storage_virtual_machine_id = "StorageVirtualMachineId",
            .subtype = "Subtype",
            .uuid = "UUID",
            .tags = "Tags",
            .lifecycle_transition_reason = "LifecycleTransitionReason",
            .root_volume_security_style = "RootVolumeSecurityStyle",
        };
        return @field(mappings, field_name);
    }
};

pub const SvmEndpoints = struct {
    iscsi: ?SvmEndpoint = null,
    management: ?SvmEndpoint = null,
    nfs: ?SvmEndpoint = null,
    smb: ?SvmEndpoint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iscsi = "Iscsi",
            .management = "Management",
            .nfs = "Nfs",
            .smb = "Smb",
        };
        return @field(mappings, field_name);
    }
};

pub const SvmEndpoint = struct {
    dns_name: ?[]const u8 = null,
    ip_addresses: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dns_name = "DNSName",
            .ip_addresses = "IpAddresses",
        };
        return @field(mappings, field_name);
    }
};

pub const SvmActiveDirectoryConfiguration = struct {
    net_bios_name: ?[]const u8 = null,
    self_managed_active_directory_configuration: ?SelfManagedActiveDirectoryAttributes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .net_bios_name = "NetBiosName",
            .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfManagedActiveDirectoryConfigurationUpdates = struct {
    user_name: ?[]const u8 = null,
    password: ?[]const u8 = null,
    dns_ips: ?[][]const u8 = null,
    domain_name: ?[]const u8 = null,
    organizational_unit_distinguished_name: ?[]const u8 = null,
    file_system_administrators_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_name = "UserName",
            .password = "Password",
            .dns_ips = "DnsIps",
            .domain_name = "DomainName",
            .organizational_unit_distinguished_name = "OrganizationalUnitDistinguishedName",
            .file_system_administrators_group = "FileSystemAdministratorsGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const LustreLogCreateConfiguration = struct {
    level: []const u8,
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .level = "Level",
            .destination = "Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const WindowsAuditLogCreateConfiguration = struct {
    file_access_audit_log_level: []const u8,
    file_share_access_audit_log_level: []const u8,
    audit_log_destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_access_audit_log_level = "FileAccessAuditLogLevel",
            .file_share_access_audit_log_level = "FileShareAccessAuditLogLevel",
            .audit_log_destination = "AuditLogDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const FileCache = struct {
    owner_id: ?[]const u8 = null,
    creation_time: ?i64 = null,
    file_cache_id: ?[]const u8 = null,
    file_cache_type: ?[]const u8 = null,
    file_cache_type_version: ?[]const u8 = null,
    lifecycle: ?[]const u8 = null,
    failure_details: ?FileCacheFailureDetails = null,
    storage_capacity: ?i64 = null,
    vpc_id: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    network_interface_ids: ?[][]const u8 = null,
    dns_name: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    lustre_configuration: ?FileCacheLustreConfiguration = null,
    data_repository_association_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .creation_time = "CreationTime",
            .file_cache_id = "FileCacheId",
            .file_cache_type = "FileCacheType",
            .file_cache_type_version = "FileCacheTypeVersion",
            .lifecycle = "Lifecycle",
            .failure_details = "FailureDetails",
            .storage_capacity = "StorageCapacity",
            .vpc_id = "VpcId",
            .subnet_ids = "SubnetIds",
            .network_interface_ids = "NetworkInterfaceIds",
            .dns_name = "DNSName",
            .kms_key_id = "KmsKeyId",
            .resource_arn = "ResourceARN",
            .lustre_configuration = "LustreConfiguration",
            .data_repository_association_ids = "DataRepositoryAssociationIds",
        };
        return @field(mappings, field_name);
    }
};

pub const FileCacheLustreConfiguration = struct {
    per_unit_storage_throughput: ?i64 = null,
    deployment_type: ?[]const u8 = null,
    mount_name: ?[]const u8 = null,
    weekly_maintenance_start_time: ?[]const u8 = null,
    metadata_configuration: ?FileCacheLustreMetadataConfiguration = null,
    log_configuration: ?LustreLogConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .per_unit_storage_throughput = "PerUnitStorageThroughput",
            .deployment_type = "DeploymentType",
            .mount_name = "MountName",
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .metadata_configuration = "MetadataConfiguration",
            .log_configuration = "LogConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const FileCacheLustreMetadataConfiguration = struct {
    storage_capacity: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_capacity = "StorageCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const FileCacheFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryAssociation = struct {
    association_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    file_system_id: ?[]const u8 = null,
    lifecycle: ?[]const u8 = null,
    failure_details: ?DataRepositoryFailureDetails = null,
    file_system_path: ?[]const u8 = null,
    data_repository_path: ?[]const u8 = null,
    batch_import_meta_data_on_create: ?bool = null,
    imported_file_chunk_size: ?i64 = null,
    s3: ?S3DataRepositoryConfiguration = null,
    tags: ?[]Tag = null,
    creation_time: ?i64 = null,
    file_cache_id: ?[]const u8 = null,
    file_cache_path: ?[]const u8 = null,
    data_repository_subdirectories: ?[][]const u8 = null,
    nfs: ?NFSDataRepositoryConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "AssociationId",
            .resource_arn = "ResourceARN",
            .file_system_id = "FileSystemId",
            .lifecycle = "Lifecycle",
            .failure_details = "FailureDetails",
            .file_system_path = "FileSystemPath",
            .data_repository_path = "DataRepositoryPath",
            .batch_import_meta_data_on_create = "BatchImportMetaDataOnCreate",
            .imported_file_chunk_size = "ImportedFileChunkSize",
            .s3 = "S3",
            .tags = "Tags",
            .creation_time = "CreationTime",
            .file_cache_id = "FileCacheId",
            .file_cache_path = "FileCachePath",
            .data_repository_subdirectories = "DataRepositorySubdirectories",
            .nfs = "NFS",
        };
        return @field(mappings, field_name);
    }
};

pub const NFSDataRepositoryConfiguration = struct {
    version: []const u8,
    dns_ips: ?[][]const u8 = null,
    auto_export_policy: ?AutoExportPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
            .dns_ips = "DnsIps",
            .auto_export_policy = "AutoExportPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoExportPolicy = struct {
    events: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .events = "Events",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DataRepositoryConfiguration = struct {
    auto_import_policy: ?AutoImportPolicy = null,
    auto_export_policy: ?AutoExportPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_import_policy = "AutoImportPolicy",
            .auto_export_policy = "AutoExportPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoImportPolicy = struct {
    events: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .events = "Events",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryTask = struct {
    task_id: []const u8,
    lifecycle: []const u8,
    type: []const u8,
    creation_time: i64,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    resource_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    file_system_id: ?[]const u8 = null,
    paths: ?[][]const u8 = null,
    failure_details: ?DataRepositoryTaskFailureDetails = null,
    status: ?DataRepositoryTaskStatus = null,
    report: ?CompletionReport = null,
    capacity_to_release: ?i64 = null,
    file_cache_id: ?[]const u8 = null,
    release_configuration: ?ReleaseConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_id = "TaskId",
            .lifecycle = "Lifecycle",
            .type = "Type",
            .creation_time = "CreationTime",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .resource_arn = "ResourceARN",
            .tags = "Tags",
            .file_system_id = "FileSystemId",
            .paths = "Paths",
            .failure_details = "FailureDetails",
            .status = "Status",
            .report = "Report",
            .capacity_to_release = "CapacityToRelease",
            .file_cache_id = "FileCacheId",
            .release_configuration = "ReleaseConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ReleaseConfiguration = struct {
    duration_since_last_access: ?DurationSinceLastAccess = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration_since_last_access = "DurationSinceLastAccess",
        };
        return @field(mappings, field_name);
    }
};

pub const DurationSinceLastAccess = struct {
    unit: ?[]const u8 = null,
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unit = "Unit",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const CompletionReport = struct {
    enabled: bool,
    path: ?[]const u8 = null,
    format: ?[]const u8 = null,
    scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .path = "Path",
            .format = "Format",
            .scope = "Scope",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryTaskStatus = struct {
    total_count: ?i64 = null,
    succeeded_count: ?i64 = null,
    failed_count: ?i64 = null,
    last_updated_time: ?i64 = null,
    released_capacity: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_count = "TotalCount",
            .succeeded_count = "SucceededCount",
            .failed_count = "FailedCount",
            .last_updated_time = "LastUpdatedTime",
            .released_capacity = "ReleasedCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryTaskFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const Backup = struct {
    backup_id: []const u8,
    lifecycle: []const u8,
    failure_details: ?BackupFailureDetails = null,
    type: []const u8,
    progress_percent: ?i64 = null,
    creation_time: i64,
    kms_key_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    file_system: FileSystem,
    directory_information: ?ActiveDirectoryBackupAttributes = null,
    owner_id: ?[]const u8 = null,
    source_backup_id: ?[]const u8 = null,
    source_backup_region: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    volume: ?Volume = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_id = "BackupId",
            .lifecycle = "Lifecycle",
            .failure_details = "FailureDetails",
            .type = "Type",
            .progress_percent = "ProgressPercent",
            .creation_time = "CreationTime",
            .kms_key_id = "KmsKeyId",
            .resource_arn = "ResourceARN",
            .tags = "Tags",
            .file_system = "FileSystem",
            .directory_information = "DirectoryInformation",
            .owner_id = "OwnerId",
            .source_backup_id = "SourceBackupId",
            .source_backup_region = "SourceBackupRegion",
            .resource_type = "ResourceType",
            .volume = "Volume",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveDirectoryBackupAttributes = struct {
    domain_name: ?[]const u8 = null,
    active_directory_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .active_directory_id = "ActiveDirectoryId",
            .resource_arn = "ResourceARN",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateOntapVolumeConfiguration = struct {
    junction_path: ?[]const u8 = null,
    security_style: ?[]const u8 = null,
    size_in_megabytes: ?i64 = null,
    storage_efficiency_enabled: ?bool = null,
    storage_virtual_machine_id: []const u8,
    tiering_policy: ?TieringPolicy = null,
    ontap_volume_type: ?[]const u8 = null,
    snapshot_policy: ?[]const u8 = null,
    copy_tags_to_backups: ?bool = null,
    snaplock_configuration: ?CreateSnaplockConfiguration = null,
    volume_style: ?[]const u8 = null,
    aggregate_configuration: ?CreateAggregateConfiguration = null,
    size_in_bytes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .junction_path = "JunctionPath",
            .security_style = "SecurityStyle",
            .size_in_megabytes = "SizeInMegabytes",
            .storage_efficiency_enabled = "StorageEfficiencyEnabled",
            .storage_virtual_machine_id = "StorageVirtualMachineId",
            .tiering_policy = "TieringPolicy",
            .ontap_volume_type = "OntapVolumeType",
            .snapshot_policy = "SnapshotPolicy",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .snaplock_configuration = "SnaplockConfiguration",
            .volume_style = "VolumeStyle",
            .aggregate_configuration = "AggregateConfiguration",
            .size_in_bytes = "SizeInBytes",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateAggregateConfiguration = struct {
    aggregates: ?[][]const u8 = null,
    constituents_per_aggregate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aggregates = "Aggregates",
            .constituents_per_aggregate = "ConstituentsPerAggregate",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateSnaplockConfiguration = struct {
    audit_log_volume: ?bool = null,
    autocommit_period: ?AutocommitPeriod = null,
    privileged_delete: ?[]const u8 = null,
    retention_period: ?SnaplockRetentionPeriod = null,
    snaplock_type: []const u8,
    volume_append_mode_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit_log_volume = "AuditLogVolume",
            .autocommit_period = "AutocommitPeriod",
            .privileged_delete = "PrivilegedDelete",
            .retention_period = "RetentionPeriod",
            .snaplock_type = "SnaplockType",
            .volume_append_mode_enabled = "VolumeAppendModeEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfManagedActiveDirectoryConfiguration = struct {
    domain_name: []const u8,
    organizational_unit_distinguished_name: ?[]const u8 = null,
    file_system_administrators_group: ?[]const u8 = null,
    user_name: []const u8,
    password: []const u8,
    dns_ips: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .organizational_unit_distinguished_name = "OrganizationalUnitDistinguishedName",
            .file_system_administrators_group = "FileSystemAdministratorsGroup",
            .user_name = "UserName",
            .password = "Password",
            .dns_ips = "DnsIps",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateFileSystemOpenZFSConfiguration = struct {
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    copy_tags_to_volumes: ?bool = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    deployment_type: []const u8,
    throughput_capacity: i64,
    weekly_maintenance_start_time: ?[]const u8 = null,
    disk_iops_configuration: ?DiskIopsConfiguration = null,
    root_volume_configuration: ?OpenZFSCreateRootVolumeConfiguration = null,
    preferred_subnet_id: ?[]const u8 = null,
    endpoint_ip_address_range: ?[]const u8 = null,
    route_table_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .copy_tags_to_volumes = "CopyTagsToVolumes",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .deployment_type = "DeploymentType",
            .throughput_capacity = "ThroughputCapacity",
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .disk_iops_configuration = "DiskIopsConfiguration",
            .root_volume_configuration = "RootVolumeConfiguration",
            .preferred_subnet_id = "PreferredSubnetId",
            .endpoint_ip_address_range = "EndpointIpAddressRange",
            .route_table_ids = "RouteTableIds",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenZFSCreateRootVolumeConfiguration = struct {
    record_size_kib: ?i64 = null,
    data_compression_type: ?[]const u8 = null,
    nfs_exports: ?[]OpenZFSNfsExport = null,
    user_and_group_quotas: ?[]OpenZFSUserOrGroupQuota = null,
    copy_tags_to_snapshots: ?bool = null,
    read_only: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .record_size_kib = "RecordSizeKiB",
            .data_compression_type = "DataCompressionType",
            .nfs_exports = "NfsExports",
            .user_and_group_quotas = "UserAndGroupQuotas",
            .copy_tags_to_snapshots = "CopyTagsToSnapshots",
            .read_only = "ReadOnly",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateFileSystemLustreConfiguration = struct {
    weekly_maintenance_start_time: ?[]const u8 = null,
    import_path: ?[]const u8 = null,
    export_path: ?[]const u8 = null,
    imported_file_chunk_size: ?i64 = null,
    deployment_type: ?[]const u8 = null,
    auto_import_policy: ?[]const u8 = null,
    per_unit_storage_throughput: ?i64 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    drive_cache_type: ?[]const u8 = null,
    data_compression_type: ?[]const u8 = null,
    log_configuration: ?LustreLogCreateConfiguration = null,
    root_squash_configuration: ?LustreRootSquashConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .import_path = "ImportPath",
            .export_path = "ExportPath",
            .imported_file_chunk_size = "ImportedFileChunkSize",
            .deployment_type = "DeploymentType",
            .auto_import_policy = "AutoImportPolicy",
            .per_unit_storage_throughput = "PerUnitStorageThroughput",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .drive_cache_type = "DriveCacheType",
            .data_compression_type = "DataCompressionType",
            .log_configuration = "LogConfiguration",
            .root_squash_configuration = "RootSquashConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateFileSystemWindowsConfiguration = struct {
    active_directory_id: ?[]const u8 = null,
    self_managed_active_directory_configuration: ?SelfManagedActiveDirectoryConfiguration = null,
    deployment_type: ?[]const u8 = null,
    preferred_subnet_id: ?[]const u8 = null,
    throughput_capacity: i64,
    weekly_maintenance_start_time: ?[]const u8 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    aliases: ?[][]const u8 = null,
    audit_log_configuration: ?WindowsAuditLogCreateConfiguration = null,
    disk_iops_configuration: ?DiskIopsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_directory_id = "ActiveDirectoryId",
            .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
            .deployment_type = "DeploymentType",
            .preferred_subnet_id = "PreferredSubnetId",
            .throughput_capacity = "ThroughputCapacity",
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .aliases = "Aliases",
            .audit_log_configuration = "AuditLogConfiguration",
            .disk_iops_configuration = "DiskIopsConfiguration",
        };
        return @field(mappings, field_name);
    }
};
