const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-10-01";
pub const sdk_id: []const u8 = "GameLift";
pub const arn_namespace: ?[]const u8 = "gamelift";
pub const endpoint_prefix: []const u8 = "gamelift";
pub const sigv4_name: []const u8 = "gamelift";
pub const name: []const u8 = "GameLift";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-10-01",
    sdk_id: []const u8 = "GameLift",
    arn_namespace: ?[]const u8 = "gamelift",
    endpoint_prefix: []const u8 = "gamelift",
    sigv4_name: []const u8 = "gamelift",
    name: []const u8 = "GameLift",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const accept_match: struct {
    action_name: []const u8 = "AcceptMatch",
    Request: type = struct {
        ticket_id: []const u8,
        player_ids: [][]const u8,
        acceptance_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ticket_id = "TicketId",
                .player_ids = "PlayerIds",
                .acceptance_type = "AcceptanceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_match) } {
            return .{ .service_metadata = service_metadata, .action = accept_match };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        UnsupportedRegion,
    },
} = .{};
pub const claim_game_server: struct {
    action_name: []const u8 = "ClaimGameServer",
    Request: type = struct {
        game_server_group_name: []const u8,
        game_server_id: ?[]const u8 = null,
        game_server_data: ?[]const u8 = null,
        filter_option: ?struct {
            instance_statuses: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_statuses = "InstanceStatuses",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .game_server_id = "GameServerId",
                .game_server_data = "GameServerData",
                .filter_option = "FilterOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(claim_game_server) } {
            return .{ .service_metadata = service_metadata, .action = claim_game_server };
        }
    },
    Response: type = struct {
        game_server: ?GameServer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server = "GameServer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        NotFound,
        OutOfCapacity,
        Unauthorized,
    },
} = .{};
pub const create_alias: struct {
    action_name: []const u8 = "CreateAlias",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        routing_strategy: RoutingStrategy,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .routing_strategy = "RoutingStrategy",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_alias };
        }
    },
    Response: type = struct {
        alias: ?Alias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        LimitExceeded,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const create_build: struct {
    action_name: []const u8 = "CreateBuild",
    Request: type = struct {
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        storage_location: ?S3Location = null,
        operating_system: ?[]const u8 = null,
        tags: ?[]Tag = null,
        server_sdk_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .version = "Version",
                .storage_location = "StorageLocation",
                .operating_system = "OperatingSystem",
                .tags = "Tags",
                .server_sdk_version = "ServerSdkVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_build) } {
            return .{ .service_metadata = service_metadata, .action = create_build };
        }
    },
    Response: type = struct {
        build: ?Build = null,
        upload_credentials: ?AwsCredentials = null,
        storage_location: ?S3Location = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .build = "Build",
                .upload_credentials = "UploadCredentials",
                .storage_location = "StorageLocation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const create_fleet: struct {
    action_name: []const u8 = "CreateFleet",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        build_id: ?[]const u8 = null,
        script_id: ?[]const u8 = null,
        server_launch_path: ?[]const u8 = null,
        server_launch_parameters: ?[]const u8 = null,
        log_paths: ?[][]const u8 = null,
        ec2_instance_type: ?[]const u8 = null,
        ec2_inbound_permissions: ?[]IpPermission = null,
        new_game_session_protection_policy: ?[]const u8 = null,
        runtime_configuration: ?RuntimeConfiguration = null,
        resource_creation_limit_policy: ?ResourceCreationLimitPolicy = null,
        metric_groups: ?[][]const u8 = null,
        peer_vpc_aws_account_id: ?[]const u8 = null,
        peer_vpc_id: ?[]const u8 = null,
        fleet_type: ?[]const u8 = null,
        instance_role_arn: ?[]const u8 = null,
        certificate_configuration: ?CertificateConfiguration = null,
        locations: ?[]LocationConfiguration = null,
        tags: ?[]Tag = null,
        compute_type: ?[]const u8 = null,
        anywhere_configuration: ?AnywhereConfiguration = null,
        instance_role_credentials_provider: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .build_id = "BuildId",
                .script_id = "ScriptId",
                .server_launch_path = "ServerLaunchPath",
                .server_launch_parameters = "ServerLaunchParameters",
                .log_paths = "LogPaths",
                .ec2_instance_type = "EC2InstanceType",
                .ec2_inbound_permissions = "EC2InboundPermissions",
                .new_game_session_protection_policy = "NewGameSessionProtectionPolicy",
                .runtime_configuration = "RuntimeConfiguration",
                .resource_creation_limit_policy = "ResourceCreationLimitPolicy",
                .metric_groups = "MetricGroups",
                .peer_vpc_aws_account_id = "PeerVpcAwsAccountId",
                .peer_vpc_id = "PeerVpcId",
                .fleet_type = "FleetType",
                .instance_role_arn = "InstanceRoleArn",
                .certificate_configuration = "CertificateConfiguration",
                .locations = "Locations",
                .tags = "Tags",
                .compute_type = "ComputeType",
                .anywhere_configuration = "AnywhereConfiguration",
                .instance_role_credentials_provider = "InstanceRoleCredentialsProvider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fleet) } {
            return .{ .service_metadata = service_metadata, .action = create_fleet };
        }
    },
    Response: type = struct {
        fleet_attributes: ?FleetAttributes = null,
        location_states: ?[]LocationState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_attributes = "FleetAttributes",
                .location_states = "LocationStates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        LimitExceeded,
        NotFound,
        TaggingFailed,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const create_fleet_locations: struct {
    action_name: []const u8 = "CreateFleetLocations",
    Request: type = struct {
        fleet_id: []const u8,
        locations: []LocationConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .locations = "Locations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fleet_locations) } {
            return .{ .service_metadata = service_metadata, .action = create_fleet_locations };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,
        location_states: ?[]LocationState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
                .location_states = "LocationStates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidFleetStatus,
        InvalidRequest,
        LimitExceeded,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const create_game_server_group: struct {
    action_name: []const u8 = "CreateGameServerGroup",
    Request: type = struct {
        game_server_group_name: []const u8,
        role_arn: []const u8,
        min_size: i64,
        max_size: i64,
        launch_template: struct {
            launch_template_id: ?[]const u8 = null,
            launch_template_name: ?[]const u8 = null,
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .launch_template_id = "LaunchTemplateId",
                    .launch_template_name = "LaunchTemplateName",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        },
        instance_definitions: []InstanceDefinition,
        auto_scaling_policy: ?struct {
            estimated_instance_warmup: ?i64 = null,
            target_tracking_configuration: struct {
                target_value: f64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .target_value = "TargetValue",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .estimated_instance_warmup = "EstimatedInstanceWarmup",
                    .target_tracking_configuration = "TargetTrackingConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        balancing_strategy: ?[]const u8 = null,
        game_server_protection_policy: ?[]const u8 = null,
        vpc_subnets: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .role_arn = "RoleArn",
                .min_size = "MinSize",
                .max_size = "MaxSize",
                .launch_template = "LaunchTemplate",
                .instance_definitions = "InstanceDefinitions",
                .auto_scaling_policy = "AutoScalingPolicy",
                .balancing_strategy = "BalancingStrategy",
                .game_server_protection_policy = "GameServerProtectionPolicy",
                .vpc_subnets = "VpcSubnets",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_game_server_group) } {
            return .{ .service_metadata = service_metadata, .action = create_game_server_group };
        }
    },
    Response: type = struct {
        game_server_group: ?GameServerGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group = "GameServerGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const create_game_session: struct {
    action_name: []const u8 = "CreateGameSession",
    Request: type = struct {
        fleet_id: ?[]const u8 = null,
        alias_id: ?[]const u8 = null,
        maximum_player_session_count: i64,
        name: ?[]const u8 = null,
        game_properties: ?[]GameProperty = null,
        creator_id: ?[]const u8 = null,
        game_session_id: ?[]const u8 = null,
        idempotency_token: ?[]const u8 = null,
        game_session_data: ?[]const u8 = null,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .alias_id = "AliasId",
                .maximum_player_session_count = "MaximumPlayerSessionCount",
                .name = "Name",
                .game_properties = "GameProperties",
                .creator_id = "CreatorId",
                .game_session_id = "GameSessionId",
                .idempotency_token = "IdempotencyToken",
                .game_session_data = "GameSessionData",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_game_session) } {
            return .{ .service_metadata = service_metadata, .action = create_game_session };
        }
    },
    Response: type = struct {
        game_session: ?GameSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session = "GameSession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        FleetCapacityExceeded,
        IdempotentParameterMismatch,
        InternalService,
        InvalidFleetStatus,
        InvalidRequest,
        LimitExceeded,
        NotFound,
        TerminalRoutingStrategy,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const create_game_session_queue: struct {
    action_name: []const u8 = "CreateGameSessionQueue",
    Request: type = struct {
        name: []const u8,
        timeout_in_seconds: ?i64 = null,
        player_latency_policies: ?[]PlayerLatencyPolicy = null,
        destinations: ?[]GameSessionQueueDestination = null,
        filter_configuration: ?FilterConfiguration = null,
        priority_configuration: ?PriorityConfiguration = null,
        custom_event_data: ?[]const u8 = null,
        notification_target: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .timeout_in_seconds = "TimeoutInSeconds",
                .player_latency_policies = "PlayerLatencyPolicies",
                .destinations = "Destinations",
                .filter_configuration = "FilterConfiguration",
                .priority_configuration = "PriorityConfiguration",
                .custom_event_data = "CustomEventData",
                .notification_target = "NotificationTarget",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_game_session_queue) } {
            return .{ .service_metadata = service_metadata, .action = create_game_session_queue };
        }
    },
    Response: type = struct {
        game_session_queue: ?GameSessionQueue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_queue = "GameSessionQueue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        LimitExceeded,
        NotFound,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const create_location: struct {
    action_name: []const u8 = "CreateLocation",
    Request: type = struct {
        location_name: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_name = "LocationName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location) } {
            return .{ .service_metadata = service_metadata, .action = create_location };
        }
    },
    Response: type = struct {
        location: ?LocationModel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        LimitExceeded,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const create_matchmaking_configuration: struct {
    action_name: []const u8 = "CreateMatchmakingConfiguration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        game_session_queue_arns: ?[][]const u8 = null,
        request_timeout_seconds: i64,
        acceptance_timeout_seconds: ?i64 = null,
        acceptance_required: bool,
        rule_set_name: []const u8,
        notification_target: ?[]const u8 = null,
        additional_player_count: ?i64 = null,
        custom_event_data: ?[]const u8 = null,
        game_properties: ?[]GameProperty = null,
        game_session_data: ?[]const u8 = null,
        backfill_mode: ?[]const u8 = null,
        flex_match_mode: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .game_session_queue_arns = "GameSessionQueueArns",
                .request_timeout_seconds = "RequestTimeoutSeconds",
                .acceptance_timeout_seconds = "AcceptanceTimeoutSeconds",
                .acceptance_required = "AcceptanceRequired",
                .rule_set_name = "RuleSetName",
                .notification_target = "NotificationTarget",
                .additional_player_count = "AdditionalPlayerCount",
                .custom_event_data = "CustomEventData",
                .game_properties = "GameProperties",
                .game_session_data = "GameSessionData",
                .backfill_mode = "BackfillMode",
                .flex_match_mode = "FlexMatchMode",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_matchmaking_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_matchmaking_configuration };
        }
    },
    Response: type = struct {
        configuration: ?MatchmakingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        LimitExceeded,
        NotFound,
        TaggingFailed,
        UnsupportedRegion,
    },
} = .{};
pub const create_matchmaking_rule_set: struct {
    action_name: []const u8 = "CreateMatchmakingRuleSet",
    Request: type = struct {
        name: []const u8,
        rule_set_body: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .rule_set_body = "RuleSetBody",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_matchmaking_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = create_matchmaking_rule_set };
        }
    },
    Response: type = struct {
        rule_set: MatchmakingRuleSet,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set = "RuleSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        LimitExceeded,
        TaggingFailed,
        UnsupportedRegion,
    },
} = .{};
pub const create_player_session: struct {
    action_name: []const u8 = "CreatePlayerSession",
    Request: type = struct {
        game_session_id: []const u8,
        player_id: []const u8,
        player_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_id = "GameSessionId",
                .player_id = "PlayerId",
                .player_data = "PlayerData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_player_session) } {
            return .{ .service_metadata = service_metadata, .action = create_player_session };
        }
    },
    Response: type = struct {
        player_session: ?PlayerSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .player_session = "PlayerSession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GameSessionFull,
        InternalService,
        InvalidGameSessionStatus,
        InvalidRequest,
        NotFound,
        TerminalRoutingStrategy,
        Unauthorized,
    },
} = .{};
pub const create_player_sessions: struct {
    action_name: []const u8 = "CreatePlayerSessions",
    Request: type = struct {
        game_session_id: []const u8,
        player_ids: [][]const u8,
        player_data_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_id = "GameSessionId",
                .player_ids = "PlayerIds",
                .player_data_map = "PlayerDataMap",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "player_data_map", field_name))
                return try serializeMap(self.player_data_map, self.fieldNameFor("player_data_map"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_player_sessions) } {
            return .{ .service_metadata = service_metadata, .action = create_player_sessions };
        }
    },
    Response: type = struct {
        player_sessions: ?[]PlayerSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .player_sessions = "PlayerSessions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GameSessionFull,
        InternalService,
        InvalidGameSessionStatus,
        InvalidRequest,
        NotFound,
        TerminalRoutingStrategy,
        Unauthorized,
    },
} = .{};
pub const create_script: struct {
    action_name: []const u8 = "CreateScript",
    Request: type = struct {
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        storage_location: ?S3Location = null,
        zip_file: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .version = "Version",
                .storage_location = "StorageLocation",
                .zip_file = "ZipFile",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_script) } {
            return .{ .service_metadata = service_metadata, .action = create_script };
        }
    },
    Response: type = struct {
        script: ?Script = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .script = "Script",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const create_vpc_peering_authorization: struct {
    action_name: []const u8 = "CreateVpcPeeringAuthorization",
    Request: type = struct {
        game_lift_aws_account_id: []const u8,
        peer_vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_lift_aws_account_id = "GameLiftAwsAccountId",
                .peer_vpc_id = "PeerVpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_peering_authorization) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_peering_authorization };
        }
    },
    Response: type = struct {
        vpc_peering_authorization: ?VpcPeeringAuthorization = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_peering_authorization = "VpcPeeringAuthorization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_vpc_peering_connection: struct {
    action_name: []const u8 = "CreateVpcPeeringConnection",
    Request: type = struct {
        fleet_id: []const u8,
        peer_vpc_aws_account_id: []const u8,
        peer_vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .peer_vpc_aws_account_id = "PeerVpcAwsAccountId",
                .peer_vpc_id = "PeerVpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_peering_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_peering_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_alias: struct {
    action_name: []const u8 = "DeleteAlias",
    Request: type = struct {
        alias_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_alias };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const delete_build: struct {
    action_name: []const u8 = "DeleteBuild",
    Request: type = struct {
        build_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .build_id = "BuildId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_build) } {
            return .{ .service_metadata = service_metadata, .action = delete_build };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const delete_fleet: struct {
    action_name: []const u8 = "DeleteFleet",
    Request: type = struct {
        fleet_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleet) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleet };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidFleetStatus,
        InvalidRequest,
        NotFound,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const delete_fleet_locations: struct {
    action_name: []const u8 = "DeleteFleetLocations",
    Request: type = struct {
        fleet_id: []const u8,
        locations: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .locations = "Locations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleet_locations) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleet_locations };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,
        location_states: ?[]LocationState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
                .location_states = "LocationStates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const delete_game_server_group: struct {
    action_name: []const u8 = "DeleteGameServerGroup",
    Request: type = struct {
        game_server_group_name: []const u8,
        delete_option: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .delete_option = "DeleteOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_game_server_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_game_server_group };
        }
    },
    Response: type = struct {
        game_server_group: ?GameServerGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group = "GameServerGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_game_session_queue: struct {
    action_name: []const u8 = "DeleteGameSessionQueue",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_game_session_queue) } {
            return .{ .service_metadata = service_metadata, .action = delete_game_session_queue };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const delete_location: struct {
    action_name: []const u8 = "DeleteLocation",
    Request: type = struct {
        location_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_name = "LocationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_location) } {
            return .{ .service_metadata = service_metadata, .action = delete_location };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_matchmaking_configuration: struct {
    action_name: []const u8 = "DeleteMatchmakingConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_matchmaking_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_matchmaking_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
        UnsupportedRegion,
    },
} = .{};
pub const delete_matchmaking_rule_set: struct {
    action_name: []const u8 = "DeleteMatchmakingRuleSet",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_matchmaking_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_matchmaking_rule_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
        UnsupportedRegion,
    },
} = .{};
pub const delete_scaling_policy: struct {
    action_name: []const u8 = "DeleteScalingPolicy",
    Request: type = struct {
        name: []const u8,
        fleet_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .fleet_id = "FleetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_scaling_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_script: struct {
    action_name: []const u8 = "DeleteScript",
    Request: type = struct {
        script_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .script_id = "ScriptId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_script) } {
            return .{ .service_metadata = service_metadata, .action = delete_script };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
        Unauthorized,
    },
} = .{};
pub const delete_vpc_peering_authorization: struct {
    action_name: []const u8 = "DeleteVpcPeeringAuthorization",
    Request: type = struct {
        game_lift_aws_account_id: []const u8,
        peer_vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_lift_aws_account_id = "GameLiftAwsAccountId",
                .peer_vpc_id = "PeerVpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_peering_authorization) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_peering_authorization };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_vpc_peering_connection: struct {
    action_name: []const u8 = "DeleteVpcPeeringConnection",
    Request: type = struct {
        fleet_id: []const u8,
        vpc_peering_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .vpc_peering_connection_id = "VpcPeeringConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_peering_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_peering_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const deregister_compute: struct {
    action_name: []const u8 = "DeregisterCompute",
    Request: type = struct {
        fleet_id: []const u8,
        compute_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .compute_name = "ComputeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_compute) } {
            return .{ .service_metadata = service_metadata, .action = deregister_compute };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const deregister_game_server: struct {
    action_name: []const u8 = "DeregisterGameServer",
    Request: type = struct {
        game_server_group_name: []const u8,
        game_server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .game_server_id = "GameServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_game_server) } {
            return .{ .service_metadata = service_metadata, .action = deregister_game_server };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_alias: struct {
    action_name: []const u8 = "DescribeAlias",
    Request: type = struct {
        alias_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_alias) } {
            return .{ .service_metadata = service_metadata, .action = describe_alias };
        }
    },
    Response: type = struct {
        alias: ?Alias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_build: struct {
    action_name: []const u8 = "DescribeBuild",
    Request: type = struct {
        build_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .build_id = "BuildId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_build) } {
            return .{ .service_metadata = service_metadata, .action = describe_build };
        }
    },
    Response: type = struct {
        build: ?Build = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .build = "Build",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_compute: struct {
    action_name: []const u8 = "DescribeCompute",
    Request: type = struct {
        fleet_id: []const u8,
        compute_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .compute_name = "ComputeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_compute) } {
            return .{ .service_metadata = service_metadata, .action = describe_compute };
        }
    },
    Response: type = struct {
        compute: ?Compute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute = "Compute",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_ec2_instance_limits: struct {
    action_name: []const u8 = "DescribeEC2InstanceLimits",
    Request: type = struct {
        ec2_instance_type: ?[]const u8 = null,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ec2_instance_type = "EC2InstanceType",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ec2_instance_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_ec2_instance_limits };
        }
    },
    Response: type = struct {
        ec2_instance_limits: ?[]struct {
            ec2_instance_type: ?[]const u8 = null,
            current_instances: ?i64 = null,
            instance_limit: ?i64 = null,
            location: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ec2_instance_type = "EC2InstanceType",
                    .current_instances = "CurrentInstances",
                    .instance_limit = "InstanceLimit",
                    .location = "Location",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ec2_instance_limits = "EC2InstanceLimits",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_fleet_attributes: struct {
    action_name: []const u8 = "DescribeFleetAttributes",
    Request: type = struct {
        fleet_ids: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_ids = "FleetIds",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_attributes };
        }
    },
    Response: type = struct {
        fleet_attributes: ?[]FleetAttributes = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_attributes = "FleetAttributes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_fleet_capacity: struct {
    action_name: []const u8 = "DescribeFleetCapacity",
    Request: type = struct {
        fleet_ids: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_ids = "FleetIds",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_capacity) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_capacity };
        }
    },
    Response: type = struct {
        fleet_capacity: ?[]FleetCapacity = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_capacity = "FleetCapacity",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_fleet_events: struct {
    action_name: []const u8 = "DescribeFleetEvents",
    Request: type = struct {
        fleet_id: []const u8,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_events };
        }
    },
    Response: type = struct {
        events: ?[]struct {
            event_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            event_code: ?[]const u8 = null,
            message: ?[]const u8 = null,
            event_time: ?i64 = null,
            pre_signed_log_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_id = "EventId",
                    .resource_id = "ResourceId",
                    .event_code = "EventCode",
                    .message = "Message",
                    .event_time = "EventTime",
                    .pre_signed_log_url = "PreSignedLogUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "Events",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_fleet_location_attributes: struct {
    action_name: []const u8 = "DescribeFleetLocationAttributes",
    Request: type = struct {
        fleet_id: []const u8,
        locations: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .locations = "Locations",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_location_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_location_attributes };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,
        location_attributes: ?[]struct {
            location_state: ?LocationState = null,
            stopped_actions: ?[][]const u8 = null,
            update_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_state = "LocationState",
                    .stopped_actions = "StoppedActions",
                    .update_status = "UpdateStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
                .location_attributes = "LocationAttributes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_fleet_location_capacity: struct {
    action_name: []const u8 = "DescribeFleetLocationCapacity",
    Request: type = struct {
        fleet_id: []const u8,
        location: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_location_capacity) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_location_capacity };
        }
    },
    Response: type = struct {
        fleet_capacity: ?FleetCapacity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_capacity = "FleetCapacity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_fleet_location_utilization: struct {
    action_name: []const u8 = "DescribeFleetLocationUtilization",
    Request: type = struct {
        fleet_id: []const u8,
        location: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_location_utilization) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_location_utilization };
        }
    },
    Response: type = struct {
        fleet_utilization: ?FleetUtilization = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_utilization = "FleetUtilization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_fleet_port_settings: struct {
    action_name: []const u8 = "DescribeFleetPortSettings",
    Request: type = struct {
        fleet_id: []const u8,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_port_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_port_settings };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,
        inbound_permissions: ?[]IpPermission = null,
        update_status: ?[]const u8 = null,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
                .inbound_permissions = "InboundPermissions",
                .update_status = "UpdateStatus",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_fleet_utilization: struct {
    action_name: []const u8 = "DescribeFleetUtilization",
    Request: type = struct {
        fleet_ids: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_ids = "FleetIds",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_utilization) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_utilization };
        }
    },
    Response: type = struct {
        fleet_utilization: ?[]FleetUtilization = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_utilization = "FleetUtilization",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_game_server: struct {
    action_name: []const u8 = "DescribeGameServer",
    Request: type = struct {
        game_server_group_name: []const u8,
        game_server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .game_server_id = "GameServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_game_server) } {
            return .{ .service_metadata = service_metadata, .action = describe_game_server };
        }
    },
    Response: type = struct {
        game_server: ?GameServer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server = "GameServer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_game_server_group: struct {
    action_name: []const u8 = "DescribeGameServerGroup",
    Request: type = struct {
        game_server_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_game_server_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_game_server_group };
        }
    },
    Response: type = struct {
        game_server_group: ?GameServerGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group = "GameServerGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_game_server_instances: struct {
    action_name: []const u8 = "DescribeGameServerInstances",
    Request: type = struct {
        game_server_group_name: []const u8,
        instance_ids: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .instance_ids = "InstanceIds",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_game_server_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_game_server_instances };
        }
    },
    Response: type = struct {
        game_server_instances: ?[]struct {
            game_server_group_name: ?[]const u8 = null,
            game_server_group_arn: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            instance_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .game_server_group_name = "GameServerGroupName",
                    .game_server_group_arn = "GameServerGroupArn",
                    .instance_id = "InstanceId",
                    .instance_status = "InstanceStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_instances = "GameServerInstances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_game_session_details: struct {
    action_name: []const u8 = "DescribeGameSessionDetails",
    Request: type = struct {
        fleet_id: ?[]const u8 = null,
        game_session_id: ?[]const u8 = null,
        alias_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        status_filter: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .game_session_id = "GameSessionId",
                .alias_id = "AliasId",
                .location = "Location",
                .status_filter = "StatusFilter",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_game_session_details) } {
            return .{ .service_metadata = service_metadata, .action = describe_game_session_details };
        }
    },
    Response: type = struct {
        game_session_details: ?[]struct {
            game_session: ?GameSession = null,
            protection_policy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .game_session = "GameSession",
                    .protection_policy = "ProtectionPolicy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_details = "GameSessionDetails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TerminalRoutingStrategy,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_game_session_placement: struct {
    action_name: []const u8 = "DescribeGameSessionPlacement",
    Request: type = struct {
        placement_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_id = "PlacementId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_game_session_placement) } {
            return .{ .service_metadata = service_metadata, .action = describe_game_session_placement };
        }
    },
    Response: type = struct {
        game_session_placement: ?GameSessionPlacement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_placement = "GameSessionPlacement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_game_session_queues: struct {
    action_name: []const u8 = "DescribeGameSessionQueues",
    Request: type = struct {
        names: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_game_session_queues) } {
            return .{ .service_metadata = service_metadata, .action = describe_game_session_queues };
        }
    },
    Response: type = struct {
        game_session_queues: ?[]GameSessionQueue = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_queues = "GameSessionQueues",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_game_sessions: struct {
    action_name: []const u8 = "DescribeGameSessions",
    Request: type = struct {
        fleet_id: ?[]const u8 = null,
        game_session_id: ?[]const u8 = null,
        alias_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        status_filter: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .game_session_id = "GameSessionId",
                .alias_id = "AliasId",
                .location = "Location",
                .status_filter = "StatusFilter",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_game_sessions) } {
            return .{ .service_metadata = service_metadata, .action = describe_game_sessions };
        }
    },
    Response: type = struct {
        game_sessions: ?[]GameSession = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_sessions = "GameSessions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TerminalRoutingStrategy,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_instances: struct {
    action_name: []const u8 = "DescribeInstances",
    Request: type = struct {
        fleet_id: []const u8,
        instance_id: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .instance_id = "InstanceId",
                .limit = "Limit",
                .next_token = "NextToken",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            fleet_id: ?[]const u8 = null,
            fleet_arn: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            ip_address: ?[]const u8 = null,
            dns_name: ?[]const u8 = null,
            operating_system: ?[]const u8 = null,
            type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            location: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fleet_id = "FleetId",
                    .fleet_arn = "FleetArn",
                    .instance_id = "InstanceId",
                    .ip_address = "IpAddress",
                    .dns_name = "DnsName",
                    .operating_system = "OperatingSystem",
                    .type = "Type",
                    .status = "Status",
                    .creation_time = "CreationTime",
                    .location = "Location",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_matchmaking: struct {
    action_name: []const u8 = "DescribeMatchmaking",
    Request: type = struct {
        ticket_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ticket_ids = "TicketIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_matchmaking) } {
            return .{ .service_metadata = service_metadata, .action = describe_matchmaking };
        }
    },
    Response: type = struct {
        ticket_list: ?[]MatchmakingTicket = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ticket_list = "TicketList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        UnsupportedRegion,
    },
} = .{};
pub const describe_matchmaking_configurations: struct {
    action_name: []const u8 = "DescribeMatchmakingConfigurations",
    Request: type = struct {
        names: ?[][]const u8 = null,
        rule_set_name: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .rule_set_name = "RuleSetName",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_matchmaking_configurations) } {
            return .{ .service_metadata = service_metadata, .action = describe_matchmaking_configurations };
        }
    },
    Response: type = struct {
        configurations: ?[]MatchmakingConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configurations = "Configurations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        UnsupportedRegion,
    },
} = .{};
pub const describe_matchmaking_rule_sets: struct {
    action_name: []const u8 = "DescribeMatchmakingRuleSets",
    Request: type = struct {
        names: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_matchmaking_rule_sets) } {
            return .{ .service_metadata = service_metadata, .action = describe_matchmaking_rule_sets };
        }
    },
    Response: type = struct {
        rule_sets: []MatchmakingRuleSet,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_sets = "RuleSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        UnsupportedRegion,
    },
} = .{};
pub const describe_player_sessions: struct {
    action_name: []const u8 = "DescribePlayerSessions",
    Request: type = struct {
        game_session_id: ?[]const u8 = null,
        player_id: ?[]const u8 = null,
        player_session_id: ?[]const u8 = null,
        player_session_status_filter: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_id = "GameSessionId",
                .player_id = "PlayerId",
                .player_session_id = "PlayerSessionId",
                .player_session_status_filter = "PlayerSessionStatusFilter",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_player_sessions) } {
            return .{ .service_metadata = service_metadata, .action = describe_player_sessions };
        }
    },
    Response: type = struct {
        player_sessions: ?[]PlayerSession = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .player_sessions = "PlayerSessions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_runtime_configuration: struct {
    action_name: []const u8 = "DescribeRuntimeConfiguration",
    Request: type = struct {
        fleet_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_runtime_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_runtime_configuration };
        }
    },
    Response: type = struct {
        runtime_configuration: ?RuntimeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runtime_configuration = "RuntimeConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_scaling_policies: struct {
    action_name: []const u8 = "DescribeScalingPolicies",
    Request: type = struct {
        fleet_id: []const u8,
        status_filter: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .status_filter = "StatusFilter",
                .limit = "Limit",
                .next_token = "NextToken",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scaling_policies) } {
            return .{ .service_metadata = service_metadata, .action = describe_scaling_policies };
        }
    },
    Response: type = struct {
        scaling_policies: ?[]struct {
            fleet_id: ?[]const u8 = null,
            fleet_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            scaling_adjustment: ?i64 = null,
            scaling_adjustment_type: ?[]const u8 = null,
            comparison_operator: ?[]const u8 = null,
            threshold: ?f64 = null,
            evaluation_periods: ?i64 = null,
            metric_name: ?[]const u8 = null,
            policy_type: ?[]const u8 = null,
            target_configuration: ?TargetConfiguration = null,
            update_status: ?[]const u8 = null,
            location: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fleet_id = "FleetId",
                    .fleet_arn = "FleetArn",
                    .name = "Name",
                    .status = "Status",
                    .scaling_adjustment = "ScalingAdjustment",
                    .scaling_adjustment_type = "ScalingAdjustmentType",
                    .comparison_operator = "ComparisonOperator",
                    .threshold = "Threshold",
                    .evaluation_periods = "EvaluationPeriods",
                    .metric_name = "MetricName",
                    .policy_type = "PolicyType",
                    .target_configuration = "TargetConfiguration",
                    .update_status = "UpdateStatus",
                    .location = "Location",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scaling_policies = "ScalingPolicies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const describe_script: struct {
    action_name: []const u8 = "DescribeScript",
    Request: type = struct {
        script_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .script_id = "ScriptId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_script) } {
            return .{ .service_metadata = service_metadata, .action = describe_script };
        }
    },
    Response: type = struct {
        script: ?Script = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .script = "Script",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_vpc_peering_authorizations: struct {
    action_name: []const u8 = "DescribeVpcPeeringAuthorizations",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_peering_authorizations) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_peering_authorizations };
        }
    },
    Response: type = struct {
        vpc_peering_authorizations: ?[]VpcPeeringAuthorization = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_peering_authorizations = "VpcPeeringAuthorizations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
    },
} = .{};
pub const describe_vpc_peering_connections: struct {
    action_name: []const u8 = "DescribeVpcPeeringConnections",
    Request: type = struct {
        fleet_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_peering_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_peering_connections };
        }
    },
    Response: type = struct {
        vpc_peering_connections: ?[]struct {
            fleet_id: ?[]const u8 = null,
            fleet_arn: ?[]const u8 = null,
            ip_v4_cidr_block: ?[]const u8 = null,
            vpc_peering_connection_id: ?[]const u8 = null,
            status: ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "Code",
                        .message = "Message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            peer_vpc_id: ?[]const u8 = null,
            game_lift_vpc_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fleet_id = "FleetId",
                    .fleet_arn = "FleetArn",
                    .ip_v4_cidr_block = "IpV4CidrBlock",
                    .vpc_peering_connection_id = "VpcPeeringConnectionId",
                    .status = "Status",
                    .peer_vpc_id = "PeerVpcId",
                    .game_lift_vpc_id = "GameLiftVpcId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_peering_connections = "VpcPeeringConnections",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_compute_access: struct {
    action_name: []const u8 = "GetComputeAccess",
    Request: type = struct {
        fleet_id: []const u8,
        compute_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .compute_name = "ComputeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compute_access) } {
            return .{ .service_metadata = service_metadata, .action = get_compute_access };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,
        compute_name: ?[]const u8 = null,
        compute_arn: ?[]const u8 = null,
        credentials: ?AwsCredentials = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
                .compute_name = "ComputeName",
                .compute_arn = "ComputeArn",
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_compute_auth_token: struct {
    action_name: []const u8 = "GetComputeAuthToken",
    Request: type = struct {
        fleet_id: []const u8,
        compute_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .compute_name = "ComputeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compute_auth_token) } {
            return .{ .service_metadata = service_metadata, .action = get_compute_auth_token };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,
        compute_name: ?[]const u8 = null,
        compute_arn: ?[]const u8 = null,
        auth_token: ?[]const u8 = null,
        expiration_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
                .compute_name = "ComputeName",
                .compute_arn = "ComputeArn",
                .auth_token = "AuthToken",
                .expiration_timestamp = "ExpirationTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_game_session_log_url: struct {
    action_name: []const u8 = "GetGameSessionLogUrl",
    Request: type = struct {
        game_session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_id = "GameSessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_game_session_log_url) } {
            return .{ .service_metadata = service_metadata, .action = get_game_session_log_url };
        }
    },
    Response: type = struct {
        pre_signed_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pre_signed_url = "PreSignedUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_instance_access: struct {
    action_name: []const u8 = "GetInstanceAccess",
    Request: type = struct {
        fleet_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_instance_access) } {
            return .{ .service_metadata = service_metadata, .action = get_instance_access };
        }
    },
    Response: type = struct {
        instance_access: ?struct {
            fleet_id: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            ip_address: ?[]const u8 = null,
            operating_system: ?[]const u8 = null,
            credentials: ?struct {
                user_name: ?[]const u8 = null,
                secret: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .user_name = "UserName",
                        .secret = "Secret",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fleet_id = "FleetId",
                    .instance_id = "InstanceId",
                    .ip_address = "IpAddress",
                    .operating_system = "OperatingSystem",
                    .credentials = "Credentials",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_access = "InstanceAccess",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_aliases: struct {
    action_name: []const u8 = "ListAliases",
    Request: type = struct {
        routing_strategy_type: ?[]const u8 = null,
        name: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_strategy_type = "RoutingStrategyType",
                .name = "Name",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[]Alias = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
    },
} = .{};
pub const list_builds: struct {
    action_name: []const u8 = "ListBuilds",
    Request: type = struct {
        status: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_builds) } {
            return .{ .service_metadata = service_metadata, .action = list_builds };
        }
    },
    Response: type = struct {
        builds: ?[]Build = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .builds = "Builds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
    },
} = .{};
pub const list_compute: struct {
    action_name: []const u8 = "ListCompute",
    Request: type = struct {
        fleet_id: []const u8,
        location: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .location = "Location",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_compute) } {
            return .{ .service_metadata = service_metadata, .action = list_compute };
        }
    },
    Response: type = struct {
        compute_list: ?[]Compute = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_list = "ComputeList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
    },
} = .{};
pub const list_fleets: struct {
    action_name: []const u8 = "ListFleets",
    Request: type = struct {
        build_id: ?[]const u8 = null,
        script_id: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .build_id = "BuildId",
                .script_id = "ScriptId",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fleets) } {
            return .{ .service_metadata = service_metadata, .action = list_fleets };
        }
    },
    Response: type = struct {
        fleet_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_ids = "FleetIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_game_server_groups: struct {
    action_name: []const u8 = "ListGameServerGroups",
    Request: type = struct {
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_game_server_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_game_server_groups };
        }
    },
    Response: type = struct {
        game_server_groups: ?[]GameServerGroup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_groups = "GameServerGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
    },
} = .{};
pub const list_game_servers: struct {
    action_name: []const u8 = "ListGameServers",
    Request: type = struct {
        game_server_group_name: []const u8,
        sort_order: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .sort_order = "SortOrder",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_game_servers) } {
            return .{ .service_metadata = service_metadata, .action = list_game_servers };
        }
    },
    Response: type = struct {
        game_servers: ?[]GameServer = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_servers = "GameServers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
    },
} = .{};
pub const list_locations: struct {
    action_name: []const u8 = "ListLocations",
    Request: type = struct {
        filters: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_locations) } {
            return .{ .service_metadata = service_metadata, .action = list_locations };
        }
    },
    Response: type = struct {
        locations: ?[]LocationModel = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locations = "Locations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
    },
} = .{};
pub const list_scripts: struct {
    action_name: []const u8 = "ListScripts",
    Request: type = struct {
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_scripts) } {
            return .{ .service_metadata = service_metadata, .action = list_scripts };
        }
    },
    Response: type = struct {
        scripts: ?[]Script = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scripts = "Scripts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
    },
} = .{};
pub const put_scaling_policy: struct {
    action_name: []const u8 = "PutScalingPolicy",
    Request: type = struct {
        name: []const u8,
        fleet_id: []const u8,
        scaling_adjustment: ?i64 = null,
        scaling_adjustment_type: ?[]const u8 = null,
        threshold: ?f64 = null,
        comparison_operator: ?[]const u8 = null,
        evaluation_periods: ?i64 = null,
        metric_name: []const u8,
        policy_type: ?[]const u8 = null,
        target_configuration: ?TargetConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .fleet_id = "FleetId",
                .scaling_adjustment = "ScalingAdjustment",
                .scaling_adjustment_type = "ScalingAdjustmentType",
                .threshold = "Threshold",
                .comparison_operator = "ComparisonOperator",
                .evaluation_periods = "EvaluationPeriods",
                .metric_name = "MetricName",
                .policy_type = "PolicyType",
                .target_configuration = "TargetConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_scaling_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_scaling_policy };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const register_compute: struct {
    action_name: []const u8 = "RegisterCompute",
    Request: type = struct {
        fleet_id: []const u8,
        compute_name: []const u8,
        certificate_path: ?[]const u8 = null,
        dns_name: ?[]const u8 = null,
        ip_address: ?[]const u8 = null,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .compute_name = "ComputeName",
                .certificate_path = "CertificatePath",
                .dns_name = "DnsName",
                .ip_address = "IpAddress",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_compute) } {
            return .{ .service_metadata = service_metadata, .action = register_compute };
        }
    },
    Response: type = struct {
        compute: ?Compute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute = "Compute",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const register_game_server: struct {
    action_name: []const u8 = "RegisterGameServer",
    Request: type = struct {
        game_server_group_name: []const u8,
        game_server_id: []const u8,
        instance_id: []const u8,
        connection_info: ?[]const u8 = null,
        game_server_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .game_server_id = "GameServerId",
                .instance_id = "InstanceId",
                .connection_info = "ConnectionInfo",
                .game_server_data = "GameServerData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_game_server) } {
            return .{ .service_metadata = service_metadata, .action = register_game_server };
        }
    },
    Response: type = struct {
        game_server: ?GameServer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server = "GameServer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidRequest,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const request_upload_credentials: struct {
    action_name: []const u8 = "RequestUploadCredentials",
    Request: type = struct {
        build_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .build_id = "BuildId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(request_upload_credentials) } {
            return .{ .service_metadata = service_metadata, .action = request_upload_credentials };
        }
    },
    Response: type = struct {
        upload_credentials: ?AwsCredentials = null,
        storage_location: ?S3Location = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload_credentials = "UploadCredentials",
                .storage_location = "StorageLocation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const resolve_alias: struct {
    action_name: []const u8 = "ResolveAlias",
    Request: type = struct {
        alias_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resolve_alias) } {
            return .{ .service_metadata = service_metadata, .action = resolve_alias };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TerminalRoutingStrategy,
        Unauthorized,
    },
} = .{};
pub const resume_game_server_group: struct {
    action_name: []const u8 = "ResumeGameServerGroup",
    Request: type = struct {
        game_server_group_name: []const u8,
        resume_actions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .resume_actions = "ResumeActions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_game_server_group) } {
            return .{ .service_metadata = service_metadata, .action = resume_game_server_group };
        }
    },
    Response: type = struct {
        game_server_group: ?GameServerGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group = "GameServerGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const search_game_sessions: struct {
    action_name: []const u8 = "SearchGameSessions",
    Request: type = struct {
        fleet_id: ?[]const u8 = null,
        alias_id: ?[]const u8 = null,
        location: ?[]const u8 = null,
        filter_expression: ?[]const u8 = null,
        sort_expression: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .alias_id = "AliasId",
                .location = "Location",
                .filter_expression = "FilterExpression",
                .sort_expression = "SortExpression",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_game_sessions) } {
            return .{ .service_metadata = service_metadata, .action = search_game_sessions };
        }
    },
    Response: type = struct {
        game_sessions: ?[]GameSession = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_sessions = "GameSessions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TerminalRoutingStrategy,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const start_fleet_actions: struct {
    action_name: []const u8 = "StartFleetActions",
    Request: type = struct {
        fleet_id: []const u8,
        actions: [][]const u8,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .actions = "Actions",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_fleet_actions) } {
            return .{ .service_metadata = service_metadata, .action = start_fleet_actions };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const start_game_session_placement: struct {
    action_name: []const u8 = "StartGameSessionPlacement",
    Request: type = struct {
        placement_id: []const u8,
        game_session_queue_name: []const u8,
        game_properties: ?[]GameProperty = null,
        maximum_player_session_count: i64,
        game_session_name: ?[]const u8 = null,
        player_latencies: ?[]PlayerLatency = null,
        desired_player_sessions: ?[]struct {
            player_id: ?[]const u8 = null,
            player_data: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .player_id = "PlayerId",
                    .player_data = "PlayerData",
                };
                return @field(mappings, field_name);
            }
        } = null,
        game_session_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_id = "PlacementId",
                .game_session_queue_name = "GameSessionQueueName",
                .game_properties = "GameProperties",
                .maximum_player_session_count = "MaximumPlayerSessionCount",
                .game_session_name = "GameSessionName",
                .player_latencies = "PlayerLatencies",
                .desired_player_sessions = "DesiredPlayerSessions",
                .game_session_data = "GameSessionData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_game_session_placement) } {
            return .{ .service_metadata = service_metadata, .action = start_game_session_placement };
        }
    },
    Response: type = struct {
        game_session_placement: ?GameSessionPlacement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_placement = "GameSessionPlacement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const start_match_backfill: struct {
    action_name: []const u8 = "StartMatchBackfill",
    Request: type = struct {
        ticket_id: ?[]const u8 = null,
        configuration_name: []const u8,
        game_session_arn: ?[]const u8 = null,
        players: []Player,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ticket_id = "TicketId",
                .configuration_name = "ConfigurationName",
                .game_session_arn = "GameSessionArn",
                .players = "Players",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_match_backfill) } {
            return .{ .service_metadata = service_metadata, .action = start_match_backfill };
        }
    },
    Response: type = struct {
        matchmaking_ticket: ?MatchmakingTicket = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .matchmaking_ticket = "MatchmakingTicket",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        UnsupportedRegion,
    },
} = .{};
pub const start_matchmaking: struct {
    action_name: []const u8 = "StartMatchmaking",
    Request: type = struct {
        ticket_id: ?[]const u8 = null,
        configuration_name: []const u8,
        players: []Player,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ticket_id = "TicketId",
                .configuration_name = "ConfigurationName",
                .players = "Players",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_matchmaking) } {
            return .{ .service_metadata = service_metadata, .action = start_matchmaking };
        }
    },
    Response: type = struct {
        matchmaking_ticket: ?MatchmakingTicket = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .matchmaking_ticket = "MatchmakingTicket",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        UnsupportedRegion,
    },
} = .{};
pub const stop_fleet_actions: struct {
    action_name: []const u8 = "StopFleetActions",
    Request: type = struct {
        fleet_id: []const u8,
        actions: [][]const u8,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .actions = "Actions",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_fleet_actions) } {
            return .{ .service_metadata = service_metadata, .action = stop_fleet_actions };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const stop_game_session_placement: struct {
    action_name: []const u8 = "StopGameSessionPlacement",
    Request: type = struct {
        placement_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_id = "PlacementId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_game_session_placement) } {
            return .{ .service_metadata = service_metadata, .action = stop_game_session_placement };
        }
    },
    Response: type = struct {
        game_session_placement: ?GameSessionPlacement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_placement = "GameSessionPlacement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const stop_matchmaking: struct {
    action_name: []const u8 = "StopMatchmaking",
    Request: type = struct {
        ticket_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ticket_id = "TicketId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_matchmaking) } {
            return .{ .service_metadata = service_metadata, .action = stop_matchmaking };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        UnsupportedRegion,
    },
} = .{};
pub const suspend_game_server_group: struct {
    action_name: []const u8 = "SuspendGameServerGroup",
    Request: type = struct {
        game_server_group_name: []const u8,
        suspend_actions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .suspend_actions = "SuspendActions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(suspend_game_server_group) } {
            return .{ .service_metadata = service_metadata, .action = suspend_game_server_group };
        }
    },
    Response: type = struct {
        game_server_group: ?GameServerGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group = "GameServerGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        TaggingFailed,
    },
} = .{};
pub const update_alias: struct {
    action_name: []const u8 = "UpdateAlias",
    Request: type = struct {
        alias_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        routing_strategy: ?RoutingStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .name = "Name",
                .description = "Description",
                .routing_strategy = "RoutingStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_alias };
        }
    },
    Response: type = struct {
        alias: ?Alias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_build: struct {
    action_name: []const u8 = "UpdateBuild",
    Request: type = struct {
        build_id: []const u8,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .build_id = "BuildId",
                .name = "Name",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_build) } {
            return .{ .service_metadata = service_metadata, .action = update_build };
        }
    },
    Response: type = struct {
        build: ?Build = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .build = "Build",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_fleet_attributes: struct {
    action_name: []const u8 = "UpdateFleetAttributes",
    Request: type = struct {
        fleet_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        new_game_session_protection_policy: ?[]const u8 = null,
        resource_creation_limit_policy: ?ResourceCreationLimitPolicy = null,
        metric_groups: ?[][]const u8 = null,
        anywhere_configuration: ?AnywhereConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .name = "Name",
                .description = "Description",
                .new_game_session_protection_policy = "NewGameSessionProtectionPolicy",
                .resource_creation_limit_policy = "ResourceCreationLimitPolicy",
                .metric_groups = "MetricGroups",
                .anywhere_configuration = "AnywhereConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_fleet_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_fleet_attributes };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidFleetStatus,
        InvalidRequest,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_fleet_capacity: struct {
    action_name: []const u8 = "UpdateFleetCapacity",
    Request: type = struct {
        fleet_id: []const u8,
        desired_instances: ?i64 = null,
        min_size: ?i64 = null,
        max_size: ?i64 = null,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .desired_instances = "DesiredInstances",
                .min_size = "MinSize",
                .max_size = "MaxSize",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_fleet_capacity) } {
            return .{ .service_metadata = service_metadata, .action = update_fleet_capacity };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,
        location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidFleetStatus,
        InvalidRequest,
        LimitExceeded,
        NotFound,
        Unauthorized,
        UnsupportedRegion,
    },
} = .{};
pub const update_fleet_port_settings: struct {
    action_name: []const u8 = "UpdateFleetPortSettings",
    Request: type = struct {
        fleet_id: []const u8,
        inbound_permission_authorizations: ?[]IpPermission = null,
        inbound_permission_revocations: ?[]IpPermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .inbound_permission_authorizations = "InboundPermissionAuthorizations",
                .inbound_permission_revocations = "InboundPermissionRevocations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_fleet_port_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_fleet_port_settings };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidFleetStatus,
        InvalidRequest,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_game_server: struct {
    action_name: []const u8 = "UpdateGameServer",
    Request: type = struct {
        game_server_group_name: []const u8,
        game_server_id: []const u8,
        game_server_data: ?[]const u8 = null,
        utilization_status: ?[]const u8 = null,
        health_check: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .game_server_id = "GameServerId",
                .game_server_data = "GameServerData",
                .utilization_status = "UtilizationStatus",
                .health_check = "HealthCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_game_server) } {
            return .{ .service_metadata = service_metadata, .action = update_game_server };
        }
    },
    Response: type = struct {
        game_server: ?GameServer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server = "GameServer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_game_server_group: struct {
    action_name: []const u8 = "UpdateGameServerGroup",
    Request: type = struct {
        game_server_group_name: []const u8,
        role_arn: ?[]const u8 = null,
        instance_definitions: ?[]InstanceDefinition = null,
        game_server_protection_policy: ?[]const u8 = null,
        balancing_strategy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group_name = "GameServerGroupName",
                .role_arn = "RoleArn",
                .instance_definitions = "InstanceDefinitions",
                .game_server_protection_policy = "GameServerProtectionPolicy",
                .balancing_strategy = "BalancingStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_game_server_group) } {
            return .{ .service_metadata = service_metadata, .action = update_game_server_group };
        }
    },
    Response: type = struct {
        game_server_group: ?GameServerGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_server_group = "GameServerGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_game_session: struct {
    action_name: []const u8 = "UpdateGameSession",
    Request: type = struct {
        game_session_id: []const u8,
        maximum_player_session_count: ?i64 = null,
        name: ?[]const u8 = null,
        player_session_creation_policy: ?[]const u8 = null,
        protection_policy: ?[]const u8 = null,
        game_properties: ?[]GameProperty = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_id = "GameSessionId",
                .maximum_player_session_count = "MaximumPlayerSessionCount",
                .name = "Name",
                .player_session_creation_policy = "PlayerSessionCreationPolicy",
                .protection_policy = "ProtectionPolicy",
                .game_properties = "GameProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_game_session) } {
            return .{ .service_metadata = service_metadata, .action = update_game_session };
        }
    },
    Response: type = struct {
        game_session: ?GameSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session = "GameSession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidGameSessionStatus,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_game_session_queue: struct {
    action_name: []const u8 = "UpdateGameSessionQueue",
    Request: type = struct {
        name: []const u8,
        timeout_in_seconds: ?i64 = null,
        player_latency_policies: ?[]PlayerLatencyPolicy = null,
        destinations: ?[]GameSessionQueueDestination = null,
        filter_configuration: ?FilterConfiguration = null,
        priority_configuration: ?PriorityConfiguration = null,
        custom_event_data: ?[]const u8 = null,
        notification_target: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .timeout_in_seconds = "TimeoutInSeconds",
                .player_latency_policies = "PlayerLatencyPolicies",
                .destinations = "Destinations",
                .filter_configuration = "FilterConfiguration",
                .priority_configuration = "PriorityConfiguration",
                .custom_event_data = "CustomEventData",
                .notification_target = "NotificationTarget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_game_session_queue) } {
            return .{ .service_metadata = service_metadata, .action = update_game_session_queue };
        }
    },
    Response: type = struct {
        game_session_queue: ?GameSessionQueue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .game_session_queue = "GameSessionQueue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_matchmaking_configuration: struct {
    action_name: []const u8 = "UpdateMatchmakingConfiguration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        game_session_queue_arns: ?[][]const u8 = null,
        request_timeout_seconds: ?i64 = null,
        acceptance_timeout_seconds: ?i64 = null,
        acceptance_required: ?bool = null,
        rule_set_name: ?[]const u8 = null,
        notification_target: ?[]const u8 = null,
        additional_player_count: ?i64 = null,
        custom_event_data: ?[]const u8 = null,
        game_properties: ?[]GameProperty = null,
        game_session_data: ?[]const u8 = null,
        backfill_mode: ?[]const u8 = null,
        flex_match_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .game_session_queue_arns = "GameSessionQueueArns",
                .request_timeout_seconds = "RequestTimeoutSeconds",
                .acceptance_timeout_seconds = "AcceptanceTimeoutSeconds",
                .acceptance_required = "AcceptanceRequired",
                .rule_set_name = "RuleSetName",
                .notification_target = "NotificationTarget",
                .additional_player_count = "AdditionalPlayerCount",
                .custom_event_data = "CustomEventData",
                .game_properties = "GameProperties",
                .game_session_data = "GameSessionData",
                .backfill_mode = "BackfillMode",
                .flex_match_mode = "FlexMatchMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_matchmaking_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_matchmaking_configuration };
        }
    },
    Response: type = struct {
        configuration: ?MatchmakingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        UnsupportedRegion,
    },
} = .{};
pub const update_runtime_configuration: struct {
    action_name: []const u8 = "UpdateRuntimeConfiguration",
    Request: type = struct {
        fleet_id: []const u8,
        runtime_configuration: RuntimeConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "FleetId",
                .runtime_configuration = "RuntimeConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_runtime_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_runtime_configuration };
        }
    },
    Response: type = struct {
        runtime_configuration: ?RuntimeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runtime_configuration = "RuntimeConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidFleetStatus,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_script: struct {
    action_name: []const u8 = "UpdateScript",
    Request: type = struct {
        script_id: []const u8,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        storage_location: ?S3Location = null,
        zip_file: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .script_id = "ScriptId",
                .name = "Name",
                .version = "Version",
                .storage_location = "StorageLocation",
                .zip_file = "ZipFile",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_script) } {
            return .{ .service_metadata = service_metadata, .action = update_script };
        }
    },
    Response: type = struct {
        script: ?Script = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .script = "Script",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const validate_matchmaking_rule_set: struct {
    action_name: []const u8 = "ValidateMatchmakingRuleSet",
    Request: type = struct {
        rule_set_body: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_body = "RuleSetBody",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_matchmaking_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = validate_matchmaking_rule_set };
        }
    },
    Response: type = struct {
        valid: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .valid = "Valid",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        UnsupportedRegion,
    },
} = .{};

pub const Script = struct {
    script_id: ?[]const u8 = null,
    script_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,
    size_on_disk: ?i64 = null,
    creation_time: ?i64 = null,
    storage_location: ?S3Location = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .script_id = "ScriptId",
            .script_arn = "ScriptArn",
            .name = "Name",
            .version = "Version",
            .size_on_disk = "SizeOnDisk",
            .creation_time = "CreationTime",
            .storage_location = "StorageLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    object_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
            .role_arn = "RoleArn",
            .object_version = "ObjectVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const RuntimeConfiguration = struct {
    server_processes: ?[]ServerProcess = null,
    max_concurrent_game_session_activations: ?i64 = null,
    game_session_activation_timeout_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_processes = "ServerProcesses",
            .max_concurrent_game_session_activations = "MaxConcurrentGameSessionActivations",
            .game_session_activation_timeout_seconds = "GameSessionActivationTimeoutSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerProcess = struct {
    launch_path: []const u8,
    parameters: ?[]const u8 = null,
    concurrent_executions: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_path = "LaunchPath",
            .parameters = "Parameters",
            .concurrent_executions = "ConcurrentExecutions",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchmakingConfiguration = struct {
    name: ?[]const u8 = null,
    configuration_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    game_session_queue_arns: ?[][]const u8 = null,
    request_timeout_seconds: ?i64 = null,
    acceptance_timeout_seconds: ?i64 = null,
    acceptance_required: ?bool = null,
    rule_set_name: ?[]const u8 = null,
    rule_set_arn: ?[]const u8 = null,
    notification_target: ?[]const u8 = null,
    additional_player_count: ?i64 = null,
    custom_event_data: ?[]const u8 = null,
    creation_time: ?i64 = null,
    game_properties: ?[]GameProperty = null,
    game_session_data: ?[]const u8 = null,
    backfill_mode: ?[]const u8 = null,
    flex_match_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .configuration_arn = "ConfigurationArn",
            .description = "Description",
            .game_session_queue_arns = "GameSessionQueueArns",
            .request_timeout_seconds = "RequestTimeoutSeconds",
            .acceptance_timeout_seconds = "AcceptanceTimeoutSeconds",
            .acceptance_required = "AcceptanceRequired",
            .rule_set_name = "RuleSetName",
            .rule_set_arn = "RuleSetArn",
            .notification_target = "NotificationTarget",
            .additional_player_count = "AdditionalPlayerCount",
            .custom_event_data = "CustomEventData",
            .creation_time = "CreationTime",
            .game_properties = "GameProperties",
            .game_session_data = "GameSessionData",
            .backfill_mode = "BackfillMode",
            .flex_match_mode = "FlexMatchMode",
        };
        return @field(mappings, field_name);
    }
};

pub const GameProperty = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const GameSessionQueue = struct {
    name: ?[]const u8 = null,
    game_session_queue_arn: ?[]const u8 = null,
    timeout_in_seconds: ?i64 = null,
    player_latency_policies: ?[]PlayerLatencyPolicy = null,
    destinations: ?[]GameSessionQueueDestination = null,
    filter_configuration: ?FilterConfiguration = null,
    priority_configuration: ?PriorityConfiguration = null,
    custom_event_data: ?[]const u8 = null,
    notification_target: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .game_session_queue_arn = "GameSessionQueueArn",
            .timeout_in_seconds = "TimeoutInSeconds",
            .player_latency_policies = "PlayerLatencyPolicies",
            .destinations = "Destinations",
            .filter_configuration = "FilterConfiguration",
            .priority_configuration = "PriorityConfiguration",
            .custom_event_data = "CustomEventData",
            .notification_target = "NotificationTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const PriorityConfiguration = struct {
    priority_order: ?[][]const u8 = null,
    location_order: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority_order = "PriorityOrder",
            .location_order = "LocationOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterConfiguration = struct {
    allowed_locations: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_locations = "AllowedLocations",
        };
        return @field(mappings, field_name);
    }
};

pub const GameSessionQueueDestination = struct {
    destination_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_arn = "DestinationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PlayerLatencyPolicy = struct {
    maximum_individual_player_latency_milliseconds: ?i64 = null,
    policy_duration_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_individual_player_latency_milliseconds = "MaximumIndividualPlayerLatencyMilliseconds",
            .policy_duration_seconds = "PolicyDurationSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const GameSession = struct {
    game_session_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    fleet_id: ?[]const u8 = null,
    fleet_arn: ?[]const u8 = null,
    creation_time: ?i64 = null,
    termination_time: ?i64 = null,
    current_player_session_count: ?i64 = null,
    maximum_player_session_count: ?i64 = null,
    status: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    game_properties: ?[]GameProperty = null,
    ip_address: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    port: ?i64 = null,
    player_session_creation_policy: ?[]const u8 = null,
    creator_id: ?[]const u8 = null,
    game_session_data: ?[]const u8 = null,
    matchmaker_data: ?[]const u8 = null,
    location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .game_session_id = "GameSessionId",
            .name = "Name",
            .fleet_id = "FleetId",
            .fleet_arn = "FleetArn",
            .creation_time = "CreationTime",
            .termination_time = "TerminationTime",
            .current_player_session_count = "CurrentPlayerSessionCount",
            .maximum_player_session_count = "MaximumPlayerSessionCount",
            .status = "Status",
            .status_reason = "StatusReason",
            .game_properties = "GameProperties",
            .ip_address = "IpAddress",
            .dns_name = "DnsName",
            .port = "Port",
            .player_session_creation_policy = "PlayerSessionCreationPolicy",
            .creator_id = "CreatorId",
            .game_session_data = "GameSessionData",
            .matchmaker_data = "MatchmakerData",
            .location = "Location",
        };
        return @field(mappings, field_name);
    }
};

pub const GameServerGroup = struct {
    game_server_group_name: ?[]const u8 = null,
    game_server_group_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    instance_definitions: ?[]InstanceDefinition = null,
    balancing_strategy: ?[]const u8 = null,
    game_server_protection_policy: ?[]const u8 = null,
    auto_scaling_group_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    suspended_actions: ?[][]const u8 = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .game_server_group_name = "GameServerGroupName",
            .game_server_group_arn = "GameServerGroupArn",
            .role_arn = "RoleArn",
            .instance_definitions = "InstanceDefinitions",
            .balancing_strategy = "BalancingStrategy",
            .game_server_protection_policy = "GameServerProtectionPolicy",
            .auto_scaling_group_arn = "AutoScalingGroupArn",
            .status = "Status",
            .status_reason = "StatusReason",
            .suspended_actions = "SuspendedActions",
            .creation_time = "CreationTime",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceDefinition = struct {
    instance_type: []const u8,
    weighted_capacity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "InstanceType",
            .weighted_capacity = "WeightedCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const GameServer = struct {
    game_server_group_name: ?[]const u8 = null,
    game_server_group_arn: ?[]const u8 = null,
    game_server_id: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    connection_info: ?[]const u8 = null,
    game_server_data: ?[]const u8 = null,
    claim_status: ?[]const u8 = null,
    utilization_status: ?[]const u8 = null,
    registration_time: ?i64 = null,
    last_claim_time: ?i64 = null,
    last_health_check_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .game_server_group_name = "GameServerGroupName",
            .game_server_group_arn = "GameServerGroupArn",
            .game_server_id = "GameServerId",
            .instance_id = "InstanceId",
            .connection_info = "ConnectionInfo",
            .game_server_data = "GameServerData",
            .claim_status = "ClaimStatus",
            .utilization_status = "UtilizationStatus",
            .registration_time = "RegistrationTime",
            .last_claim_time = "LastClaimTime",
            .last_health_check_time = "LastHealthCheckTime",
        };
        return @field(mappings, field_name);
    }
};

pub const IpPermission = struct {
    from_port: i64,
    to_port: i64,
    ip_range: []const u8,
    protocol: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "FromPort",
            .to_port = "ToPort",
            .ip_range = "IpRange",
            .protocol = "Protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const AnywhereConfiguration = struct {
    cost: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cost = "Cost",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceCreationLimitPolicy = struct {
    new_game_sessions_per_creator: ?i64 = null,
    policy_period_in_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .new_game_sessions_per_creator = "NewGameSessionsPerCreator",
            .policy_period_in_minutes = "PolicyPeriodInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const Build = struct {
    build_id: ?[]const u8 = null,
    build_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,
    status: ?[]const u8 = null,
    size_on_disk: ?i64 = null,
    operating_system: ?[]const u8 = null,
    creation_time: ?i64 = null,
    server_sdk_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .build_id = "BuildId",
            .build_arn = "BuildArn",
            .name = "Name",
            .version = "Version",
            .status = "Status",
            .size_on_disk = "SizeOnDisk",
            .operating_system = "OperatingSystem",
            .creation_time = "CreationTime",
            .server_sdk_version = "ServerSdkVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const Alias = struct {
    alias_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    alias_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    routing_strategy: ?RoutingStrategy = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alias_id = "AliasId",
            .name = "Name",
            .alias_arn = "AliasArn",
            .description = "Description",
            .routing_strategy = "RoutingStrategy",
            .creation_time = "CreationTime",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingStrategy = struct {
    type: ?[]const u8 = null,
    fleet_id: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .fleet_id = "FleetId",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const GameSessionPlacement = struct {
    placement_id: ?[]const u8 = null,
    game_session_queue_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    game_properties: ?[]GameProperty = null,
    maximum_player_session_count: ?i64 = null,
    game_session_name: ?[]const u8 = null,
    game_session_id: ?[]const u8 = null,
    game_session_arn: ?[]const u8 = null,
    game_session_region: ?[]const u8 = null,
    player_latencies: ?[]PlayerLatency = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    ip_address: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    port: ?i64 = null,
    placed_player_sessions: ?[]PlacedPlayerSession = null,
    game_session_data: ?[]const u8 = null,
    matchmaker_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .placement_id = "PlacementId",
            .game_session_queue_name = "GameSessionQueueName",
            .status = "Status",
            .game_properties = "GameProperties",
            .maximum_player_session_count = "MaximumPlayerSessionCount",
            .game_session_name = "GameSessionName",
            .game_session_id = "GameSessionId",
            .game_session_arn = "GameSessionArn",
            .game_session_region = "GameSessionRegion",
            .player_latencies = "PlayerLatencies",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .ip_address = "IpAddress",
            .dns_name = "DnsName",
            .port = "Port",
            .placed_player_sessions = "PlacedPlayerSessions",
            .game_session_data = "GameSessionData",
            .matchmaker_data = "MatchmakerData",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacedPlayerSession = struct {
    player_id: ?[]const u8 = null,
    player_session_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .player_id = "PlayerId",
            .player_session_id = "PlayerSessionId",
        };
        return @field(mappings, field_name);
    }
};

pub const PlayerLatency = struct {
    player_id: ?[]const u8 = null,
    region_identifier: ?[]const u8 = null,
    latency_in_milliseconds: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .player_id = "PlayerId",
            .region_identifier = "RegionIdentifier",
            .latency_in_milliseconds = "LatencyInMilliseconds",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchmakingTicket = struct {
    ticket_id: ?[]const u8 = null,
    configuration_name: ?[]const u8 = null,
    configuration_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    players: ?[]Player = null,
    game_session_connection_info: ?GameSessionConnectionInfo = null,
    estimated_wait_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ticket_id = "TicketId",
            .configuration_name = "ConfigurationName",
            .configuration_arn = "ConfigurationArn",
            .status = "Status",
            .status_reason = "StatusReason",
            .status_message = "StatusMessage",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .players = "Players",
            .game_session_connection_info = "GameSessionConnectionInfo",
            .estimated_wait_time = "EstimatedWaitTime",
        };
        return @field(mappings, field_name);
    }
};

pub const GameSessionConnectionInfo = struct {
    game_session_arn: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    port: ?i64 = null,
    matched_player_sessions: ?[]MatchedPlayerSession = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .game_session_arn = "GameSessionArn",
            .ip_address = "IpAddress",
            .dns_name = "DnsName",
            .port = "Port",
            .matched_player_sessions = "MatchedPlayerSessions",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchedPlayerSession = struct {
    player_id: ?[]const u8 = null,
    player_session_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .player_id = "PlayerId",
            .player_session_id = "PlayerSessionId",
        };
        return @field(mappings, field_name);
    }
};

pub const Player = struct {
    player_id: ?[]const u8 = null,
    player_attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AttributeValue = null,
    } = null,
    team: ?[]const u8 = null,
    latency_in_ms: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .player_id = "PlayerId",
            .player_attributes = "PlayerAttributes",
            .team = "Team",
            .latency_in_ms = "LatencyInMs",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "player_attributes", field_name))
            return try serializeMap(self.player_attributes, self.fieldNameFor("player_attributes"), options, out_stream);
        if (std.mem.eql(u8, "latency_in_ms", field_name))
            return try serializeMap(self.latency_in_ms, self.fieldNameFor("latency_in_ms"), options, out_stream);
        return false;
    }
};

pub const AttributeValue = struct {
    s: ?[]const u8 = null,
    n: ?f64 = null,
    sl: ?[][]const u8 = null,
    sdm: ?[]struct {
        key: ?[]const u8 = null,
        value: ?f64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s = "S",
            .n = "N",
            .sl = "SL",
            .sdm = "SDM",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "sdm", field_name))
            return try serializeMap(self.sdm, self.fieldNameFor("sdm"), options, out_stream);
        return false;
    }
};

pub const AwsCredentials = struct {
    access_key_id: ?[]const u8 = null,
    secret_access_key: ?[]const u8 = null,
    session_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_key_id = "AccessKeyId",
            .secret_access_key = "SecretAccessKey",
            .session_token = "SessionToken",
        };
        return @field(mappings, field_name);
    }
};

pub const Compute = struct {
    fleet_id: ?[]const u8 = null,
    fleet_arn: ?[]const u8 = null,
    compute_name: ?[]const u8 = null,
    compute_arn: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    compute_status: ?[]const u8 = null,
    location: ?[]const u8 = null,
    creation_time: ?i64 = null,
    operating_system: ?[]const u8 = null,
    type: ?[]const u8 = null,
    game_lift_service_sdk_endpoint: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fleet_id = "FleetId",
            .fleet_arn = "FleetArn",
            .compute_name = "ComputeName",
            .compute_arn = "ComputeArn",
            .ip_address = "IpAddress",
            .dns_name = "DnsName",
            .compute_status = "ComputeStatus",
            .location = "Location",
            .creation_time = "CreationTime",
            .operating_system = "OperatingSystem",
            .type = "Type",
            .game_lift_service_sdk_endpoint = "GameLiftServiceSdkEndpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetConfiguration = struct {
    target_value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_value = "TargetValue",
        };
        return @field(mappings, field_name);
    }
};

pub const LocationModel = struct {
    location_name: ?[]const u8 = null,
    location_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .location_name = "LocationName",
            .location_arn = "LocationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcPeeringAuthorization = struct {
    game_lift_aws_account_id: ?[]const u8 = null,
    peer_vpc_aws_account_id: ?[]const u8 = null,
    peer_vpc_id: ?[]const u8 = null,
    creation_time: ?i64 = null,
    expiration_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .game_lift_aws_account_id = "GameLiftAwsAccountId",
            .peer_vpc_aws_account_id = "PeerVpcAwsAccountId",
            .peer_vpc_id = "PeerVpcId",
            .creation_time = "CreationTime",
            .expiration_time = "ExpirationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const PlayerSession = struct {
    player_session_id: ?[]const u8 = null,
    player_id: ?[]const u8 = null,
    game_session_id: ?[]const u8 = null,
    fleet_id: ?[]const u8 = null,
    fleet_arn: ?[]const u8 = null,
    creation_time: ?i64 = null,
    termination_time: ?i64 = null,
    status: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    port: ?i64 = null,
    player_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .player_session_id = "PlayerSessionId",
            .player_id = "PlayerId",
            .game_session_id = "GameSessionId",
            .fleet_id = "FleetId",
            .fleet_arn = "FleetArn",
            .creation_time = "CreationTime",
            .termination_time = "TerminationTime",
            .status = "Status",
            .ip_address = "IpAddress",
            .dns_name = "DnsName",
            .port = "Port",
            .player_data = "PlayerData",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchmakingRuleSet = struct {
    rule_set_name: ?[]const u8 = null,
    rule_set_arn: ?[]const u8 = null,
    rule_set_body: []const u8,
    creation_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_set_name = "RuleSetName",
            .rule_set_arn = "RuleSetArn",
            .rule_set_body = "RuleSetBody",
            .creation_time = "CreationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetUtilization = struct {
    fleet_id: ?[]const u8 = null,
    fleet_arn: ?[]const u8 = null,
    active_server_process_count: ?i64 = null,
    active_game_session_count: ?i64 = null,
    current_player_session_count: ?i64 = null,
    maximum_player_session_count: ?i64 = null,
    location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fleet_id = "FleetId",
            .fleet_arn = "FleetArn",
            .active_server_process_count = "ActiveServerProcessCount",
            .active_game_session_count = "ActiveGameSessionCount",
            .current_player_session_count = "CurrentPlayerSessionCount",
            .maximum_player_session_count = "MaximumPlayerSessionCount",
            .location = "Location",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetCapacity = struct {
    fleet_id: ?[]const u8 = null,
    fleet_arn: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    instance_counts: ?EC2InstanceCounts = null,
    location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fleet_id = "FleetId",
            .fleet_arn = "FleetArn",
            .instance_type = "InstanceType",
            .instance_counts = "InstanceCounts",
            .location = "Location",
        };
        return @field(mappings, field_name);
    }
};

pub const EC2InstanceCounts = struct {
    desired: ?i64 = null,
    minimum: ?i64 = null,
    maximum: ?i64 = null,
    pending: ?i64 = null,
    active: ?i64 = null,
    idle: ?i64 = null,
    terminating: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .desired = "DESIRED",
            .minimum = "MINIMUM",
            .maximum = "MAXIMUM",
            .pending = "PENDING",
            .active = "ACTIVE",
            .idle = "IDLE",
            .terminating = "TERMINATING",
        };
        return @field(mappings, field_name);
    }
};

pub const LocationState = struct {
    location: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .location = "Location",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetAttributes = struct {
    fleet_id: ?[]const u8 = null,
    fleet_arn: ?[]const u8 = null,
    fleet_type: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    description: ?[]const u8 = null,
    name: ?[]const u8 = null,
    creation_time: ?i64 = null,
    termination_time: ?i64 = null,
    status: ?[]const u8 = null,
    build_id: ?[]const u8 = null,
    build_arn: ?[]const u8 = null,
    script_id: ?[]const u8 = null,
    script_arn: ?[]const u8 = null,
    server_launch_path: ?[]const u8 = null,
    server_launch_parameters: ?[]const u8 = null,
    log_paths: ?[][]const u8 = null,
    new_game_session_protection_policy: ?[]const u8 = null,
    operating_system: ?[]const u8 = null,
    resource_creation_limit_policy: ?ResourceCreationLimitPolicy = null,
    metric_groups: ?[][]const u8 = null,
    stopped_actions: ?[][]const u8 = null,
    instance_role_arn: ?[]const u8 = null,
    certificate_configuration: ?CertificateConfiguration = null,
    compute_type: ?[]const u8 = null,
    anywhere_configuration: ?AnywhereConfiguration = null,
    instance_role_credentials_provider: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fleet_id = "FleetId",
            .fleet_arn = "FleetArn",
            .fleet_type = "FleetType",
            .instance_type = "InstanceType",
            .description = "Description",
            .name = "Name",
            .creation_time = "CreationTime",
            .termination_time = "TerminationTime",
            .status = "Status",
            .build_id = "BuildId",
            .build_arn = "BuildArn",
            .script_id = "ScriptId",
            .script_arn = "ScriptArn",
            .server_launch_path = "ServerLaunchPath",
            .server_launch_parameters = "ServerLaunchParameters",
            .log_paths = "LogPaths",
            .new_game_session_protection_policy = "NewGameSessionProtectionPolicy",
            .operating_system = "OperatingSystem",
            .resource_creation_limit_policy = "ResourceCreationLimitPolicy",
            .metric_groups = "MetricGroups",
            .stopped_actions = "StoppedActions",
            .instance_role_arn = "InstanceRoleArn",
            .certificate_configuration = "CertificateConfiguration",
            .compute_type = "ComputeType",
            .anywhere_configuration = "AnywhereConfiguration",
            .instance_role_credentials_provider = "InstanceRoleCredentialsProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateConfiguration = struct {
    certificate_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_type = "CertificateType",
        };
        return @field(mappings, field_name);
    }
};

pub const LocationConfiguration = struct {
    location: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .location = "Location",
        };
        return @field(mappings, field_name);
    }
};
