const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-06-01";
pub const sdk_id: []const u8 = "Glacier";
pub const arn_namespace: ?[]const u8 = "glacier";
pub const endpoint_prefix: []const u8 = "glacier";
pub const sigv4_name: []const u8 = "glacier";
pub const name: []const u8 = "Glacier";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2012-06-01",
    sdk_id: []const u8 = "Glacier",
    arn_namespace: ?[]const u8 = "glacier",
    endpoint_prefix: []const u8 = "glacier",
    sigv4_name: []const u8 = "glacier",
    name: []const u8 = "Glacier",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const abort_multipart_upload: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{accountId}/vaults/{vaultName}/multipart-uploads/{uploadId}",
        .success_code = 204,
    };

    action_name: []const u8 = "AbortMultipartUpload",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        upload_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .upload_id = "uploadId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(abort_multipart_upload) } {
            return .{ .service_metadata = service_metadata, .action = abort_multipart_upload };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const abort_vault_lock: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{accountId}/vaults/{vaultName}/lock-policy",
        .success_code = 204,
    };

    action_name: []const u8 = "AbortVaultLock",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(abort_vault_lock) } {
            return .{ .service_metadata = service_metadata, .action = abort_vault_lock };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const add_tags_to_vault: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/vaults/{vaultName}/tags?operation=add",
        .success_code = 204,
    };

    action_name: []const u8 = "AddTagsToVault",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_vault) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_vault };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const complete_multipart_upload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/vaults/{vaultName}/multipart-uploads/{uploadId}",
        .success_code = 201,
    };

    action_name: []const u8 = "CompleteMultipartUpload",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        upload_id: []const u8,
        archive_size: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        pub const http_header = .{
            .archive_size = "x-amz-archive-size",
            .checksum = "x-amz-sha256-tree-hash",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .upload_id = "uploadId",
                .archive_size = "archiveSize",
                .checksum = "checksum",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(complete_multipart_upload) } {
            return .{ .service_metadata = service_metadata, .action = complete_multipart_upload };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        archive_id: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .checksum = "x-amz-sha256-tree-hash",
            .archive_id = "x-amz-archive-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "location",
                .checksum = "checksum",
                .archive_id = "archiveId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const complete_vault_lock: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/vaults/{vaultName}/lock-policy/{lockId}",
        .success_code = 204,
    };

    action_name: []const u8 = "CompleteVaultLock",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        lock_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .lock_id = "lockId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(complete_vault_lock) } {
            return .{ .service_metadata = service_metadata, .action = complete_vault_lock };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const create_vault: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{accountId}/vaults/{vaultName}",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVault",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vault) } {
            return .{ .service_metadata = service_metadata, .action = create_vault };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const delete_archive: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{accountId}/vaults/{vaultName}/archives/{archiveId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteArchive",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        archive_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .archive_id = "archiveId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_archive) } {
            return .{ .service_metadata = service_metadata, .action = delete_archive };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_vault: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{accountId}/vaults/{vaultName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVault",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vault) } {
            return .{ .service_metadata = service_metadata, .action = delete_vault };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_vault_access_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{accountId}/vaults/{vaultName}/access-policy",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVaultAccessPolicy",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vault_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_vault_access_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_vault_notifications: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{accountId}/vaults/{vaultName}/notification-configuration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVaultNotifications",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vault_notifications) } {
            return .{ .service_metadata = service_metadata, .action = delete_vault_notifications };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJob",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        job_description: ?[]const u8 = null,
        action: ?[]const u8 = null,
        archive_id: ?[]const u8 = null,
        vault_arn: ?[]const u8 = null,
        creation_date: ?[]const u8 = null,
        completed: ?bool = null,
        status_code: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        archive_size_in_bytes: ?i64 = null,
        inventory_size_in_bytes: ?i64 = null,
        sns_topic: ?[]const u8 = null,
        completion_date: ?[]const u8 = null,
        sha256_tree_hash: ?[]const u8 = null,
        archive_sha256_tree_hash: ?[]const u8 = null,
        retrieval_byte_range: ?[]const u8 = null,
        tier: ?[]const u8 = null,
        inventory_retrieval_parameters: ?InventoryRetrievalJobDescription = null,
        job_output_path: ?[]const u8 = null,
        select_parameters: ?SelectParameters = null,
        output_location: ?OutputLocation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .job_description = "JobDescription",
                .action = "Action",
                .archive_id = "ArchiveId",
                .vault_arn = "VaultARN",
                .creation_date = "CreationDate",
                .completed = "Completed",
                .status_code = "StatusCode",
                .status_message = "StatusMessage",
                .archive_size_in_bytes = "ArchiveSizeInBytes",
                .inventory_size_in_bytes = "InventorySizeInBytes",
                .sns_topic = "SNSTopic",
                .completion_date = "CompletionDate",
                .sha256_tree_hash = "SHA256TreeHash",
                .archive_sha256_tree_hash = "ArchiveSHA256TreeHash",
                .retrieval_byte_range = "RetrievalByteRange",
                .tier = "Tier",
                .inventory_retrieval_parameters = "InventoryRetrievalParameters",
                .job_output_path = "JobOutputPath",
                .select_parameters = "SelectParameters",
                .output_location = "OutputLocation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_vault: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeVault",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vault) } {
            return .{ .service_metadata = service_metadata, .action = describe_vault };
        }
    },
    Response: type = struct {
        vault_arn: ?[]const u8 = null,
        vault_name: ?[]const u8 = null,
        creation_date: ?[]const u8 = null,
        last_inventory_date: ?[]const u8 = null,
        number_of_archives: ?i64 = null,
        size_in_bytes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vault_arn = "VaultARN",
                .vault_name = "VaultName",
                .creation_date = "CreationDate",
                .last_inventory_date = "LastInventoryDate",
                .number_of_archives = "NumberOfArchives",
                .size_in_bytes = "SizeInBytes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_data_retrieval_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/policies/data-retrieval",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataRetrievalPolicy",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_retrieval_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_data_retrieval_policy };
        }
    },
    Response: type = struct {
        policy: ?DataRetrievalPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const get_job_output: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/jobs/{jobId}/output",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJobOutput",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        job_id: []const u8,
        range: ?[]const u8 = null,
        pub const http_header = .{
            .range = "Range",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .job_id = "jobId",
                .range = "range",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_output) } {
            return .{ .service_metadata = service_metadata, .action = get_job_output };
        }
    },
    Response: type = struct {
        body: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        status: ?i64 = null,
        content_range: ?[]const u8 = null,
        accept_ranges: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        archive_description: ?[]const u8 = null,
        pub const http_header = .{
            .checksum = "x-amz-sha256-tree-hash",
            .content_range = "Content-Range",
            .accept_ranges = "Accept-Ranges",
            .content_type = "Content-Type",
            .archive_description = "x-amz-archive-description",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "body",
                .checksum = "checksum",
                .status = "status",
                .content_range = "contentRange",
                .accept_ranges = "acceptRanges",
                .content_type = "contentType",
                .archive_description = "archiveDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_vault_access_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/access-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVaultAccessPolicy",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vault_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_vault_access_policy };
        }
    },
    Response: type = struct {
        policy: ?VaultAccessPolicy = null,

        pub const http_payload: []const u8 = "policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_vault_lock: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/lock-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVaultLock",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vault_lock) } {
            return .{ .service_metadata = service_metadata, .action = get_vault_lock };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        state: ?[]const u8 = null,
        expiration_date: ?[]const u8 = null,
        creation_date: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .state = "State",
                .expiration_date = "ExpirationDate",
                .creation_date = "CreationDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_vault_notifications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/notification-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVaultNotifications",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vault_notifications) } {
            return .{ .service_metadata = service_metadata, .action = get_vault_notifications };
        }
    },
    Response: type = struct {
        vault_notification_config: ?VaultNotificationConfig = null,

        pub const http_payload: []const u8 = "vault_notification_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vault_notification_config = "vaultNotificationConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const initiate_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/vaults/{vaultName}/jobs",
        .success_code = 202,
    };

    action_name: []const u8 = "InitiateJob",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        job_parameters: ?struct {
            format: ?[]const u8 = null,
            type: ?[]const u8 = null,
            archive_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            sns_topic: ?[]const u8 = null,
            retrieval_byte_range: ?[]const u8 = null,
            tier: ?[]const u8 = null,
            inventory_retrieval_parameters: ?struct {
                start_date: ?[]const u8 = null,
                end_date: ?[]const u8 = null,
                limit: ?[]const u8 = null,
                marker: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_date = "StartDate",
                        .end_date = "EndDate",
                        .limit = "Limit",
                        .marker = "Marker",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            select_parameters: ?SelectParameters = null,
            output_location: ?OutputLocation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .format = "Format",
                    .type = "Type",
                    .archive_id = "ArchiveId",
                    .description = "Description",
                    .sns_topic = "SNSTopic",
                    .retrieval_byte_range = "RetrievalByteRange",
                    .tier = "Tier",
                    .inventory_retrieval_parameters = "InventoryRetrievalParameters",
                    .select_parameters = "SelectParameters",
                    .output_location = "OutputLocation",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "job_parameters";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .job_parameters = "jobParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initiate_job) } {
            return .{ .service_metadata = service_metadata, .action = initiate_job };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        job_output_path: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .job_id = "x-amz-job-id",
            .job_output_path = "x-amz-job-output-path",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "location",
                .job_id = "jobId",
                .job_output_path = "jobOutputPath",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientCapacity,
        InvalidParameterValue,
        MissingParameterValue,
        PolicyEnforced,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const initiate_multipart_upload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/vaults/{vaultName}/multipart-uploads",
        .success_code = 201,
    };

    action_name: []const u8 = "InitiateMultipartUpload",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        archive_description: ?[]const u8 = null,
        part_size: ?[]const u8 = null,
        pub const http_header = .{
            .archive_description = "x-amz-archive-description",
            .part_size = "x-amz-part-size",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .archive_description = "archiveDescription",
                .part_size = "partSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initiate_multipart_upload) } {
            return .{ .service_metadata = service_metadata, .action = initiate_multipart_upload };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        upload_id: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .upload_id = "x-amz-multipart-upload-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "location",
                .upload_id = "uploadId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const initiate_vault_lock: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/vaults/{vaultName}/lock-policy",
        .success_code = 201,
    };

    action_name: []const u8 = "InitiateVaultLock",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        policy: ?struct {
            policy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy = "Policy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initiate_vault_lock) } {
            return .{ .service_metadata = service_metadata, .action = initiate_vault_lock };
        }
    },
    Response: type = struct {
        lock_id: ?[]const u8 = null,
        pub const http_header = .{
            .lock_id = "x-amz-lock-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lock_id = "lockId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,
        statuscode: ?[]const u8 = null,
        completed: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .marker = "marker",
            .statuscode = "statuscode",
            .completed = "completed",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .limit = "limit",
                .marker = "marker",
                .statuscode = "statuscode",
                .completed = "completed",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        job_list: ?[]GlacierJobDescription = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_list = "JobList",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_multipart_uploads: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/multipart-uploads",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMultipartUploads",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .marker = "marker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .limit = "limit",
                .marker = "marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_multipart_uploads) } {
            return .{ .service_metadata = service_metadata, .action = list_multipart_uploads };
        }
    },
    Response: type = struct {
        uploads_list: ?[]struct {
            multipart_upload_id: ?[]const u8 = null,
            vault_arn: ?[]const u8 = null,
            archive_description: ?[]const u8 = null,
            part_size_in_bytes: ?i64 = null,
            creation_date: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .multipart_upload_id = "MultipartUploadId",
                    .vault_arn = "VaultARN",
                    .archive_description = "ArchiveDescription",
                    .part_size_in_bytes = "PartSizeInBytes",
                    .creation_date = "CreationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uploads_list = "UploadsList",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_parts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/multipart-uploads/{uploadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListParts",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        upload_id: []const u8,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .marker = "marker",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .upload_id = "uploadId",
                .marker = "marker",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_parts) } {
            return .{ .service_metadata = service_metadata, .action = list_parts };
        }
    },
    Response: type = struct {
        multipart_upload_id: ?[]const u8 = null,
        vault_arn: ?[]const u8 = null,
        archive_description: ?[]const u8 = null,
        part_size_in_bytes: ?i64 = null,
        creation_date: ?[]const u8 = null,
        parts: ?[]struct {
            range_in_bytes: ?[]const u8 = null,
            sha256_tree_hash: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .range_in_bytes = "RangeInBytes",
                    .sha256_tree_hash = "SHA256TreeHash",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multipart_upload_id = "MultipartUploadId",
                .vault_arn = "VaultARN",
                .archive_description = "ArchiveDescription",
                .part_size_in_bytes = "PartSizeInBytes",
                .creation_date = "CreationDate",
                .parts = "Parts",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_provisioned_capacity: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/provisioned-capacity",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProvisionedCapacity",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_provisioned_capacity) } {
            return .{ .service_metadata = service_metadata, .action = list_provisioned_capacity };
        }
    },
    Response: type = struct {
        provisioned_capacity_list: ?[]struct {
            capacity_id: ?[]const u8 = null,
            start_date: ?[]const u8 = null,
            expiration_date: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .capacity_id = "CapacityId",
                    .start_date = "StartDate",
                    .expiration_date = "ExpirationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_capacity_list = "ProvisionedCapacityList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_tags_for_vault: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults/{vaultName}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForVault",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_vault) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_vault };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_vaults: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{accountId}/vaults",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVaults",
    Request: type = struct {
        account_id: []const u8,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .marker = "marker",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .marker = "marker",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vaults) } {
            return .{ .service_metadata = service_metadata, .action = list_vaults };
        }
    },
    Response: type = struct {
        vault_list: ?[]DescribeVaultOutput = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vault_list = "VaultList",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const purchase_provisioned_capacity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/provisioned-capacity",
        .success_code = 201,
    };

    action_name: []const u8 = "PurchaseProvisionedCapacity",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_provisioned_capacity) } {
            return .{ .service_metadata = service_metadata, .action = purchase_provisioned_capacity };
        }
    },
    Response: type = struct {
        capacity_id: ?[]const u8 = null,
        pub const http_header = .{
            .capacity_id = "x-amz-capacity-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_id = "capacityId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const remove_tags_from_vault: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/vaults/{vaultName}/tags?operation=remove",
        .success_code = 204,
    };

    action_name: []const u8 = "RemoveTagsFromVault",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        tag_keys: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_vault) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_vault };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const set_data_retrieval_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{accountId}/policies/data-retrieval",
        .success_code = 204,
    };

    action_name: []const u8 = "SetDataRetrievalPolicy",
    Request: type = struct {
        account_id: []const u8,
        policy: ?DataRetrievalPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_data_retrieval_policy) } {
            return .{ .service_metadata = service_metadata, .action = set_data_retrieval_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const set_vault_access_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{accountId}/vaults/{vaultName}/access-policy",
        .success_code = 204,
    };

    action_name: []const u8 = "SetVaultAccessPolicy",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        policy: ?VaultAccessPolicy = null,

        pub const http_payload: []const u8 = "policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_vault_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = set_vault_access_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const set_vault_notifications: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{accountId}/vaults/{vaultName}/notification-configuration",
        .success_code = 204,
    };

    action_name: []const u8 = "SetVaultNotifications",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        vault_notification_config: ?VaultNotificationConfig = null,

        pub const http_payload: []const u8 = "vault_notification_config";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .vault_notification_config = "vaultNotificationConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_vault_notifications) } {
            return .{ .service_metadata = service_metadata, .action = set_vault_notifications };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const upload_archive: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{accountId}/vaults/{vaultName}/archives",
        .success_code = 201,
    };

    action_name: []const u8 = "UploadArchive",
    Request: type = struct {
        vault_name: []const u8,
        account_id: []const u8,
        archive_description: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        body: ?[]const u8 = null,
        pub const http_header = .{
            .archive_description = "x-amz-archive-description",
            .checksum = "x-amz-sha256-tree-hash",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vault_name = "vaultName",
                .account_id = "accountId",
                .archive_description = "archiveDescription",
                .checksum = "checksum",
                .body = "body",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upload_archive) } {
            return .{ .service_metadata = service_metadata, .action = upload_archive };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        archive_id: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
            .checksum = "x-amz-sha256-tree-hash",
            .archive_id = "x-amz-archive-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "location",
                .checksum = "checksum",
                .archive_id = "archiveId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const upload_multipart_part: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{accountId}/vaults/{vaultName}/multipart-uploads/{uploadId}",
        .success_code = 204,
    };

    action_name: []const u8 = "UploadMultipartPart",
    Request: type = struct {
        account_id: []const u8,
        vault_name: []const u8,
        upload_id: []const u8,
        checksum: ?[]const u8 = null,
        range: ?[]const u8 = null,
        body: ?[]const u8 = null,
        pub const http_header = .{
            .checksum = "x-amz-sha256-tree-hash",
            .range = "Content-Range",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .vault_name = "vaultName",
                .upload_id = "uploadId",
                .checksum = "checksum",
                .range = "range",
                .body = "body",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upload_multipart_part) } {
            return .{ .service_metadata = service_metadata, .action = upload_multipart_part };
        }
    },
    Response: type = struct {
        checksum: ?[]const u8 = null,
        pub const http_header = .{
            .checksum = "x-amz-sha256-tree-hash",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .checksum = "checksum",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};

pub const VaultNotificationConfig = struct {
    sns_topic: ?[]const u8 = null,
    events: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic = "SNSTopic",
            .events = "Events",
        };
        return @field(mappings, field_name);
    }
};

pub const VaultAccessPolicy = struct {
    policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy = "Policy",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRetrievalPolicy = struct {
    rules: ?[]DataRetrievalRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRetrievalRule = struct {
    strategy: ?[]const u8 = null,
    bytes_per_hour: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .strategy = "Strategy",
            .bytes_per_hour = "BytesPerHour",
        };
        return @field(mappings, field_name);
    }
};

pub const DescribeVaultOutput = struct {
    vault_arn: ?[]const u8 = null,
    vault_name: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    last_inventory_date: ?[]const u8 = null,
    number_of_archives: ?i64 = null,
    size_in_bytes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vault_arn = "VaultARN",
            .vault_name = "VaultName",
            .creation_date = "CreationDate",
            .last_inventory_date = "LastInventoryDate",
            .number_of_archives = "NumberOfArchives",
            .size_in_bytes = "SizeInBytes",
        };
        return @field(mappings, field_name);
    }
};

pub const GlacierJobDescription = struct {
    job_id: ?[]const u8 = null,
    job_description: ?[]const u8 = null,
    action: ?[]const u8 = null,
    archive_id: ?[]const u8 = null,
    vault_arn: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    completed: ?bool = null,
    status_code: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    archive_size_in_bytes: ?i64 = null,
    inventory_size_in_bytes: ?i64 = null,
    sns_topic: ?[]const u8 = null,
    completion_date: ?[]const u8 = null,
    sha256_tree_hash: ?[]const u8 = null,
    archive_sha256_tree_hash: ?[]const u8 = null,
    retrieval_byte_range: ?[]const u8 = null,
    tier: ?[]const u8 = null,
    inventory_retrieval_parameters: ?InventoryRetrievalJobDescription = null,
    job_output_path: ?[]const u8 = null,
    select_parameters: ?SelectParameters = null,
    output_location: ?OutputLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "JobId",
            .job_description = "JobDescription",
            .action = "Action",
            .archive_id = "ArchiveId",
            .vault_arn = "VaultARN",
            .creation_date = "CreationDate",
            .completed = "Completed",
            .status_code = "StatusCode",
            .status_message = "StatusMessage",
            .archive_size_in_bytes = "ArchiveSizeInBytes",
            .inventory_size_in_bytes = "InventorySizeInBytes",
            .sns_topic = "SNSTopic",
            .completion_date = "CompletionDate",
            .sha256_tree_hash = "SHA256TreeHash",
            .archive_sha256_tree_hash = "ArchiveSHA256TreeHash",
            .retrieval_byte_range = "RetrievalByteRange",
            .tier = "Tier",
            .inventory_retrieval_parameters = "InventoryRetrievalParameters",
            .job_output_path = "JobOutputPath",
            .select_parameters = "SelectParameters",
            .output_location = "OutputLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputLocation = struct {
    s3: ?S3Location = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "S3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    bucket_name: ?[]const u8 = null,
    prefix: ?[]const u8 = null,
    encryption: ?Encryption = null,
    canned_acl: ?[]const u8 = null,
    access_control_list: ?[]Grant = null,
    tagging: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    user_metadata: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .prefix = "Prefix",
            .encryption = "Encryption",
            .canned_acl = "CannedACL",
            .access_control_list = "AccessControlList",
            .tagging = "Tagging",
            .user_metadata = "UserMetadata",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tagging", field_name))
            return try serializeMap(self.tagging, self.fieldNameFor("tagging"), options, out_stream);
        if (std.mem.eql(u8, "user_metadata", field_name))
            return try serializeMap(self.user_metadata, self.fieldNameFor("user_metadata"), options, out_stream);
        return false;
    }
};

pub const Grant = struct {
    grantee: ?Grantee = null,
    permission: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grantee = "Grantee",
            .permission = "Permission",
        };
        return @field(mappings, field_name);
    }
};

pub const Grantee = struct {
    type: []const u8,
    display_name: ?[]const u8 = null,
    uri: ?[]const u8 = null,
    id: ?[]const u8 = null,
    email_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .display_name = "DisplayName",
            .uri = "URI",
            .id = "ID",
            .email_address = "EmailAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const Encryption = struct {
    encryption_type: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    kms_context: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_type = "EncryptionType",
            .kms_key_id = "KMSKeyId",
            .kms_context = "KMSContext",
        };
        return @field(mappings, field_name);
    }
};

pub const SelectParameters = struct {
    input_serialization: ?InputSerialization = null,
    expression_type: ?[]const u8 = null,
    expression: ?[]const u8 = null,
    output_serialization: ?OutputSerialization = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_serialization = "InputSerialization",
            .expression_type = "ExpressionType",
            .expression = "Expression",
            .output_serialization = "OutputSerialization",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputSerialization = struct {
    csv: ?CSVOutput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv = "csv",
        };
        return @field(mappings, field_name);
    }
};

pub const CSVOutput = struct {
    quote_fields: ?[]const u8 = null,
    quote_escape_character: ?[]const u8 = null,
    record_delimiter: ?[]const u8 = null,
    field_delimiter: ?[]const u8 = null,
    quote_character: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quote_fields = "QuoteFields",
            .quote_escape_character = "QuoteEscapeCharacter",
            .record_delimiter = "RecordDelimiter",
            .field_delimiter = "FieldDelimiter",
            .quote_character = "QuoteCharacter",
        };
        return @field(mappings, field_name);
    }
};

pub const InputSerialization = struct {
    csv: ?CSVInput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv = "csv",
        };
        return @field(mappings, field_name);
    }
};

pub const CSVInput = struct {
    file_header_info: ?[]const u8 = null,
    comments: ?[]const u8 = null,
    quote_escape_character: ?[]const u8 = null,
    record_delimiter: ?[]const u8 = null,
    field_delimiter: ?[]const u8 = null,
    quote_character: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_header_info = "FileHeaderInfo",
            .comments = "Comments",
            .quote_escape_character = "QuoteEscapeCharacter",
            .record_delimiter = "RecordDelimiter",
            .field_delimiter = "FieldDelimiter",
            .quote_character = "QuoteCharacter",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryRetrievalJobDescription = struct {
    format: ?[]const u8 = null,
    start_date: ?[]const u8 = null,
    end_date: ?[]const u8 = null,
    limit: ?[]const u8 = null,
    marker: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .start_date = "StartDate",
            .end_date = "EndDate",
            .limit = "Limit",
            .marker = "Marker",
        };
        return @field(mappings, field_name);
    }
};
