const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-08-08";
pub const sdk_id: []const u8 = "Global Accelerator";
pub const arn_namespace: ?[]const u8 = "globalaccelerator";
pub const endpoint_prefix: []const u8 = "globalaccelerator";
pub const sigv4_name: []const u8 = "globalaccelerator";
pub const name: []const u8 = "GlobalAccelerator_V20180706";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-08-08",
    sdk_id: []const u8 = "Global Accelerator",
    arn_namespace: ?[]const u8 = "globalaccelerator",
    endpoint_prefix: []const u8 = "globalaccelerator",
    sigv4_name: []const u8 = "globalaccelerator",
    name: []const u8 = "GlobalAccelerator_V20180706",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_custom_routing_endpoints: struct {
    action_name: []const u8 = "AddCustomRoutingEndpoints",
    Request: type = struct {
        endpoint_configurations: []struct {
            endpoint_id: ?[]const u8 = null,
            attachment_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint_id = "EndpointId",
                    .attachment_arn = "AttachmentArn",
                };
                return @field(mappings, field_name);
            }
        },
        endpoint_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_configurations = "EndpointConfigurations",
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_custom_routing_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = add_custom_routing_endpoints };
        }
    },
    Response: type = struct {
        endpoint_descriptions: ?[]CustomRoutingEndpointDescription = null,
        endpoint_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_descriptions = "EndpointDescriptions",
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        EndpointAlreadyExists,
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
    },
} = .{};
pub const add_endpoints: struct {
    action_name: []const u8 = "AddEndpoints",
    Request: type = struct {
        endpoint_configurations: []EndpointConfiguration,
        endpoint_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_configurations = "EndpointConfigurations",
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = add_endpoints };
        }
    },
    Response: type = struct {
        endpoint_descriptions: ?[]EndpointDescription = null,
        endpoint_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_descriptions = "EndpointDescriptions",
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
        TransactionInProgress,
    },
} = .{};
pub const advertise_byoip_cidr: struct {
    action_name: []const u8 = "AdvertiseByoipCidr",
    Request: type = struct {
        cidr: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(advertise_byoip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = advertise_byoip_cidr };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "ByoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ByoipCidrNotFound,
        IncorrectCidrState,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const allow_custom_routing_traffic: struct {
    action_name: []const u8 = "AllowCustomRoutingTraffic",
    Request: type = struct {
        endpoint_group_arn: []const u8,
        endpoint_id: []const u8,
        destination_addresses: ?[][]const u8 = null,
        destination_ports: ?[]i64 = null,
        allow_all_traffic_to_endpoint: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group_arn = "EndpointGroupArn",
                .endpoint_id = "EndpointId",
                .destination_addresses = "DestinationAddresses",
                .destination_ports = "DestinationPorts",
                .allow_all_traffic_to_endpoint = "AllowAllTrafficToEndpoint",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allow_custom_routing_traffic) } {
            return .{ .service_metadata = service_metadata, .action = allow_custom_routing_traffic };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const create_accelerator: struct {
    action_name: []const u8 = "CreateAccelerator",
    Request: type = struct {
        name: []const u8,
        ip_address_type: ?[]const u8 = null,
        ip_addresses: ?[][]const u8 = null,
        enabled: ?bool = null,
        idempotency_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .ip_address_type = "IpAddressType",
                .ip_addresses = "IpAddresses",
                .enabled = "Enabled",
                .idempotency_token = "IdempotencyToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_accelerator) } {
            return .{ .service_metadata = service_metadata, .action = create_accelerator };
        }
    },
    Response: type = struct {
        accelerator: ?Accelerator = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator = "Accelerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
    },
} = .{};
pub const create_cross_account_attachment: struct {
    action_name: []const u8 = "CreateCrossAccountAttachment",
    Request: type = struct {
        name: []const u8,
        principals: ?[][]const u8 = null,
        resources: ?[]Resource = null,
        idempotency_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .principals = "Principals",
                .resources = "Resources",
                .idempotency_token = "IdempotencyToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cross_account_attachment) } {
            return .{ .service_metadata = service_metadata, .action = create_cross_account_attachment };
        }
    },
    Response: type = struct {
        cross_account_attachment: ?Attachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_attachment = "CrossAccountAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
        TransactionInProgress,
    },
} = .{};
pub const create_custom_routing_accelerator: struct {
    action_name: []const u8 = "CreateCustomRoutingAccelerator",
    Request: type = struct {
        name: []const u8,
        ip_address_type: ?[]const u8 = null,
        ip_addresses: ?[][]const u8 = null,
        enabled: ?bool = null,
        idempotency_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .ip_address_type = "IpAddressType",
                .ip_addresses = "IpAddresses",
                .enabled = "Enabled",
                .idempotency_token = "IdempotencyToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_routing_accelerator) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_routing_accelerator };
        }
    },
    Response: type = struct {
        accelerator: ?CustomRoutingAccelerator = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator = "Accelerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
    },
} = .{};
pub const create_custom_routing_endpoint_group: struct {
    action_name: []const u8 = "CreateCustomRoutingEndpointGroup",
    Request: type = struct {
        listener_arn: []const u8,
        endpoint_group_region: []const u8,
        destination_configurations: []struct {
            from_port: i64,
            to_port: i64,
            protocols: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .from_port = "FromPort",
                    .to_port = "ToPort",
                    .protocols = "Protocols",
                };
                return @field(mappings, field_name);
            }
        },
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .endpoint_group_region = "EndpointGroupRegion",
                .destination_configurations = "DestinationConfigurations",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_routing_endpoint_group) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_routing_endpoint_group };
        }
    },
    Response: type = struct {
        endpoint_group: ?CustomRoutingEndpointGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group = "EndpointGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        AccessDenied,
        EndpointGroupAlreadyExists,
        InternalServiceError,
        InvalidArgument,
        InvalidPortRange,
        LimitExceeded,
        ListenerNotFound,
    },
} = .{};
pub const create_custom_routing_listener: struct {
    action_name: []const u8 = "CreateCustomRoutingListener",
    Request: type = struct {
        accelerator_arn: []const u8,
        port_ranges: []PortRange,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .port_ranges = "PortRanges",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_routing_listener) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_routing_listener };
        }
    },
    Response: type = struct {
        listener: ?CustomRoutingListener = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener = "Listener",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
        InvalidPortRange,
        LimitExceeded,
    },
} = .{};
pub const create_endpoint_group: struct {
    action_name: []const u8 = "CreateEndpointGroup",
    Request: type = struct {
        listener_arn: []const u8,
        endpoint_group_region: []const u8,
        endpoint_configurations: ?[]EndpointConfiguration = null,
        traffic_dial_percentage: ?f32 = null,
        health_check_port: ?i64 = null,
        health_check_protocol: ?[]const u8 = null,
        health_check_path: ?[]const u8 = null,
        health_check_interval_seconds: ?i64 = null,
        threshold_count: ?i64 = null,
        idempotency_token: []const u8,
        port_overrides: ?[]PortOverride = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .endpoint_group_region = "EndpointGroupRegion",
                .endpoint_configurations = "EndpointConfigurations",
                .traffic_dial_percentage = "TrafficDialPercentage",
                .health_check_port = "HealthCheckPort",
                .health_check_protocol = "HealthCheckProtocol",
                .health_check_path = "HealthCheckPath",
                .health_check_interval_seconds = "HealthCheckIntervalSeconds",
                .threshold_count = "ThresholdCount",
                .idempotency_token = "IdempotencyToken",
                .port_overrides = "PortOverrides",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_endpoint_group) } {
            return .{ .service_metadata = service_metadata, .action = create_endpoint_group };
        }
    },
    Response: type = struct {
        endpoint_group: ?EndpointGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group = "EndpointGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        AccessDenied,
        EndpointGroupAlreadyExists,
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
        ListenerNotFound,
    },
} = .{};
pub const create_listener: struct {
    action_name: []const u8 = "CreateListener",
    Request: type = struct {
        accelerator_arn: []const u8,
        port_ranges: []PortRange,
        protocol: []const u8,
        client_affinity: ?[]const u8 = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .port_ranges = "PortRanges",
                .protocol = "Protocol",
                .client_affinity = "ClientAffinity",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_listener) } {
            return .{ .service_metadata = service_metadata, .action = create_listener };
        }
    },
    Response: type = struct {
        listener: ?Listener = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener = "Listener",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
        InvalidPortRange,
        LimitExceeded,
    },
} = .{};
pub const delete_accelerator: struct {
    action_name: []const u8 = "DeleteAccelerator",
    Request: type = struct {
        accelerator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_accelerator) } {
            return .{ .service_metadata = service_metadata, .action = delete_accelerator };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AcceleratorNotDisabled,
        AcceleratorNotFound,
        AssociatedListenerFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const delete_cross_account_attachment: struct {
    action_name: []const u8 = "DeleteCrossAccountAttachment",
    Request: type = struct {
        attachment_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_arn = "AttachmentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cross_account_attachment) } {
            return .{ .service_metadata = service_metadata, .action = delete_cross_account_attachment };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AttachmentNotFound,
        InternalServiceError,
        InvalidArgument,
        TransactionInProgress,
    },
} = .{};
pub const delete_custom_routing_accelerator: struct {
    action_name: []const u8 = "DeleteCustomRoutingAccelerator",
    Request: type = struct {
        accelerator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_routing_accelerator) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_routing_accelerator };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AcceleratorNotDisabled,
        AcceleratorNotFound,
        AssociatedListenerFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const delete_custom_routing_endpoint_group: struct {
    action_name: []const u8 = "DeleteCustomRoutingEndpointGroup",
    Request: type = struct {
        endpoint_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_routing_endpoint_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_routing_endpoint_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const delete_custom_routing_listener: struct {
    action_name: []const u8 = "DeleteCustomRoutingListener",
    Request: type = struct {
        listener_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_routing_listener) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_routing_listener };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AssociatedEndpointGroupFound,
        InternalServiceError,
        InvalidArgument,
        ListenerNotFound,
    },
} = .{};
pub const delete_endpoint_group: struct {
    action_name: []const u8 = "DeleteEndpointGroup",
    Request: type = struct {
        endpoint_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const delete_listener: struct {
    action_name: []const u8 = "DeleteListener",
    Request: type = struct {
        listener_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_listener) } {
            return .{ .service_metadata = service_metadata, .action = delete_listener };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AssociatedEndpointGroupFound,
        InternalServiceError,
        InvalidArgument,
        ListenerNotFound,
    },
} = .{};
pub const deny_custom_routing_traffic: struct {
    action_name: []const u8 = "DenyCustomRoutingTraffic",
    Request: type = struct {
        endpoint_group_arn: []const u8,
        endpoint_id: []const u8,
        destination_addresses: ?[][]const u8 = null,
        destination_ports: ?[]i64 = null,
        deny_all_traffic_to_endpoint: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group_arn = "EndpointGroupArn",
                .endpoint_id = "EndpointId",
                .destination_addresses = "DestinationAddresses",
                .destination_ports = "DestinationPorts",
                .deny_all_traffic_to_endpoint = "DenyAllTrafficToEndpoint",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deny_custom_routing_traffic) } {
            return .{ .service_metadata = service_metadata, .action = deny_custom_routing_traffic };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const deprovision_byoip_cidr: struct {
    action_name: []const u8 = "DeprovisionByoipCidr",
    Request: type = struct {
        cidr: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprovision_byoip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = deprovision_byoip_cidr };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "ByoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ByoipCidrNotFound,
        IncorrectCidrState,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const describe_accelerator: struct {
    action_name: []const u8 = "DescribeAccelerator",
    Request: type = struct {
        accelerator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_accelerator) } {
            return .{ .service_metadata = service_metadata, .action = describe_accelerator };
        }
    },
    Response: type = struct {
        accelerator: ?Accelerator = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator = "Accelerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const describe_accelerator_attributes: struct {
    action_name: []const u8 = "DescribeAcceleratorAttributes",
    Request: type = struct {
        accelerator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_accelerator_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_accelerator_attributes };
        }
    },
    Response: type = struct {
        accelerator_attributes: ?AcceleratorAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_attributes = "AcceleratorAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const describe_cross_account_attachment: struct {
    action_name: []const u8 = "DescribeCrossAccountAttachment",
    Request: type = struct {
        attachment_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_arn = "AttachmentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cross_account_attachment) } {
            return .{ .service_metadata = service_metadata, .action = describe_cross_account_attachment };
        }
    },
    Response: type = struct {
        cross_account_attachment: ?Attachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_attachment = "CrossAccountAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AttachmentNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const describe_custom_routing_accelerator: struct {
    action_name: []const u8 = "DescribeCustomRoutingAccelerator",
    Request: type = struct {
        accelerator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_routing_accelerator) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_routing_accelerator };
        }
    },
    Response: type = struct {
        accelerator: ?CustomRoutingAccelerator = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator = "Accelerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const describe_custom_routing_accelerator_attributes: struct {
    action_name: []const u8 = "DescribeCustomRoutingAcceleratorAttributes",
    Request: type = struct {
        accelerator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_routing_accelerator_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_routing_accelerator_attributes };
        }
    },
    Response: type = struct {
        accelerator_attributes: ?CustomRoutingAcceleratorAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_attributes = "AcceleratorAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const describe_custom_routing_endpoint_group: struct {
    action_name: []const u8 = "DescribeCustomRoutingEndpointGroup",
    Request: type = struct {
        endpoint_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_routing_endpoint_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_routing_endpoint_group };
        }
    },
    Response: type = struct {
        endpoint_group: ?CustomRoutingEndpointGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group = "EndpointGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const describe_custom_routing_listener: struct {
    action_name: []const u8 = "DescribeCustomRoutingListener",
    Request: type = struct {
        listener_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_routing_listener) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_routing_listener };
        }
    },
    Response: type = struct {
        listener: ?CustomRoutingListener = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener = "Listener",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        ListenerNotFound,
    },
} = .{};
pub const describe_endpoint_group: struct {
    action_name: []const u8 = "DescribeEndpointGroup",
    Request: type = struct {
        endpoint_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint_group };
        }
    },
    Response: type = struct {
        endpoint_group: ?EndpointGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group = "EndpointGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const describe_listener: struct {
    action_name: []const u8 = "DescribeListener",
    Request: type = struct {
        listener_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_listener) } {
            return .{ .service_metadata = service_metadata, .action = describe_listener };
        }
    },
    Response: type = struct {
        listener: ?Listener = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener = "Listener",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        ListenerNotFound,
    },
} = .{};
pub const list_accelerators: struct {
    action_name: []const u8 = "ListAccelerators",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accelerators) } {
            return .{ .service_metadata = service_metadata, .action = list_accelerators };
        }
    },
    Response: type = struct {
        accelerators: ?[]Accelerator = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerators = "Accelerators",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_byoip_cidrs: struct {
    action_name: []const u8 = "ListByoipCidrs",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_byoip_cidrs) } {
            return .{ .service_metadata = service_metadata, .action = list_byoip_cidrs };
        }
    },
    Response: type = struct {
        byoip_cidrs: ?[]ByoipCidr = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidrs = "ByoipCidrs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_cross_account_attachments: struct {
    action_name: []const u8 = "ListCrossAccountAttachments",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cross_account_attachments) } {
            return .{ .service_metadata = service_metadata, .action = list_cross_account_attachments };
        }
    },
    Response: type = struct {
        cross_account_attachments: ?[]Attachment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_attachments = "CrossAccountAttachments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_cross_account_resource_accounts: struct {
    action_name: []const u8 = "ListCrossAccountResourceAccounts",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cross_account_resource_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_cross_account_resource_accounts };
        }
    },
    Response: type = struct {
        resource_owner_aws_account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_owner_aws_account_ids = "ResourceOwnerAwsAccountIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
    },
} = .{};
pub const list_cross_account_resources: struct {
    action_name: []const u8 = "ListCrossAccountResources",
    Request: type = struct {
        accelerator_arn: ?[]const u8 = null,
        resource_owner_aws_account_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .resource_owner_aws_account_id = "ResourceOwnerAwsAccountId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cross_account_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_cross_account_resources };
        }
    },
    Response: type = struct {
        cross_account_resources: ?[]struct {
            endpoint_id: ?[]const u8 = null,
            attachment_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint_id = "EndpointId",
                    .attachment_arn = "AttachmentArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_resources = "CrossAccountResources",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        AccessDenied,
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_custom_routing_accelerators: struct {
    action_name: []const u8 = "ListCustomRoutingAccelerators",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_routing_accelerators) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_routing_accelerators };
        }
    },
    Response: type = struct {
        accelerators: ?[]CustomRoutingAccelerator = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerators = "Accelerators",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_custom_routing_endpoint_groups: struct {
    action_name: []const u8 = "ListCustomRoutingEndpointGroups",
    Request: type = struct {
        listener_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_routing_endpoint_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_routing_endpoint_groups };
        }
    },
    Response: type = struct {
        endpoint_groups: ?[]CustomRoutingEndpointGroup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_groups = "EndpointGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
        ListenerNotFound,
    },
} = .{};
pub const list_custom_routing_listeners: struct {
    action_name: []const u8 = "ListCustomRoutingListeners",
    Request: type = struct {
        accelerator_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_routing_listeners) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_routing_listeners };
        }
    },
    Response: type = struct {
        listeners: ?[]CustomRoutingListener = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listeners = "Listeners",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_custom_routing_port_mappings: struct {
    action_name: []const u8 = "ListCustomRoutingPortMappings",
    Request: type = struct {
        accelerator_arn: []const u8,
        endpoint_group_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .endpoint_group_arn = "EndpointGroupArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_routing_port_mappings) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_routing_port_mappings };
        }
    },
    Response: type = struct {
        port_mappings: ?[]struct {
            accelerator_port: ?i64 = null,
            endpoint_group_arn: ?[]const u8 = null,
            endpoint_id: ?[]const u8 = null,
            destination_socket_address: ?SocketAddress = null,
            protocols: ?[][]const u8 = null,
            destination_traffic_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .accelerator_port = "AcceleratorPort",
                    .endpoint_group_arn = "EndpointGroupArn",
                    .endpoint_id = "EndpointId",
                    .destination_socket_address = "DestinationSocketAddress",
                    .protocols = "Protocols",
                    .destination_traffic_state = "DestinationTrafficState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .port_mappings = "PortMappings",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_custom_routing_port_mappings_by_destination: struct {
    action_name: []const u8 = "ListCustomRoutingPortMappingsByDestination",
    Request: type = struct {
        endpoint_id: []const u8,
        destination_address: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_id = "EndpointId",
                .destination_address = "DestinationAddress",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_routing_port_mappings_by_destination) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_routing_port_mappings_by_destination };
        }
    },
    Response: type = struct {
        destination_port_mappings: ?[]struct {
            accelerator_arn: ?[]const u8 = null,
            accelerator_socket_addresses: ?[]SocketAddress = null,
            endpoint_group_arn: ?[]const u8 = null,
            endpoint_id: ?[]const u8 = null,
            endpoint_group_region: ?[]const u8 = null,
            destination_socket_address: ?SocketAddress = null,
            ip_address_type: ?[]const u8 = null,
            destination_traffic_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .accelerator_arn = "AcceleratorArn",
                    .accelerator_socket_addresses = "AcceleratorSocketAddresses",
                    .endpoint_group_arn = "EndpointGroupArn",
                    .endpoint_id = "EndpointId",
                    .endpoint_group_region = "EndpointGroupRegion",
                    .destination_socket_address = "DestinationSocketAddress",
                    .ip_address_type = "IpAddressType",
                    .destination_traffic_state = "DestinationTrafficState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_port_mappings = "DestinationPortMappings",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EndpointNotFound,
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_endpoint_groups: struct {
    action_name: []const u8 = "ListEndpointGroups",
    Request: type = struct {
        listener_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_endpoint_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_endpoint_groups };
        }
    },
    Response: type = struct {
        endpoint_groups: ?[]EndpointGroup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_groups = "EndpointGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
        ListenerNotFound,
    },
} = .{};
pub const list_listeners: struct {
    action_name: []const u8 = "ListListeners",
    Request: type = struct {
        accelerator_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_listeners) } {
            return .{ .service_metadata = service_metadata, .action = list_listeners };
        }
    },
    Response: type = struct {
        listeners: ?[]Listener = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listeners = "Listeners",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
        InvalidNextToken,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const provision_byoip_cidr: struct {
    action_name: []const u8 = "ProvisionByoipCidr",
    Request: type = struct {
        cidr: []const u8,
        cidr_authorization_context: struct {
            message: []const u8,
            signature: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "Message",
                    .signature = "Signature",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
                .cidr_authorization_context = "CidrAuthorizationContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_byoip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = provision_byoip_cidr };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "ByoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncorrectCidrState,
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
    },
} = .{};
pub const remove_custom_routing_endpoints: struct {
    action_name: []const u8 = "RemoveCustomRoutingEndpoints",
    Request: type = struct {
        endpoint_ids: [][]const u8,
        endpoint_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_ids = "EndpointIds",
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_custom_routing_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = remove_custom_routing_endpoints };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        EndpointGroupNotFound,
        EndpointNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const remove_endpoints: struct {
    action_name: []const u8 = "RemoveEndpoints",
    Request: type = struct {
        endpoint_identifiers: []struct {
            endpoint_id: []const u8,
            client_ip_preservation_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint_id = "EndpointId",
                    .client_ip_preservation_enabled = "ClientIPPreservationEnabled",
                };
                return @field(mappings, field_name);
            }
        },
        endpoint_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_identifiers = "EndpointIdentifiers",
                .endpoint_group_arn = "EndpointGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = remove_endpoints };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
        TransactionInProgress,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const update_accelerator: struct {
    action_name: []const u8 = "UpdateAccelerator",
    Request: type = struct {
        accelerator_arn: []const u8,
        name: ?[]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .name = "Name",
                .ip_address_type = "IpAddressType",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_accelerator) } {
            return .{ .service_metadata = service_metadata, .action = update_accelerator };
        }
    },
    Response: type = struct {
        accelerator: ?Accelerator = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator = "Accelerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        AccessDenied,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const update_accelerator_attributes: struct {
    action_name: []const u8 = "UpdateAcceleratorAttributes",
    Request: type = struct {
        accelerator_arn: []const u8,
        flow_logs_enabled: ?bool = null,
        flow_logs_s3_bucket: ?[]const u8 = null,
        flow_logs_s3_prefix: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .flow_logs_enabled = "FlowLogsEnabled",
                .flow_logs_s3_bucket = "FlowLogsS3Bucket",
                .flow_logs_s3_prefix = "FlowLogsS3Prefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_accelerator_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_accelerator_attributes };
        }
    },
    Response: type = struct {
        accelerator_attributes: ?AcceleratorAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_attributes = "AcceleratorAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        AccessDenied,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const update_cross_account_attachment: struct {
    action_name: []const u8 = "UpdateCrossAccountAttachment",
    Request: type = struct {
        attachment_arn: []const u8,
        name: ?[]const u8 = null,
        add_principals: ?[][]const u8 = null,
        remove_principals: ?[][]const u8 = null,
        add_resources: ?[]Resource = null,
        remove_resources: ?[]Resource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_arn = "AttachmentArn",
                .name = "Name",
                .add_principals = "AddPrincipals",
                .remove_principals = "RemovePrincipals",
                .add_resources = "AddResources",
                .remove_resources = "RemoveResources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cross_account_attachment) } {
            return .{ .service_metadata = service_metadata, .action = update_cross_account_attachment };
        }
    },
    Response: type = struct {
        cross_account_attachment: ?Attachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_attachment = "CrossAccountAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AttachmentNotFound,
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
        TransactionInProgress,
    },
} = .{};
pub const update_custom_routing_accelerator: struct {
    action_name: []const u8 = "UpdateCustomRoutingAccelerator",
    Request: type = struct {
        accelerator_arn: []const u8,
        name: ?[]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .name = "Name",
                .ip_address_type = "IpAddressType",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_custom_routing_accelerator) } {
            return .{ .service_metadata = service_metadata, .action = update_custom_routing_accelerator };
        }
    },
    Response: type = struct {
        accelerator: ?CustomRoutingAccelerator = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator = "Accelerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const update_custom_routing_accelerator_attributes: struct {
    action_name: []const u8 = "UpdateCustomRoutingAcceleratorAttributes",
    Request: type = struct {
        accelerator_arn: []const u8,
        flow_logs_enabled: ?bool = null,
        flow_logs_s3_bucket: ?[]const u8 = null,
        flow_logs_s3_prefix: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_arn = "AcceleratorArn",
                .flow_logs_enabled = "FlowLogsEnabled",
                .flow_logs_s3_bucket = "FlowLogsS3Bucket",
                .flow_logs_s3_prefix = "FlowLogsS3Prefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_custom_routing_accelerator_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_custom_routing_accelerator_attributes };
        }
    },
    Response: type = struct {
        accelerator_attributes: ?CustomRoutingAcceleratorAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accelerator_attributes = "AcceleratorAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AcceleratorNotFound,
        AccessDenied,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};
pub const update_custom_routing_listener: struct {
    action_name: []const u8 = "UpdateCustomRoutingListener",
    Request: type = struct {
        listener_arn: []const u8,
        port_ranges: []PortRange,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .port_ranges = "PortRanges",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_custom_routing_listener) } {
            return .{ .service_metadata = service_metadata, .action = update_custom_routing_listener };
        }
    },
    Response: type = struct {
        listener: ?CustomRoutingListener = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener = "Listener",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        InvalidPortRange,
        LimitExceeded,
        ListenerNotFound,
    },
} = .{};
pub const update_endpoint_group: struct {
    action_name: []const u8 = "UpdateEndpointGroup",
    Request: type = struct {
        endpoint_group_arn: []const u8,
        endpoint_configurations: ?[]EndpointConfiguration = null,
        traffic_dial_percentage: ?f32 = null,
        health_check_port: ?i64 = null,
        health_check_protocol: ?[]const u8 = null,
        health_check_path: ?[]const u8 = null,
        health_check_interval_seconds: ?i64 = null,
        threshold_count: ?i64 = null,
        port_overrides: ?[]PortOverride = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group_arn = "EndpointGroupArn",
                .endpoint_configurations = "EndpointConfigurations",
                .traffic_dial_percentage = "TrafficDialPercentage",
                .health_check_port = "HealthCheckPort",
                .health_check_protocol = "HealthCheckProtocol",
                .health_check_path = "HealthCheckPath",
                .health_check_interval_seconds = "HealthCheckIntervalSeconds",
                .threshold_count = "ThresholdCount",
                .port_overrides = "PortOverrides",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_endpoint_group) } {
            return .{ .service_metadata = service_metadata, .action = update_endpoint_group };
        }
    },
    Response: type = struct {
        endpoint_group: ?EndpointGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_group = "EndpointGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EndpointGroupNotFound,
        InternalServiceError,
        InvalidArgument,
        LimitExceeded,
    },
} = .{};
pub const update_listener: struct {
    action_name: []const u8 = "UpdateListener",
    Request: type = struct {
        listener_arn: []const u8,
        port_ranges: ?[]PortRange = null,
        protocol: ?[]const u8 = null,
        client_affinity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener_arn = "ListenerArn",
                .port_ranges = "PortRanges",
                .protocol = "Protocol",
                .client_affinity = "ClientAffinity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_listener) } {
            return .{ .service_metadata = service_metadata, .action = update_listener };
        }
    },
    Response: type = struct {
        listener: ?Listener = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .listener = "Listener",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        InvalidPortRange,
        LimitExceeded,
        ListenerNotFound,
    },
} = .{};
pub const withdraw_byoip_cidr: struct {
    action_name: []const u8 = "WithdrawByoipCidr",
    Request: type = struct {
        cidr: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(withdraw_byoip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = withdraw_byoip_cidr };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "ByoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ByoipCidrNotFound,
        IncorrectCidrState,
        InternalServiceError,
        InvalidArgument,
    },
} = .{};

pub const ByoipCidr = struct {
    cidr: ?[]const u8 = null,
    state: ?[]const u8 = null,
    events: ?[]ByoipCidrEvent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "Cidr",
            .state = "State",
            .events = "Events",
        };
        return @field(mappings, field_name);
    }
};

pub const ByoipCidrEvent = struct {
    message: ?[]const u8 = null,
    timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
            .timestamp = "Timestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const Listener = struct {
    listener_arn: ?[]const u8 = null,
    port_ranges: ?[]PortRange = null,
    protocol: ?[]const u8 = null,
    client_affinity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .listener_arn = "ListenerArn",
            .port_ranges = "PortRanges",
            .protocol = "Protocol",
            .client_affinity = "ClientAffinity",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRange = struct {
    from_port: ?i64 = null,
    to_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "FromPort",
            .to_port = "ToPort",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointGroup = struct {
    endpoint_group_arn: ?[]const u8 = null,
    endpoint_group_region: ?[]const u8 = null,
    endpoint_descriptions: ?[]EndpointDescription = null,
    traffic_dial_percentage: ?f32 = null,
    health_check_port: ?i64 = null,
    health_check_protocol: ?[]const u8 = null,
    health_check_path: ?[]const u8 = null,
    health_check_interval_seconds: ?i64 = null,
    threshold_count: ?i64 = null,
    port_overrides: ?[]PortOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_group_arn = "EndpointGroupArn",
            .endpoint_group_region = "EndpointGroupRegion",
            .endpoint_descriptions = "EndpointDescriptions",
            .traffic_dial_percentage = "TrafficDialPercentage",
            .health_check_port = "HealthCheckPort",
            .health_check_protocol = "HealthCheckProtocol",
            .health_check_path = "HealthCheckPath",
            .health_check_interval_seconds = "HealthCheckIntervalSeconds",
            .threshold_count = "ThresholdCount",
            .port_overrides = "PortOverrides",
        };
        return @field(mappings, field_name);
    }
};

pub const PortOverride = struct {
    listener_port: ?i64 = null,
    endpoint_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .listener_port = "ListenerPort",
            .endpoint_port = "EndpointPort",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointDescription = struct {
    endpoint_id: ?[]const u8 = null,
    weight: ?i64 = null,
    health_state: ?[]const u8 = null,
    health_reason: ?[]const u8 = null,
    client_ip_preservation_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_id = "EndpointId",
            .weight = "Weight",
            .health_state = "HealthState",
            .health_reason = "HealthReason",
            .client_ip_preservation_enabled = "ClientIPPreservationEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointConfiguration = struct {
    endpoint_id: ?[]const u8 = null,
    weight: ?i64 = null,
    client_ip_preservation_enabled: ?bool = null,
    attachment_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_id = "EndpointId",
            .weight = "Weight",
            .client_ip_preservation_enabled = "ClientIPPreservationEnabled",
            .attachment_arn = "AttachmentArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRoutingListener = struct {
    listener_arn: ?[]const u8 = null,
    port_ranges: ?[]PortRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .listener_arn = "ListenerArn",
            .port_ranges = "PortRanges",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRoutingAcceleratorAttributes = struct {
    flow_logs_enabled: ?bool = null,
    flow_logs_s3_bucket: ?[]const u8 = null,
    flow_logs_s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_logs_enabled = "FlowLogsEnabled",
            .flow_logs_s3_bucket = "FlowLogsS3Bucket",
            .flow_logs_s3_prefix = "FlowLogsS3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRoutingAccelerator = struct {
    accelerator_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    ip_address_type: ?[]const u8 = null,
    enabled: ?bool = null,
    ip_sets: ?[]IpSet = null,
    dns_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_modified_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accelerator_arn = "AcceleratorArn",
            .name = "Name",
            .ip_address_type = "IpAddressType",
            .enabled = "Enabled",
            .ip_sets = "IpSets",
            .dns_name = "DnsName",
            .status = "Status",
            .created_time = "CreatedTime",
            .last_modified_time = "LastModifiedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const IpSet = struct {
    ip_family: ?[]const u8 = null,
    ip_addresses: ?[][]const u8 = null,
    ip_address_family: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_family = "IpFamily",
            .ip_addresses = "IpAddresses",
            .ip_address_family = "IpAddressFamily",
        };
        return @field(mappings, field_name);
    }
};

pub const Attachment = struct {
    attachment_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    principals: ?[][]const u8 = null,
    resources: ?[]Resource = null,
    last_modified_time: ?i64 = null,
    created_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment_arn = "AttachmentArn",
            .name = "Name",
            .principals = "Principals",
            .resources = "Resources",
            .last_modified_time = "LastModifiedTime",
            .created_time = "CreatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    endpoint_id: []const u8,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_id = "EndpointId",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};

pub const AcceleratorAttributes = struct {
    flow_logs_enabled: ?bool = null,
    flow_logs_s3_bucket: ?[]const u8 = null,
    flow_logs_s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_logs_enabled = "FlowLogsEnabled",
            .flow_logs_s3_bucket = "FlowLogsS3Bucket",
            .flow_logs_s3_prefix = "FlowLogsS3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Accelerator = struct {
    accelerator_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    ip_address_type: ?[]const u8 = null,
    enabled: ?bool = null,
    ip_sets: ?[]IpSet = null,
    dns_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_modified_time: ?i64 = null,
    dual_stack_dns_name: ?[]const u8 = null,
    events: ?[]AcceleratorEvent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accelerator_arn = "AcceleratorArn",
            .name = "Name",
            .ip_address_type = "IpAddressType",
            .enabled = "Enabled",
            .ip_sets = "IpSets",
            .dns_name = "DnsName",
            .status = "Status",
            .created_time = "CreatedTime",
            .last_modified_time = "LastModifiedTime",
            .dual_stack_dns_name = "DualStackDnsName",
            .events = "Events",
        };
        return @field(mappings, field_name);
    }
};

pub const AcceleratorEvent = struct {
    message: ?[]const u8 = null,
    timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
            .timestamp = "Timestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SocketAddress = struct {
    ip_address: ?[]const u8 = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "IpAddress",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRoutingEndpointGroup = struct {
    endpoint_group_arn: ?[]const u8 = null,
    endpoint_group_region: ?[]const u8 = null,
    destination_descriptions: ?[]CustomRoutingDestinationDescription = null,
    endpoint_descriptions: ?[]CustomRoutingEndpointDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_group_arn = "EndpointGroupArn",
            .endpoint_group_region = "EndpointGroupRegion",
            .destination_descriptions = "DestinationDescriptions",
            .endpoint_descriptions = "EndpointDescriptions",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRoutingEndpointDescription = struct {
    endpoint_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_id = "EndpointId",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRoutingDestinationDescription = struct {
    from_port: ?i64 = null,
    to_port: ?i64 = null,
    protocols: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "FromPort",
            .to_port = "ToPort",
            .protocols = "Protocols",
        };
        return @field(mappings, field_name);
    }
};
