const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-06-07";
pub const sdk_id: []const u8 = "Greengrass";
pub const arn_namespace: ?[]const u8 = "greengrass";
pub const endpoint_prefix: []const u8 = "greengrass";
pub const sigv4_name: []const u8 = "greengrass";
pub const name: []const u8 = "Greengrass";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-06-07",
    sdk_id: []const u8 = "Greengrass",
    arn_namespace: ?[]const u8 = "greengrass",
    endpoint_prefix: []const u8 = "greengrass",
    sigv4_name: []const u8 = "greengrass",
    name: []const u8 = "Greengrass",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_role_to_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/groups/{GroupId}/role",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateRoleToGroup",
    Request: type = struct {
        group_id: []const u8,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_role_to_group) } {
            return .{ .service_metadata = service_metadata, .action = associate_role_to_group };
        }
    },
    Response: type = struct {
        associated_at: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associated_at = "AssociatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const associate_service_role_to_account: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/servicerole",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateServiceRoleToAccount",
    Request: type = struct {
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_service_role_to_account) } {
            return .{ .service_metadata = service_metadata, .action = associate_service_role_to_account };
        }
    },
    Response: type = struct {
        associated_at: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associated_at = "AssociatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_connector_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/connectors",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConnectorDefinition",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        initial_version: ?ConnectorDefinitionVersion = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .initial_version = "InitialVersion",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connector_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_connector_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_connector_definition_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/connectors/{ConnectorDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConnectorDefinitionVersion",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        connector_definition_id: []const u8,
        connectors: ?[]Connector = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .connector_definition_id = "ConnectorDefinitionId",
                .connectors = "Connectors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connector_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = create_connector_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_core_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/cores",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCoreDefinition",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        initial_version: ?CoreDefinitionVersion = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .initial_version = "InitialVersion",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_core_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_core_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_core_definition_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/cores/{CoreDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCoreDefinitionVersion",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        core_definition_id: []const u8,
        cores: ?[]Core = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .core_definition_id = "CoreDefinitionId",
                .cores = "Cores",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_core_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = create_core_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/groups/{GroupId}/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDeployment",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        deployment_id: ?[]const u8 = null,
        deployment_type: []const u8,
        group_id: []const u8,
        group_version_id: ?[]const u8 = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .deployment_id = "DeploymentId",
                .deployment_type = "DeploymentType",
                .group_id = "GroupId",
                .group_version_id = "GroupVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deployment) } {
            return .{ .service_metadata = service_metadata, .action = create_deployment };
        }
    },
    Response: type = struct {
        deployment_arn: ?[]const u8 = null,
        deployment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_arn = "DeploymentArn",
                .deployment_id = "DeploymentId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_device_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDeviceDefinition",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        initial_version: ?DeviceDefinitionVersion = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .initial_version = "InitialVersion",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_device_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_device_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_device_definition_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/devices/{DeviceDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDeviceDefinitionVersion",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        device_definition_id: []const u8,
        devices: ?[]Device = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .device_definition_id = "DeviceDefinitionId",
                .devices = "Devices",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_device_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = create_device_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_function_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/functions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFunctionDefinition",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        initial_version: ?FunctionDefinitionVersion = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .initial_version = "InitialVersion",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_function_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_function_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_function_definition_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/functions/{FunctionDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFunctionDefinitionVersion",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        default_config: ?FunctionDefaultConfig = null,
        function_definition_id: []const u8,
        functions: ?[]Function = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .default_config = "DefaultConfig",
                .function_definition_id = "FunctionDefinitionId",
                .functions = "Functions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_function_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = create_function_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroup",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        initial_version: ?GroupVersion = null,
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .initial_version = "InitialVersion",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group) } {
            return .{ .service_metadata = service_metadata, .action = create_group };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_group_certificate_authority: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/groups/{GroupId}/certificateauthorities",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroupCertificateAuthority",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        group_id: []const u8,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = create_group_certificate_authority };
        }
    },
    Response: type = struct {
        group_certificate_authority_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_certificate_authority_arn = "GroupCertificateAuthorityArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_group_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/groups/{GroupId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroupVersion",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        connector_definition_version_arn: ?[]const u8 = null,
        core_definition_version_arn: ?[]const u8 = null,
        device_definition_version_arn: ?[]const u8 = null,
        function_definition_version_arn: ?[]const u8 = null,
        group_id: []const u8,
        logger_definition_version_arn: ?[]const u8 = null,
        resource_definition_version_arn: ?[]const u8 = null,
        subscription_definition_version_arn: ?[]const u8 = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .connector_definition_version_arn = "ConnectorDefinitionVersionArn",
                .core_definition_version_arn = "CoreDefinitionVersionArn",
                .device_definition_version_arn = "DeviceDefinitionVersionArn",
                .function_definition_version_arn = "FunctionDefinitionVersionArn",
                .group_id = "GroupId",
                .logger_definition_version_arn = "LoggerDefinitionVersionArn",
                .resource_definition_version_arn = "ResourceDefinitionVersionArn",
                .subscription_definition_version_arn = "SubscriptionDefinitionVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group_version) } {
            return .{ .service_metadata = service_metadata, .action = create_group_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_logger_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/loggers",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLoggerDefinition",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        initial_version: ?LoggerDefinitionVersion = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .initial_version = "InitialVersion",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_logger_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_logger_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_logger_definition_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/loggers/{LoggerDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLoggerDefinitionVersion",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        logger_definition_id: []const u8,
        loggers: ?[]Logger = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .logger_definition_id = "LoggerDefinitionId",
                .loggers = "Loggers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_logger_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = create_logger_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_resource_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResourceDefinition",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        initial_version: ?ResourceDefinitionVersion = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .initial_version = "InitialVersion",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_resource_definition_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/resources/{ResourceDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResourceDefinitionVersion",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        resource_definition_id: []const u8,
        resources: ?[]Resource = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .resource_definition_id = "ResourceDefinitionId",
                .resources = "Resources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_software_update_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/updates",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSoftwareUpdateJob",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        s3_url_signer_role: []const u8,
        software_to_update: []const u8,
        update_agent_log_level: ?[]const u8 = null,
        update_targets: [][]const u8,
        update_targets_architecture: []const u8,
        update_targets_operating_system: []const u8,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .s3_url_signer_role = "S3UrlSignerRole",
                .software_to_update = "SoftwareToUpdate",
                .update_agent_log_level = "UpdateAgentLogLevel",
                .update_targets = "UpdateTargets",
                .update_targets_architecture = "UpdateTargetsArchitecture",
                .update_targets_operating_system = "UpdateTargetsOperatingSystem",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_software_update_job) } {
            return .{ .service_metadata = service_metadata, .action = create_software_update_job };
        }
    },
    Response: type = struct {
        iot_job_arn: ?[]const u8 = null,
        iot_job_id: ?[]const u8 = null,
        platform_software_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iot_job_arn = "IotJobArn",
                .iot_job_id = "IotJobId",
                .platform_software_version = "PlatformSoftwareVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_subscription_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/subscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSubscriptionDefinition",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        initial_version: ?SubscriptionDefinitionVersion = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .initial_version = "InitialVersion",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subscription_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_subscription_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const create_subscription_definition_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/definition/subscriptions/{SubscriptionDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSubscriptionDefinitionVersion",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        subscription_definition_id: []const u8,
        subscriptions: ?[]Subscription = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .subscription_definition_id = "SubscriptionDefinitionId",
                .subscriptions = "Subscriptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subscription_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = create_subscription_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const delete_connector_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/definition/connectors/{ConnectorDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConnectorDefinition",
    Request: type = struct {
        connector_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_definition_id = "ConnectorDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connector_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_connector_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const delete_core_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/definition/cores/{CoreDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCoreDefinition",
    Request: type = struct {
        core_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_definition_id = "CoreDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_core_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_core_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const delete_device_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/definition/devices/{DeviceDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDeviceDefinition",
    Request: type = struct {
        device_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_definition_id = "DeviceDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_device_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const delete_function_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/definition/functions/{FunctionDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFunctionDefinition",
    Request: type = struct {
        function_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_definition_id = "FunctionDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_function_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_function_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const delete_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/groups/{GroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const delete_logger_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/definition/loggers/{LoggerDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLoggerDefinition",
    Request: type = struct {
        logger_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logger_definition_id = "LoggerDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_logger_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_logger_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const delete_resource_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/definition/resources/{ResourceDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResourceDefinition",
    Request: type = struct {
        resource_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_definition_id = "ResourceDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const delete_subscription_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/definition/subscriptions/{SubscriptionDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSubscriptionDefinition",
    Request: type = struct {
        subscription_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_definition_id = "SubscriptionDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subscription_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_subscription_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const disassociate_role_from_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/groups/{GroupId}/role",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateRoleFromGroup",
    Request: type = struct {
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_role_from_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_role_from_group };
        }
    },
    Response: type = struct {
        disassociated_at: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .disassociated_at = "DisassociatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const disassociate_service_role_from_account: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/greengrass/servicerole",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateServiceRoleFromAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_service_role_from_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_service_role_from_account };
        }
    },
    Response: type = struct {
        disassociated_at: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .disassociated_at = "DisassociatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const get_associated_role: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}/role",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssociatedRole",
    Request: type = struct {
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_associated_role) } {
            return .{ .service_metadata = service_metadata, .action = get_associated_role };
        }
    },
    Response: type = struct {
        associated_at: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associated_at = "AssociatedAt",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_bulk_deployment_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/bulk/deployments/{BulkDeploymentId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBulkDeploymentStatus",
    Request: type = struct {
        bulk_deployment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bulk_deployment_id = "BulkDeploymentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bulk_deployment_status) } {
            return .{ .service_metadata = service_metadata, .action = get_bulk_deployment_status };
        }
    },
    Response: type = struct {
        bulk_deployment_metrics: ?struct {
            invalid_input_records: ?i64 = null,
            records_processed: ?i64 = null,
            retry_attempts: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .invalid_input_records = "InvalidInputRecords",
                    .records_processed = "RecordsProcessed",
                    .retry_attempts = "RetryAttempts",
                };
                return @field(mappings, field_name);
            }
        } = null,
        bulk_deployment_status: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        error_details: ?[]ErrorDetail = null,
        error_message: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bulk_deployment_metrics = "BulkDeploymentMetrics",
                .bulk_deployment_status = "BulkDeploymentStatus",
                .created_at = "CreatedAt",
                .error_details = "ErrorDetails",
                .error_message = "ErrorMessage",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_connectivity_info: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/things/{ThingName}/connectivityInfo",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnectivityInfo",
    Request: type = struct {
        thing_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "ThingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connectivity_info) } {
            return .{ .service_metadata = service_metadata, .action = get_connectivity_info };
        }
    },
    Response: type = struct {
        connectivity_info: ?[]ConnectivityInfo = null,
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connectivity_info = "ConnectivityInfo",
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_connector_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/connectors/{ConnectorDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnectorDefinition",
    Request: type = struct {
        connector_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_definition_id = "ConnectorDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connector_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_connector_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_connector_definition_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/connectors/{ConnectorDefinitionId}/versions/{ConnectorDefinitionVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnectorDefinitionVersion",
    Request: type = struct {
        connector_definition_id: []const u8,
        connector_definition_version_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_definition_id = "ConnectorDefinitionId",
                .connector_definition_version_id = "ConnectorDefinitionVersionId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connector_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = get_connector_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        definition: ?ConnectorDefinitionVersion = null,
        id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .definition = "Definition",
                .id = "Id",
                .next_token = "NextToken",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_core_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/cores/{CoreDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCoreDefinition",
    Request: type = struct {
        core_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_definition_id = "CoreDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_core_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_core_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_core_definition_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/cores/{CoreDefinitionId}/versions/{CoreDefinitionVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCoreDefinitionVersion",
    Request: type = struct {
        core_definition_id: []const u8,
        core_definition_version_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_definition_id = "CoreDefinitionId",
                .core_definition_version_id = "CoreDefinitionVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_core_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = get_core_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        definition: ?CoreDefinitionVersion = null,
        id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .definition = "Definition",
                .id = "Id",
                .next_token = "NextToken",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_deployment_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}/deployments/{DeploymentId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeploymentStatus",
    Request: type = struct {
        deployment_id: []const u8,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_id = "DeploymentId",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployment_status) } {
            return .{ .service_metadata = service_metadata, .action = get_deployment_status };
        }
    },
    Response: type = struct {
        deployment_status: ?[]const u8 = null,
        deployment_type: ?[]const u8 = null,
        error_details: ?[]ErrorDetail = null,
        error_message: ?[]const u8 = null,
        updated_at: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_status = "DeploymentStatus",
                .deployment_type = "DeploymentType",
                .error_details = "ErrorDetails",
                .error_message = "ErrorMessage",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_device_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/devices/{DeviceDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeviceDefinition",
    Request: type = struct {
        device_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_definition_id = "DeviceDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_device_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_device_definition_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/devices/{DeviceDefinitionId}/versions/{DeviceDefinitionVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeviceDefinitionVersion",
    Request: type = struct {
        device_definition_id: []const u8,
        device_definition_version_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_definition_id = "DeviceDefinitionId",
                .device_definition_version_id = "DeviceDefinitionVersionId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = get_device_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        definition: ?DeviceDefinitionVersion = null,
        id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .definition = "Definition",
                .id = "Id",
                .next_token = "NextToken",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_function_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/functions/{FunctionDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunctionDefinition",
    Request: type = struct {
        function_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_definition_id = "FunctionDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_function_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_function_definition_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/functions/{FunctionDefinitionId}/versions/{FunctionDefinitionVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunctionDefinitionVersion",
    Request: type = struct {
        function_definition_id: []const u8,
        function_definition_version_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_definition_id = "FunctionDefinitionId",
                .function_definition_version_id = "FunctionDefinitionVersionId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = get_function_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        definition: ?FunctionDefinitionVersion = null,
        id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .definition = "Definition",
                .id = "Id",
                .next_token = "NextToken",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroup",
    Request: type = struct {
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group) } {
            return .{ .service_metadata = service_metadata, .action = get_group };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_group_certificate_authority: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}/certificateauthorities/{CertificateAuthorityId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroupCertificateAuthority",
    Request: type = struct {
        certificate_authority_id: []const u8,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_id = "CertificateAuthorityId",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = get_group_certificate_authority };
        }
    },
    Response: type = struct {
        group_certificate_authority_arn: ?[]const u8 = null,
        group_certificate_authority_id: ?[]const u8 = null,
        pem_encoded_certificate: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_certificate_authority_arn = "GroupCertificateAuthorityArn",
                .group_certificate_authority_id = "GroupCertificateAuthorityId",
                .pem_encoded_certificate = "PemEncodedCertificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_group_certificate_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}/certificateauthorities/configuration/expiry",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroupCertificateConfiguration",
    Request: type = struct {
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group_certificate_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_group_certificate_configuration };
        }
    },
    Response: type = struct {
        certificate_authority_expiry_in_milliseconds: ?[]const u8 = null,
        certificate_expiry_in_milliseconds: ?[]const u8 = null,
        group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_expiry_in_milliseconds = "CertificateAuthorityExpiryInMilliseconds",
                .certificate_expiry_in_milliseconds = "CertificateExpiryInMilliseconds",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_group_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}/versions/{GroupVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroupVersion",
    Request: type = struct {
        group_id: []const u8,
        group_version_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .group_version_id = "GroupVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group_version) } {
            return .{ .service_metadata = service_metadata, .action = get_group_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        definition: ?GroupVersion = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .definition = "Definition",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_logger_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/loggers/{LoggerDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLoggerDefinition",
    Request: type = struct {
        logger_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logger_definition_id = "LoggerDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_logger_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_logger_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_logger_definition_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/loggers/{LoggerDefinitionId}/versions/{LoggerDefinitionVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLoggerDefinitionVersion",
    Request: type = struct {
        logger_definition_id: []const u8,
        logger_definition_version_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logger_definition_id = "LoggerDefinitionId",
                .logger_definition_version_id = "LoggerDefinitionVersionId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_logger_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = get_logger_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        definition: ?LoggerDefinitionVersion = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .definition = "Definition",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_resource_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/resources/{ResourceDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceDefinition",
    Request: type = struct {
        resource_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_definition_id = "ResourceDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_resource_definition_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/resources/{ResourceDefinitionId}/versions/{ResourceDefinitionVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceDefinitionVersion",
    Request: type = struct {
        resource_definition_id: []const u8,
        resource_definition_version_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_definition_id = "ResourceDefinitionId",
                .resource_definition_version_id = "ResourceDefinitionVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        definition: ?ResourceDefinitionVersion = null,
        id: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .definition = "Definition",
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_service_role_for_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/servicerole",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServiceRoleForAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_role_for_account) } {
            return .{ .service_metadata = service_metadata, .action = get_service_role_for_account };
        }
    },
    Response: type = struct {
        associated_at: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associated_at = "AssociatedAt",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const get_subscription_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/subscriptions/{SubscriptionDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSubscriptionDefinition",
    Request: type = struct {
        subscription_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_definition_id = "SubscriptionDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_subscription_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_subscription_definition };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        id: ?[]const u8 = null,
        last_updated_timestamp: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        latest_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .id = "Id",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .latest_version = "LatestVersion",
                .latest_version_arn = "LatestVersionArn",
                .name = "Name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_subscription_definition_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/subscriptions/{SubscriptionDefinitionId}/versions/{SubscriptionDefinitionVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSubscriptionDefinitionVersion",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        subscription_definition_id: []const u8,
        subscription_definition_version_id: []const u8,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .subscription_definition_id = "SubscriptionDefinitionId",
                .subscription_definition_version_id = "SubscriptionDefinitionVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_subscription_definition_version) } {
            return .{ .service_metadata = service_metadata, .action = get_subscription_definition_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_timestamp: ?[]const u8 = null,
        definition: ?SubscriptionDefinitionVersion = null,
        id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_timestamp = "CreationTimestamp",
                .definition = "Definition",
                .id = "Id",
                .next_token = "NextToken",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const get_thing_runtime_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/things/{ThingName}/runtimeconfig",
        .success_code = 200,
    };

    action_name: []const u8 = "GetThingRuntimeConfiguration",
    Request: type = struct {
        thing_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "ThingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_thing_runtime_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_thing_runtime_configuration };
        }
    },
    Response: type = struct {
        runtime_configuration: ?struct {
            telemetry_configuration: ?struct {
                configuration_sync_status: ?[]const u8 = null,
                telemetry: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .configuration_sync_status = "ConfigurationSyncStatus",
                        .telemetry = "Telemetry",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .telemetry_configuration = "TelemetryConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runtime_configuration = "RuntimeConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_bulk_deployment_detailed_reports: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/bulk/deployments/{BulkDeploymentId}/detailed-reports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBulkDeploymentDetailedReports",
    Request: type = struct {
        bulk_deployment_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bulk_deployment_id = "BulkDeploymentId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bulk_deployment_detailed_reports) } {
            return .{ .service_metadata = service_metadata, .action = list_bulk_deployment_detailed_reports };
        }
    },
    Response: type = struct {
        deployments: ?[]struct {
            created_at: ?[]const u8 = null,
            deployment_arn: ?[]const u8 = null,
            deployment_id: ?[]const u8 = null,
            deployment_status: ?[]const u8 = null,
            deployment_type: ?[]const u8 = null,
            error_details: ?[]ErrorDetail = null,
            error_message: ?[]const u8 = null,
            group_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "CreatedAt",
                    .deployment_arn = "DeploymentArn",
                    .deployment_id = "DeploymentId",
                    .deployment_status = "DeploymentStatus",
                    .deployment_type = "DeploymentType",
                    .error_details = "ErrorDetails",
                    .error_message = "ErrorMessage",
                    .group_arn = "GroupArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployments = "Deployments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_bulk_deployments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/bulk/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBulkDeployments",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bulk_deployments) } {
            return .{ .service_metadata = service_metadata, .action = list_bulk_deployments };
        }
    },
    Response: type = struct {
        bulk_deployments: ?[]struct {
            bulk_deployment_arn: ?[]const u8 = null,
            bulk_deployment_id: ?[]const u8 = null,
            created_at: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bulk_deployment_arn = "BulkDeploymentArn",
                    .bulk_deployment_id = "BulkDeploymentId",
                    .created_at = "CreatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bulk_deployments = "BulkDeployments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_connector_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/connectors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConnectorDefinitions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connector_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_connector_definitions };
        }
    },
    Response: type = struct {
        definitions: ?[]DefinitionInformation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definitions = "Definitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_connector_definition_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/connectors/{ConnectorDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConnectorDefinitionVersions",
    Request: type = struct {
        connector_definition_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_definition_id = "ConnectorDefinitionId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connector_definition_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_connector_definition_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]VersionInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_core_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/cores",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCoreDefinitions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_core_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_core_definitions };
        }
    },
    Response: type = struct {
        definitions: ?[]DefinitionInformation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definitions = "Definitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_core_definition_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/cores/{CoreDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCoreDefinitionVersions",
    Request: type = struct {
        core_definition_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_definition_id = "CoreDefinitionId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_core_definition_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_core_definition_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]VersionInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_deployments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeployments",
    Request: type = struct {
        group_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_deployments) } {
            return .{ .service_metadata = service_metadata, .action = list_deployments };
        }
    },
    Response: type = struct {
        deployments: ?[]struct {
            created_at: ?[]const u8 = null,
            deployment_arn: ?[]const u8 = null,
            deployment_id: ?[]const u8 = null,
            deployment_type: ?[]const u8 = null,
            group_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "CreatedAt",
                    .deployment_arn = "DeploymentArn",
                    .deployment_id = "DeploymentId",
                    .deployment_type = "DeploymentType",
                    .group_arn = "GroupArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployments = "Deployments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_device_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeviceDefinitions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_device_definitions };
        }
    },
    Response: type = struct {
        definitions: ?[]DefinitionInformation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definitions = "Definitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_device_definition_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/devices/{DeviceDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeviceDefinitionVersions",
    Request: type = struct {
        device_definition_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_definition_id = "DeviceDefinitionId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_definition_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_device_definition_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]VersionInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_function_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/functions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFunctionDefinitions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_function_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_function_definitions };
        }
    },
    Response: type = struct {
        definitions: ?[]DefinitionInformation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definitions = "Definitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_function_definition_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/functions/{FunctionDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFunctionDefinitionVersions",
    Request: type = struct {
        function_definition_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_definition_id = "FunctionDefinitionId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_function_definition_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_function_definition_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]VersionInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_group_certificate_authorities: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}/certificateauthorities",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroupCertificateAuthorities",
    Request: type = struct {
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_group_certificate_authorities) } {
            return .{ .service_metadata = service_metadata, .action = list_group_certificate_authorities };
        }
    },
    Response: type = struct {
        group_certificate_authorities: ?[]struct {
            group_certificate_authority_arn: ?[]const u8 = null,
            group_certificate_authority_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_certificate_authority_arn = "GroupCertificateAuthorityArn",
                    .group_certificate_authority_id = "GroupCertificateAuthorityId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_certificate_authorities = "GroupCertificateAuthorities",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        groups: ?[]struct {
            arn: ?[]const u8 = null,
            creation_timestamp: ?[]const u8 = null,
            id: ?[]const u8 = null,
            last_updated_timestamp: ?[]const u8 = null,
            latest_version: ?[]const u8 = null,
            latest_version_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .creation_timestamp = "CreationTimestamp",
                    .id = "Id",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .latest_version = "LatestVersion",
                    .latest_version_arn = "LatestVersionArn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_group_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/groups/{GroupId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroupVersions",
    Request: type = struct {
        group_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_group_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_group_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]VersionInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_logger_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/loggers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLoggerDefinitions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_logger_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_logger_definitions };
        }
    },
    Response: type = struct {
        definitions: ?[]DefinitionInformation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definitions = "Definitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_logger_definition_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/loggers/{LoggerDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLoggerDefinitionVersions",
    Request: type = struct {
        logger_definition_id: []const u8,
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logger_definition_id = "LoggerDefinitionId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_logger_definition_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_logger_definition_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]VersionInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_resource_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourceDefinitions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_definitions };
        }
    },
    Response: type = struct {
        definitions: ?[]DefinitionInformation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definitions = "Definitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_resource_definition_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/resources/{ResourceDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourceDefinitionVersions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        resource_definition_id: []const u8,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .resource_definition_id = "ResourceDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_definition_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_definition_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]VersionInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_subscription_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/subscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSubscriptionDefinitions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscription_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_subscription_definitions };
        }
    },
    Response: type = struct {
        definitions: ?[]DefinitionInformation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definitions = "Definitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_subscription_definition_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/greengrass/definition/subscriptions/{SubscriptionDefinitionId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSubscriptionDefinitionVersions",
    Request: type = struct {
        max_results: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        subscription_definition_id: []const u8,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .subscription_definition_id = "SubscriptionDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscription_definition_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_subscription_definition_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]VersionInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const reset_deployments: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/groups/{GroupId}/deployments/$reset",
        .success_code = 200,
    };

    action_name: []const u8 = "ResetDeployments",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        force: ?bool = null,
        group_id: []const u8,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .force = "Force",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_deployments) } {
            return .{ .service_metadata = service_metadata, .action = reset_deployments };
        }
    },
    Response: type = struct {
        deployment_arn: ?[]const u8 = null,
        deployment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_arn = "DeploymentArn",
                .deployment_id = "DeploymentId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const start_bulk_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/greengrass/bulk/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "StartBulkDeployment",
    Request: type = struct {
        amzn_client_token: ?[]const u8 = null,
        execution_role_arn: []const u8,
        input_file_uri: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .amzn_client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amzn_client_token = "AmznClientToken",
                .execution_role_arn = "ExecutionRoleArn",
                .input_file_uri = "InputFileUri",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_bulk_deployment) } {
            return .{ .service_metadata = service_metadata, .action = start_bulk_deployment };
        }
    },
    Response: type = struct {
        bulk_deployment_arn: ?[]const u8 = null,
        bulk_deployment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bulk_deployment_arn = "BulkDeploymentArn",
                .bulk_deployment_id = "BulkDeploymentId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const stop_bulk_deployment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/bulk/deployments/{BulkDeploymentId}/$stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopBulkDeployment",
    Request: type = struct {
        bulk_deployment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bulk_deployment_id = "BulkDeploymentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_bulk_deployment) } {
            return .{ .service_metadata = service_metadata, .action = stop_bulk_deployment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_connectivity_info: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/things/{ThingName}/connectivityInfo",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConnectivityInfo",
    Request: type = struct {
        connectivity_info: ?[]ConnectivityInfo = null,
        thing_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connectivity_info = "ConnectivityInfo",
                .thing_name = "ThingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connectivity_info) } {
            return .{ .service_metadata = service_metadata, .action = update_connectivity_info };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "message",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_connector_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/definition/connectors/{ConnectorDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConnectorDefinition",
    Request: type = struct {
        connector_definition_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_definition_id = "ConnectorDefinitionId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connector_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_connector_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_core_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/definition/cores/{CoreDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCoreDefinition",
    Request: type = struct {
        core_definition_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_definition_id = "CoreDefinitionId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_core_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_core_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_device_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/definition/devices/{DeviceDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDeviceDefinition",
    Request: type = struct {
        device_definition_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_definition_id = "DeviceDefinitionId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_device_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_function_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/definition/functions/{FunctionDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFunctionDefinition",
    Request: type = struct {
        function_definition_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_definition_id = "FunctionDefinitionId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_function_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_function_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/groups/{GroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGroup",
    Request: type = struct {
        group_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group) } {
            return .{ .service_metadata = service_metadata, .action = update_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_group_certificate_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/groups/{GroupId}/certificateauthorities/configuration/expiry",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGroupCertificateConfiguration",
    Request: type = struct {
        certificate_expiry_in_milliseconds: ?[]const u8 = null,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_expiry_in_milliseconds = "CertificateExpiryInMilliseconds",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group_certificate_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_group_certificate_configuration };
        }
    },
    Response: type = struct {
        certificate_authority_expiry_in_milliseconds: ?[]const u8 = null,
        certificate_expiry_in_milliseconds: ?[]const u8 = null,
        group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_authority_expiry_in_milliseconds = "CertificateAuthorityExpiryInMilliseconds",
                .certificate_expiry_in_milliseconds = "CertificateExpiryInMilliseconds",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_logger_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/definition/loggers/{LoggerDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLoggerDefinition",
    Request: type = struct {
        logger_definition_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logger_definition_id = "LoggerDefinitionId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_logger_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_logger_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_resource_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/definition/resources/{ResourceDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourceDefinition",
    Request: type = struct {
        name: ?[]const u8 = null,
        resource_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .resource_definition_id = "ResourceDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_subscription_definition: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/definition/subscriptions/{SubscriptionDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSubscriptionDefinition",
    Request: type = struct {
        name: ?[]const u8 = null,
        subscription_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .subscription_definition_id = "SubscriptionDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subscription_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_subscription_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_thing_runtime_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/greengrass/things/{ThingName}/runtimeconfig",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThingRuntimeConfiguration",
    Request: type = struct {
        telemetry_configuration: ?struct {
            telemetry: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .telemetry = "Telemetry",
                };
                return @field(mappings, field_name);
            }
        } = null,
        thing_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .telemetry_configuration = "TelemetryConfiguration",
                .thing_name = "ThingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_thing_runtime_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_thing_runtime_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};

pub const ConnectivityInfo = struct {
    host_address: ?[]const u8 = null,
    id: ?[]const u8 = null,
    metadata: ?[]const u8 = null,
    port_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_address = "HostAddress",
            .id = "Id",
            .metadata = "Metadata",
            .port_number = "PortNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const VersionInformation = struct {
    arn: ?[]const u8 = null,
    creation_timestamp: ?[]const u8 = null,
    id: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .creation_timestamp = "CreationTimestamp",
            .id = "Id",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const DefinitionInformation = struct {
    arn: ?[]const u8 = null,
    creation_timestamp: ?[]const u8 = null,
    id: ?[]const u8 = null,
    last_updated_timestamp: ?[]const u8 = null,
    latest_version: ?[]const u8 = null,
    latest_version_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .creation_timestamp = "CreationTimestamp",
            .id = "Id",
            .last_updated_timestamp = "LastUpdatedTimestamp",
            .latest_version = "LatestVersion",
            .latest_version_arn = "LatestVersionArn",
            .name = "Name",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ErrorDetail = struct {
    detailed_error_code: ?[]const u8 = null,
    detailed_error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detailed_error_code = "DetailedErrorCode",
            .detailed_error_message = "DetailedErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscriptionDefinitionVersion = struct {
    subscriptions: ?[]Subscription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subscriptions = "Subscriptions",
        };
        return @field(mappings, field_name);
    }
};

pub const Subscription = struct {
    id: []const u8,
    source: []const u8,
    subject: []const u8,
    target: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .source = "Source",
            .subject = "Subject",
            .target = "Target",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDefinitionVersion = struct {
    resources: ?[]Resource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resources = "Resources",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    id: []const u8,
    name: []const u8,
    resource_data_container: ResourceDataContainer,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .resource_data_container = "ResourceDataContainer",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDataContainer = struct {
    local_device_resource_data: ?LocalDeviceResourceData = null,
    local_volume_resource_data: ?LocalVolumeResourceData = null,
    s3_machine_learning_model_resource_data: ?S3MachineLearningModelResourceData = null,
    sage_maker_machine_learning_model_resource_data: ?SageMakerMachineLearningModelResourceData = null,
    secrets_manager_secret_resource_data: ?SecretsManagerSecretResourceData = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_device_resource_data = "LocalDeviceResourceData",
            .local_volume_resource_data = "LocalVolumeResourceData",
            .s3_machine_learning_model_resource_data = "S3MachineLearningModelResourceData",
            .sage_maker_machine_learning_model_resource_data = "SageMakerMachineLearningModelResourceData",
            .secrets_manager_secret_resource_data = "SecretsManagerSecretResourceData",
        };
        return @field(mappings, field_name);
    }
};

pub const SecretsManagerSecretResourceData = struct {
    arn: ?[]const u8 = null,
    additional_staging_labels_to_download: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "ARN",
            .additional_staging_labels_to_download = "AdditionalStagingLabelsToDownload",
        };
        return @field(mappings, field_name);
    }
};

pub const SageMakerMachineLearningModelResourceData = struct {
    destination_path: ?[]const u8 = null,
    owner_setting: ?ResourceDownloadOwnerSetting = null,
    sage_maker_job_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_path = "DestinationPath",
            .owner_setting = "OwnerSetting",
            .sage_maker_job_arn = "SageMakerJobArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDownloadOwnerSetting = struct {
    group_owner: []const u8,
    group_permission: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_owner = "GroupOwner",
            .group_permission = "GroupPermission",
        };
        return @field(mappings, field_name);
    }
};

pub const S3MachineLearningModelResourceData = struct {
    destination_path: ?[]const u8 = null,
    owner_setting: ?ResourceDownloadOwnerSetting = null,
    s3_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_path = "DestinationPath",
            .owner_setting = "OwnerSetting",
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalVolumeResourceData = struct {
    destination_path: ?[]const u8 = null,
    group_owner_setting: ?GroupOwnerSetting = null,
    source_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_path = "DestinationPath",
            .group_owner_setting = "GroupOwnerSetting",
            .source_path = "SourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupOwnerSetting = struct {
    auto_add_group_owner: ?bool = null,
    group_owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_add_group_owner = "AutoAddGroupOwner",
            .group_owner = "GroupOwner",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalDeviceResourceData = struct {
    group_owner_setting: ?GroupOwnerSetting = null,
    source_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_owner_setting = "GroupOwnerSetting",
            .source_path = "SourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggerDefinitionVersion = struct {
    loggers: ?[]Logger = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .loggers = "Loggers",
        };
        return @field(mappings, field_name);
    }
};

pub const Logger = struct {
    component: []const u8,
    id: []const u8,
    level: []const u8,
    space: ?i64 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component = "Component",
            .id = "Id",
            .level = "Level",
            .space = "Space",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupVersion = struct {
    connector_definition_version_arn: ?[]const u8 = null,
    core_definition_version_arn: ?[]const u8 = null,
    device_definition_version_arn: ?[]const u8 = null,
    function_definition_version_arn: ?[]const u8 = null,
    logger_definition_version_arn: ?[]const u8 = null,
    resource_definition_version_arn: ?[]const u8 = null,
    subscription_definition_version_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_definition_version_arn = "ConnectorDefinitionVersionArn",
            .core_definition_version_arn = "CoreDefinitionVersionArn",
            .device_definition_version_arn = "DeviceDefinitionVersionArn",
            .function_definition_version_arn = "FunctionDefinitionVersionArn",
            .logger_definition_version_arn = "LoggerDefinitionVersionArn",
            .resource_definition_version_arn = "ResourceDefinitionVersionArn",
            .subscription_definition_version_arn = "SubscriptionDefinitionVersionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionDefinitionVersion = struct {
    default_config: ?FunctionDefaultConfig = null,
    functions: ?[]Function = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_config = "DefaultConfig",
            .functions = "Functions",
        };
        return @field(mappings, field_name);
    }
};

pub const Function = struct {
    function_arn: ?[]const u8 = null,
    function_configuration: ?FunctionConfiguration = null,
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "FunctionArn",
            .function_configuration = "FunctionConfiguration",
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionConfiguration = struct {
    encoding_type: ?[]const u8 = null,
    environment: ?FunctionConfigurationEnvironment = null,
    exec_args: ?[]const u8 = null,
    executable: ?[]const u8 = null,
    memory_size: ?i64 = null,
    pinned: ?bool = null,
    timeout: ?i64 = null,
    function_runtime_override: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encoding_type = "EncodingType",
            .environment = "Environment",
            .exec_args = "ExecArgs",
            .executable = "Executable",
            .memory_size = "MemorySize",
            .pinned = "Pinned",
            .timeout = "Timeout",
            .function_runtime_override = "FunctionRuntimeOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionConfigurationEnvironment = struct {
    access_sysfs: ?bool = null,
    execution: ?FunctionExecutionConfig = null,
    resource_access_policies: ?[]ResourceAccessPolicy = null,
    variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_sysfs = "AccessSysfs",
            .execution = "Execution",
            .resource_access_policies = "ResourceAccessPolicies",
            .variables = "Variables",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "variables", field_name))
            return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
        return false;
    }
};

pub const ResourceAccessPolicy = struct {
    permission: ?[]const u8 = null,
    resource_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .permission = "Permission",
            .resource_id = "ResourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionExecutionConfig = struct {
    isolation_mode: ?[]const u8 = null,
    run_as: ?FunctionRunAsConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .isolation_mode = "IsolationMode",
            .run_as = "RunAs",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionRunAsConfig = struct {
    gid: ?i64 = null,
    uid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gid = "Gid",
            .uid = "Uid",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionDefaultConfig = struct {
    execution: ?FunctionDefaultExecutionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execution = "Execution",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionDefaultExecutionConfig = struct {
    isolation_mode: ?[]const u8 = null,
    run_as: ?FunctionRunAsConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .isolation_mode = "IsolationMode",
            .run_as = "RunAs",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceDefinitionVersion = struct {
    devices: ?[]Device = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .devices = "Devices",
        };
        return @field(mappings, field_name);
    }
};

pub const Device = struct {
    certificate_arn: []const u8,
    id: []const u8,
    sync_shadow: ?bool = null,
    thing_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "CertificateArn",
            .id = "Id",
            .sync_shadow = "SyncShadow",
            .thing_arn = "ThingArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CoreDefinitionVersion = struct {
    cores: ?[]Core = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cores = "Cores",
        };
        return @field(mappings, field_name);
    }
};

pub const Core = struct {
    certificate_arn: []const u8,
    id: []const u8,
    sync_shadow: ?bool = null,
    thing_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "CertificateArn",
            .id = "Id",
            .sync_shadow = "SyncShadow",
            .thing_arn = "ThingArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorDefinitionVersion = struct {
    connectors: ?[]Connector = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connectors = "Connectors",
        };
        return @field(mappings, field_name);
    }
};

pub const Connector = struct {
    connector_arn: []const u8,
    id: []const u8,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connector_arn = "ConnectorArn",
            .id = "Id",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};
