const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-11-28";
pub const sdk_id: []const u8 = "GuardDuty";
pub const arn_namespace: ?[]const u8 = "guardduty";
pub const endpoint_prefix: []const u8 = "guardduty";
pub const sigv4_name: []const u8 = "guardduty";
pub const name: []const u8 = "GuardDutyAPIService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-11-28",
    sdk_id: []const u8 = "GuardDuty",
    arn_namespace: ?[]const u8 = "guardduty",
    endpoint_prefix: []const u8 = "guardduty",
    sigv4_name: []const u8 = "guardduty",
    name: []const u8 = "GuardDutyAPIService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_administrator_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/administrator",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptAdministratorInvitation",
    Request: type = struct {
        detector_id: []const u8,
        administrator_id: []const u8,
        invitation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .administrator_id = "administratorId",
                .invitation_id = "invitationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_administrator_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_administrator_invitation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const accept_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/master",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptInvitation",
    Request: type = struct {
        detector_id: []const u8,
        master_id: []const u8,
        invitation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .master_id = "masterId",
                .invitation_id = "invitationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_invitation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const archive_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/findings/archive",
        .success_code = 200,
    };

    action_name: []const u8 = "ArchiveFindings",
    Request: type = struct {
        detector_id: []const u8,
        finding_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .finding_ids = "findingIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(archive_findings) } {
            return .{ .service_metadata = service_metadata, .action = archive_findings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDetector",
    Request: type = struct {
        enable: bool,
        client_token: ?[]const u8 = null,
        finding_publishing_frequency: ?[]const u8 = null,
        data_sources: ?DataSourceConfigurations = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        features: ?[]DetectorFeatureConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enable = "enable",
                .client_token = "clientToken",
                .finding_publishing_frequency = "findingPublishingFrequency",
                .data_sources = "dataSources",
                .tags = "tags",
                .features = "features",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_detector) } {
            return .{ .service_metadata = service_metadata, .action = create_detector };
        }
    },
    Response: type = struct {
        detector_id: ?[]const u8 = null,
        unprocessed_data_sources: ?struct {
            malware_protection: ?MalwareProtectionConfigurationResult = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .malware_protection = "malwareProtection",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .unprocessed_data_sources = "unprocessedDataSources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/filter",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFilter",
    Request: type = struct {
        detector_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        action: ?[]const u8 = null,
        rank: ?i64 = null,
        finding_criteria: FindingCriteria,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .name = "name",
                .description = "description",
                .action = "action",
                .rank = "rank",
                .finding_criteria = "findingCriteria",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_filter) } {
            return .{ .service_metadata = service_metadata, .action = create_filter };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_ip_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/ipset",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIPSet",
    Request: type = struct {
        detector_id: []const u8,
        name: []const u8,
        format: []const u8,
        location: []const u8,
        activate: bool,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .name = "name",
                .format = "format",
                .location = "location",
                .activate = "activate",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = create_ip_set };
        }
    },
    Response: type = struct {
        ip_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set_id = "ipSetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMembers",
    Request: type = struct {
        detector_id: []const u8,
        account_details: []struct {
            account_id: []const u8,
            email: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .email = "email",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_details = "accountDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_members) } {
            return .{ .service_metadata = service_metadata, .action = create_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_publishing_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/publishingDestination",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePublishingDestination",
    Request: type = struct {
        detector_id: []const u8,
        destination_type: []const u8,
        destination_properties: DestinationProperties,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .destination_type = "destinationType",
                .destination_properties = "destinationProperties",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_publishing_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_publishing_destination };
        }
    },
    Response: type = struct {
        destination_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_id = "destinationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_sample_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/findings/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSampleFindings",
    Request: type = struct {
        detector_id: []const u8,
        finding_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .finding_types = "findingTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sample_findings) } {
            return .{ .service_metadata = service_metadata, .action = create_sample_findings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const create_threat_intel_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/threatintelset",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateThreatIntelSet",
    Request: type = struct {
        detector_id: []const u8,
        name: []const u8,
        format: []const u8,
        location: []const u8,
        activate: bool,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .name = "name",
                .format = "format",
                .location = "location",
                .activate = "activate",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_threat_intel_set) } {
            return .{ .service_metadata = service_metadata, .action = create_threat_intel_set };
        }
    },
    Response: type = struct {
        threat_intel_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .threat_intel_set_id = "threatIntelSetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const decline_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitation/decline",
        .success_code = 200,
    };

    action_name: []const u8 = "DeclineInvitations",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decline_invitations) } {
            return .{ .service_metadata = service_metadata, .action = decline_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const delete_detector: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/detector/{DetectorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDetector",
    Request: type = struct {
        detector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_detector) } {
            return .{ .service_metadata = service_metadata, .action = delete_detector };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const delete_filter: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/detector/{DetectorId}/filter/{FilterName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFilter",
    Request: type = struct {
        detector_id: []const u8,
        filter_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .filter_name = "filterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_filter) } {
            return .{ .service_metadata = service_metadata, .action = delete_filter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const delete_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitation/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInvitations",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_invitations) } {
            return .{ .service_metadata = service_metadata, .action = delete_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const delete_ip_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/detector/{DetectorId}/ipset/{IpSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIPSet",
    Request: type = struct {
        detector_id: []const u8,
        ip_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .ip_set_id = "ipSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_ip_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const delete_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMembers",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_members) } {
            return .{ .service_metadata = service_metadata, .action = delete_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const delete_publishing_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/detector/{DetectorId}/publishingDestination/{DestinationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePublishingDestination",
    Request: type = struct {
        detector_id: []const u8,
        destination_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .destination_id = "destinationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_publishing_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_publishing_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const delete_threat_intel_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/detector/{DetectorId}/threatintelset/{ThreatIntelSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteThreatIntelSet",
    Request: type = struct {
        detector_id: []const u8,
        threat_intel_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .threat_intel_set_id = "threatIntelSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_threat_intel_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_threat_intel_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const describe_malware_scans: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/malware-scans",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeMalwareScans",
    Request: type = struct {
        detector_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter_criteria: ?struct {
            filter_criterion: ?[]struct {
                criterion_key: ?[]const u8 = null,
                filter_condition: ?struct {
                    equals_value: ?[]const u8 = null,
                    greater_than: ?i64 = null,
                    less_than: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .equals_value = "equalsValue",
                            .greater_than = "greaterThan",
                            .less_than = "lessThan",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .criterion_key = "criterionKey",
                        .filter_condition = "filterCondition",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .filter_criterion = "filterCriterion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort_criteria: ?SortCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filter_criteria = "filterCriteria",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_malware_scans) } {
            return .{ .service_metadata = service_metadata, .action = describe_malware_scans };
        }
    },
    Response: type = struct {
        scans: []struct {
            detector_id: ?[]const u8 = null,
            admin_detector_id: ?[]const u8 = null,
            scan_id: ?[]const u8 = null,
            scan_status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            scan_start_time: ?i64 = null,
            scan_end_time: ?i64 = null,
            trigger_details: ?struct {
                guard_duty_finding_id: ?[]const u8 = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .guard_duty_finding_id = "guardDutyFindingId",
                        .description = "description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            resource_details: ?struct {
                instance_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .instance_arn = "instanceArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            scan_result_details: ?struct {
                scan_result: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .scan_result = "scanResult",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            account_id: ?[]const u8 = null,
            total_bytes: ?i64 = null,
            file_count: ?i64 = null,
            attached_volumes: ?[]VolumeDetail = null,
            scan_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .detector_id = "detectorId",
                    .admin_detector_id = "adminDetectorId",
                    .scan_id = "scanId",
                    .scan_status = "scanStatus",
                    .failure_reason = "failureReason",
                    .scan_start_time = "scanStartTime",
                    .scan_end_time = "scanEndTime",
                    .trigger_details = "triggerDetails",
                    .resource_details = "resourceDetails",
                    .scan_result_details = "scanResultDetails",
                    .account_id = "accountId",
                    .total_bytes = "totalBytes",
                    .file_count = "fileCount",
                    .attached_volumes = "attachedVolumes",
                    .scan_type = "scanType",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scans = "scans",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const describe_organization_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/admin",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationConfiguration",
    Request: type = struct {
        detector_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_configuration };
        }
    },
    Response: type = struct {
        auto_enable: ?bool = null,
        member_account_limit_reached: bool,
        data_sources: ?struct {
            s3_logs: struct {
                auto_enable: bool,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .auto_enable = "autoEnable",
                    };
                    return @field(mappings, field_name);
                }
            },
            kubernetes: ?struct {
                audit_logs: struct {
                    auto_enable: bool,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .auto_enable = "autoEnable",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .audit_logs = "auditLogs",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            malware_protection: ?struct {
                scan_ec2_instance_with_findings: ?struct {
                    ebs_volumes: ?struct {
                        auto_enable: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .auto_enable = "autoEnable",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .ebs_volumes = "ebsVolumes",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .scan_ec2_instance_with_findings = "scanEc2InstanceWithFindings",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_logs = "s3Logs",
                    .kubernetes = "kubernetes",
                    .malware_protection = "malwareProtection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        features: ?[]struct {
            name: ?[]const u8 = null,
            auto_enable: ?[]const u8 = null,
            additional_configuration: ?[]struct {
                name: ?[]const u8 = null,
                auto_enable: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .auto_enable = "autoEnable",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .auto_enable = "autoEnable",
                    .additional_configuration = "additionalConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        auto_enable_organization_members: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "autoEnable",
                .member_account_limit_reached = "memberAccountLimitReached",
                .data_sources = "dataSources",
                .features = "features",
                .next_token = "nextToken",
                .auto_enable_organization_members = "autoEnableOrganizationMembers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const describe_publishing_destination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/publishingDestination/{DestinationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePublishingDestination",
    Request: type = struct {
        detector_id: []const u8,
        destination_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .destination_id = "destinationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_publishing_destination) } {
            return .{ .service_metadata = service_metadata, .action = describe_publishing_destination };
        }
    },
    Response: type = struct {
        destination_id: []const u8,
        destination_type: []const u8,
        status: []const u8,
        publishing_failure_start_timestamp: i64,
        destination_properties: DestinationProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_id = "destinationId",
                .destination_type = "destinationType",
                .status = "status",
                .publishing_failure_start_timestamp = "publishingFailureStartTimestamp",
                .destination_properties = "destinationProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const disable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/admin/disable",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "adminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = disable_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const disassociate_from_administrator_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/administrator/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFromAdministratorAccount",
    Request: type = struct {
        detector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_from_administrator_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_from_administrator_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const disassociate_from_master_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/master/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFromMasterAccount",
    Request: type = struct {
        detector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_from_master_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_from_master_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const disassociate_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateMembers",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_members) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const enable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/admin/enable",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "adminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = enable_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_administrator_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/administrator",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAdministratorAccount",
    Request: type = struct {
        detector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_administrator_account) } {
            return .{ .service_metadata = service_metadata, .action = get_administrator_account };
        }
    },
    Response: type = struct {
        administrator: struct {
            account_id: ?[]const u8 = null,
            invitation_id: ?[]const u8 = null,
            relationship_status: ?[]const u8 = null,
            invited_at: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .invitation_id = "invitationId",
                    .relationship_status = "relationshipStatus",
                    .invited_at = "invitedAt",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .administrator = "administrator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_coverage_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/coverage/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCoverageStatistics",
    Request: type = struct {
        detector_id: []const u8,
        filter_criteria: ?CoverageFilterCriteria = null,
        statistics_type: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .filter_criteria = "filterCriteria",
                .statistics_type = "statisticsType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_coverage_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_coverage_statistics };
        }
    },
    Response: type = struct {
        coverage_statistics: ?struct {
            count_by_resource_type: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            count_by_coverage_status: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .count_by_resource_type = "countByResourceType",
                    .count_by_coverage_status = "countByCoverageStatus",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "count_by_resource_type", field_name))
                    return try serializeMap(self.count_by_resource_type, self.fieldNameFor("count_by_resource_type"), options, out_stream);
                if (std.mem.eql(u8, "count_by_coverage_status", field_name))
                    return try serializeMap(self.count_by_coverage_status, self.fieldNameFor("count_by_coverage_status"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coverage_statistics = "coverageStatistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_detector: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDetector",
    Request: type = struct {
        detector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_detector) } {
            return .{ .service_metadata = service_metadata, .action = get_detector };
        }
    },
    Response: type = struct {
        created_at: ?[]const u8 = null,
        finding_publishing_frequency: ?[]const u8 = null,
        service_role: []const u8,
        status: []const u8,
        updated_at: ?[]const u8 = null,
        data_sources: ?DataSourceConfigurationsResult = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        features: ?[]struct {
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            updated_at: ?i64 = null,
            additional_configuration: ?[]struct {
                name: ?[]const u8 = null,
                status: ?[]const u8 = null,
                updated_at: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .status = "status",
                        .updated_at = "updatedAt",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .status = "status",
                    .updated_at = "updatedAt",
                    .additional_configuration = "additionalConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_at = "createdAt",
                .finding_publishing_frequency = "findingPublishingFrequency",
                .service_role = "serviceRole",
                .status = "status",
                .updated_at = "updatedAt",
                .data_sources = "dataSources",
                .tags = "tags",
                .features = "features",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_filter: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/filter/{FilterName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFilter",
    Request: type = struct {
        detector_id: []const u8,
        filter_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .filter_name = "filterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_filter) } {
            return .{ .service_metadata = service_metadata, .action = get_filter };
        }
    },
    Response: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        action: []const u8,
        rank: ?i64 = null,
        finding_criteria: FindingCriteria,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .action = "action",
                .rank = "rank",
                .finding_criteria = "findingCriteria",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/findings/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindings",
    Request: type = struct {
        detector_id: []const u8,
        finding_ids: [][]const u8,
        sort_criteria: ?SortCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .finding_ids = "findingIds",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings) } {
            return .{ .service_metadata = service_metadata, .action = get_findings };
        }
    },
    Response: type = struct {
        findings: []struct {
            account_id: []const u8,
            arn: []const u8,
            confidence: ?f64 = null,
            created_at: []const u8,
            description: ?[]const u8 = null,
            id: []const u8,
            partition: ?[]const u8 = null,
            region: []const u8,
            resource: struct {
                access_key_details: ?struct {
                    access_key_id: ?[]const u8 = null,
                    principal_id: ?[]const u8 = null,
                    user_name: ?[]const u8 = null,
                    user_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .access_key_id = "accessKeyId",
                            .principal_id = "principalId",
                            .user_name = "userName",
                            .user_type = "userType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                s3_bucket_details: ?[]struct {
                    arn: ?[]const u8 = null,
                    name: ?[]const u8 = null,
                    type: ?[]const u8 = null,
                    created_at: ?i64 = null,
                    owner: ?struct {
                        id: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .id = "id",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    tags: ?[]Tag = null,
                    default_server_side_encryption: ?struct {
                        encryption_type: ?[]const u8 = null,
                        kms_master_key_arn: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .encryption_type = "encryptionType",
                                .kms_master_key_arn = "kmsMasterKeyArn",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    public_access: ?struct {
                        permission_configuration: ?struct {
                            bucket_level_permissions: ?struct {
                                access_control_list: ?struct {
                                    allows_public_read_access: ?bool = null,
                                    allows_public_write_access: ?bool = null,

                                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                        const mappings = .{
                                            .allows_public_read_access = "allowsPublicReadAccess",
                                            .allows_public_write_access = "allowsPublicWriteAccess",
                                        };
                                        return @field(mappings, field_name);
                                    }
                                } = null,
                                bucket_policy: ?struct {
                                    allows_public_read_access: ?bool = null,
                                    allows_public_write_access: ?bool = null,

                                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                        const mappings = .{
                                            .allows_public_read_access = "allowsPublicReadAccess",
                                            .allows_public_write_access = "allowsPublicWriteAccess",
                                        };
                                        return @field(mappings, field_name);
                                    }
                                } = null,
                                block_public_access: ?BlockPublicAccess = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .access_control_list = "accessControlList",
                                        .bucket_policy = "bucketPolicy",
                                        .block_public_access = "blockPublicAccess",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,
                            account_level_permissions: ?struct {
                                block_public_access: ?BlockPublicAccess = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .block_public_access = "blockPublicAccess",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .bucket_level_permissions = "bucketLevelPermissions",
                                    .account_level_permissions = "accountLevelPermissions",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        effective_permission: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .permission_configuration = "permissionConfiguration",
                                .effective_permission = "effectivePermission",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .arn = "arn",
                            .name = "name",
                            .type = "type",
                            .created_at = "createdAt",
                            .owner = "owner",
                            .tags = "tags",
                            .default_server_side_encryption = "defaultServerSideEncryption",
                            .public_access = "publicAccess",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                instance_details: ?struct {
                    availability_zone: ?[]const u8 = null,
                    iam_instance_profile: ?struct {
                        arn: ?[]const u8 = null,
                        id: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .arn = "arn",
                                .id = "id",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    image_description: ?[]const u8 = null,
                    image_id: ?[]const u8 = null,
                    instance_id: ?[]const u8 = null,
                    instance_state: ?[]const u8 = null,
                    instance_type: ?[]const u8 = null,
                    outpost_arn: ?[]const u8 = null,
                    launch_time: ?[]const u8 = null,
                    network_interfaces: ?[]struct {
                        ipv6_addresses: ?[][]const u8 = null,
                        network_interface_id: ?[]const u8 = null,
                        private_dns_name: ?[]const u8 = null,
                        private_ip_address: ?[]const u8 = null,
                        private_ip_addresses: ?[]struct {
                            private_dns_name: ?[]const u8 = null,
                            private_ip_address: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .private_dns_name = "privateDnsName",
                                    .private_ip_address = "privateIpAddress",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        public_dns_name: ?[]const u8 = null,
                        public_ip: ?[]const u8 = null,
                        security_groups: ?[]SecurityGroup = null,
                        subnet_id: ?[]const u8 = null,
                        vpc_id: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .ipv6_addresses = "ipv6Addresses",
                                .network_interface_id = "networkInterfaceId",
                                .private_dns_name = "privateDnsName",
                                .private_ip_address = "privateIpAddress",
                                .private_ip_addresses = "privateIpAddresses",
                                .public_dns_name = "publicDnsName",
                                .public_ip = "publicIp",
                                .security_groups = "securityGroups",
                                .subnet_id = "subnetId",
                                .vpc_id = "vpcId",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    platform: ?[]const u8 = null,
                    product_codes: ?[]struct {
                        code: ?[]const u8 = null,
                        product_type: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .code = "productCodeId",
                                .product_type = "productCodeType",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    tags: ?[]Tag = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .availability_zone = "availabilityZone",
                            .iam_instance_profile = "iamInstanceProfile",
                            .image_description = "imageDescription",
                            .image_id = "imageId",
                            .instance_id = "instanceId",
                            .instance_state = "instanceState",
                            .instance_type = "instanceType",
                            .outpost_arn = "outpostArn",
                            .launch_time = "launchTime",
                            .network_interfaces = "networkInterfaces",
                            .platform = "platform",
                            .product_codes = "productCodes",
                            .tags = "tags",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                eks_cluster_details: ?struct {
                    name: ?[]const u8 = null,
                    arn: ?[]const u8 = null,
                    vpc_id: ?[]const u8 = null,
                    status: ?[]const u8 = null,
                    tags: ?[]Tag = null,
                    created_at: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .arn = "arn",
                            .vpc_id = "vpcId",
                            .status = "status",
                            .tags = "tags",
                            .created_at = "createdAt",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                kubernetes_details: ?struct {
                    kubernetes_user_details: ?struct {
                        username: ?[]const u8 = null,
                        uid: ?[]const u8 = null,
                        groups: ?[][]const u8 = null,
                        session_name: ?[][]const u8 = null,
                        impersonated_user: ?struct {
                            username: ?[]const u8 = null,
                            groups: ?[][]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .username = "username",
                                    .groups = "groups",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .username = "username",
                                .uid = "uid",
                                .groups = "groups",
                                .session_name = "sessionName",
                                .impersonated_user = "impersonatedUser",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    kubernetes_workload_details: ?struct {
                        name: ?[]const u8 = null,
                        type: ?[]const u8 = null,
                        uid: ?[]const u8 = null,
                        namespace: ?[]const u8 = null,
                        host_network: ?bool = null,
                        containers: ?[]Container = null,
                        volumes: ?[]Volume = null,
                        service_account_name: ?[]const u8 = null,
                        host_ipc: ?bool = null,
                        host_pid: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "name",
                                .type = "type",
                                .uid = "uid",
                                .namespace = "namespace",
                                .host_network = "hostNetwork",
                                .containers = "containers",
                                .volumes = "volumes",
                                .service_account_name = "serviceAccountName",
                                .host_ipc = "hostIPC",
                                .host_pid = "hostPID",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .kubernetes_user_details = "kubernetesUserDetails",
                            .kubernetes_workload_details = "kubernetesWorkloadDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                resource_type: ?[]const u8 = null,
                ebs_volume_details: ?struct {
                    scanned_volume_details: ?[]VolumeDetail = null,
                    skipped_volume_details: ?[]VolumeDetail = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .scanned_volume_details = "scannedVolumeDetails",
                            .skipped_volume_details = "skippedVolumeDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ecs_cluster_details: ?struct {
                    name: ?[]const u8 = null,
                    arn: ?[]const u8 = null,
                    status: ?[]const u8 = null,
                    active_services_count: ?i64 = null,
                    registered_container_instances_count: ?i64 = null,
                    running_tasks_count: ?i64 = null,
                    tags: ?[]Tag = null,
                    task_details: ?struct {
                        arn: ?[]const u8 = null,
                        definition_arn: ?[]const u8 = null,
                        version: ?[]const u8 = null,
                        task_created_at: ?i64 = null,
                        started_at: ?i64 = null,
                        started_by: ?[]const u8 = null,
                        tags: ?[]Tag = null,
                        volumes: ?[]Volume = null,
                        containers: ?[]Container = null,
                        group: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .arn = "arn",
                                .definition_arn = "definitionArn",
                                .version = "version",
                                .task_created_at = "createdAt",
                                .started_at = "startedAt",
                                .started_by = "startedBy",
                                .tags = "tags",
                                .volumes = "volumes",
                                .containers = "containers",
                                .group = "group",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .arn = "arn",
                            .status = "status",
                            .active_services_count = "activeServicesCount",
                            .registered_container_instances_count = "registeredContainerInstancesCount",
                            .running_tasks_count = "runningTasksCount",
                            .tags = "tags",
                            .task_details = "taskDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                container_details: ?Container = null,
                rds_db_instance_details: ?struct {
                    db_instance_identifier: ?[]const u8 = null,
                    engine: ?[]const u8 = null,
                    engine_version: ?[]const u8 = null,
                    db_cluster_identifier: ?[]const u8 = null,
                    db_instance_arn: ?[]const u8 = null,
                    tags: ?[]Tag = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .db_instance_identifier = "dbInstanceIdentifier",
                            .engine = "engine",
                            .engine_version = "engineVersion",
                            .db_cluster_identifier = "dbClusterIdentifier",
                            .db_instance_arn = "dbInstanceArn",
                            .tags = "tags",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                rds_db_user_details: ?struct {
                    user: ?[]const u8 = null,
                    application: ?[]const u8 = null,
                    database: ?[]const u8 = null,
                    ssl: ?[]const u8 = null,
                    auth_method: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .user = "user",
                            .application = "application",
                            .database = "database",
                            .ssl = "ssl",
                            .auth_method = "authMethod",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                lambda_details: ?struct {
                    function_arn: ?[]const u8 = null,
                    function_name: ?[]const u8 = null,
                    description: ?[]const u8 = null,
                    last_modified_at: ?i64 = null,
                    revision_id: ?[]const u8 = null,
                    function_version: ?[]const u8 = null,
                    role: ?[]const u8 = null,
                    vpc_config: ?struct {
                        subnet_ids: ?[][]const u8 = null,
                        vpc_id: ?[]const u8 = null,
                        security_groups: ?[]SecurityGroup = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .subnet_ids = "subnetIds",
                                .vpc_id = "vpcId",
                                .security_groups = "securityGroups",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    tags: ?[]Tag = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .function_arn = "functionArn",
                            .function_name = "functionName",
                            .description = "description",
                            .last_modified_at = "lastModifiedAt",
                            .revision_id = "revisionId",
                            .function_version = "functionVersion",
                            .role = "role",
                            .vpc_config = "vpcConfig",
                            .tags = "tags",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .access_key_details = "accessKeyDetails",
                        .s3_bucket_details = "s3BucketDetails",
                        .instance_details = "instanceDetails",
                        .eks_cluster_details = "eksClusterDetails",
                        .kubernetes_details = "kubernetesDetails",
                        .resource_type = "resourceType",
                        .ebs_volume_details = "ebsVolumeDetails",
                        .ecs_cluster_details = "ecsClusterDetails",
                        .container_details = "containerDetails",
                        .rds_db_instance_details = "rdsDbInstanceDetails",
                        .rds_db_user_details = "rdsDbUserDetails",
                        .lambda_details = "lambdaDetails",
                    };
                    return @field(mappings, field_name);
                }
            },
            schema_version: []const u8,
            service: ?struct {
                action: ?struct {
                    action_type: ?[]const u8 = null,
                    aws_api_call_action: ?struct {
                        api: ?[]const u8 = null,
                        caller_type: ?[]const u8 = null,
                        domain_details: ?struct {
                            domain: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .domain = "domain",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        error_code: ?[]const u8 = null,
                        user_agent: ?[]const u8 = null,
                        remote_ip_details: ?RemoteIpDetails = null,
                        service_name: ?[]const u8 = null,
                        remote_account_details: ?struct {
                            account_id: ?[]const u8 = null,
                            affiliated: ?bool = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .account_id = "accountId",
                                    .affiliated = "affiliated",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        affected_resources: ?[]struct {
                            key: ?[]const u8 = null,
                            value: ?[]const u8 = null,
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .api = "api",
                                .caller_type = "callerType",
                                .domain_details = "domainDetails",
                                .error_code = "errorCode",
                                .user_agent = "userAgent",
                                .remote_ip_details = "remoteIpDetails",
                                .service_name = "serviceName",
                                .remote_account_details = "remoteAccountDetails",
                                .affected_resources = "affectedResources",
                            };
                            return @field(mappings, field_name);
                        }

                        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                            if (std.mem.eql(u8, "affected_resources", field_name))
                                return try serializeMap(self.affected_resources, self.fieldNameFor("affected_resources"), options, out_stream);
                            return false;
                        }
                    } = null,
                    dns_request_action: ?struct {
                        domain: ?[]const u8 = null,
                        protocol: ?[]const u8 = null,
                        blocked: ?bool = null,
                        domain_with_suffix: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .domain = "domain",
                                .protocol = "protocol",
                                .blocked = "blocked",
                                .domain_with_suffix = "domainWithSuffix",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    network_connection_action: ?struct {
                        blocked: ?bool = null,
                        connection_direction: ?[]const u8 = null,
                        local_port_details: ?LocalPortDetails = null,
                        protocol: ?[]const u8 = null,
                        local_ip_details: ?LocalIpDetails = null,
                        remote_ip_details: ?RemoteIpDetails = null,
                        remote_port_details: ?struct {
                            port: ?i64 = null,
                            port_name: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .port = "port",
                                    .port_name = "portName",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .blocked = "blocked",
                                .connection_direction = "connectionDirection",
                                .local_port_details = "localPortDetails",
                                .protocol = "protocol",
                                .local_ip_details = "localIpDetails",
                                .remote_ip_details = "remoteIpDetails",
                                .remote_port_details = "remotePortDetails",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    port_probe_action: ?struct {
                        blocked: ?bool = null,
                        port_probe_details: ?[]struct {
                            local_port_details: ?LocalPortDetails = null,
                            local_ip_details: ?LocalIpDetails = null,
                            remote_ip_details: ?RemoteIpDetails = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .local_port_details = "localPortDetails",
                                    .local_ip_details = "localIpDetails",
                                    .remote_ip_details = "remoteIpDetails",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .blocked = "blocked",
                                .port_probe_details = "portProbeDetails",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    kubernetes_api_call_action: ?struct {
                        request_uri: ?[]const u8 = null,
                        verb: ?[]const u8 = null,
                        source_ips: ?[][]const u8 = null,
                        user_agent: ?[]const u8 = null,
                        remote_ip_details: ?RemoteIpDetails = null,
                        status_code: ?i64 = null,
                        parameters: ?[]const u8 = null,
                        resource: ?[]const u8 = null,
                        subresource: ?[]const u8 = null,
                        namespace: ?[]const u8 = null,
                        resource_name: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .request_uri = "requestUri",
                                .verb = "verb",
                                .source_ips = "sourceIps",
                                .user_agent = "userAgent",
                                .remote_ip_details = "remoteIpDetails",
                                .status_code = "statusCode",
                                .parameters = "parameters",
                                .resource = "resource",
                                .subresource = "subresource",
                                .namespace = "namespace",
                                .resource_name = "resourceName",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    rds_login_attempt_action: ?struct {
                        remote_ip_details: ?RemoteIpDetails = null,
                        login_attributes: ?[]struct {
                            user: ?[]const u8 = null,
                            application: ?[]const u8 = null,
                            failed_login_attempts: ?i64 = null,
                            successful_login_attempts: ?i64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .user = "user",
                                    .application = "application",
                                    .failed_login_attempts = "failedLoginAttempts",
                                    .successful_login_attempts = "successfulLoginAttempts",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .remote_ip_details = "remoteIpDetails",
                                .login_attributes = "LoginAttributes",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    kubernetes_permission_checked_details: ?struct {
                        verb: ?[]const u8 = null,
                        resource: ?[]const u8 = null,
                        namespace: ?[]const u8 = null,
                        allowed: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .verb = "verb",
                                .resource = "resource",
                                .namespace = "namespace",
                                .allowed = "allowed",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    kubernetes_role_binding_details: ?struct {
                        kind: ?[]const u8 = null,
                        name: ?[]const u8 = null,
                        uid: ?[]const u8 = null,
                        role_ref_name: ?[]const u8 = null,
                        role_ref_kind: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .kind = "kind",
                                .name = "name",
                                .uid = "uid",
                                .role_ref_name = "roleRefName",
                                .role_ref_kind = "roleRefKind",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    kubernetes_role_details: ?struct {
                        kind: ?[]const u8 = null,
                        name: ?[]const u8 = null,
                        uid: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .kind = "kind",
                                .name = "name",
                                .uid = "uid",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .action_type = "actionType",
                            .aws_api_call_action = "awsApiCallAction",
                            .dns_request_action = "dnsRequestAction",
                            .network_connection_action = "networkConnectionAction",
                            .port_probe_action = "portProbeAction",
                            .kubernetes_api_call_action = "kubernetesApiCallAction",
                            .rds_login_attempt_action = "rdsLoginAttemptAction",
                            .kubernetes_permission_checked_details = "kubernetesPermissionCheckedDetails",
                            .kubernetes_role_binding_details = "kubernetesRoleBindingDetails",
                            .kubernetes_role_details = "kubernetesRoleDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                evidence: ?struct {
                    threat_intelligence_details: ?[]struct {
                        threat_list_name: ?[]const u8 = null,
                        threat_names: ?[][]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .threat_list_name = "threatListName",
                                .threat_names = "threatNames",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .threat_intelligence_details = "threatIntelligenceDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                archived: ?bool = null,
                count: ?i64 = null,
                detector_id: ?[]const u8 = null,
                event_first_seen: ?[]const u8 = null,
                event_last_seen: ?[]const u8 = null,
                resource_role: ?[]const u8 = null,
                service_name: ?[]const u8 = null,
                user_feedback: ?[]const u8 = null,
                additional_info: ?struct {
                    value: ?[]const u8 = null,
                    type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value = "value",
                            .type = "type",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                feature_name: ?[]const u8 = null,
                ebs_volume_scan_details: ?struct {
                    scan_id: ?[]const u8 = null,
                    scan_started_at: ?i64 = null,
                    scan_completed_at: ?i64 = null,
                    trigger_finding_id: ?[]const u8 = null,
                    sources: ?[][]const u8 = null,
                    scan_detections: ?struct {
                        scanned_item_count: ?struct {
                            total_gb: ?i64 = null,
                            files: ?i64 = null,
                            volumes: ?i64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .total_gb = "totalGb",
                                    .files = "files",
                                    .volumes = "volumes",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        threats_detected_item_count: ?struct {
                            files: ?i64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .files = "files",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        highest_severity_threat_details: ?struct {
                            severity: ?[]const u8 = null,
                            threat_name: ?[]const u8 = null,
                            count: ?i64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .severity = "severity",
                                    .threat_name = "threatName",
                                    .count = "count",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        threat_detected_by_name: ?struct {
                            item_count: ?i64 = null,
                            unique_threat_name_count: ?i64 = null,
                            shortened: ?bool = null,
                            threat_names: ?[]struct {
                                name: ?[]const u8 = null,
                                severity: ?[]const u8 = null,
                                item_count: ?i64 = null,
                                file_paths: ?[]struct {
                                    file_path: ?[]const u8 = null,
                                    volume_arn: ?[]const u8 = null,
                                    hash: ?[]const u8 = null,
                                    file_name: ?[]const u8 = null,

                                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                        const mappings = .{
                                            .file_path = "filePath",
                                            .volume_arn = "volumeArn",
                                            .hash = "hash",
                                            .file_name = "fileName",
                                        };
                                        return @field(mappings, field_name);
                                    }
                                } = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .name = "name",
                                        .severity = "severity",
                                        .item_count = "itemCount",
                                        .file_paths = "filePaths",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .item_count = "itemCount",
                                    .unique_threat_name_count = "uniqueThreatNameCount",
                                    .shortened = "shortened",
                                    .threat_names = "threatNames",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .scanned_item_count = "scannedItemCount",
                                .threats_detected_item_count = "threatsDetectedItemCount",
                                .highest_severity_threat_details = "highestSeverityThreatDetails",
                                .threat_detected_by_name = "threatDetectedByName",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    scan_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .scan_id = "scanId",
                            .scan_started_at = "scanStartedAt",
                            .scan_completed_at = "scanCompletedAt",
                            .trigger_finding_id = "triggerFindingId",
                            .sources = "sources",
                            .scan_detections = "scanDetections",
                            .scan_type = "scanType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                runtime_details: ?struct {
                    process: ?ProcessDetails = null,
                    context: ?struct {
                        modifying_process: ?ProcessDetails = null,
                        modified_at: ?i64 = null,
                        script_path: ?[]const u8 = null,
                        library_path: ?[]const u8 = null,
                        ld_preload_value: ?[]const u8 = null,
                        socket_path: ?[]const u8 = null,
                        runc_binary_path: ?[]const u8 = null,
                        release_agent_path: ?[]const u8 = null,
                        mount_source: ?[]const u8 = null,
                        mount_target: ?[]const u8 = null,
                        file_system_type: ?[]const u8 = null,
                        flags: ?[][]const u8 = null,
                        module_name: ?[]const u8 = null,
                        module_file_path: ?[]const u8 = null,
                        module_sha256: ?[]const u8 = null,
                        shell_history_file_path: ?[]const u8 = null,
                        target_process: ?ProcessDetails = null,
                        address_family: ?[]const u8 = null,
                        iana_protocol_number: ?i64 = null,
                        memory_regions: ?[][]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .modifying_process = "modifyingProcess",
                                .modified_at = "modifiedAt",
                                .script_path = "scriptPath",
                                .library_path = "libraryPath",
                                .ld_preload_value = "ldPreloadValue",
                                .socket_path = "socketPath",
                                .runc_binary_path = "runcBinaryPath",
                                .release_agent_path = "releaseAgentPath",
                                .mount_source = "mountSource",
                                .mount_target = "mountTarget",
                                .file_system_type = "fileSystemType",
                                .flags = "flags",
                                .module_name = "moduleName",
                                .module_file_path = "moduleFilePath",
                                .module_sha256 = "moduleSha256",
                                .shell_history_file_path = "shellHistoryFilePath",
                                .target_process = "targetProcess",
                                .address_family = "addressFamily",
                                .iana_protocol_number = "ianaProtocolNumber",
                                .memory_regions = "memoryRegions",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .process = "process",
                            .context = "context",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                detection: ?struct {
                    anomaly: ?struct {
                        profiles: ?[]struct {
                            key: ?[]const u8 = null,
                            value: ?[]struct {
                                key: ?[]const u8 = null,
                                value: ?[]AnomalyObject = null,
                            } = null,


                        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                            if (std.mem.eql(u8, "value", field_name))
                                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
                            return false;
                        }
                        } = null,
                        unusual: ?struct {
                            behavior: ?[]struct {
                                key: ?[]const u8 = null,
                                value: ?[]struct {
                                    key: ?[]const u8 = null,
                                    value: ?AnomalyObject = null,
                                } = null,


                            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                                if (std.mem.eql(u8, "value", field_name))
                                    return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
                                return false;
                            }
                            } = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .behavior = "behavior",
                                };
                                return @field(mappings, field_name);
                            }

                            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                                if (std.mem.eql(u8, "behavior", field_name))
                                    return try serializeMap(self.behavior, self.fieldNameFor("behavior"), options, out_stream);
                                return false;
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .profiles = "profiles",
                                .unusual = "unusual",
                            };
                            return @field(mappings, field_name);
                        }

                        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                            if (std.mem.eql(u8, "profiles", field_name))
                                return try serializeMap(self.profiles, self.fieldNameFor("profiles"), options, out_stream);
                            return false;
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .anomaly = "anomaly",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action = "action",
                        .evidence = "evidence",
                        .archived = "archived",
                        .count = "count",
                        .detector_id = "detectorId",
                        .event_first_seen = "eventFirstSeen",
                        .event_last_seen = "eventLastSeen",
                        .resource_role = "resourceRole",
                        .service_name = "serviceName",
                        .user_feedback = "userFeedback",
                        .additional_info = "additionalInfo",
                        .feature_name = "featureName",
                        .ebs_volume_scan_details = "ebsVolumeScanDetails",
                        .runtime_details = "runtimeDetails",
                        .detection = "detection",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            severity: f64,
            title: ?[]const u8 = null,
            type: []const u8,
            updated_at: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .arn = "arn",
                    .confidence = "confidence",
                    .created_at = "createdAt",
                    .description = "description",
                    .id = "id",
                    .partition = "partition",
                    .region = "region",
                    .resource = "resource",
                    .schema_version = "schemaVersion",
                    .service = "service",
                    .severity = "severity",
                    .title = "title",
                    .type = "type",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_findings_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/findings/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindingsStatistics",
    Request: type = struct {
        detector_id: []const u8,
        finding_statistic_types: [][]const u8,
        finding_criteria: ?FindingCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .finding_statistic_types = "findingStatisticTypes",
                .finding_criteria = "findingCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_findings_statistics };
        }
    },
    Response: type = struct {
        finding_statistics: struct {
            count_by_severity: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .count_by_severity = "countBySeverity",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "count_by_severity", field_name))
                    return try serializeMap(self.count_by_severity, self.fieldNameFor("count_by_severity"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_statistics = "findingStatistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_invitations_count: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitation/count",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInvitationsCount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_invitations_count) } {
            return .{ .service_metadata = service_metadata, .action = get_invitations_count };
        }
    },
    Response: type = struct {
        invitations_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations_count = "invitationsCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_ip_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/ipset/{IpSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIPSet",
    Request: type = struct {
        detector_id: []const u8,
        ip_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .ip_set_id = "ipSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = get_ip_set };
        }
    },
    Response: type = struct {
        name: []const u8,
        format: []const u8,
        location: []const u8,
        status: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .format = "format",
                .location = "location",
                .status = "status",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_malware_scan_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/malware-scan-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMalwareScanSettings",
    Request: type = struct {
        detector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_malware_scan_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_malware_scan_settings };
        }
    },
    Response: type = struct {
        scan_resource_criteria: ?ScanResourceCriteria = null,
        ebs_snapshot_preservation: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_resource_criteria = "scanResourceCriteria",
                .ebs_snapshot_preservation = "ebsSnapshotPreservation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_master_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/master",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMasterAccount",
    Request: type = struct {
        detector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_master_account) } {
            return .{ .service_metadata = service_metadata, .action = get_master_account };
        }
    },
    Response: type = struct {
        master: struct {
            account_id: ?[]const u8 = null,
            invitation_id: ?[]const u8 = null,
            relationship_status: ?[]const u8 = null,
            invited_at: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .invitation_id = "invitationId",
                    .relationship_status = "relationshipStatus",
                    .invited_at = "invitedAt",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .master = "master",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_member_detectors: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member/detector/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMemberDetectors",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_member_detectors) } {
            return .{ .service_metadata = service_metadata, .action = get_member_detectors };
        }
    },
    Response: type = struct {
        member_data_source_configurations: []struct {
            account_id: []const u8,
            data_sources: ?DataSourceConfigurationsResult = null,
            features: ?[]struct {
                name: ?[]const u8 = null,
                status: ?[]const u8 = null,
                updated_at: ?i64 = null,
                additional_configuration: ?[]struct {
                    name: ?[]const u8 = null,
                    status: ?[]const u8 = null,
                    updated_at: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .status = "status",
                            .updated_at = "updatedAt",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .status = "status",
                        .updated_at = "updatedAt",
                        .additional_configuration = "additionalConfiguration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .data_sources = "dataSources",
                    .features = "features",
                };
                return @field(mappings, field_name);
            }
        },
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_data_source_configurations = "members",
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMembers",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_members) } {
            return .{ .service_metadata = service_metadata, .action = get_members };
        }
    },
    Response: type = struct {
        members: []Member,
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "members",
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_organization_statistics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/organization/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOrganizationStatistics",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_organization_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_organization_statistics };
        }
    },
    Response: type = struct {
        organization_details: ?struct {
            updated_at: ?i64 = null,
            organization_statistics: ?struct {
                total_accounts_count: ?i64 = null,
                member_accounts_count: ?i64 = null,
                active_accounts_count: ?i64 = null,
                enabled_accounts_count: ?i64 = null,
                count_by_feature: ?[]struct {
                    name: ?[]const u8 = null,
                    enabled_accounts_count: ?i64 = null,
                    additional_configuration: ?[]struct {
                        name: ?[]const u8 = null,
                        enabled_accounts_count: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "name",
                                .enabled_accounts_count = "enabledAccountsCount",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .enabled_accounts_count = "enabledAccountsCount",
                            .additional_configuration = "additionalConfiguration",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total_accounts_count = "totalAccountsCount",
                        .member_accounts_count = "memberAccountsCount",
                        .active_accounts_count = "activeAccountsCount",
                        .enabled_accounts_count = "enabledAccountsCount",
                        .count_by_feature = "countByFeature",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .updated_at = "updatedAt",
                    .organization_statistics = "organizationStatistics",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_details = "organizationDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_remaining_free_trial_days: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/freeTrial/daysRemaining",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRemainingFreeTrialDays",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_remaining_free_trial_days) } {
            return .{ .service_metadata = service_metadata, .action = get_remaining_free_trial_days };
        }
    },
    Response: type = struct {
        accounts: ?[]struct {
            account_id: ?[]const u8 = null,
            data_sources: ?struct {
                cloud_trail: ?DataSourceFreeTrial = null,
                dns_logs: ?DataSourceFreeTrial = null,
                flow_logs: ?DataSourceFreeTrial = null,
                s3_logs: ?DataSourceFreeTrial = null,
                kubernetes: ?struct {
                    audit_logs: ?DataSourceFreeTrial = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .audit_logs = "auditLogs",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                malware_protection: ?struct {
                    scan_ec2_instance_with_findings: ?DataSourceFreeTrial = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .scan_ec2_instance_with_findings = "scanEc2InstanceWithFindings",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cloud_trail = "cloudTrail",
                        .dns_logs = "dnsLogs",
                        .flow_logs = "flowLogs",
                        .s3_logs = "s3Logs",
                        .kubernetes = "kubernetes",
                        .malware_protection = "malwareProtection",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            features: ?[]struct {
                name: ?[]const u8 = null,
                free_trial_days_remaining: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .free_trial_days_remaining = "freeTrialDaysRemaining",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .data_sources = "dataSources",
                    .features = "features",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unprocessed_accounts: ?[]UnprocessedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "accounts",
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_threat_intel_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/threatintelset/{ThreatIntelSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetThreatIntelSet",
    Request: type = struct {
        detector_id: []const u8,
        threat_intel_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .threat_intel_set_id = "threatIntelSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_threat_intel_set) } {
            return .{ .service_metadata = service_metadata, .action = get_threat_intel_set };
        }
    },
    Response: type = struct {
        name: []const u8,
        format: []const u8,
        location: []const u8,
        status: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .format = "format",
                .location = "location",
                .status = "status",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const get_usage_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/usage/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUsageStatistics",
    Request: type = struct {
        detector_id: []const u8,
        usage_statistic_type: []const u8,
        usage_criteria: struct {
            account_ids: ?[][]const u8 = null,
            data_sources: ?[][]const u8 = null,
            resources: ?[][]const u8 = null,
            features: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_ids = "accountIds",
                    .data_sources = "dataSources",
                    .resources = "resources",
                    .features = "features",
                };
                return @field(mappings, field_name);
            }
        },
        unit: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .usage_statistic_type = "usageStatisticsType",
                .usage_criteria = "usageCriteria",
                .unit = "unit",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_usage_statistics };
        }
    },
    Response: type = struct {
        usage_statistics: ?struct {
            sum_by_account: ?[]struct {
                account_id: ?[]const u8 = null,
                total: ?Total = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .account_id = "accountId",
                        .total = "total",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            top_accounts_by_feature: ?[]struct {
                feature: ?[]const u8 = null,
                accounts: ?[]struct {
                    account_id: ?[]const u8 = null,
                    total: ?Total = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .account_id = "accountId",
                            .total = "total",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .feature = "feature",
                        .accounts = "accounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            sum_by_data_source: ?[]struct {
                data_source: ?[]const u8 = null,
                total: ?Total = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .data_source = "dataSource",
                        .total = "total",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            sum_by_resource: ?[]UsageResourceResult = null,
            top_resources: ?[]UsageResourceResult = null,
            sum_by_feature: ?[]struct {
                feature: ?[]const u8 = null,
                total: ?Total = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .feature = "feature",
                        .total = "total",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sum_by_account = "sumByAccount",
                    .top_accounts_by_feature = "topAccountsByFeature",
                    .sum_by_data_source = "sumByDataSource",
                    .sum_by_resource = "sumByResource",
                    .top_resources = "topResources",
                    .sum_by_feature = "sumByFeature",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_statistics = "usageStatistics",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const invite_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member/invite",
        .success_code = 200,
    };

    action_name: []const u8 = "InviteMembers",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: [][]const u8,
        disable_email_notification: ?bool = null,
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
                .disable_email_notification = "disableEmailNotification",
                .message = "message",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invite_members) } {
            return .{ .service_metadata = service_metadata, .action = invite_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_coverage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/coverage",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCoverage",
    Request: type = struct {
        detector_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter_criteria: ?CoverageFilterCriteria = null,
        sort_criteria: ?struct {
            attribute_name: ?[]const u8 = null,
            order_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "attributeName",
                    .order_by = "orderBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filter_criteria = "filterCriteria",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_coverage) } {
            return .{ .service_metadata = service_metadata, .action = list_coverage };
        }
    },
    Response: type = struct {
        resources: []struct {
            resource_id: ?[]const u8 = null,
            detector_id: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            resource_details: ?struct {
                eks_cluster_details: ?struct {
                    cluster_name: ?[]const u8 = null,
                    covered_nodes: ?i64 = null,
                    compatible_nodes: ?i64 = null,
                    addon_details: ?struct {
                        addon_version: ?[]const u8 = null,
                        addon_status: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .addon_version = "addonVersion",
                                .addon_status = "addonStatus",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    management_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cluster_name = "clusterName",
                            .covered_nodes = "coveredNodes",
                            .compatible_nodes = "compatibleNodes",
                            .addon_details = "addonDetails",
                            .management_type = "managementType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                resource_type: ?[]const u8 = null,
                ecs_cluster_details: ?struct {
                    cluster_name: ?[]const u8 = null,
                    fargate_details: ?struct {
                        issues: ?[][]const u8 = null,
                        management_type: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .issues = "issues",
                                .management_type = "managementType",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    container_instance_details: ?struct {
                        covered_container_instances: ?i64 = null,
                        compatible_container_instances: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .covered_container_instances = "coveredContainerInstances",
                                .compatible_container_instances = "compatibleContainerInstances",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cluster_name = "clusterName",
                            .fargate_details = "fargateDetails",
                            .container_instance_details = "containerInstanceDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ec2_instance_details: ?struct {
                    instance_id: ?[]const u8 = null,
                    instance_type: ?[]const u8 = null,
                    cluster_arn: ?[]const u8 = null,
                    agent_details: ?struct {
                        version: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .version = "version",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    management_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .instance_id = "instanceId",
                            .instance_type = "instanceType",
                            .cluster_arn = "clusterArn",
                            .agent_details = "agentDetails",
                            .management_type = "managementType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .eks_cluster_details = "eksClusterDetails",
                        .resource_type = "resourceType",
                        .ecs_cluster_details = "ecsClusterDetails",
                        .ec2_instance_details = "ec2InstanceDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            coverage_status: ?[]const u8 = null,
            issue: ?[]const u8 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "resourceId",
                    .detector_id = "detectorId",
                    .account_id = "accountId",
                    .resource_details = "resourceDetails",
                    .coverage_status = "coverageStatus",
                    .issue = "issue",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "resources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_detectors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDetectors",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_detectors) } {
            return .{ .service_metadata = service_metadata, .action = list_detectors };
        }
    },
    Response: type = struct {
        detector_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_ids = "detectorIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_filters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/filter",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFilters",
    Request: type = struct {
        detector_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_filters) } {
            return .{ .service_metadata = service_metadata, .action = list_filters };
        }
    },
    Response: type = struct {
        filter_names: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_names = "filterNames",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/findings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindings",
    Request: type = struct {
        detector_id: []const u8,
        finding_criteria: ?FindingCriteria = null,
        sort_criteria: ?SortCriteria = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .finding_criteria = "findingCriteria",
                .sort_criteria = "sortCriteria",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_findings };
        }
    },
    Response: type = struct {
        finding_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_ids = "findingIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_invitations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitation",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInvitations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_invitations) } {
            return .{ .service_metadata = service_metadata, .action = list_invitations };
        }
    },
    Response: type = struct {
        invitations: ?[]struct {
            account_id: ?[]const u8 = null,
            invitation_id: ?[]const u8 = null,
            relationship_status: ?[]const u8 = null,
            invited_at: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .invitation_id = "invitationId",
                    .relationship_status = "relationshipStatus",
                    .invited_at = "invitedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations = "invitations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_ip_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/ipset",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIPSets",
    Request: type = struct {
        detector_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ip_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_ip_sets };
        }
    },
    Response: type = struct {
        ip_set_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set_ids = "ipSetIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_members: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/member",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMembers",
    Request: type = struct {
        detector_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        only_associated: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .only_associated = "onlyAssociated",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .only_associated = "onlyAssociated",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_members) } {
            return .{ .service_metadata = service_metadata, .action = list_members };
        }
    },
    Response: type = struct {
        members: ?[]Member = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "members",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_organization_admin_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/admin",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationAdminAccounts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_admin_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_admin_accounts };
        }
    },
    Response: type = struct {
        admin_accounts: ?[]struct {
            admin_account_id: ?[]const u8 = null,
            admin_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .admin_account_id = "adminAccountId",
                    .admin_status = "adminStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_accounts = "adminAccounts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_publishing_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/publishingDestination",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPublishingDestinations",
    Request: type = struct {
        detector_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_publishing_destinations) } {
            return .{ .service_metadata = service_metadata, .action = list_publishing_destinations };
        }
    },
    Response: type = struct {
        destinations: []struct {
            destination_id: []const u8,
            destination_type: []const u8,
            status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .destination_id = "destinationId",
                    .destination_type = "destinationType",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destinations = "destinations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const list_threat_intel_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector/{DetectorId}/threatintelset",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThreatIntelSets",
    Request: type = struct {
        detector_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_threat_intel_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_threat_intel_sets };
        }
    },
    Response: type = struct {
        threat_intel_set_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .threat_intel_set_ids = "threatIntelSetIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const start_malware_scan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/malware-scan/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMalwareScan",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_malware_scan) } {
            return .{ .service_metadata = service_metadata, .action = start_malware_scan };
        }
    },
    Response: type = struct {
        scan_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_id = "scanId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServerError,
    },
} = .{};
pub const start_monitoring_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMonitoringMembers",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_monitoring_members) } {
            return .{ .service_metadata = service_metadata, .action = start_monitoring_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const stop_monitoring_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopMonitoringMembers",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_monitoring_members) } {
            return .{ .service_metadata = service_metadata, .action = stop_monitoring_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const unarchive_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/findings/unarchive",
        .success_code = 200,
    };

    action_name: []const u8 = "UnarchiveFindings",
    Request: type = struct {
        detector_id: []const u8,
        finding_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .finding_ids = "findingIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unarchive_findings) } {
            return .{ .service_metadata = service_metadata, .action = unarchive_findings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDetector",
    Request: type = struct {
        detector_id: []const u8,
        enable: ?bool = null,
        finding_publishing_frequency: ?[]const u8 = null,
        data_sources: ?DataSourceConfigurations = null,
        features: ?[]DetectorFeatureConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .enable = "enable",
                .finding_publishing_frequency = "findingPublishingFrequency",
                .data_sources = "dataSources",
                .features = "features",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_detector) } {
            return .{ .service_metadata = service_metadata, .action = update_detector };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/filter/{FilterName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFilter",
    Request: type = struct {
        detector_id: []const u8,
        filter_name: []const u8,
        description: ?[]const u8 = null,
        action: ?[]const u8 = null,
        rank: ?i64 = null,
        finding_criteria: ?FindingCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .filter_name = "filterName",
                .description = "description",
                .action = "action",
                .rank = "rank",
                .finding_criteria = "findingCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_filter) } {
            return .{ .service_metadata = service_metadata, .action = update_filter };
        }
    },
    Response: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_findings_feedback: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/findings/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFindingsFeedback",
    Request: type = struct {
        detector_id: []const u8,
        finding_ids: [][]const u8,
        feedback: []const u8,
        comments: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .finding_ids = "findingIds",
                .feedback = "feedback",
                .comments = "comments",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_findings_feedback) } {
            return .{ .service_metadata = service_metadata, .action = update_findings_feedback };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_ip_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/ipset/{IpSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIPSet",
    Request: type = struct {
        detector_id: []const u8,
        ip_set_id: []const u8,
        name: ?[]const u8 = null,
        location: ?[]const u8 = null,
        activate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .ip_set_id = "ipSetId",
                .name = "name",
                .location = "location",
                .activate = "activate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = update_ip_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_malware_scan_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/malware-scan-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMalwareScanSettings",
    Request: type = struct {
        detector_id: []const u8,
        scan_resource_criteria: ?ScanResourceCriteria = null,
        ebs_snapshot_preservation: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .scan_resource_criteria = "scanResourceCriteria",
                .ebs_snapshot_preservation = "ebsSnapshotPreservation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_malware_scan_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_malware_scan_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_member_detectors: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/member/detector/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMemberDetectors",
    Request: type = struct {
        detector_id: []const u8,
        account_ids: [][]const u8,
        data_sources: ?DataSourceConfigurations = null,
        features: ?[]struct {
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            additional_configuration: ?[]struct {
                name: ?[]const u8 = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .status = "status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .status = "status",
                    .additional_configuration = "additionalConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .account_ids = "accountIds",
                .data_sources = "dataSources",
                .features = "features",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_member_detectors) } {
            return .{ .service_metadata = service_metadata, .action = update_member_detectors };
        }
    },
    Response: type = struct {
        unprocessed_accounts: []UnprocessedAccount,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_organization_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/admin",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOrganizationConfiguration",
    Request: type = struct {
        detector_id: []const u8,
        auto_enable: ?bool = null,
        data_sources: ?struct {
            s3_logs: ?struct {
                auto_enable: bool,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .auto_enable = "autoEnable",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            kubernetes: ?struct {
                audit_logs: struct {
                    auto_enable: bool,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .auto_enable = "autoEnable",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .audit_logs = "auditLogs",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            malware_protection: ?struct {
                scan_ec2_instance_with_findings: ?struct {
                    ebs_volumes: ?struct {
                        auto_enable: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .auto_enable = "autoEnable",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .ebs_volumes = "ebsVolumes",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .scan_ec2_instance_with_findings = "scanEc2InstanceWithFindings",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_logs = "s3Logs",
                    .kubernetes = "kubernetes",
                    .malware_protection = "malwareProtection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        features: ?[]struct {
            name: ?[]const u8 = null,
            auto_enable: ?[]const u8 = null,
            additional_configuration: ?[]struct {
                name: ?[]const u8 = null,
                auto_enable: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .auto_enable = "autoEnable",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .auto_enable = "autoEnable",
                    .additional_configuration = "additionalConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        auto_enable_organization_members: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .auto_enable = "autoEnable",
                .data_sources = "dataSources",
                .features = "features",
                .auto_enable_organization_members = "autoEnableOrganizationMembers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_organization_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_publishing_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/publishingDestination/{DestinationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePublishingDestination",
    Request: type = struct {
        detector_id: []const u8,
        destination_id: []const u8,
        destination_properties: ?DestinationProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .destination_id = "destinationId",
                .destination_properties = "destinationProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_publishing_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_publishing_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};
pub const update_threat_intel_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector/{DetectorId}/threatintelset/{ThreatIntelSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThreatIntelSet",
    Request: type = struct {
        detector_id: []const u8,
        threat_intel_set_id: []const u8,
        name: ?[]const u8 = null,
        location: ?[]const u8 = null,
        activate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_id = "detectorId",
                .threat_intel_set_id = "threatIntelSetId",
                .name = "name",
                .location = "location",
                .activate = "activate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_threat_intel_set) } {
            return .{ .service_metadata = service_metadata, .action = update_threat_intel_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
    },
} = .{};

pub const DestinationProperties = struct {
    destination_arn: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_arn = "destinationArn",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const UnprocessedAccount = struct {
    account_id: []const u8,
    result: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .result = "result",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceConfigurations = struct {
    s3_logs: ?S3LogsConfiguration = null,
    kubernetes: ?KubernetesConfiguration = null,
    malware_protection: ?MalwareProtectionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_logs = "s3Logs",
            .kubernetes = "kubernetes",
            .malware_protection = "malwareProtection",
        };
        return @field(mappings, field_name);
    }
};

pub const MalwareProtectionConfiguration = struct {
    scan_ec2_instance_with_findings: ?ScanEc2InstanceWithFindings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scan_ec2_instance_with_findings = "scanEc2InstanceWithFindings",
        };
        return @field(mappings, field_name);
    }
};

pub const ScanEc2InstanceWithFindings = struct {
    ebs_volumes: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_volumes = "ebsVolumes",
        };
        return @field(mappings, field_name);
    }
};

pub const KubernetesConfiguration = struct {
    audit_logs: KubernetesAuditLogsConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit_logs = "auditLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const KubernetesAuditLogsConfiguration = struct {
    enable: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable = "enable",
        };
        return @field(mappings, field_name);
    }
};

pub const S3LogsConfiguration = struct {
    enable: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable = "enable",
        };
        return @field(mappings, field_name);
    }
};

pub const ScanResourceCriteria = struct {
    include: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ScanCondition = null,
    } = null,
    exclude: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ScanCondition = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .include = "include",
            .exclude = "exclude",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "include", field_name))
            return try serializeMap(self.include, self.fieldNameFor("include"), options, out_stream);
        if (std.mem.eql(u8, "exclude", field_name))
            return try serializeMap(self.exclude, self.fieldNameFor("exclude"), options, out_stream);
        return false;
    }
};

pub const ScanCondition = struct {
    map_equals: []ScanConditionPair,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .map_equals = "mapEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const ScanConditionPair = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const FindingCriteria = struct {
    criterion: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Condition = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .criterion = "criterion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "criterion", field_name))
            return try serializeMap(self.criterion, self.fieldNameFor("criterion"), options, out_stream);
        return false;
    }
};

pub const Condition = struct {
    eq: ?[][]const u8 = null,
    neq: ?[][]const u8 = null,
    gt: ?i64 = null,
    gte: ?i64 = null,
    lt: ?i64 = null,
    lte: ?i64 = null,
    equals: ?[][]const u8 = null,
    not_equals: ?[][]const u8 = null,
    greater_than: ?i64 = null,
    greater_than_or_equal: ?i64 = null,
    less_than: ?i64 = null,
    less_than_or_equal: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eq = "eq",
            .neq = "neq",
            .gt = "gt",
            .gte = "gte",
            .lt = "lt",
            .lte = "lte",
            .equals = "equals",
            .not_equals = "notEquals",
            .greater_than = "greaterThan",
            .greater_than_or_equal = "greaterThanOrEqual",
            .less_than = "lessThan",
            .less_than_or_equal = "lessThanOrEqual",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectorFeatureConfiguration = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    additional_configuration: ?[]DetectorAdditionalConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .status = "status",
            .additional_configuration = "additionalConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectorAdditionalConfiguration = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const Member = struct {
    account_id: []const u8,
    detector_id: ?[]const u8 = null,
    master_id: []const u8,
    email: []const u8,
    relationship_status: []const u8,
    invited_at: ?[]const u8 = null,
    updated_at: []const u8,
    administrator_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .detector_id = "detectorId",
            .master_id = "masterId",
            .email = "email",
            .relationship_status = "relationshipStatus",
            .invited_at = "invitedAt",
            .updated_at = "updatedAt",
            .administrator_id = "administratorId",
        };
        return @field(mappings, field_name);
    }
};

pub const SortCriteria = struct {
    attribute_name: ?[]const u8 = null,
    order_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "attributeName",
            .order_by = "orderBy",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageFilterCriteria = struct {
    filter_criterion: ?[]CoverageFilterCriterion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_criterion = "filterCriterion",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageFilterCriterion = struct {
    criterion_key: ?[]const u8 = null,
    filter_condition: ?CoverageFilterCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .criterion_key = "criterionKey",
            .filter_condition = "filterCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageFilterCondition = struct {
    equals: ?[][]const u8 = null,
    not_equals: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .equals = "equals",
            .not_equals = "notEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const Total = struct {
    amount: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amount = "amount",
            .unit = "unit",
        };
        return @field(mappings, field_name);
    }
};

pub const UsageResourceResult = struct {
    resource: ?[]const u8 = null,
    total: ?Total = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource = "resource",
            .total = "total",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceFreeTrial = struct {
    free_trial_days_remaining: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .free_trial_days_remaining = "freeTrialDaysRemaining",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceConfigurationsResult = struct {
    cloud_trail: CloudTrailConfigurationResult,
    dns_logs: DNSLogsConfigurationResult,
    flow_logs: FlowLogsConfigurationResult,
    s3_logs: S3LogsConfigurationResult,
    kubernetes: ?KubernetesConfigurationResult = null,
    malware_protection: ?MalwareProtectionConfigurationResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_trail = "cloudTrail",
            .dns_logs = "dnsLogs",
            .flow_logs = "flowLogs",
            .s3_logs = "s3Logs",
            .kubernetes = "kubernetes",
            .malware_protection = "malwareProtection",
        };
        return @field(mappings, field_name);
    }
};

pub const MalwareProtectionConfigurationResult = struct {
    scan_ec2_instance_with_findings: ?ScanEc2InstanceWithFindingsResult = null,
    service_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scan_ec2_instance_with_findings = "scanEc2InstanceWithFindings",
            .service_role = "serviceRole",
        };
        return @field(mappings, field_name);
    }
};

pub const ScanEc2InstanceWithFindingsResult = struct {
    ebs_volumes: ?EbsVolumesResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_volumes = "ebsVolumes",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsVolumesResult = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const KubernetesConfigurationResult = struct {
    audit_logs: KubernetesAuditLogsConfigurationResult,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit_logs = "auditLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const KubernetesAuditLogsConfigurationResult = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const S3LogsConfigurationResult = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const FlowLogsConfigurationResult = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const DNSLogsConfigurationResult = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudTrailConfigurationResult = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalyObject = struct {
    profile_type: ?[]const u8 = null,
    profile_subtype: ?[]const u8 = null,
    observations: ?Observations = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .profile_type = "profileType",
            .profile_subtype = "profileSubtype",
            .observations = "observations",
        };
        return @field(mappings, field_name);
    }
};

pub const Observations = struct {
    text: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "text",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessDetails = struct {
    name: ?[]const u8 = null,
    executable_path: ?[]const u8 = null,
    executable_sha256: ?[]const u8 = null,
    namespace_pid: ?i64 = null,
    pwd: ?[]const u8 = null,
    pid: ?i64 = null,
    start_time: ?i64 = null,
    uuid: ?[]const u8 = null,
    parent_uuid: ?[]const u8 = null,
    user: ?[]const u8 = null,
    user_id: ?i64 = null,
    euid: ?i64 = null,
    lineage: ?[]LineageObject = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .executable_path = "executablePath",
            .executable_sha256 = "executableSha256",
            .namespace_pid = "namespacePid",
            .pwd = "pwd",
            .pid = "pid",
            .start_time = "startTime",
            .uuid = "uuid",
            .parent_uuid = "parentUuid",
            .user = "user",
            .user_id = "userId",
            .euid = "euid",
            .lineage = "lineage",
        };
        return @field(mappings, field_name);
    }
};

pub const LineageObject = struct {
    start_time: ?i64 = null,
    namespace_pid: ?i64 = null,
    user_id: ?i64 = null,
    name: ?[]const u8 = null,
    pid: ?i64 = null,
    uuid: ?[]const u8 = null,
    executable_path: ?[]const u8 = null,
    euid: ?i64 = null,
    parent_uuid: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "startTime",
            .namespace_pid = "namespacePid",
            .user_id = "userId",
            .name = "name",
            .pid = "pid",
            .uuid = "uuid",
            .executable_path = "executablePath",
            .euid = "euid",
            .parent_uuid = "parentUuid",
        };
        return @field(mappings, field_name);
    }
};

pub const RemoteIpDetails = struct {
    city: ?City = null,
    country: ?Country = null,
    geo_location: ?GeoLocation = null,
    ip_address_v4: ?[]const u8 = null,
    organization: ?Organization = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .city = "city",
            .country = "country",
            .geo_location = "geoLocation",
            .ip_address_v4 = "ipAddressV4",
            .organization = "organization",
        };
        return @field(mappings, field_name);
    }
};

pub const Organization = struct {
    asn: ?[]const u8 = null,
    asn_org: ?[]const u8 = null,
    isp: ?[]const u8 = null,
    org: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asn = "asn",
            .asn_org = "asnOrg",
            .isp = "isp",
            .org = "org",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoLocation = struct {
    lat: ?f64 = null,
    lon: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lat = "lat",
            .lon = "lon",
        };
        return @field(mappings, field_name);
    }
};

pub const Country = struct {
    country_code: ?[]const u8 = null,
    country_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country_code = "countryCode",
            .country_name = "countryName",
        };
        return @field(mappings, field_name);
    }
};

pub const City = struct {
    city_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .city_name = "cityName",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalIpDetails = struct {
    ip_address_v4: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address_v4 = "ipAddressV4",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalPortDetails = struct {
    port: ?i64 = null,
    port_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port = "port",
            .port_name = "portName",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityGroup = struct {
    group_id: ?[]const u8 = null,
    group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_id = "groupId",
            .group_name = "groupName",
        };
        return @field(mappings, field_name);
    }
};

pub const Container = struct {
    container_runtime: ?[]const u8 = null,
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    image: ?[]const u8 = null,
    image_prefix: ?[]const u8 = null,
    volume_mounts: ?[]VolumeMount = null,
    security_context: ?SecurityContext = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_runtime = "containerRuntime",
            .id = "id",
            .name = "name",
            .image = "image",
            .image_prefix = "imagePrefix",
            .volume_mounts = "volumeMounts",
            .security_context = "securityContext",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityContext = struct {
    privileged: ?bool = null,
    allow_privilege_escalation: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .privileged = "privileged",
            .allow_privilege_escalation = "allowPrivilegeEscalation",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeMount = struct {
    name: ?[]const u8 = null,
    mount_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .mount_path = "mountPath",
        };
        return @field(mappings, field_name);
    }
};

pub const Volume = struct {
    name: ?[]const u8 = null,
    host_path: ?HostPath = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .host_path = "hostPath",
        };
        return @field(mappings, field_name);
    }
};

pub const HostPath = struct {
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "path",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeDetail = struct {
    volume_arn: ?[]const u8 = null,
    volume_type: ?[]const u8 = null,
    device_name: ?[]const u8 = null,
    volume_size_in_gb: ?i64 = null,
    encryption_type: ?[]const u8 = null,
    snapshot_arn: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_arn = "volumeArn",
            .volume_type = "volumeType",
            .device_name = "deviceName",
            .volume_size_in_gb = "volumeSizeInGB",
            .encryption_type = "encryptionType",
            .snapshot_arn = "snapshotArn",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const BlockPublicAccess = struct {
    ignore_public_acls: ?bool = null,
    restrict_public_buckets: ?bool = null,
    block_public_acls: ?bool = null,
    block_public_policy: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ignore_public_acls = "ignorePublicAcls",
            .restrict_public_buckets = "restrictPublicBuckets",
            .block_public_acls = "blockPublicAcls",
            .block_public_policy = "blockPublicPolicy",
        };
        return @field(mappings, field_name);
    }
};
