const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-08-04";
pub const sdk_id: []const u8 = "Health";
pub const arn_namespace: ?[]const u8 = "health";
pub const endpoint_prefix: []const u8 = "health";
pub const sigv4_name: []const u8 = "health";
pub const name: []const u8 = "AWSHealth_20160804";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-08-04",
    sdk_id: []const u8 = "Health",
    arn_namespace: ?[]const u8 = "health",
    endpoint_prefix: []const u8 = "health",
    sigv4_name: []const u8 = "health",
    name: []const u8 = "AWSHealth_20160804",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const describe_affected_accounts_for_organization: struct {
    action_name: []const u8 = "DescribeAffectedAccountsForOrganization",
    Request: type = struct {
        event_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_arn = "eventArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_affected_accounts_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_affected_accounts_for_organization };
        }
    },
    Response: type = struct {
        affected_accounts: ?[][]const u8 = null,
        event_scope_code: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .affected_accounts = "affectedAccounts",
                .event_scope_code = "eventScopeCode",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPaginationToken,
    },
} = .{};
pub const describe_affected_entities: struct {
    action_name: []const u8 = "DescribeAffectedEntities",
    Request: type = struct {
        filter: struct {
            event_arns: [][]const u8,
            entity_arns: ?[][]const u8 = null,
            entity_values: ?[][]const u8 = null,
            last_updated_times: ?[]DateTimeRange = null,
            tags: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            status_codes: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_arns = "eventArns",
                    .entity_arns = "entityArns",
                    .entity_values = "entityValues",
                    .last_updated_times = "lastUpdatedTimes",
                    .tags = "tags",
                    .status_codes = "statusCodes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        locale: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .locale = "locale",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_affected_entities) } {
            return .{ .service_metadata = service_metadata, .action = describe_affected_entities };
        }
    },
    Response: type = struct {
        entities: ?[]AffectedEntity = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entities = "entities",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPaginationToken,
        UnsupportedLocale,
    },
} = .{};
pub const describe_affected_entities_for_organization: struct {
    action_name: []const u8 = "DescribeAffectedEntitiesForOrganization",
    Request: type = struct {
        organization_entity_filters: ?[]EventAccountFilter = null,
        locale: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        organization_entity_account_filters: ?[]struct {
            event_arn: []const u8,
            aws_account_id: ?[]const u8 = null,
            status_codes: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_arn = "eventArn",
                    .aws_account_id = "awsAccountId",
                    .status_codes = "statusCodes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_entity_filters = "organizationEntityFilters",
                .locale = "locale",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .organization_entity_account_filters = "organizationEntityAccountFilters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_affected_entities_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_affected_entities_for_organization };
        }
    },
    Response: type = struct {
        entities: ?[]AffectedEntity = null,
        failed_set: ?[]struct {
            aws_account_id: ?[]const u8 = null,
            event_arn: ?[]const u8 = null,
            error_name: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_account_id = "awsAccountId",
                    .event_arn = "eventArn",
                    .error_name = "errorName",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entities = "entities",
                .failed_set = "failedSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPaginationToken,
        UnsupportedLocale,
    },
} = .{};
pub const describe_entity_aggregates: struct {
    action_name: []const u8 = "DescribeEntityAggregates",
    Request: type = struct {
        event_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_arns = "eventArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_entity_aggregates) } {
            return .{ .service_metadata = service_metadata, .action = describe_entity_aggregates };
        }
    },
    Response: type = struct {
        entity_aggregates: ?[]struct {
            event_arn: ?[]const u8 = null,
            count: ?i64 = null,
            statuses: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_arn = "eventArn",
                    .count = "count",
                    .statuses = "statuses",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "statuses", field_name))
                    return try serializeMap(self.statuses, self.fieldNameFor("statuses"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_aggregates = "entityAggregates",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_entity_aggregates_for_organization: struct {
    action_name: []const u8 = "DescribeEntityAggregatesForOrganization",
    Request: type = struct {
        event_arns: [][]const u8,
        aws_account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_arns = "eventArns",
                .aws_account_ids = "awsAccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_entity_aggregates_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_entity_aggregates_for_organization };
        }
    },
    Response: type = struct {
        organization_entity_aggregates: ?[]struct {
            event_arn: ?[]const u8 = null,
            count: ?i64 = null,
            statuses: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            accounts: ?[]struct {
                account_id: ?[]const u8 = null,
                count: ?i64 = null,
                statuses: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .account_id = "accountId",
                        .count = "count",
                        .statuses = "statuses",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "statuses", field_name))
                        return try serializeMap(self.statuses, self.fieldNameFor("statuses"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_arn = "eventArn",
                    .count = "count",
                    .statuses = "statuses",
                    .accounts = "accounts",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "statuses", field_name))
                    return try serializeMap(self.statuses, self.fieldNameFor("statuses"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_entity_aggregates = "organizationEntityAggregates",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_aggregates: struct {
    action_name: []const u8 = "DescribeEventAggregates",
    Request: type = struct {
        filter: ?EventFilter = null,
        aggregate_field: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .aggregate_field = "aggregateField",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_aggregates) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_aggregates };
        }
    },
    Response: type = struct {
        event_aggregates: ?[]struct {
            aggregate_value: ?[]const u8 = null,
            count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aggregate_value = "aggregateValue",
                    .count = "count",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_aggregates = "eventAggregates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPaginationToken,
    },
} = .{};
pub const describe_event_details: struct {
    action_name: []const u8 = "DescribeEventDetails",
    Request: type = struct {
        event_arns: [][]const u8,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_arns = "eventArns",
                .locale = "locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_details) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_details };
        }
    },
    Response: type = struct {
        successful_set: ?[]struct {
            event: ?Event = null,
            event_description: ?EventDescription = null,
            event_metadata: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event = "event",
                    .event_description = "eventDescription",
                    .event_metadata = "eventMetadata",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "event_metadata", field_name))
                    return try serializeMap(self.event_metadata, self.fieldNameFor("event_metadata"), options, out_stream);
                return false;
            }
        } = null,
        failed_set: ?[]struct {
            event_arn: ?[]const u8 = null,
            error_name: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_arn = "eventArn",
                    .error_name = "errorName",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_set = "successfulSet",
                .failed_set = "failedSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        UnsupportedLocale,
    },
} = .{};
pub const describe_event_details_for_organization: struct {
    action_name: []const u8 = "DescribeEventDetailsForOrganization",
    Request: type = struct {
        organization_event_detail_filters: []EventAccountFilter,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_event_detail_filters = "organizationEventDetailFilters",
                .locale = "locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_details_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_details_for_organization };
        }
    },
    Response: type = struct {
        successful_set: ?[]struct {
            aws_account_id: ?[]const u8 = null,
            event: ?Event = null,
            event_description: ?EventDescription = null,
            event_metadata: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_account_id = "awsAccountId",
                    .event = "event",
                    .event_description = "eventDescription",
                    .event_metadata = "eventMetadata",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "event_metadata", field_name))
                    return try serializeMap(self.event_metadata, self.fieldNameFor("event_metadata"), options, out_stream);
                return false;
            }
        } = null,
        failed_set: ?[]struct {
            aws_account_id: ?[]const u8 = null,
            event_arn: ?[]const u8 = null,
            error_name: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_account_id = "awsAccountId",
                    .event_arn = "eventArn",
                    .error_name = "errorName",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_set = "successfulSet",
                .failed_set = "failedSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        UnsupportedLocale,
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        filter: ?EventFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .locale = "locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        events: ?[]Event = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "events",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPaginationToken,
        UnsupportedLocale,
    },
} = .{};
pub const describe_events_for_organization: struct {
    action_name: []const u8 = "DescribeEventsForOrganization",
    Request: type = struct {
        filter: ?struct {
            event_type_codes: ?[][]const u8 = null,
            aws_account_ids: ?[][]const u8 = null,
            services: ?[][]const u8 = null,
            regions: ?[][]const u8 = null,
            start_time: ?DateTimeRange = null,
            end_time: ?DateTimeRange = null,
            last_updated_time: ?DateTimeRange = null,
            entity_arns: ?[][]const u8 = null,
            entity_values: ?[][]const u8 = null,
            event_type_categories: ?[][]const u8 = null,
            event_status_codes: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_type_codes = "eventTypeCodes",
                    .aws_account_ids = "awsAccountIds",
                    .services = "services",
                    .regions = "regions",
                    .start_time = "startTime",
                    .end_time = "endTime",
                    .last_updated_time = "lastUpdatedTime",
                    .entity_arns = "entityArns",
                    .entity_values = "entityValues",
                    .event_type_categories = "eventTypeCategories",
                    .event_status_codes = "eventStatusCodes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .locale = "locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_events_for_organization };
        }
    },
    Response: type = struct {
        events: ?[]struct {
            arn: ?[]const u8 = null,
            service: ?[]const u8 = null,
            event_type_code: ?[]const u8 = null,
            event_type_category: ?[]const u8 = null,
            event_scope_code: ?[]const u8 = null,
            region: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            status_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .service = "service",
                    .event_type_code = "eventTypeCode",
                    .event_type_category = "eventTypeCategory",
                    .event_scope_code = "eventScopeCode",
                    .region = "region",
                    .start_time = "startTime",
                    .end_time = "endTime",
                    .last_updated_time = "lastUpdatedTime",
                    .status_code = "statusCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "events",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPaginationToken,
        UnsupportedLocale,
    },
} = .{};
pub const describe_event_types: struct {
    action_name: []const u8 = "DescribeEventTypes",
    Request: type = struct {
        filter: ?struct {
            event_type_codes: ?[][]const u8 = null,
            services: ?[][]const u8 = null,
            event_type_categories: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_type_codes = "eventTypeCodes",
                    .services = "services",
                    .event_type_categories = "eventTypeCategories",
                };
                return @field(mappings, field_name);
            }
        } = null,
        locale: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .locale = "locale",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_types) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_types };
        }
    },
    Response: type = struct {
        event_types: ?[]struct {
            service: ?[]const u8 = null,
            code: ?[]const u8 = null,
            category: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service = "service",
                    .code = "code",
                    .category = "category",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_types = "eventTypes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPaginationToken,
        UnsupportedLocale,
    },
} = .{};
pub const describe_health_service_status_for_organization: struct {
    action_name: []const u8 = "DescribeHealthServiceStatusForOrganization",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_health_service_status_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_health_service_status_for_organization };
        }
    },
    Response: type = struct {
        health_service_access_status_for_organization: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_service_access_status_for_organization = "healthServiceAccessStatusForOrganization",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_health_service_access_for_organization: struct {
    action_name: []const u8 = "DisableHealthServiceAccessForOrganization",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_health_service_access_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = disable_health_service_access_for_organization };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
    },
} = .{};
pub const enable_health_service_access_for_organization: struct {
    action_name: []const u8 = "EnableHealthServiceAccessForOrganization",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_health_service_access_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = enable_health_service_access_for_organization };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
    },
} = .{};

pub const DateTimeRange = struct {
    from: ?i64 = null,
    to: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "from",
            .to = "to",
        };
        return @field(mappings, field_name);
    }
};

pub const Event = struct {
    arn: ?[]const u8 = null,
    service: ?[]const u8 = null,
    event_type_code: ?[]const u8 = null,
    event_type_category: ?[]const u8 = null,
    region: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    status_code: ?[]const u8 = null,
    event_scope_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .service = "service",
            .event_type_code = "eventTypeCode",
            .event_type_category = "eventTypeCategory",
            .region = "region",
            .availability_zone = "availabilityZone",
            .start_time = "startTime",
            .end_time = "endTime",
            .last_updated_time = "lastUpdatedTime",
            .status_code = "statusCode",
            .event_scope_code = "eventScopeCode",
        };
        return @field(mappings, field_name);
    }
};

pub const EventFilter = struct {
    event_arns: ?[][]const u8 = null,
    event_type_codes: ?[][]const u8 = null,
    services: ?[][]const u8 = null,
    regions: ?[][]const u8 = null,
    availability_zones: ?[][]const u8 = null,
    start_times: ?[]DateTimeRange = null,
    end_times: ?[]DateTimeRange = null,
    last_updated_times: ?[]DateTimeRange = null,
    entity_arns: ?[][]const u8 = null,
    entity_values: ?[][]const u8 = null,
    event_type_categories: ?[][]const u8 = null,
    tags: ?[][]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    event_status_codes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_arns = "eventArns",
            .event_type_codes = "eventTypeCodes",
            .services = "services",
            .regions = "regions",
            .availability_zones = "availabilityZones",
            .start_times = "startTimes",
            .end_times = "endTimes",
            .last_updated_times = "lastUpdatedTimes",
            .entity_arns = "entityArns",
            .entity_values = "entityValues",
            .event_type_categories = "eventTypeCategories",
            .tags = "tags",
            .event_status_codes = "eventStatusCodes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const EventDescription = struct {
    latest_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .latest_description = "latestDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const EventAccountFilter = struct {
    event_arn: []const u8,
    aws_account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_arn = "eventArn",
            .aws_account_id = "awsAccountId",
        };
        return @field(mappings, field_name);
    }
};

pub const AffectedEntity = struct {
    entity_arn: ?[]const u8 = null,
    event_arn: ?[]const u8 = null,
    entity_value: ?[]const u8 = null,
    entity_url: ?[]const u8 = null,
    aws_account_id: ?[]const u8 = null,
    last_updated_time: ?i64 = null,
    status_code: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_arn = "entityArn",
            .event_arn = "eventArn",
            .entity_value = "entityValue",
            .entity_url = "entityUrl",
            .aws_account_id = "awsAccountId",
            .last_updated_time = "lastUpdatedTime",
            .status_code = "statusCode",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};
