const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-01";
pub const sdk_id: []const u8 = "HealthLake";
pub const arn_namespace: ?[]const u8 = "healthlake";
pub const endpoint_prefix: []const u8 = "healthlake";
pub const sigv4_name: []const u8 = "healthlake";
pub const name: []const u8 = "HealthLake";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-01",
    sdk_id: []const u8 = "HealthLake",
    arn_namespace: ?[]const u8 = "healthlake",
    endpoint_prefix: []const u8 = "healthlake",
    sigv4_name: []const u8 = "healthlake",
    name: []const u8 = "HealthLake",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_fhir_datastore: struct {
    action_name: []const u8 = "CreateFHIRDatastore",
    Request: type = struct {
        datastore_name: ?[]const u8 = null,
        datastore_type_version: []const u8,
        sse_configuration: ?SseConfiguration = null,
        preload_data_config: ?PreloadDataConfig = null,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,
        identity_provider_configuration: ?IdentityProviderConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_name = "DatastoreName",
                .datastore_type_version = "DatastoreTypeVersion",
                .sse_configuration = "SseConfiguration",
                .preload_data_config = "PreloadDataConfig",
                .client_token = "ClientToken",
                .tags = "Tags",
                .identity_provider_configuration = "IdentityProviderConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fhir_datastore) } {
            return .{ .service_metadata = service_metadata, .action = create_fhir_datastore };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        datastore_arn: []const u8,
        datastore_status: []const u8,
        datastore_endpoint: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .datastore_arn = "DatastoreArn",
                .datastore_status = "DatastoreStatus",
                .datastore_endpoint = "DatastoreEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_fhir_datastore: struct {
    action_name: []const u8 = "DeleteFHIRDatastore",
    Request: type = struct {
        datastore_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fhir_datastore) } {
            return .{ .service_metadata = service_metadata, .action = delete_fhir_datastore };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        datastore_arn: []const u8,
        datastore_status: []const u8,
        datastore_endpoint: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .datastore_arn = "DatastoreArn",
                .datastore_status = "DatastoreStatus",
                .datastore_endpoint = "DatastoreEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_fhir_datastore: struct {
    action_name: []const u8 = "DescribeFHIRDatastore",
    Request: type = struct {
        datastore_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fhir_datastore) } {
            return .{ .service_metadata = service_metadata, .action = describe_fhir_datastore };
        }
    },
    Response: type = struct {
        datastore_properties: DatastoreProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_properties = "DatastoreProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_fhir_export_job: struct {
    action_name: []const u8 = "DescribeFHIRExportJob",
    Request: type = struct {
        datastore_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fhir_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_fhir_export_job };
        }
    },
    Response: type = struct {
        export_job_properties: ExportJobProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_job_properties = "ExportJobProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_fhir_import_job: struct {
    action_name: []const u8 = "DescribeFHIRImportJob",
    Request: type = struct {
        datastore_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fhir_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_fhir_import_job };
        }
    },
    Response: type = struct {
        import_job_properties: ImportJobProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_job_properties = "ImportJobProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_fhir_datastores: struct {
    action_name: []const u8 = "ListFHIRDatastores",
    Request: type = struct {
        filter: ?struct {
            datastore_name: ?[]const u8 = null,
            datastore_status: ?[]const u8 = null,
            created_before: ?i64 = null,
            created_after: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .datastore_name = "DatastoreName",
                    .datastore_status = "DatastoreStatus",
                    .created_before = "CreatedBefore",
                    .created_after = "CreatedAfter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fhir_datastores) } {
            return .{ .service_metadata = service_metadata, .action = list_fhir_datastores };
        }
    },
    Response: type = struct {
        datastore_properties_list: []DatastoreProperties,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_properties_list = "DatastorePropertiesList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_fhir_export_jobs: struct {
    action_name: []const u8 = "ListFHIRExportJobs",
    Request: type = struct {
        datastore_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        job_name: ?[]const u8 = null,
        job_status: ?[]const u8 = null,
        submitted_before: ?i64 = null,
        submitted_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .job_name = "JobName",
                .job_status = "JobStatus",
                .submitted_before = "SubmittedBefore",
                .submitted_after = "SubmittedAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fhir_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_fhir_export_jobs };
        }
    },
    Response: type = struct {
        export_job_properties_list: []ExportJobProperties,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_job_properties_list = "ExportJobPropertiesList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_fhir_import_jobs: struct {
    action_name: []const u8 = "ListFHIRImportJobs",
    Request: type = struct {
        datastore_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        job_name: ?[]const u8 = null,
        job_status: ?[]const u8 = null,
        submitted_before: ?i64 = null,
        submitted_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "DatastoreId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .job_name = "JobName",
                .job_status = "JobStatus",
                .submitted_before = "SubmittedBefore",
                .submitted_after = "SubmittedAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fhir_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_fhir_import_jobs };
        }
    },
    Response: type = struct {
        import_job_properties_list: []ImportJobProperties,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_job_properties_list = "ImportJobPropertiesList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_fhir_export_job: struct {
    action_name: []const u8 = "StartFHIRExportJob",
    Request: type = struct {
        job_name: ?[]const u8 = null,
        output_data_config: OutputDataConfig,
        datastore_id: []const u8,
        data_access_role_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .output_data_config = "OutputDataConfig",
                .datastore_id = "DatastoreId",
                .data_access_role_arn = "DataAccessRoleArn",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_fhir_export_job) } {
            return .{ .service_metadata = service_metadata, .action = start_fhir_export_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        job_status: []const u8,
        datastore_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .job_status = "JobStatus",
                .datastore_id = "DatastoreId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_fhir_import_job: struct {
    action_name: []const u8 = "StartFHIRImportJob",
    Request: type = struct {
        job_name: ?[]const u8 = null,
        input_data_config: InputDataConfig,
        job_output_data_config: OutputDataConfig,
        datastore_id: []const u8,
        data_access_role_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .input_data_config = "InputDataConfig",
                .job_output_data_config = "JobOutputDataConfig",
                .datastore_id = "DatastoreId",
                .data_access_role_arn = "DataAccessRoleArn",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_fhir_import_job) } {
            return .{ .service_metadata = service_metadata, .action = start_fhir_import_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        job_status: []const u8,
        datastore_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .job_status = "JobStatus",
                .datastore_id = "DatastoreId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputDataConfig = union {
    s3_configuration: ?S3Configuration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_configuration = "S3Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Configuration = struct {
    s3_uri: []const u8,
    kms_key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDataConfig = union {
    s3_uri: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportJobProperties = struct {
    job_id: []const u8,
    job_name: ?[]const u8 = null,
    job_status: []const u8,
    submit_time: i64,
    end_time: ?i64 = null,
    datastore_id: []const u8,
    input_data_config: InputDataConfig,
    job_output_data_config: ?OutputDataConfig = null,
    job_progress_report: ?JobProgressReport = null,
    data_access_role_arn: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "JobId",
            .job_name = "JobName",
            .job_status = "JobStatus",
            .submit_time = "SubmitTime",
            .end_time = "EndTime",
            .datastore_id = "DatastoreId",
            .input_data_config = "InputDataConfig",
            .job_output_data_config = "JobOutputDataConfig",
            .job_progress_report = "JobProgressReport",
            .data_access_role_arn = "DataAccessRoleArn",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const JobProgressReport = struct {
    total_number_of_scanned_files: ?i64 = null,
    total_size_of_scanned_files_in_mb: ?f64 = null,
    total_number_of_imported_files: ?i64 = null,
    total_number_of_resources_scanned: ?i64 = null,
    total_number_of_resources_imported: ?i64 = null,
    total_number_of_resources_with_customer_error: ?i64 = null,
    total_number_of_files_read_with_customer_error: ?i64 = null,
    throughput: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_number_of_scanned_files = "TotalNumberOfScannedFiles",
            .total_size_of_scanned_files_in_mb = "TotalSizeOfScannedFilesInMB",
            .total_number_of_imported_files = "TotalNumberOfImportedFiles",
            .total_number_of_resources_scanned = "TotalNumberOfResourcesScanned",
            .total_number_of_resources_imported = "TotalNumberOfResourcesImported",
            .total_number_of_resources_with_customer_error = "TotalNumberOfResourcesWithCustomerError",
            .total_number_of_files_read_with_customer_error = "TotalNumberOfFilesReadWithCustomerError",
            .throughput = "Throughput",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportJobProperties = struct {
    job_id: []const u8,
    job_name: ?[]const u8 = null,
    job_status: []const u8,
    submit_time: i64,
    end_time: ?i64 = null,
    datastore_id: []const u8,
    output_data_config: OutputDataConfig,
    data_access_role_arn: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "JobId",
            .job_name = "JobName",
            .job_status = "JobStatus",
            .submit_time = "SubmitTime",
            .end_time = "EndTime",
            .datastore_id = "DatastoreId",
            .output_data_config = "OutputDataConfig",
            .data_access_role_arn = "DataAccessRoleArn",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DatastoreProperties = struct {
    datastore_id: []const u8,
    datastore_arn: []const u8,
    datastore_name: ?[]const u8 = null,
    datastore_status: []const u8,
    created_at: ?i64 = null,
    datastore_type_version: []const u8,
    datastore_endpoint: []const u8,
    sse_configuration: ?SseConfiguration = null,
    preload_data_config: ?PreloadDataConfig = null,
    identity_provider_configuration: ?IdentityProviderConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .datastore_id = "DatastoreId",
            .datastore_arn = "DatastoreArn",
            .datastore_name = "DatastoreName",
            .datastore_status = "DatastoreStatus",
            .created_at = "CreatedAt",
            .datastore_type_version = "DatastoreTypeVersion",
            .datastore_endpoint = "DatastoreEndpoint",
            .sse_configuration = "SseConfiguration",
            .preload_data_config = "PreloadDataConfig",
            .identity_provider_configuration = "IdentityProviderConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityProviderConfiguration = struct {
    authorization_strategy: []const u8,
    fine_grained_authorization_enabled: ?bool = null,
    metadata: ?[]const u8 = null,
    idp_lambda_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authorization_strategy = "AuthorizationStrategy",
            .fine_grained_authorization_enabled = "FineGrainedAuthorizationEnabled",
            .metadata = "Metadata",
            .idp_lambda_arn = "IdpLambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PreloadDataConfig = struct {
    preload_data_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .preload_data_type = "PreloadDataType",
        };
        return @field(mappings, field_name);
    }
};

pub const SseConfiguration = struct {
    kms_encryption_config: KmsEncryptionConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_encryption_config = "KmsEncryptionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const KmsEncryptionConfig = struct {
    cmk_type: []const u8,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cmk_type = "CmkType",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};
