const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-03-01";
pub const sdk_id: []const u8 = "Honeycode";
pub const arn_namespace: ?[]const u8 = "honeycode";
pub const endpoint_prefix: []const u8 = "honeycode";
pub const sigv4_name: []const u8 = "honeycode";
pub const name: []const u8 = "SheetsPublicApiService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-03-01",
    sdk_id: []const u8 = "Honeycode",
    arn_namespace: ?[]const u8 = "honeycode",
    endpoint_prefix: []const u8 = "honeycode",
    sigv4_name: []const u8 = "honeycode",
    name: []const u8 = "SheetsPublicApiService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_create_table_rows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workbooks/{workbookId}/tables/{tableId}/rows/batchcreate",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchCreateTableRows",
    Request: type = struct {
        workbook_id: []const u8,
        table_id: []const u8,
        rows_to_create: []struct {
            batch_item_id: []const u8,
            cells_to_create: []struct {
                key: ?[]const u8 = null,
                value: ?CellInput = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .batch_item_id = "batchItemId",
                    .cells_to_create = "cellsToCreate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "cells_to_create", field_name))
                    return try serializeMap(self.cells_to_create, self.fieldNameFor("cells_to_create"), options, out_stream);
                return false;
            }
        },
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .table_id = "tableId",
                .rows_to_create = "rowsToCreate",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_table_rows) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_table_rows };
        }
    },
    Response: type = struct {
        workbook_cursor: i64,
        created_rows: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        failed_batch_items: ?[]FailedBatchItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_cursor = "workbookCursor",
                .created_rows = "createdRows",
                .failed_batch_items = "failedBatchItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "created_rows", field_name))
                return try serializeMap(self.created_rows, self.fieldNameFor("created_rows"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceQuotaExceeded,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_delete_table_rows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workbooks/{workbookId}/tables/{tableId}/rows/batchdelete",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeleteTableRows",
    Request: type = struct {
        workbook_id: []const u8,
        table_id: []const u8,
        row_ids: [][]const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .table_id = "tableId",
                .row_ids = "rowIds",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_table_rows) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_table_rows };
        }
    },
    Response: type = struct {
        workbook_cursor: i64,
        failed_batch_items: ?[]FailedBatchItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_cursor = "workbookCursor",
                .failed_batch_items = "failedBatchItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_update_table_rows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workbooks/{workbookId}/tables/{tableId}/rows/batchupdate",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateTableRows",
    Request: type = struct {
        workbook_id: []const u8,
        table_id: []const u8,
        rows_to_update: []struct {
            row_id: []const u8,
            cells_to_update: []struct {
                key: ?[]const u8 = null,
                value: ?CellInput = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .row_id = "rowId",
                    .cells_to_update = "cellsToUpdate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "cells_to_update", field_name))
                    return try serializeMap(self.cells_to_update, self.fieldNameFor("cells_to_update"), options, out_stream);
                return false;
            }
        },
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .table_id = "tableId",
                .rows_to_update = "rowsToUpdate",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_table_rows) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_table_rows };
        }
    },
    Response: type = struct {
        workbook_cursor: i64,
        failed_batch_items: ?[]FailedBatchItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_cursor = "workbookCursor",
                .failed_batch_items = "failedBatchItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_upsert_table_rows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workbooks/{workbookId}/tables/{tableId}/rows/batchupsert",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpsertTableRows",
    Request: type = struct {
        workbook_id: []const u8,
        table_id: []const u8,
        rows_to_upsert: []struct {
            batch_item_id: []const u8,
            filter: Filter,
            cells_to_update: []struct {
                key: ?[]const u8 = null,
                value: ?CellInput = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .batch_item_id = "batchItemId",
                    .filter = "filter",
                    .cells_to_update = "cellsToUpdate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "cells_to_update", field_name))
                    return try serializeMap(self.cells_to_update, self.fieldNameFor("cells_to_update"), options, out_stream);
                return false;
            }
        },
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .table_id = "tableId",
                .rows_to_upsert = "rowsToUpsert",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_upsert_table_rows) } {
            return .{ .service_metadata = service_metadata, .action = batch_upsert_table_rows };
        }
    },
    Response: type = struct {
        rows: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                row_ids: [][]const u8,
                upsert_action: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .row_ids = "rowIds",
                        .upsert_action = "upsertAction",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },
        workbook_cursor: i64,
        failed_batch_items: ?[]FailedBatchItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rows = "rows",
                .workbook_cursor = "workbookCursor",
                .failed_batch_items = "failedBatchItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "rows", field_name))
                return try serializeMap(self.rows, self.fieldNameFor("rows"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceQuotaExceeded,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_table_data_import_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workbooks/{workbookId}/tables/{tableId}/import/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTableDataImportJob",
    Request: type = struct {
        workbook_id: []const u8,
        table_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .table_id = "tableId",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_table_data_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_table_data_import_job };
        }
    },
    Response: type = struct {
        job_status: []const u8,
        message: []const u8,
        job_metadata: struct {
            submitter: struct {
                email: ?[]const u8 = null,
                user_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .email = "email",
                        .user_arn = "userArn",
                    };
                    return @field(mappings, field_name);
                }
            },
            submit_time: i64,
            import_options: ImportOptions,
            data_source: ImportDataSource,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .submitter = "submitter",
                    .submit_time = "submitTime",
                    .import_options = "importOptions",
                    .data_source = "dataSource",
                };
                return @field(mappings, field_name);
            }
        },
        error_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "jobStatus",
                .message = "message",
                .job_metadata = "jobMetadata",
                .error_code = "errorCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const get_screen_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/screendata",
        .success_code = 200,
    };

    action_name: []const u8 = "GetScreenData",
    Request: type = struct {
        workbook_id: []const u8,
        app_id: []const u8,
        screen_id: []const u8,
        variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?VariableValue = null,
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .app_id = "appId",
                .screen_id = "screenId",
                .variables = "variables",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "variables", field_name))
                return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_screen_data) } {
            return .{ .service_metadata = service_metadata, .action = get_screen_data };
        }
    },
    Response: type = struct {
        results: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                headers: []struct {
                    name: []const u8,
                    format: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .format = "format",
                        };
                        return @field(mappings, field_name);
                    }
                },
                rows: []struct {
                    row_id: ?[]const u8 = null,
                    data_items: []struct {
                        override_format: ?[]const u8 = null,
                        raw_value: ?[]const u8 = null,
                        formatted_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .override_format = "overrideFormat",
                                .raw_value = "rawValue",
                                .formatted_value = "formattedValue",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .row_id = "rowId",
                            .data_items = "dataItems",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .headers = "headers",
                        .rows = "rows",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },
        workbook_cursor: i64,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "results",
                .workbook_cursor = "workbookCursor",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "results", field_name))
                return try serializeMap(self.results, self.fieldNameFor("results"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const invoke_screen_automation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workbooks/{workbookId}/apps/{appId}/screens/{screenId}/automations/{screenAutomationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "InvokeScreenAutomation",
    Request: type = struct {
        workbook_id: []const u8,
        app_id: []const u8,
        screen_id: []const u8,
        screen_automation_id: []const u8,
        variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?VariableValue = null,
        } = null,
        row_id: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .app_id = "appId",
                .screen_id = "screenId",
                .screen_automation_id = "screenAutomationId",
                .variables = "variables",
                .row_id = "rowId",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "variables", field_name))
                return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invoke_screen_automation) } {
            return .{ .service_metadata = service_metadata, .action = invoke_screen_automation };
        }
    },
    Response: type = struct {
        workbook_cursor: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_cursor = "workbookCursor",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AutomationExecution,
        AutomationExecutionTimeout,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceQuotaExceeded,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const list_table_columns: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workbooks/{workbookId}/tables/{tableId}/columns",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTableColumns",
    Request: type = struct {
        workbook_id: []const u8,
        table_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .table_id = "tableId",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_table_columns) } {
            return .{ .service_metadata = service_metadata, .action = list_table_columns };
        }
    },
    Response: type = struct {
        table_columns: []struct {
            table_column_id: ?[]const u8 = null,
            table_column_name: ?[]const u8 = null,
            format: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_column_id = "tableColumnId",
                    .table_column_name = "tableColumnName",
                    .format = "format",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        workbook_cursor: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_columns = "tableColumns",
                .next_token = "nextToken",
                .workbook_cursor = "workbookCursor",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const list_table_rows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workbooks/{workbookId}/tables/{tableId}/rows/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTableRows",
    Request: type = struct {
        workbook_id: []const u8,
        table_id: []const u8,
        row_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .table_id = "tableId",
                .row_ids = "rowIds",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_table_rows) } {
            return .{ .service_metadata = service_metadata, .action = list_table_rows };
        }
    },
    Response: type = struct {
        column_ids: [][]const u8,
        rows: []TableRow,
        row_ids_not_found: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        workbook_cursor: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_ids = "columnIds",
                .rows = "rows",
                .row_ids_not_found = "rowIdsNotFound",
                .next_token = "nextToken",
                .workbook_cursor = "workbookCursor",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tables: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workbooks/{workbookId}/tables",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTables",
    Request: type = struct {
        workbook_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tables) } {
            return .{ .service_metadata = service_metadata, .action = list_tables };
        }
    },
    Response: type = struct {
        tables: []struct {
            table_id: ?[]const u8 = null,
            table_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_id = "tableId",
                    .table_name = "tableName",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        workbook_cursor: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tables = "tables",
                .next_token = "nextToken",
                .workbook_cursor = "workbookCursor",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const query_table_rows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workbooks/{workbookId}/tables/{tableId}/rows/query",
        .success_code = 200,
    };

    action_name: []const u8 = "QueryTableRows",
    Request: type = struct {
        workbook_id: []const u8,
        table_id: []const u8,
        filter_formula: Filter,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .table_id = "tableId",
                .filter_formula = "filterFormula",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query_table_rows) } {
            return .{ .service_metadata = service_metadata, .action = query_table_rows };
        }
    },
    Response: type = struct {
        column_ids: [][]const u8,
        rows: []TableRow,
        next_token: ?[]const u8 = null,
        workbook_cursor: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_ids = "columnIds",
                .rows = "rows",
                .next_token = "nextToken",
                .workbook_cursor = "workbookCursor",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const start_table_data_import_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workbooks/{workbookId}/tables/{destinationTableId}/import",
        .success_code = 200,
    };

    action_name: []const u8 = "StartTableDataImportJob",
    Request: type = struct {
        workbook_id: []const u8,
        data_source: ImportDataSource,
        data_format: []const u8,
        destination_table_id: []const u8,
        import_options: ImportOptions,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workbook_id = "workbookId",
                .data_source = "dataSource",
                .data_format = "dataFormat",
                .destination_table_id = "destinationTableId",
                .import_options = "importOptions",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_table_data_import_job) } {
            return .{ .service_metadata = service_metadata, .action = start_table_data_import_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        job_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .job_status = "jobStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceQuotaExceeded,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        RequestTimeout,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};

pub const ImportOptions = struct {
    destination_options: ?DestinationOptions = null,
    delimited_text_options: ?DelimitedTextImportOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_options = "destinationOptions",
            .delimited_text_options = "delimitedTextOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DelimitedTextImportOptions = struct {
    delimiter: []const u8,
    has_header_row: ?bool = null,
    ignore_empty_rows: ?bool = null,
    data_character_encoding: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delimiter = "delimiter",
            .has_header_row = "hasHeaderRow",
            .ignore_empty_rows = "ignoreEmptyRows",
            .data_character_encoding = "dataCharacterEncoding",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationOptions = struct {
    column_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?SourceDataColumnProperties = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_map = "columnMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "column_map", field_name))
            return try serializeMap(self.column_map, self.fieldNameFor("column_map"), options, out_stream);
        return false;
    }
};

pub const SourceDataColumnProperties = struct {
    column_index: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_index = "columnIndex",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportDataSource = struct {
    data_source_config: ImportDataSourceConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_config = "dataSourceConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportDataSourceConfig = struct {
    data_source_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_url = "dataSourceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const TableRow = struct {
    row_id: []const u8,
    cells: []Cell,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .row_id = "rowId",
            .cells = "cells",
        };
        return @field(mappings, field_name);
    }
};

pub const Cell = struct {
    formula: ?[]const u8 = null,
    format: ?[]const u8 = null,
    raw_value: ?[]const u8 = null,
    formatted_value: ?[]const u8 = null,
    formatted_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .formula = "formula",
            .format = "format",
            .raw_value = "rawValue",
            .formatted_value = "formattedValue",
            .formatted_values = "formattedValues",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    formula: []const u8,
    context_row_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .formula = "formula",
            .context_row_id = "contextRowId",
        };
        return @field(mappings, field_name);
    }
};

pub const VariableValue = struct {
    raw_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .raw_value = "rawValue",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedBatchItem = struct {
    id: []const u8,
    error_message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const CellInput = struct {
    fact: ?[]const u8 = null,
    facts: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fact = "fact",
            .facts = "facts",
        };
        return @field(mappings, field_name);
    }
};
