const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-06-15";
pub const sdk_id: []const u8 = "identitystore";
pub const arn_namespace: ?[]const u8 = "identitystore";
pub const endpoint_prefix: []const u8 = "identitystore";
pub const sigv4_name: []const u8 = "identitystore";
pub const name: []const u8 = "AWSIdentityStore";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-06-15",
    sdk_id: []const u8 = "identitystore",
    arn_namespace: ?[]const u8 = "identitystore",
    endpoint_prefix: []const u8 = "identitystore",
    sigv4_name: []const u8 = "identitystore",
    name: []const u8 = "AWSIdentityStore",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const get_group_id: struct {
    action_name: []const u8 = "GetGroupId",
    Request: type = struct {
        identity_store_id: []const u8,
        alternate_identifier: AlternateIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .alternate_identifier = "AlternateIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group_id) } {
            return .{ .service_metadata = service_metadata, .action = get_group_id };
        }
    },
    Response: type = struct {
        group_id: []const u8,
        identity_store_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .identity_store_id = "IdentityStoreId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_group_membership_id: struct {
    action_name: []const u8 = "GetGroupMembershipId",
    Request: type = struct {
        identity_store_id: []const u8,
        group_id: []const u8,
        member_id: MemberId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .group_id = "GroupId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group_membership_id) } {
            return .{ .service_metadata = service_metadata, .action = get_group_membership_id };
        }
    },
    Response: type = struct {
        membership_id: []const u8,
        identity_store_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .membership_id = "MembershipId",
                .identity_store_id = "IdentityStoreId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_user_id: struct {
    action_name: []const u8 = "GetUserId",
    Request: type = struct {
        identity_store_id: []const u8,
        alternate_identifier: AlternateIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .alternate_identifier = "AlternateIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_id) } {
            return .{ .service_metadata = service_metadata, .action = get_user_id };
        }
    },
    Response: type = struct {
        user_id: []const u8,
        identity_store_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .identity_store_id = "IdentityStoreId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const is_member_in_groups: struct {
    action_name: []const u8 = "IsMemberInGroups",
    Request: type = struct {
        identity_store_id: []const u8,
        member_id: MemberId,
        group_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .member_id = "MemberId",
                .group_ids = "GroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(is_member_in_groups) } {
            return .{ .service_metadata = service_metadata, .action = is_member_in_groups };
        }
    },
    Response: type = struct {
        results: []struct {
            group_id: ?[]const u8 = null,
            member_id: ?MemberId = null,
            membership_exists: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_id = "GroupId",
                    .member_id = "MemberId",
                    .membership_exists = "MembershipExists",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_group_memberships_for_member: struct {
    action_name: []const u8 = "ListGroupMembershipsForMember",
    Request: type = struct {
        identity_store_id: []const u8,
        member_id: MemberId,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .member_id = "MemberId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_group_memberships_for_member) } {
            return .{ .service_metadata = service_metadata, .action = list_group_memberships_for_member };
        }
    },
    Response: type = struct {
        group_memberships: []struct {
            identity_store_id: []const u8,
            membership_id: ?[]const u8 = null,
            group_id: ?[]const u8 = null,
            member_id: ?MemberId = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identity_store_id = "IdentityStoreId",
                    .membership_id = "MembershipId",
                    .group_id = "GroupId",
                    .member_id = "MemberId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_memberships = "GroupMemberships",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const MemberId = union {
    user_id: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_id = "UserId",
        };
        return @field(mappings, field_name);
    }
};

pub const AlternateIdentifier = union {
    external_id: ?ExternalId,
    unique_attribute: ?UniqueAttribute,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_id = "ExternalId",
            .unique_attribute = "UniqueAttribute",
        };
        return @field(mappings, field_name);
    }
};

pub const UniqueAttribute = struct {
    attribute_path: []const u8,
    attribute_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_path = "AttributePath",
            .attribute_value = "AttributeValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ExternalId = struct {
    issuer: []const u8,
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issuer = "Issuer",
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};
