const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-02";
pub const sdk_id: []const u8 = "imagebuilder";
pub const arn_namespace: ?[]const u8 = "imagebuilder";
pub const endpoint_prefix: []const u8 = "imagebuilder";
pub const sigv4_name: []const u8 = "imagebuilder";
pub const name: []const u8 = "imagebuilder";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-02",
    sdk_id: []const u8 = "imagebuilder",
    arn_namespace: ?[]const u8 = "imagebuilder",
    endpoint_prefix: []const u8 = "imagebuilder",
    sigv4_name: []const u8 = "imagebuilder",
    name: []const u8 = "imagebuilder",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_image_creation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CancelImageCreation",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelImageCreation",
    Request: type = struct {
        image_build_version_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_build_version_arn = "imageBuildVersionArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_image_creation) } {
            return .{ .service_metadata = service_metadata, .action = cancel_image_creation };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const cancel_lifecycle_execution: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CancelLifecycleExecution",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelLifecycleExecution",
    Request: type = struct {
        lifecycle_execution_id: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_execution_id = "lifecycleExecutionId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_lifecycle_execution) } {
            return .{ .service_metadata = service_metadata, .action = cancel_lifecycle_execution };
        }
    },
    Response: type = struct {
        lifecycle_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_execution_id = "lifecycleExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const create_component: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateComponent",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateComponent",
    Request: type = struct {
        name: []const u8,
        semantic_version: []const u8,
        description: ?[]const u8 = null,
        change_description: ?[]const u8 = null,
        platform: []const u8,
        supported_os_versions: ?[][]const u8 = null,
        data: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .semantic_version = "semanticVersion",
                .description = "description",
                .change_description = "changeDescription",
                .platform = "platform",
                .supported_os_versions = "supportedOsVersions",
                .data = "data",
                .uri = "uri",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_component) } {
            return .{ .service_metadata = service_metadata, .action = create_component };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        component_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_container_recipe: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateContainerRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateContainerRecipe",
    Request: type = struct {
        container_type: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        semantic_version: []const u8,
        components: []ComponentConfiguration,
        instance_configuration: ?InstanceConfiguration = null,
        dockerfile_template_data: ?[]const u8 = null,
        dockerfile_template_uri: ?[]const u8 = null,
        platform_override: ?[]const u8 = null,
        image_os_version_override: ?[]const u8 = null,
        parent_image: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        working_directory: ?[]const u8 = null,
        target_repository: TargetContainerRepository,
        kms_key_id: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_type = "containerType",
                .name = "name",
                .description = "description",
                .semantic_version = "semanticVersion",
                .components = "components",
                .instance_configuration = "instanceConfiguration",
                .dockerfile_template_data = "dockerfileTemplateData",
                .dockerfile_template_uri = "dockerfileTemplateUri",
                .platform_override = "platformOverride",
                .image_os_version_override = "imageOsVersionOverride",
                .parent_image = "parentImage",
                .tags = "tags",
                .working_directory = "workingDirectory",
                .target_repository = "targetRepository",
                .kms_key_id = "kmsKeyId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_container_recipe) } {
            return .{ .service_metadata = service_metadata, .action = create_container_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_distribution_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateDistributionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDistributionConfiguration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        distributions: []Distribution,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .distributions = "distributions",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_distribution_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_distribution_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        distribution_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_image: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateImage",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateImage",
    Request: type = struct {
        image_recipe_arn: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,
        distribution_configuration_arn: ?[]const u8 = null,
        infrastructure_configuration_arn: []const u8,
        image_tests_configuration: ?ImageTestsConfiguration = null,
        enhanced_image_metadata_enabled: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,
        image_scanning_configuration: ?ImageScanningConfiguration = null,
        workflows: ?[]WorkflowConfiguration = null,
        execution_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
                .container_recipe_arn = "containerRecipeArn",
                .distribution_configuration_arn = "distributionConfigurationArn",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
                .image_tests_configuration = "imageTestsConfiguration",
                .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
                .tags = "tags",
                .client_token = "clientToken",
                .image_scanning_configuration = "imageScanningConfiguration",
                .workflows = "workflows",
                .execution_role = "executionRole",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image) } {
            return .{ .service_metadata = service_metadata, .action = create_image };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_image_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateImagePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateImagePipeline",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,
        infrastructure_configuration_arn: []const u8,
        distribution_configuration_arn: ?[]const u8 = null,
        image_tests_configuration: ?ImageTestsConfiguration = null,
        enhanced_image_metadata_enabled: ?bool = null,
        schedule: ?Schedule = null,
        status: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,
        image_scanning_configuration: ?ImageScanningConfiguration = null,
        workflows: ?[]WorkflowConfiguration = null,
        execution_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .image_recipe_arn = "imageRecipeArn",
                .container_recipe_arn = "containerRecipeArn",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
                .distribution_configuration_arn = "distributionConfigurationArn",
                .image_tests_configuration = "imageTestsConfiguration",
                .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
                .schedule = "schedule",
                .status = "status",
                .tags = "tags",
                .client_token = "clientToken",
                .image_scanning_configuration = "imageScanningConfiguration",
                .workflows = "workflows",
                .execution_role = "executionRole",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_image_pipeline };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_image_recipe: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateImageRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateImageRecipe",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        semantic_version: []const u8,
        components: []ComponentConfiguration,
        parent_image: []const u8,
        block_device_mappings: ?[]InstanceBlockDeviceMapping = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        working_directory: ?[]const u8 = null,
        additional_instance_configuration: ?AdditionalInstanceConfiguration = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .semantic_version = "semanticVersion",
                .components = "components",
                .parent_image = "parentImage",
                .block_device_mappings = "blockDeviceMappings",
                .tags = "tags",
                .working_directory = "workingDirectory",
                .additional_instance_configuration = "additionalInstanceConfiguration",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image_recipe) } {
            return .{ .service_metadata = service_metadata, .action = create_image_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_infrastructure_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateInfrastructureConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateInfrastructureConfiguration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        instance_types: ?[][]const u8 = null,
        instance_profile_name: []const u8,
        security_group_ids: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        logging: ?Logging = null,
        key_pair: ?[]const u8 = null,
        terminate_instance_on_failure: ?bool = null,
        sns_topic_arn: ?[]const u8 = null,
        resource_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        instance_metadata_options: ?InstanceMetadataOptions = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .instance_types = "instanceTypes",
                .instance_profile_name = "instanceProfileName",
                .security_group_ids = "securityGroupIds",
                .subnet_id = "subnetId",
                .logging = "logging",
                .key_pair = "keyPair",
                .terminate_instance_on_failure = "terminateInstanceOnFailure",
                .sns_topic_arn = "snsTopicArn",
                .resource_tags = "resourceTags",
                .instance_metadata_options = "instanceMetadataOptions",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_tags", field_name))
                return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_infrastructure_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_infrastructure_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        infrastructure_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_lifecycle_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateLifecyclePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLifecyclePolicy",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        execution_role: []const u8,
        resource_type: []const u8,
        policy_details: []LifecyclePolicyDetail,
        resource_selection: LifecyclePolicyResourceSelection,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .status = "status",
                .execution_role = "executionRole",
                .resource_type = "resourceType",
                .policy_details = "policyDetails",
                .resource_selection = "resourceSelection",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_lifecycle_policy };
        }
    },
    Response: type = struct {
        client_token: ?[]const u8 = null,
        lifecycle_policy_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .lifecycle_policy_arn = "lifecyclePolicyArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_workflow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateWorkflow",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorkflow",
    Request: type = struct {
        name: []const u8,
        semantic_version: []const u8,
        description: ?[]const u8 = null,
        change_description: ?[]const u8 = null,
        data: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .semantic_version = "semanticVersion",
                .description = "description",
                .change_description = "changeDescription",
                .data = "data",
                .uri = "uri",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
                .client_token = "clientToken",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workflow) } {
            return .{ .service_metadata = service_metadata, .action = create_workflow };
        }
    },
    Response: type = struct {
        client_token: ?[]const u8 = null,
        workflow_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .workflow_build_version_arn = "workflowBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const delete_component: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteComponent",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteComponent",
    Request: type = struct {
        component_build_version_arn: []const u8,

        pub const http_query = .{
            .component_build_version_arn = "componentBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_component) } {
            return .{ .service_metadata = service_metadata, .action = delete_component };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_container_recipe: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteContainerRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteContainerRecipe",
    Request: type = struct {
        container_recipe_arn: []const u8,

        pub const http_query = .{
            .container_recipe_arn = "containerRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_container_recipe) } {
            return .{ .service_metadata = service_metadata, .action = delete_container_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_distribution_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteDistributionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDistributionConfiguration",
    Request: type = struct {
        distribution_configuration_arn: []const u8,

        pub const http_query = .{
            .distribution_configuration_arn = "distributionConfigurationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_distribution_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_distribution_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        distribution_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_image: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteImage",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteImage",
    Request: type = struct {
        image_build_version_arn: []const u8,

        pub const http_query = .{
            .image_build_version_arn = "imageBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image) } {
            return .{ .service_metadata = service_metadata, .action = delete_image };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_image_pipeline: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteImagePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteImagePipeline",
    Request: type = struct {
        image_pipeline_arn: []const u8,

        pub const http_query = .{
            .image_pipeline_arn = "imagePipelineArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_image_pipeline };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_image_recipe: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteImageRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteImageRecipe",
    Request: type = struct {
        image_recipe_arn: []const u8,

        pub const http_query = .{
            .image_recipe_arn = "imageRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image_recipe) } {
            return .{ .service_metadata = service_metadata, .action = delete_image_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_infrastructure_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteInfrastructureConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInfrastructureConfiguration",
    Request: type = struct {
        infrastructure_configuration_arn: []const u8,

        pub const http_query = .{
            .infrastructure_configuration_arn = "infrastructureConfigurationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_infrastructure_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_infrastructure_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        infrastructure_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_lifecycle_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteLifecyclePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLifecyclePolicy",
    Request: type = struct {
        lifecycle_policy_arn: []const u8,

        pub const http_query = .{
            .lifecycle_policy_arn = "lifecyclePolicyArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy_arn = "lifecyclePolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_lifecycle_policy };
        }
    },
    Response: type = struct {
        lifecycle_policy_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy_arn = "lifecyclePolicyArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_workflow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteWorkflow",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkflow",
    Request: type = struct {
        workflow_build_version_arn: []const u8,

        pub const http_query = .{
            .workflow_build_version_arn = "workflowBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_build_version_arn = "workflowBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workflow) } {
            return .{ .service_metadata = service_metadata, .action = delete_workflow };
        }
    },
    Response: type = struct {
        workflow_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_build_version_arn = "workflowBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_component: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetComponent",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComponent",
    Request: type = struct {
        component_build_version_arn: []const u8,

        pub const http_query = .{
            .component_build_version_arn = "componentBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_component) } {
            return .{ .service_metadata = service_metadata, .action = get_component };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component: ?struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            change_description: ?[]const u8 = null,
            type: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            supported_os_versions: ?[][]const u8 = null,
            state: ?ComponentState = null,
            parameters: ?[]struct {
                name: []const u8,
                type: []const u8,
                default_value: ?[][]const u8 = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .type = "type",
                        .default_value = "defaultValue",
                        .description = "description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            owner: ?[]const u8 = null,
            data: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            encrypted: ?bool = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            publisher: ?[]const u8 = null,
            obfuscate: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .description = "description",
                    .change_description = "changeDescription",
                    .type = "type",
                    .platform = "platform",
                    .supported_os_versions = "supportedOsVersions",
                    .state = "state",
                    .parameters = "parameters",
                    .owner = "owner",
                    .data = "data",
                    .kms_key_id = "kmsKeyId",
                    .encrypted = "encrypted",
                    .date_created = "dateCreated",
                    .tags = "tags",
                    .publisher = "publisher",
                    .obfuscate = "obfuscate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component = "component",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_component_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetComponentPolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComponentPolicy",
    Request: type = struct {
        component_arn: []const u8,

        pub const http_query = .{
            .component_arn = "componentArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_arn = "componentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_component_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_component_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Forbidden,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_container_recipe: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetContainerRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "GetContainerRecipe",
    Request: type = struct {
        container_recipe_arn: []const u8,

        pub const http_query = .{
            .container_recipe_arn = "containerRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_container_recipe) } {
            return .{ .service_metadata = service_metadata, .action = get_container_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        container_recipe: ?ContainerRecipe = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .container_recipe = "containerRecipe",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_container_recipe_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetContainerRecipePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetContainerRecipePolicy",
    Request: type = struct {
        container_recipe_arn: []const u8,

        pub const http_query = .{
            .container_recipe_arn = "containerRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_container_recipe_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_container_recipe_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Forbidden,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_distribution_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetDistributionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDistributionConfiguration",
    Request: type = struct {
        distribution_configuration_arn: []const u8,

        pub const http_query = .{
            .distribution_configuration_arn = "distributionConfigurationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_distribution_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_distribution_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        distribution_configuration: ?DistributionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .distribution_configuration = "distributionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImage",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImage",
    Request: type = struct {
        image_build_version_arn: []const u8,

        pub const http_query = .{
            .image_build_version_arn = "imageBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image) } {
            return .{ .service_metadata = service_metadata, .action = get_image };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image: ?struct {
            arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            enhanced_image_metadata_enabled: ?bool = null,
            os_version: ?[]const u8 = null,
            state: ?ImageState = null,
            image_recipe: ?ImageRecipe = null,
            container_recipe: ?ContainerRecipe = null,
            source_pipeline_name: ?[]const u8 = null,
            source_pipeline_arn: ?[]const u8 = null,
            infrastructure_configuration: ?InfrastructureConfiguration = null,
            distribution_configuration: ?DistributionConfiguration = null,
            image_tests_configuration: ?ImageTestsConfiguration = null,
            date_created: ?[]const u8 = null,
            output_resources: ?OutputResources = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            build_type: ?[]const u8 = null,
            image_source: ?[]const u8 = null,
            scan_state: ?struct {
                status: ?[]const u8 = null,
                reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "status",
                        .reason = "reason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            image_scanning_configuration: ?ImageScanningConfiguration = null,
            deprecation_time: ?i64 = null,
            lifecycle_execution_id: ?[]const u8 = null,
            execution_role: ?[]const u8 = null,
            workflows: ?[]WorkflowConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .type = "type",
                    .name = "name",
                    .version = "version",
                    .platform = "platform",
                    .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
                    .os_version = "osVersion",
                    .state = "state",
                    .image_recipe = "imageRecipe",
                    .container_recipe = "containerRecipe",
                    .source_pipeline_name = "sourcePipelineName",
                    .source_pipeline_arn = "sourcePipelineArn",
                    .infrastructure_configuration = "infrastructureConfiguration",
                    .distribution_configuration = "distributionConfiguration",
                    .image_tests_configuration = "imageTestsConfiguration",
                    .date_created = "dateCreated",
                    .output_resources = "outputResources",
                    .tags = "tags",
                    .build_type = "buildType",
                    .image_source = "imageSource",
                    .scan_state = "scanState",
                    .image_scanning_configuration = "imageScanningConfiguration",
                    .deprecation_time = "deprecationTime",
                    .lifecycle_execution_id = "lifecycleExecutionId",
                    .execution_role = "executionRole",
                    .workflows = "workflows",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image = "image",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImagePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImagePipeline",
    Request: type = struct {
        image_pipeline_arn: []const u8,

        pub const http_query = .{
            .image_pipeline_arn = "imagePipelineArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = get_image_pipeline };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_pipeline: ?ImagePipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_pipeline = "imagePipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImagePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImagePolicy",
    Request: type = struct {
        image_arn: []const u8,

        pub const http_query = .{
            .image_arn = "imageArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_arn = "imageArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_image_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Forbidden,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image_recipe: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImageRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImageRecipe",
    Request: type = struct {
        image_recipe_arn: []const u8,

        pub const http_query = .{
            .image_recipe_arn = "imageRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_recipe) } {
            return .{ .service_metadata = service_metadata, .action = get_image_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_recipe: ?ImageRecipe = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_recipe = "imageRecipe",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image_recipe_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImageRecipePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImageRecipePolicy",
    Request: type = struct {
        image_recipe_arn: []const u8,

        pub const http_query = .{
            .image_recipe_arn = "imageRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_recipe_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_image_recipe_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Forbidden,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_infrastructure_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetInfrastructureConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInfrastructureConfiguration",
    Request: type = struct {
        infrastructure_configuration_arn: []const u8,

        pub const http_query = .{
            .infrastructure_configuration_arn = "infrastructureConfigurationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_infrastructure_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_infrastructure_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        infrastructure_configuration: ?InfrastructureConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .infrastructure_configuration = "infrastructureConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_lifecycle_execution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetLifecycleExecution",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLifecycleExecution",
    Request: type = struct {
        lifecycle_execution_id: []const u8,

        pub const http_query = .{
            .lifecycle_execution_id = "lifecycleExecutionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_execution_id = "lifecycleExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lifecycle_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_lifecycle_execution };
        }
    },
    Response: type = struct {
        lifecycle_execution: ?LifecycleExecution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_execution = "lifecycleExecution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_lifecycle_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetLifecyclePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLifecyclePolicy",
    Request: type = struct {
        lifecycle_policy_arn: []const u8,

        pub const http_query = .{
            .lifecycle_policy_arn = "lifecyclePolicyArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy_arn = "lifecyclePolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_lifecycle_policy };
        }
    },
    Response: type = struct {
        lifecycle_policy: ?struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            execution_role: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            policy_details: ?[]LifecyclePolicyDetail = null,
            resource_selection: ?LifecyclePolicyResourceSelection = null,
            date_created: ?i64 = null,
            date_updated: ?i64 = null,
            date_last_run: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .status = "status",
                    .execution_role = "executionRole",
                    .resource_type = "resourceType",
                    .policy_details = "policyDetails",
                    .resource_selection = "resourceSelection",
                    .date_created = "dateCreated",
                    .date_updated = "dateUpdated",
                    .date_last_run = "dateLastRun",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy = "lifecyclePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_workflow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetWorkflow",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkflow",
    Request: type = struct {
        workflow_build_version_arn: []const u8,

        pub const http_query = .{
            .workflow_build_version_arn = "workflowBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_build_version_arn = "workflowBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow };
        }
    },
    Response: type = struct {
        workflow: ?struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            change_description: ?[]const u8 = null,
            type: ?[]const u8 = null,
            state: ?WorkflowState = null,
            owner: ?[]const u8 = null,
            data: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            parameters: ?[]struct {
                name: []const u8,
                type: []const u8,
                default_value: ?[][]const u8 = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .type = "type",
                        .default_value = "defaultValue",
                        .description = "description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .description = "description",
                    .change_description = "changeDescription",
                    .type = "type",
                    .state = "state",
                    .owner = "owner",
                    .data = "data",
                    .kms_key_id = "kmsKeyId",
                    .date_created = "dateCreated",
                    .tags = "tags",
                    .parameters = "parameters",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow = "workflow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_workflow_execution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetWorkflowExecution",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkflowExecution",
    Request: type = struct {
        workflow_execution_id: []const u8,

        pub const http_query = .{
            .workflow_execution_id = "workflowExecutionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_execution_id = "workflowExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_execution };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        workflow_build_version_arn: ?[]const u8 = null,
        workflow_execution_id: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,
        type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        message: ?[]const u8 = null,
        total_step_count: ?i64 = null,
        total_steps_succeeded: ?i64 = null,
        total_steps_failed: ?i64 = null,
        total_steps_skipped: ?i64 = null,
        start_time: ?[]const u8 = null,
        end_time: ?[]const u8 = null,
        parallel_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .workflow_build_version_arn = "workflowBuildVersionArn",
                .workflow_execution_id = "workflowExecutionId",
                .image_build_version_arn = "imageBuildVersionArn",
                .type = "type",
                .status = "status",
                .message = "message",
                .total_step_count = "totalStepCount",
                .total_steps_succeeded = "totalStepsSucceeded",
                .total_steps_failed = "totalStepsFailed",
                .total_steps_skipped = "totalStepsSkipped",
                .start_time = "startTime",
                .end_time = "endTime",
                .parallel_group = "parallelGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_workflow_step_execution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetWorkflowStepExecution",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkflowStepExecution",
    Request: type = struct {
        step_execution_id: []const u8,

        pub const http_query = .{
            .step_execution_id = "stepExecutionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .step_execution_id = "stepExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_step_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_step_execution };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        step_execution_id: ?[]const u8 = null,
        workflow_build_version_arn: ?[]const u8 = null,
        workflow_execution_id: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        action: ?[]const u8 = null,
        status: ?[]const u8 = null,
        rollback_status: ?[]const u8 = null,
        message: ?[]const u8 = null,
        inputs: ?[]const u8 = null,
        outputs: ?[]const u8 = null,
        start_time: ?[]const u8 = null,
        end_time: ?[]const u8 = null,
        on_failure: ?[]const u8 = null,
        timeout_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .step_execution_id = "stepExecutionId",
                .workflow_build_version_arn = "workflowBuildVersionArn",
                .workflow_execution_id = "workflowExecutionId",
                .image_build_version_arn = "imageBuildVersionArn",
                .name = "name",
                .description = "description",
                .action = "action",
                .status = "status",
                .rollback_status = "rollbackStatus",
                .message = "message",
                .inputs = "inputs",
                .outputs = "outputs",
                .start_time = "startTime",
                .end_time = "endTime",
                .on_failure = "onFailure",
                .timeout_seconds = "timeoutSeconds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const import_component: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/ImportComponent",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportComponent",
    Request: type = struct {
        name: []const u8,
        semantic_version: []const u8,
        description: ?[]const u8 = null,
        change_description: ?[]const u8 = null,
        type: []const u8,
        format: []const u8,
        platform: []const u8,
        data: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .semantic_version = "semanticVersion",
                .description = "description",
                .change_description = "changeDescription",
                .type = "type",
                .format = "format",
                .platform = "platform",
                .data = "data",
                .uri = "uri",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_component) } {
            return .{ .service_metadata = service_metadata, .action = import_component };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        component_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const import_vm_image: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/ImportVmImage",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportVmImage",
    Request: type = struct {
        name: []const u8,
        semantic_version: []const u8,
        description: ?[]const u8 = null,
        platform: []const u8,
        os_version: ?[]const u8 = null,
        vm_import_task_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .semantic_version = "semanticVersion",
                .description = "description",
                .platform = "platform",
                .os_version = "osVersion",
                .vm_import_task_id = "vmImportTaskId",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_vm_image) } {
            return .{ .service_metadata = service_metadata, .action = import_vm_image };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_arn = "imageArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_component_build_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListComponentBuildVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponentBuildVersions",
    Request: type = struct {
        component_version_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_version_arn = "componentVersionArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_component_build_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_component_build_versions };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            supported_os_versions: ?[][]const u8 = null,
            state: ?ComponentState = null,
            type: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            description: ?[]const u8 = null,
            change_description: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            publisher: ?[]const u8 = null,
            obfuscate: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .platform = "platform",
                    .supported_os_versions = "supportedOsVersions",
                    .state = "state",
                    .type = "type",
                    .owner = "owner",
                    .description = "description",
                    .change_description = "changeDescription",
                    .date_created = "dateCreated",
                    .tags = "tags",
                    .publisher = "publisher",
                    .obfuscate = "obfuscate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component_summary_list = "componentSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_components: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListComponents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponents",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        by_name: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .by_name = "byName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_components) } {
            return .{ .service_metadata = service_metadata, .action = list_components };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component_version_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            supported_os_versions: ?[][]const u8 = null,
            type: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            date_created: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .description = "description",
                    .platform = "platform",
                    .supported_os_versions = "supportedOsVersions",
                    .type = "type",
                    .owner = "owner",
                    .date_created = "dateCreated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component_version_list = "componentVersionList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_container_recipes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListContainerRecipes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContainerRecipes",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_container_recipes) } {
            return .{ .service_metadata = service_metadata, .action = list_container_recipes };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        container_recipe_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            container_type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            parent_image: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .container_type = "containerType",
                    .name = "name",
                    .platform = "platform",
                    .owner = "owner",
                    .parent_image = "parentImage",
                    .date_created = "dateCreated",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .container_recipe_summary_list = "containerRecipeSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_distribution_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListDistributionConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDistributionConfigurations",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distribution_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_distribution_configurations };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        distribution_configuration_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            date_updated: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            regions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .date_created = "dateCreated",
                    .date_updated = "dateUpdated",
                    .tags = "tags",
                    .regions = "regions",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .distribution_configuration_summary_list = "distributionConfigurationSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_build_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImageBuildVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImageBuildVersions",
    Request: type = struct {
        image_version_arn: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_version_arn = "imageVersionArn",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_build_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_image_build_versions };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_summary_list: ?[]ImageSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_summary_list = "imageSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_packages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImagePackages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImagePackages",
    Request: type = struct {
        image_build_version_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_build_version_arn = "imageBuildVersionArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_image_packages };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_package_list: ?[]struct {
            package_name: ?[]const u8 = null,
            package_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .package_name = "packageName",
                    .package_version = "packageVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_package_list = "imagePackageList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_pipeline_images: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImagePipelineImages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImagePipelineImages",
    Request: type = struct {
        image_pipeline_arn: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_pipeline_images) } {
            return .{ .service_metadata = service_metadata, .action = list_image_pipeline_images };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_summary_list: ?[]ImageSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_summary_list = "imageSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_pipelines: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImagePipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImagePipelines",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_image_pipelines };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_pipeline_list: ?[]ImagePipeline = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_pipeline_list = "imagePipelineList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_recipes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImageRecipes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImageRecipes",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_recipes) } {
            return .{ .service_metadata = service_metadata, .action = list_image_recipes };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_recipe_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            parent_image: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .platform = "platform",
                    .owner = "owner",
                    .parent_image = "parentImage",
                    .date_created = "dateCreated",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_recipe_summary_list = "imageRecipeSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_images: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImages",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        by_name: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        include_deprecated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .by_name = "byName",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .include_deprecated = "includeDeprecated",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_images) } {
            return .{ .service_metadata = service_metadata, .action = list_images };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_version_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            version: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            os_version: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            build_type: ?[]const u8 = null,
            image_source: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .type = "type",
                    .version = "version",
                    .platform = "platform",
                    .os_version = "osVersion",
                    .owner = "owner",
                    .date_created = "dateCreated",
                    .build_type = "buildType",
                    .image_source = "imageSource",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_version_list = "imageVersionList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_scan_finding_aggregations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImageScanFindingAggregations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImageScanFindingAggregations",
    Request: type = struct {
        filter: ?Filter = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_scan_finding_aggregations) } {
            return .{ .service_metadata = service_metadata, .action = list_image_scan_finding_aggregations };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        aggregation_type: ?[]const u8 = null,
        responses: ?[]struct {
            account_aggregation: ?struct {
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            image_aggregation: ?struct {
                image_build_version_arn: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .image_build_version_arn = "imageBuildVersionArn",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            image_pipeline_aggregation: ?struct {
                image_pipeline_arn: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .image_pipeline_arn = "imagePipelineArn",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            vulnerability_id_aggregation: ?struct {
                vulnerability_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .vulnerability_id = "vulnerabilityId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_aggregation = "accountAggregation",
                    .image_aggregation = "imageAggregation",
                    .image_pipeline_aggregation = "imagePipelineAggregation",
                    .vulnerability_id_aggregation = "vulnerabilityIdAggregation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .aggregation_type = "aggregationType",
                .responses = "responses",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_scan_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImageScanFindings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImageScanFindings",
    Request: type = struct {
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_scan_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_image_scan_findings };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        findings: ?[]struct {
            aws_account_id: ?[]const u8 = null,
            image_build_version_arn: ?[]const u8 = null,
            image_pipeline_arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            title: ?[]const u8 = null,
            remediation: ?struct {
                recommendation: ?struct {
                    text: ?[]const u8 = null,
                    url: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .text = "text",
                            .url = "url",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .recommendation = "recommendation",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            severity: ?[]const u8 = null,
            first_observed_at: ?i64 = null,
            updated_at: ?i64 = null,
            inspector_score: ?f64 = null,
            inspector_score_details: ?struct {
                adjusted_cvss: ?struct {
                    score_source: ?[]const u8 = null,
                    cvss_source: ?[]const u8 = null,
                    version: ?[]const u8 = null,
                    score: ?f64 = null,
                    scoring_vector: ?[]const u8 = null,
                    adjustments: ?[]struct {
                        metric: ?[]const u8 = null,
                        reason: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .metric = "metric",
                                .reason = "reason",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .score_source = "scoreSource",
                            .cvss_source = "cvssSource",
                            .version = "version",
                            .score = "score",
                            .scoring_vector = "scoringVector",
                            .adjustments = "adjustments",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .adjusted_cvss = "adjustedCvss",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            package_vulnerability_details: ?struct {
                vulnerability_id: []const u8,
                vulnerable_packages: ?[]struct {
                    name: ?[]const u8 = null,
                    version: ?[]const u8 = null,
                    source_layer_hash: ?[]const u8 = null,
                    epoch: ?i64 = null,
                    release: ?[]const u8 = null,
                    arch: ?[]const u8 = null,
                    package_manager: ?[]const u8 = null,
                    file_path: ?[]const u8 = null,
                    fixed_in_version: ?[]const u8 = null,
                    remediation: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .version = "version",
                            .source_layer_hash = "sourceLayerHash",
                            .epoch = "epoch",
                            .release = "release",
                            .arch = "arch",
                            .package_manager = "packageManager",
                            .file_path = "filePath",
                            .fixed_in_version = "fixedInVersion",
                            .remediation = "remediation",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                source: ?[]const u8 = null,
                cvss: ?[]struct {
                    base_score: ?f64 = null,
                    scoring_vector: ?[]const u8 = null,
                    version: ?[]const u8 = null,
                    source: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .base_score = "baseScore",
                            .scoring_vector = "scoringVector",
                            .version = "version",
                            .source = "source",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                related_vulnerabilities: ?[][]const u8 = null,
                source_url: ?[]const u8 = null,
                vendor_severity: ?[]const u8 = null,
                vendor_created_at: ?i64 = null,
                vendor_updated_at: ?i64 = null,
                reference_urls: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .vulnerability_id = "vulnerabilityId",
                        .vulnerable_packages = "vulnerablePackages",
                        .source = "source",
                        .cvss = "cvss",
                        .related_vulnerabilities = "relatedVulnerabilities",
                        .source_url = "sourceUrl",
                        .vendor_severity = "vendorSeverity",
                        .vendor_created_at = "vendorCreatedAt",
                        .vendor_updated_at = "vendorUpdatedAt",
                        .reference_urls = "referenceUrls",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            fix_available: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_account_id = "awsAccountId",
                    .image_build_version_arn = "imageBuildVersionArn",
                    .image_pipeline_arn = "imagePipelineArn",
                    .type = "type",
                    .description = "description",
                    .title = "title",
                    .remediation = "remediation",
                    .severity = "severity",
                    .first_observed_at = "firstObservedAt",
                    .updated_at = "updatedAt",
                    .inspector_score = "inspectorScore",
                    .inspector_score_details = "inspectorScoreDetails",
                    .package_vulnerability_details = "packageVulnerabilityDetails",
                    .fix_available = "fixAvailable",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .findings = "findings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_infrastructure_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListInfrastructureConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInfrastructureConfigurations",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_infrastructure_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_infrastructure_configurations };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        infrastructure_configuration_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            date_updated: ?[]const u8 = null,
            resource_tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            instance_types: ?[][]const u8 = null,
            instance_profile_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .date_created = "dateCreated",
                    .date_updated = "dateUpdated",
                    .resource_tags = "resourceTags",
                    .tags = "tags",
                    .instance_types = "instanceTypes",
                    .instance_profile_name = "instanceProfileName",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "resource_tags", field_name))
                    return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .infrastructure_configuration_summary_list = "infrastructureConfigurationSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_lifecycle_execution_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListLifecycleExecutionResources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLifecycleExecutionResources",
    Request: type = struct {
        lifecycle_execution_id: []const u8,
        parent_resource_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_execution_id = "lifecycleExecutionId",
                .parent_resource_id = "parentResourceId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lifecycle_execution_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_lifecycle_execution_resources };
        }
    },
    Response: type = struct {
        lifecycle_execution_id: ?[]const u8 = null,
        lifecycle_execution_state: ?LifecycleExecutionState = null,
        resources: ?[]struct {
            account_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            state: ?LifecycleExecutionResourceState = null,
            action: ?struct {
                name: ?[]const u8 = null,
                reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .reason = "reason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            region: ?[]const u8 = null,
            snapshots: ?[]struct {
                snapshot_id: ?[]const u8 = null,
                state: ?LifecycleExecutionResourceState = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .snapshot_id = "snapshotId",
                        .state = "state",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            image_uris: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .resource_id = "resourceId",
                    .state = "state",
                    .action = "action",
                    .region = "region",
                    .snapshots = "snapshots",
                    .image_uris = "imageUris",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_execution_id = "lifecycleExecutionId",
                .lifecycle_execution_state = "lifecycleExecutionState",
                .resources = "resources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_lifecycle_executions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListLifecycleExecutions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLifecycleExecutions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lifecycle_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_lifecycle_executions };
        }
    },
    Response: type = struct {
        lifecycle_executions: ?[]LifecycleExecution = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_executions = "lifecycleExecutions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_lifecycle_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListLifecyclePolicies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLifecyclePolicies",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lifecycle_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_lifecycle_policies };
        }
    },
    Response: type = struct {
        lifecycle_policy_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            execution_role: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            date_created: ?i64 = null,
            date_updated: ?i64 = null,
            date_last_run: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .status = "status",
                    .execution_role = "executionRole",
                    .resource_type = "resourceType",
                    .date_created = "dateCreated",
                    .date_updated = "dateUpdated",
                    .date_last_run = "dateLastRun",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy_summary_list = "lifecyclePolicySummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const list_waiting_workflow_steps: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListWaitingWorkflowSteps",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWaitingWorkflowSteps",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_waiting_workflow_steps) } {
            return .{ .service_metadata = service_metadata, .action = list_waiting_workflow_steps };
        }
    },
    Response: type = struct {
        steps: ?[]struct {
            step_execution_id: ?[]const u8 = null,
            image_build_version_arn: ?[]const u8 = null,
            workflow_execution_id: ?[]const u8 = null,
            workflow_build_version_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            action: ?[]const u8 = null,
            start_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .step_execution_id = "stepExecutionId",
                    .image_build_version_arn = "imageBuildVersionArn",
                    .workflow_execution_id = "workflowExecutionId",
                    .workflow_build_version_arn = "workflowBuildVersionArn",
                    .name = "name",
                    .action = "action",
                    .start_time = "startTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .steps = "steps",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_workflow_build_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListWorkflowBuildVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkflowBuildVersions",
    Request: type = struct {
        workflow_version_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_version_arn = "workflowVersionArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflow_build_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_workflow_build_versions };
        }
    },
    Response: type = struct {
        workflow_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            change_description: ?[]const u8 = null,
            type: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            state: ?WorkflowState = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .description = "description",
                    .change_description = "changeDescription",
                    .type = "type",
                    .owner = "owner",
                    .state = "state",
                    .date_created = "dateCreated",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_summary_list = "workflowSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_workflow_executions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListWorkflowExecutions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkflowExecutions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        image_build_version_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflow_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_workflow_executions };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        workflow_executions: ?[]struct {
            workflow_build_version_arn: ?[]const u8 = null,
            workflow_execution_id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            message: ?[]const u8 = null,
            total_step_count: ?i64 = null,
            total_steps_succeeded: ?i64 = null,
            total_steps_failed: ?i64 = null,
            total_steps_skipped: ?i64 = null,
            start_time: ?[]const u8 = null,
            end_time: ?[]const u8 = null,
            parallel_group: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workflow_build_version_arn = "workflowBuildVersionArn",
                    .workflow_execution_id = "workflowExecutionId",
                    .type = "type",
                    .status = "status",
                    .message = "message",
                    .total_step_count = "totalStepCount",
                    .total_steps_succeeded = "totalStepsSucceeded",
                    .total_steps_failed = "totalStepsFailed",
                    .total_steps_skipped = "totalStepsSkipped",
                    .start_time = "startTime",
                    .end_time = "endTime",
                    .parallel_group = "parallelGroup",
                };
                return @field(mappings, field_name);
            }
        } = null,
        image_build_version_arn: ?[]const u8 = null,
        message: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .workflow_executions = "workflowExecutions",
                .image_build_version_arn = "imageBuildVersionArn",
                .message = "message",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_workflows: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListWorkflows",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkflows",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        by_name: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .by_name = "byName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflows) } {
            return .{ .service_metadata = service_metadata, .action = list_workflows };
        }
    },
    Response: type = struct {
        workflow_version_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            type: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            date_created: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .description = "description",
                    .type = "type",
                    .owner = "owner",
                    .date_created = "dateCreated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_version_list = "workflowVersionList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_workflow_step_executions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListWorkflowStepExecutions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkflowStepExecutions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        workflow_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .workflow_execution_id = "workflowExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflow_step_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_workflow_step_executions };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        steps: ?[]struct {
            step_execution_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            action: ?[]const u8 = null,
            status: ?[]const u8 = null,
            rollback_status: ?[]const u8 = null,
            message: ?[]const u8 = null,
            inputs: ?[]const u8 = null,
            outputs: ?[]const u8 = null,
            start_time: ?[]const u8 = null,
            end_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .step_execution_id = "stepExecutionId",
                    .name = "name",
                    .description = "description",
                    .action = "action",
                    .status = "status",
                    .rollback_status = "rollbackStatus",
                    .message = "message",
                    .inputs = "inputs",
                    .outputs = "outputs",
                    .start_time = "startTime",
                    .end_time = "endTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        workflow_build_version_arn: ?[]const u8 = null,
        workflow_execution_id: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,
        message: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .steps = "steps",
                .workflow_build_version_arn = "workflowBuildVersionArn",
                .workflow_execution_id = "workflowExecutionId",
                .image_build_version_arn = "imageBuildVersionArn",
                .message = "message",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const put_component_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/PutComponentPolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutComponentPolicy",
    Request: type = struct {
        component_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_arn = "componentArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_component_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_component_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component_arn = "componentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const put_container_recipe_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/PutContainerRecipePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutContainerRecipePolicy",
    Request: type = struct {
        container_recipe_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_recipe_arn = "containerRecipeArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_container_recipe_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_container_recipe_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const put_image_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/PutImagePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutImagePolicy",
    Request: type = struct {
        image_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_arn = "imageArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_image_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_image_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_arn = "imageArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const put_image_recipe_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/PutImageRecipePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutImageRecipePolicy",
    Request: type = struct {
        image_recipe_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_image_recipe_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_image_recipe_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const send_workflow_step_action: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/SendWorkflowStepAction",
        .success_code = 200,
    };

    action_name: []const u8 = "SendWorkflowStepAction",
    Request: type = struct {
        step_execution_id: []const u8,
        image_build_version_arn: []const u8,
        action: []const u8,
        reason: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .step_execution_id = "stepExecutionId",
                .image_build_version_arn = "imageBuildVersionArn",
                .action = "action",
                .reason = "reason",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_workflow_step_action) } {
            return .{ .service_metadata = service_metadata, .action = send_workflow_step_action };
        }
    },
    Response: type = struct {
        step_execution_id: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .step_execution_id = "stepExecutionId",
                .image_build_version_arn = "imageBuildVersionArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterValue,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const start_image_pipeline_execution: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/StartImagePipelineExecution",
        .success_code = 200,
    };

    action_name: []const u8 = "StartImagePipelineExecution",
    Request: type = struct {
        image_pipeline_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_image_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_image_pipeline_execution };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const start_resource_state_update: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/StartResourceStateUpdate",
        .success_code = 200,
    };

    action_name: []const u8 = "StartResourceStateUpdate",
    Request: type = struct {
        resource_arn: []const u8,
        state: struct {
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        },
        execution_role: ?[]const u8 = null,
        include_resources: ?struct {
            amis: ?bool = null,
            snapshots: ?bool = null,
            containers: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .amis = "amis",
                    .snapshots = "snapshots",
                    .containers = "containers",
                };
                return @field(mappings, field_name);
            }
        } = null,
        exclusion_rules: ?struct {
            amis: ?LifecyclePolicyDetailExclusionRulesAmis = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .amis = "amis",
                };
                return @field(mappings, field_name);
            }
        } = null,
        update_at: ?i64 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .state = "state",
                .execution_role = "executionRole",
                .include_resources = "includeResources",
                .exclusion_rules = "exclusionRules",
                .update_at = "updateAt",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_resource_state_update) } {
            return .{ .service_metadata = service_metadata, .action = start_resource_state_update };
        }
    },
    Response: type = struct {
        lifecycle_execution_id: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_execution_id = "lifecycleExecutionId",
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const update_distribution_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/UpdateDistributionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDistributionConfiguration",
    Request: type = struct {
        distribution_configuration_arn: []const u8,
        description: ?[]const u8 = null,
        distributions: []Distribution,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_configuration_arn = "distributionConfigurationArn",
                .description = "description",
                .distributions = "distributions",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_distribution_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_distribution_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        distribution_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const update_image_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/UpdateImagePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateImagePipeline",
    Request: type = struct {
        image_pipeline_arn: []const u8,
        description: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,
        infrastructure_configuration_arn: []const u8,
        distribution_configuration_arn: ?[]const u8 = null,
        image_tests_configuration: ?ImageTestsConfiguration = null,
        enhanced_image_metadata_enabled: ?bool = null,
        schedule: ?Schedule = null,
        status: ?[]const u8 = null,
        client_token: []const u8,
        image_scanning_configuration: ?ImageScanningConfiguration = null,
        workflows: ?[]WorkflowConfiguration = null,
        execution_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
                .description = "description",
                .image_recipe_arn = "imageRecipeArn",
                .container_recipe_arn = "containerRecipeArn",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
                .distribution_configuration_arn = "distributionConfigurationArn",
                .image_tests_configuration = "imageTestsConfiguration",
                .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
                .schedule = "schedule",
                .status = "status",
                .client_token = "clientToken",
                .image_scanning_configuration = "imageScanningConfiguration",
                .workflows = "workflows",
                .execution_role = "executionRole",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_image_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = update_image_pipeline };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const update_infrastructure_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/UpdateInfrastructureConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInfrastructureConfiguration",
    Request: type = struct {
        infrastructure_configuration_arn: []const u8,
        description: ?[]const u8 = null,
        instance_types: ?[][]const u8 = null,
        instance_profile_name: []const u8,
        security_group_ids: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        logging: ?Logging = null,
        key_pair: ?[]const u8 = null,
        terminate_instance_on_failure: ?bool = null,
        sns_topic_arn: ?[]const u8 = null,
        client_token: []const u8,
        resource_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        instance_metadata_options: ?InstanceMetadataOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
                .description = "description",
                .instance_types = "instanceTypes",
                .instance_profile_name = "instanceProfileName",
                .security_group_ids = "securityGroupIds",
                .subnet_id = "subnetId",
                .logging = "logging",
                .key_pair = "keyPair",
                .terminate_instance_on_failure = "terminateInstanceOnFailure",
                .sns_topic_arn = "snsTopicArn",
                .client_token = "clientToken",
                .resource_tags = "resourceTags",
                .instance_metadata_options = "instanceMetadataOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_tags", field_name))
                return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_infrastructure_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_infrastructure_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        infrastructure_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const update_lifecycle_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/UpdateLifecyclePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLifecyclePolicy",
    Request: type = struct {
        lifecycle_policy_arn: []const u8,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        execution_role: []const u8,
        resource_type: []const u8,
        policy_details: []LifecyclePolicyDetail,
        resource_selection: LifecyclePolicyResourceSelection,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy_arn = "lifecyclePolicyArn",
                .description = "description",
                .status = "status",
                .execution_role = "executionRole",
                .resource_type = "resourceType",
                .policy_details = "policyDetails",
                .resource_selection = "resourceSelection",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_lifecycle_policy };
        }
    },
    Response: type = struct {
        lifecycle_policy_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy_arn = "lifecyclePolicyArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};

pub const LifecyclePolicyResourceSelection = struct {
    recipes: ?[]LifecyclePolicyResourceSelectionRecipe = null,
    tag_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recipes = "recipes",
            .tag_map = "tagMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tag_map", field_name))
            return try serializeMap(self.tag_map, self.fieldNameFor("tag_map"), options, out_stream);
        return false;
    }
};

pub const LifecyclePolicyResourceSelectionRecipe = struct {
    name: []const u8,
    semantic_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .semantic_version = "semanticVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecyclePolicyDetail = struct {
    action: LifecyclePolicyDetailAction,
    filter: LifecyclePolicyDetailFilter,
    exclusion_rules: ?LifecyclePolicyDetailExclusionRules = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "action",
            .filter = "filter",
            .exclusion_rules = "exclusionRules",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecyclePolicyDetailExclusionRules = struct {
    tag_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    amis: ?LifecyclePolicyDetailExclusionRulesAmis = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_map = "tagMap",
            .amis = "amis",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tag_map", field_name))
            return try serializeMap(self.tag_map, self.fieldNameFor("tag_map"), options, out_stream);
        return false;
    }
};

pub const LifecyclePolicyDetailExclusionRulesAmis = struct {
    is_public: ?bool = null,
    regions: ?[][]const u8 = null,
    shared_accounts: ?[][]const u8 = null,
    last_launched: ?LifecyclePolicyDetailExclusionRulesAmisLastLaunched = null,
    tag_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_public = "isPublic",
            .regions = "regions",
            .shared_accounts = "sharedAccounts",
            .last_launched = "lastLaunched",
            .tag_map = "tagMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tag_map", field_name))
            return try serializeMap(self.tag_map, self.fieldNameFor("tag_map"), options, out_stream);
        return false;
    }
};

pub const LifecyclePolicyDetailExclusionRulesAmisLastLaunched = struct {
    value: i64,
    unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .unit = "unit",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecyclePolicyDetailFilter = struct {
    type: []const u8,
    value: i64,
    unit: ?[]const u8 = null,
    retain_at_least: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .value = "value",
            .unit = "unit",
            .retain_at_least = "retainAtLeast",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecyclePolicyDetailAction = struct {
    type: []const u8,
    include_resources: ?LifecyclePolicyDetailActionIncludeResources = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .include_resources = "includeResources",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecyclePolicyDetailActionIncludeResources = struct {
    amis: ?bool = null,
    snapshots: ?bool = null,
    containers: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amis = "amis",
            .snapshots = "snapshots",
            .containers = "containers",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceMetadataOptions = struct {
    http_tokens: ?[]const u8 = null,
    http_put_response_hop_limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_tokens = "httpTokens",
            .http_put_response_hop_limit = "httpPutResponseHopLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const Logging = struct {
    s3_logs: ?S3Logs = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_logs = "s3Logs",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Logs = struct {
    s3_bucket_name: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "s3BucketName",
            .s3_key_prefix = "s3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowConfiguration = struct {
    workflow_arn: []const u8,
    parameters: ?[]WorkflowParameter = null,
    parallel_group: ?[]const u8 = null,
    on_failure: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_arn = "workflowArn",
            .parameters = "parameters",
            .parallel_group = "parallelGroup",
            .on_failure = "onFailure",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowParameter = struct {
    name: []const u8,
    value: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageScanningConfiguration = struct {
    image_scanning_enabled: ?bool = null,
    ecr_configuration: ?EcrConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_scanning_enabled = "imageScanningEnabled",
            .ecr_configuration = "ecrConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const EcrConfiguration = struct {
    repository_name: ?[]const u8 = null,
    container_tags: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_name = "repositoryName",
            .container_tags = "containerTags",
        };
        return @field(mappings, field_name);
    }
};

pub const Schedule = struct {
    schedule_expression: ?[]const u8 = null,
    timezone: ?[]const u8 = null,
    pipeline_execution_start_condition: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "scheduleExpression",
            .timezone = "timezone",
            .pipeline_execution_start_condition = "pipelineExecutionStartCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageTestsConfiguration = struct {
    image_tests_enabled: ?bool = null,
    timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_tests_enabled = "imageTestsEnabled",
            .timeout_minutes = "timeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const Distribution = struct {
    region: []const u8,
    ami_distribution_configuration: ?AmiDistributionConfiguration = null,
    container_distribution_configuration: ?ContainerDistributionConfiguration = null,
    license_configuration_arns: ?[][]const u8 = null,
    launch_template_configurations: ?[]LaunchTemplateConfiguration = null,
    s3_export_configuration: ?S3ExportConfiguration = null,
    fast_launch_configurations: ?[]FastLaunchConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "region",
            .ami_distribution_configuration = "amiDistributionConfiguration",
            .container_distribution_configuration = "containerDistributionConfiguration",
            .license_configuration_arns = "licenseConfigurationArns",
            .launch_template_configurations = "launchTemplateConfigurations",
            .s3_export_configuration = "s3ExportConfiguration",
            .fast_launch_configurations = "fastLaunchConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const FastLaunchConfiguration = struct {
    enabled: bool,
    snapshot_configuration: ?FastLaunchSnapshotConfiguration = null,
    max_parallel_launches: ?i64 = null,
    launch_template: ?FastLaunchLaunchTemplateSpecification = null,
    account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .snapshot_configuration = "snapshotConfiguration",
            .max_parallel_launches = "maxParallelLaunches",
            .launch_template = "launchTemplate",
            .account_id = "accountId",
        };
        return @field(mappings, field_name);
    }
};

pub const FastLaunchLaunchTemplateSpecification = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    launch_template_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .launch_template_name = "launchTemplateName",
            .launch_template_version = "launchTemplateVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const FastLaunchSnapshotConfiguration = struct {
    target_resource_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_resource_count = "targetResourceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ExportConfiguration = struct {
    role_name: []const u8,
    disk_image_format: []const u8,
    s3_bucket: []const u8,
    s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_name = "roleName",
            .disk_image_format = "diskImageFormat",
            .s3_bucket = "s3Bucket",
            .s3_prefix = "s3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateConfiguration = struct {
    launch_template_id: []const u8,
    account_id: ?[]const u8 = null,
    set_default_version: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .account_id = "accountId",
            .set_default_version = "setDefaultVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerDistributionConfiguration = struct {
    description: ?[]const u8 = null,
    container_tags: ?[][]const u8 = null,
    target_repository: TargetContainerRepository,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .container_tags = "containerTags",
            .target_repository = "targetRepository",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetContainerRepository = struct {
    service: []const u8,
    repository_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service = "service",
            .repository_name = "repositoryName",
        };
        return @field(mappings, field_name);
    }
};

pub const AmiDistributionConfiguration = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    target_account_ids: ?[][]const u8 = null,
    ami_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    kms_key_id: ?[]const u8 = null,
    launch_permission: ?LaunchPermissionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .target_account_ids = "targetAccountIds",
            .ami_tags = "amiTags",
            .kms_key_id = "kmsKeyId",
            .launch_permission = "launchPermission",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "ami_tags", field_name))
            return try serializeMap(self.ami_tags, self.fieldNameFor("ami_tags"), options, out_stream);
        return false;
    }
};

pub const LaunchPermissionConfiguration = struct {
    user_ids: ?[][]const u8 = null,
    user_groups: ?[][]const u8 = null,
    organization_arns: ?[][]const u8 = null,
    organizational_unit_arns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_ids = "userIds",
            .user_groups = "userGroups",
            .organization_arns = "organizationArns",
            .organizational_unit_arns = "organizationalUnitArns",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowState = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleExecution = struct {
    lifecycle_execution_id: ?[]const u8 = null,
    lifecycle_policy_arn: ?[]const u8 = null,
    resources_impacted_summary: ?LifecycleExecutionResourcesImpactedSummary = null,
    state: ?LifecycleExecutionState = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lifecycle_execution_id = "lifecycleExecutionId",
            .lifecycle_policy_arn = "lifecyclePolicyArn",
            .resources_impacted_summary = "resourcesImpactedSummary",
            .state = "state",
            .start_time = "startTime",
            .end_time = "endTime",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleExecutionState = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleExecutionResourcesImpactedSummary = struct {
    has_impacted_resources: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .has_impacted_resources = "hasImpactedResources",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleExecutionResourceState = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const SeverityCounts = struct {
    all: ?i64 = null,
    critical: ?i64 = null,
    high: ?i64 = null,
    medium: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .all = "all",
            .critical = "critical",
            .high = "high",
            .medium = "medium",
        };
        return @field(mappings, field_name);
    }
};

pub const ImagePipeline = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    enhanced_image_metadata_enabled: ?bool = null,
    image_recipe_arn: ?[]const u8 = null,
    container_recipe_arn: ?[]const u8 = null,
    infrastructure_configuration_arn: ?[]const u8 = null,
    distribution_configuration_arn: ?[]const u8 = null,
    image_tests_configuration: ?ImageTestsConfiguration = null,
    schedule: ?Schedule = null,
    status: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    date_updated: ?[]const u8 = null,
    date_last_run: ?[]const u8 = null,
    date_next_run: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    image_scanning_configuration: ?ImageScanningConfiguration = null,
    execution_role: ?[]const u8 = null,
    workflows: ?[]WorkflowConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .platform = "platform",
            .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
            .image_recipe_arn = "imageRecipeArn",
            .container_recipe_arn = "containerRecipeArn",
            .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            .distribution_configuration_arn = "distributionConfigurationArn",
            .image_tests_configuration = "imageTestsConfiguration",
            .schedule = "schedule",
            .status = "status",
            .date_created = "dateCreated",
            .date_updated = "dateUpdated",
            .date_last_run = "dateLastRun",
            .date_next_run = "dateNextRun",
            .tags = "tags",
            .image_scanning_configuration = "imageScanningConfiguration",
            .execution_role = "executionRole",
            .workflows = "workflows",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ImageSummary = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    version: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    os_version: ?[]const u8 = null,
    state: ?ImageState = null,
    owner: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    output_resources: ?OutputResources = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    build_type: ?[]const u8 = null,
    image_source: ?[]const u8 = null,
    deprecation_time: ?i64 = null,
    lifecycle_execution_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .type = "type",
            .version = "version",
            .platform = "platform",
            .os_version = "osVersion",
            .state = "state",
            .owner = "owner",
            .date_created = "dateCreated",
            .output_resources = "outputResources",
            .tags = "tags",
            .build_type = "buildType",
            .image_source = "imageSource",
            .deprecation_time = "deprecationTime",
            .lifecycle_execution_id = "lifecycleExecutionId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const OutputResources = struct {
    amis: ?[]Ami = null,
    containers: ?[]Container = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amis = "amis",
            .containers = "containers",
        };
        return @field(mappings, field_name);
    }
};

pub const Container = struct {
    region: ?[]const u8 = null,
    image_uris: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "region",
            .image_uris = "imageUris",
        };
        return @field(mappings, field_name);
    }
};

pub const Ami = struct {
    region: ?[]const u8 = null,
    image: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    state: ?ImageState = null,
    account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "region",
            .image = "image",
            .name = "name",
            .description = "description",
            .state = "state",
            .account_id = "accountId",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageState = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentState = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const InfrastructureConfiguration = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    instance_types: ?[][]const u8 = null,
    instance_profile_name: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    subnet_id: ?[]const u8 = null,
    logging: ?Logging = null,
    key_pair: ?[]const u8 = null,
    terminate_instance_on_failure: ?bool = null,
    sns_topic_arn: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    date_updated: ?[]const u8 = null,
    resource_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    instance_metadata_options: ?InstanceMetadataOptions = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .instance_types = "instanceTypes",
            .instance_profile_name = "instanceProfileName",
            .security_group_ids = "securityGroupIds",
            .subnet_id = "subnetId",
            .logging = "logging",
            .key_pair = "keyPair",
            .terminate_instance_on_failure = "terminateInstanceOnFailure",
            .sns_topic_arn = "snsTopicArn",
            .date_created = "dateCreated",
            .date_updated = "dateUpdated",
            .resource_tags = "resourceTags",
            .instance_metadata_options = "instanceMetadataOptions",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "resource_tags", field_name))
            return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ImageRecipe = struct {
    arn: ?[]const u8 = null,
    type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    version: ?[]const u8 = null,
    components: ?[]ComponentConfiguration = null,
    parent_image: ?[]const u8 = null,
    block_device_mappings: ?[]InstanceBlockDeviceMapping = null,
    date_created: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    working_directory: ?[]const u8 = null,
    additional_instance_configuration: ?AdditionalInstanceConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .type = "type",
            .name = "name",
            .description = "description",
            .platform = "platform",
            .owner = "owner",
            .version = "version",
            .components = "components",
            .parent_image = "parentImage",
            .block_device_mappings = "blockDeviceMappings",
            .date_created = "dateCreated",
            .tags = "tags",
            .working_directory = "workingDirectory",
            .additional_instance_configuration = "additionalInstanceConfiguration",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const AdditionalInstanceConfiguration = struct {
    systems_manager_agent: ?SystemsManagerAgent = null,
    user_data_override: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .systems_manager_agent = "systemsManagerAgent",
            .user_data_override = "userDataOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const SystemsManagerAgent = struct {
    uninstall_after_build: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uninstall_after_build = "uninstallAfterBuild",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceBlockDeviceMapping = struct {
    device_name: ?[]const u8 = null,
    ebs: ?EbsInstanceBlockDeviceSpecification = null,
    virtual_name: ?[]const u8 = null,
    no_device: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "deviceName",
            .ebs = "ebs",
            .virtual_name = "virtualName",
            .no_device = "noDevice",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsInstanceBlockDeviceSpecification = struct {
    encrypted: ?bool = null,
    delete_on_termination: ?bool = null,
    iops: ?i64 = null,
    kms_key_id: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    volume_size: ?i64 = null,
    volume_type: ?[]const u8 = null,
    throughput: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encrypted = "encrypted",
            .delete_on_termination = "deleteOnTermination",
            .iops = "iops",
            .kms_key_id = "kmsKeyId",
            .snapshot_id = "snapshotId",
            .volume_size = "volumeSize",
            .volume_type = "volumeType",
            .throughput = "throughput",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentConfiguration = struct {
    component_arn: []const u8,
    parameters: ?[]ComponentParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_arn = "componentArn",
            .parameters = "parameters",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentParameter = struct {
    name: []const u8,
    value: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DistributionConfiguration = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    distributions: ?[]Distribution = null,
    timeout_minutes: i64,
    date_created: ?[]const u8 = null,
    date_updated: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .distributions = "distributions",
            .timeout_minutes = "timeoutMinutes",
            .date_created = "dateCreated",
            .date_updated = "dateUpdated",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ContainerRecipe = struct {
    arn: ?[]const u8 = null,
    container_type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    version: ?[]const u8 = null,
    components: ?[]ComponentConfiguration = null,
    instance_configuration: ?InstanceConfiguration = null,
    dockerfile_template_data: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    encrypted: ?bool = null,
    parent_image: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    working_directory: ?[]const u8 = null,
    target_repository: ?TargetContainerRepository = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .container_type = "containerType",
            .name = "name",
            .description = "description",
            .platform = "platform",
            .owner = "owner",
            .version = "version",
            .components = "components",
            .instance_configuration = "instanceConfiguration",
            .dockerfile_template_data = "dockerfileTemplateData",
            .kms_key_id = "kmsKeyId",
            .encrypted = "encrypted",
            .parent_image = "parentImage",
            .date_created = "dateCreated",
            .tags = "tags",
            .working_directory = "workingDirectory",
            .target_repository = "targetRepository",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const InstanceConfiguration = struct {
    image: ?[]const u8 = null,
    block_device_mappings: ?[]InstanceBlockDeviceMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image = "image",
            .block_device_mappings = "blockDeviceMappings",
        };
        return @field(mappings, field_name);
    }
};
