const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-02-16";
pub const sdk_id: []const u8 = "Inspector";
pub const arn_namespace: ?[]const u8 = "inspector";
pub const endpoint_prefix: []const u8 = "inspector";
pub const sigv4_name: []const u8 = "inspector";
pub const name: []const u8 = "InspectorService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-02-16",
    sdk_id: []const u8 = "Inspector",
    arn_namespace: ?[]const u8 = "inspector",
    endpoint_prefix: []const u8 = "inspector",
    sigv4_name: []const u8 = "inspector",
    name: []const u8 = "InspectorService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_attributes_to_findings: struct {
    action_name: []const u8 = "AddAttributesToFindings",
    Request: type = struct {
        finding_arns: [][]const u8,
        attributes: []Attribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_arns = "findingArns",
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_attributes_to_findings) } {
            return .{ .service_metadata = service_metadata, .action = add_attributes_to_findings };
        }
    },
    Response: type = struct {
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const create_assessment_target: struct {
    action_name: []const u8 = "CreateAssessmentTarget",
    Request: type = struct {
        assessment_target_name: []const u8,
        resource_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_target_name = "assessmentTargetName",
                .resource_group_arn = "resourceGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_assessment_target) } {
            return .{ .service_metadata = service_metadata, .action = create_assessment_target };
        }
    },
    Response: type = struct {
        assessment_target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_target_arn = "assessmentTargetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidCrossAccountRole,
        InvalidInput,
        LimitExceeded,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const create_assessment_template: struct {
    action_name: []const u8 = "CreateAssessmentTemplate",
    Request: type = struct {
        assessment_target_arn: []const u8,
        assessment_template_name: []const u8,
        duration_in_seconds: i64,
        rules_package_arns: [][]const u8,
        user_attributes_for_findings: ?[]Attribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_target_arn = "assessmentTargetArn",
                .assessment_template_name = "assessmentTemplateName",
                .duration_in_seconds = "durationInSeconds",
                .rules_package_arns = "rulesPackageArns",
                .user_attributes_for_findings = "userAttributesForFindings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_assessment_template) } {
            return .{ .service_metadata = service_metadata, .action = create_assessment_template };
        }
    },
    Response: type = struct {
        assessment_template_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_template_arn = "assessmentTemplateArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        LimitExceeded,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const create_exclusions_preview: struct {
    action_name: []const u8 = "CreateExclusionsPreview",
    Request: type = struct {
        assessment_template_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_template_arn = "assessmentTemplateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_exclusions_preview) } {
            return .{ .service_metadata = service_metadata, .action = create_exclusions_preview };
        }
    },
    Response: type = struct {
        preview_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preview_token = "previewToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
        PreviewGenerationInProgress,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const create_resource_group: struct {
    action_name: []const u8 = "CreateResourceGroup",
    Request: type = struct {
        resource_group_tags: []ResourceGroupTag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_tags = "resourceGroupTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_group) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_group };
        }
    },
    Response: type = struct {
        resource_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_arn = "resourceGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        LimitExceeded,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const delete_assessment_run: struct {
    action_name: []const u8 = "DeleteAssessmentRun",
    Request: type = struct {
        assessment_run_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arn = "assessmentRunArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = delete_assessment_run };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AssessmentRunInProgress,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const delete_assessment_target: struct {
    action_name: []const u8 = "DeleteAssessmentTarget",
    Request: type = struct {
        assessment_target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_target_arn = "assessmentTargetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_assessment_target) } {
            return .{ .service_metadata = service_metadata, .action = delete_assessment_target };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AssessmentRunInProgress,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const delete_assessment_template: struct {
    action_name: []const u8 = "DeleteAssessmentTemplate",
    Request: type = struct {
        assessment_template_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_template_arn = "assessmentTemplateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_assessment_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_assessment_template };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AssessmentRunInProgress,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const describe_assessment_runs: struct {
    action_name: []const u8 = "DescribeAssessmentRuns",
    Request: type = struct {
        assessment_run_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arns = "assessmentRunArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_assessment_runs) } {
            return .{ .service_metadata = service_metadata, .action = describe_assessment_runs };
        }
    },
    Response: type = struct {
        assessment_runs: []struct {
            arn: []const u8,
            name: []const u8,
            assessment_template_arn: []const u8,
            state: []const u8,
            duration_in_seconds: i64,
            rules_package_arns: [][]const u8,
            user_attributes_for_findings: []Attribute,
            created_at: i64,
            started_at: ?i64 = null,
            completed_at: ?i64 = null,
            state_changed_at: i64,
            data_collected: bool,
            state_changes: []struct {
                state_changed_at: i64,
                state: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state_changed_at = "stateChangedAt",
                        .state = "state",
                    };
                    return @field(mappings, field_name);
                }
            },
            notifications: []struct {
                date: i64,
                event: []const u8,
                message: ?[]const u8 = null,
                @"error": bool,
                sns_topic_arn: ?[]const u8 = null,
                sns_publish_status_code: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .date = "date",
                        .event = "event",
                        .message = "message",
                        .@"error" = "error",
                        .sns_topic_arn = "snsTopicArn",
                        .sns_publish_status_code = "snsPublishStatusCode",
                    };
                    return @field(mappings, field_name);
                }
            },
            finding_counts: []struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .assessment_template_arn = "assessmentTemplateArn",
                    .state = "state",
                    .duration_in_seconds = "durationInSeconds",
                    .rules_package_arns = "rulesPackageArns",
                    .user_attributes_for_findings = "userAttributesForFindings",
                    .created_at = "createdAt",
                    .started_at = "startedAt",
                    .completed_at = "completedAt",
                    .state_changed_at = "stateChangedAt",
                    .data_collected = "dataCollected",
                    .state_changes = "stateChanges",
                    .notifications = "notifications",
                    .finding_counts = "findingCounts",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "finding_counts", field_name))
                    return try serializeMap(self.finding_counts, self.fieldNameFor("finding_counts"), options, out_stream);
                return false;
            }
        },
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_runs = "assessmentRuns",
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const describe_assessment_targets: struct {
    action_name: []const u8 = "DescribeAssessmentTargets",
    Request: type = struct {
        assessment_target_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_target_arns = "assessmentTargetArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_assessment_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_assessment_targets };
        }
    },
    Response: type = struct {
        assessment_targets: []struct {
            arn: []const u8,
            name: []const u8,
            resource_group_arn: ?[]const u8 = null,
            created_at: i64,
            updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .resource_group_arn = "resourceGroupArn",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        },
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_targets = "assessmentTargets",
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const describe_assessment_templates: struct {
    action_name: []const u8 = "DescribeAssessmentTemplates",
    Request: type = struct {
        assessment_template_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_template_arns = "assessmentTemplateArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_assessment_templates) } {
            return .{ .service_metadata = service_metadata, .action = describe_assessment_templates };
        }
    },
    Response: type = struct {
        assessment_templates: []struct {
            arn: []const u8,
            name: []const u8,
            assessment_target_arn: []const u8,
            duration_in_seconds: i64,
            rules_package_arns: [][]const u8,
            user_attributes_for_findings: []Attribute,
            last_assessment_run_arn: ?[]const u8 = null,
            assessment_run_count: i64,
            created_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .assessment_target_arn = "assessmentTargetArn",
                    .duration_in_seconds = "durationInSeconds",
                    .rules_package_arns = "rulesPackageArns",
                    .user_attributes_for_findings = "userAttributesForFindings",
                    .last_assessment_run_arn = "lastAssessmentRunArn",
                    .assessment_run_count = "assessmentRunCount",
                    .created_at = "createdAt",
                };
                return @field(mappings, field_name);
            }
        },
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_templates = "assessmentTemplates",
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const describe_cross_account_access_role: struct {
    action_name: []const u8 = "DescribeCrossAccountAccessRole",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cross_account_access_role) } {
            return .{ .service_metadata = service_metadata, .action = describe_cross_account_access_role };
        }
    },
    Response: type = struct {
        role_arn: []const u8,
        valid: bool,
        registered_at: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "roleArn",
                .valid = "valid",
                .registered_at = "registeredAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
    },
} = .{};
pub const describe_exclusions: struct {
    action_name: []const u8 = "DescribeExclusions",
    Request: type = struct {
        exclusion_arns: [][]const u8,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exclusion_arns = "exclusionArns",
                .locale = "locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_exclusions) } {
            return .{ .service_metadata = service_metadata, .action = describe_exclusions };
        }
    },
    Response: type = struct {
        exclusions: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                arn: []const u8,
                title: []const u8,
                description: []const u8,
                recommendation: []const u8,
                scopes: []Scope,
                attributes: ?[]Attribute = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "arn",
                        .title = "title",
                        .description = "description",
                        .recommendation = "recommendation",
                        .scopes = "scopes",
                        .attributes = "attributes",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exclusions = "exclusions",
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "exclusions", field_name))
                return try serializeMap(self.exclusions, self.fieldNameFor("exclusions"), options, out_stream);
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const describe_findings: struct {
    action_name: []const u8 = "DescribeFindings",
    Request: type = struct {
        finding_arns: [][]const u8,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_arns = "findingArns",
                .locale = "locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_findings) } {
            return .{ .service_metadata = service_metadata, .action = describe_findings };
        }
    },
    Response: type = struct {
        findings: []struct {
            arn: []const u8,
            schema_version: ?i64 = null,
            service: ?[]const u8 = null,
            service_attributes: ?struct {
                schema_version: i64,
                assessment_run_arn: ?[]const u8 = null,
                rules_package_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .schema_version = "schemaVersion",
                        .assessment_run_arn = "assessmentRunArn",
                        .rules_package_arn = "rulesPackageArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            asset_type: ?[]const u8 = null,
            asset_attributes: ?struct {
                schema_version: i64,
                agent_id: ?[]const u8 = null,
                auto_scaling_group: ?[]const u8 = null,
                ami_id: ?[]const u8 = null,
                hostname: ?[]const u8 = null,
                ipv4_addresses: ?[][]const u8 = null,
                tags: ?[]Tag = null,
                network_interfaces: ?[]struct {
                    network_interface_id: ?[]const u8 = null,
                    subnet_id: ?[]const u8 = null,
                    vpc_id: ?[]const u8 = null,
                    private_dns_name: ?[]const u8 = null,
                    private_ip_address: ?[]const u8 = null,
                    private_ip_addresses: ?[]struct {
                        private_dns_name: ?[]const u8 = null,
                        private_ip_address: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .private_dns_name = "privateDnsName",
                                .private_ip_address = "privateIpAddress",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    public_dns_name: ?[]const u8 = null,
                    public_ip: ?[]const u8 = null,
                    ipv6_addresses: ?[][]const u8 = null,
                    security_groups: ?[]struct {
                        group_name: ?[]const u8 = null,
                        group_id: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .group_name = "groupName",
                                .group_id = "groupId",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .network_interface_id = "networkInterfaceId",
                            .subnet_id = "subnetId",
                            .vpc_id = "vpcId",
                            .private_dns_name = "privateDnsName",
                            .private_ip_address = "privateIpAddress",
                            .private_ip_addresses = "privateIpAddresses",
                            .public_dns_name = "publicDnsName",
                            .public_ip = "publicIp",
                            .ipv6_addresses = "ipv6Addresses",
                            .security_groups = "securityGroups",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .schema_version = "schemaVersion",
                        .agent_id = "agentId",
                        .auto_scaling_group = "autoScalingGroup",
                        .ami_id = "amiId",
                        .hostname = "hostname",
                        .ipv4_addresses = "ipv4Addresses",
                        .tags = "tags",
                        .network_interfaces = "networkInterfaces",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            description: ?[]const u8 = null,
            recommendation: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            numeric_severity: ?f64 = null,
            confidence: ?i64 = null,
            indicator_of_compromise: ?bool = null,
            attributes: []Attribute,
            user_attributes: []Attribute,
            created_at: i64,
            updated_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .schema_version = "schemaVersion",
                    .service = "service",
                    .service_attributes = "serviceAttributes",
                    .asset_type = "assetType",
                    .asset_attributes = "assetAttributes",
                    .id = "id",
                    .title = "title",
                    .description = "description",
                    .recommendation = "recommendation",
                    .severity = "severity",
                    .numeric_severity = "numericSeverity",
                    .confidence = "confidence",
                    .indicator_of_compromise = "indicatorOfCompromise",
                    .attributes = "attributes",
                    .user_attributes = "userAttributes",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        },
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const describe_resource_groups: struct {
    action_name: []const u8 = "DescribeResourceGroups",
    Request: type = struct {
        resource_group_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_group_arns = "resourceGroupArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_groups };
        }
    },
    Response: type = struct {
        resource_groups: []struct {
            arn: []const u8,
            tags: []ResourceGroupTag,
            created_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .tags = "tags",
                    .created_at = "createdAt",
                };
                return @field(mappings, field_name);
            }
        },
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_groups = "resourceGroups",
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const describe_rules_packages: struct {
    action_name: []const u8 = "DescribeRulesPackages",
    Request: type = struct {
        rules_package_arns: [][]const u8,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules_package_arns = "rulesPackageArns",
                .locale = "locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_rules_packages) } {
            return .{ .service_metadata = service_metadata, .action = describe_rules_packages };
        }
    },
    Response: type = struct {
        rules_packages: []struct {
            arn: []const u8,
            name: []const u8,
            version: []const u8,
            provider: []const u8,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .provider = "provider",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        },
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules_packages = "rulesPackages",
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const get_assessment_report: struct {
    action_name: []const u8 = "GetAssessmentReport",
    Request: type = struct {
        assessment_run_arn: []const u8,
        report_file_format: []const u8,
        report_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arn = "assessmentRunArn",
                .report_file_format = "reportFileFormat",
                .report_type = "reportType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_assessment_report) } {
            return .{ .service_metadata = service_metadata, .action = get_assessment_report };
        }
    },
    Response: type = struct {
        status: []const u8,
        url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .url = "url",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AssessmentRunInProgress,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
        UnsupportedFeature,
    },
} = .{};
pub const get_exclusions_preview: struct {
    action_name: []const u8 = "GetExclusionsPreview",
    Request: type = struct {
        assessment_template_arn: []const u8,
        preview_token: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_template_arn = "assessmentTemplateArn",
                .preview_token = "previewToken",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .locale = "locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_exclusions_preview) } {
            return .{ .service_metadata = service_metadata, .action = get_exclusions_preview };
        }
    },
    Response: type = struct {
        preview_status: []const u8,
        exclusion_previews: ?[]struct {
            title: []const u8,
            description: []const u8,
            recommendation: []const u8,
            scopes: []Scope,
            attributes: ?[]Attribute = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .title = "title",
                    .description = "description",
                    .recommendation = "recommendation",
                    .scopes = "scopes",
                    .attributes = "attributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preview_status = "previewStatus",
                .exclusion_previews = "exclusionPreviews",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const get_telemetry_metadata: struct {
    action_name: []const u8 = "GetTelemetryMetadata",
    Request: type = struct {
        assessment_run_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arn = "assessmentRunArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_telemetry_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_telemetry_metadata };
        }
    },
    Response: type = struct {
        telemetry_metadata: []TelemetryMetadata,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .telemetry_metadata = "telemetryMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const list_assessment_run_agents: struct {
    action_name: []const u8 = "ListAssessmentRunAgents",
    Request: type = struct {
        assessment_run_arn: []const u8,
        filter: ?struct {
            agent_healths: [][]const u8,
            agent_health_codes: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agent_healths = "agentHealths",
                    .agent_health_codes = "agentHealthCodes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arn = "assessmentRunArn",
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessment_run_agents) } {
            return .{ .service_metadata = service_metadata, .action = list_assessment_run_agents };
        }
    },
    Response: type = struct {
        assessment_run_agents: []struct {
            agent_id: []const u8,
            assessment_run_arn: []const u8,
            agent_health: []const u8,
            agent_health_code: []const u8,
            agent_health_details: ?[]const u8 = null,
            auto_scaling_group: ?[]const u8 = null,
            telemetry_metadata: []TelemetryMetadata,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agent_id = "agentId",
                    .assessment_run_arn = "assessmentRunArn",
                    .agent_health = "agentHealth",
                    .agent_health_code = "agentHealthCode",
                    .agent_health_details = "agentHealthDetails",
                    .auto_scaling_group = "autoScalingGroup",
                    .telemetry_metadata = "telemetryMetadata",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_agents = "assessmentRunAgents",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const list_assessment_runs: struct {
    action_name: []const u8 = "ListAssessmentRuns",
    Request: type = struct {
        assessment_template_arns: ?[][]const u8 = null,
        filter: ?struct {
            name_pattern: ?[]const u8 = null,
            states: ?[][]const u8 = null,
            duration_range: ?DurationRange = null,
            rules_package_arns: ?[][]const u8 = null,
            start_time_range: ?TimestampRange = null,
            completion_time_range: ?TimestampRange = null,
            state_change_time_range: ?TimestampRange = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name_pattern = "namePattern",
                    .states = "states",
                    .duration_range = "durationRange",
                    .rules_package_arns = "rulesPackageArns",
                    .start_time_range = "startTimeRange",
                    .completion_time_range = "completionTimeRange",
                    .state_change_time_range = "stateChangeTimeRange",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_template_arns = "assessmentTemplateArns",
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessment_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_assessment_runs };
        }
    },
    Response: type = struct {
        assessment_run_arns: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arns = "assessmentRunArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const list_assessment_targets: struct {
    action_name: []const u8 = "ListAssessmentTargets",
    Request: type = struct {
        filter: ?struct {
            assessment_target_name_pattern: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .assessment_target_name_pattern = "assessmentTargetNamePattern",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessment_targets) } {
            return .{ .service_metadata = service_metadata, .action = list_assessment_targets };
        }
    },
    Response: type = struct {
        assessment_target_arns: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_target_arns = "assessmentTargetArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
    },
} = .{};
pub const list_assessment_templates: struct {
    action_name: []const u8 = "ListAssessmentTemplates",
    Request: type = struct {
        assessment_target_arns: ?[][]const u8 = null,
        filter: ?struct {
            name_pattern: ?[]const u8 = null,
            duration_range: ?DurationRange = null,
            rules_package_arns: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name_pattern = "namePattern",
                    .duration_range = "durationRange",
                    .rules_package_arns = "rulesPackageArns",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_target_arns = "assessmentTargetArns",
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assessment_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_assessment_templates };
        }
    },
    Response: type = struct {
        assessment_template_arns: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_template_arns = "assessmentTemplateArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const list_event_subscriptions: struct {
    action_name: []const u8 = "ListEventSubscriptions",
    Request: type = struct {
        resource_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = list_event_subscriptions };
        }
    },
    Response: type = struct {
        subscriptions: []struct {
            resource_arn: []const u8,
            topic_arn: []const u8,
            event_subscriptions: []struct {
                event: []const u8,
                subscribed_at: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event = "event",
                        .subscribed_at = "subscribedAt",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "resourceArn",
                    .topic_arn = "topicArn",
                    .event_subscriptions = "eventSubscriptions",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscriptions = "subscriptions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const list_exclusions: struct {
    action_name: []const u8 = "ListExclusions",
    Request: type = struct {
        assessment_run_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arn = "assessmentRunArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_exclusions) } {
            return .{ .service_metadata = service_metadata, .action = list_exclusions };
        }
    },
    Response: type = struct {
        exclusion_arns: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exclusion_arns = "exclusionArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const list_findings: struct {
    action_name: []const u8 = "ListFindings",
    Request: type = struct {
        assessment_run_arns: ?[][]const u8 = null,
        filter: ?struct {
            agent_ids: ?[][]const u8 = null,
            auto_scaling_groups: ?[][]const u8 = null,
            rule_names: ?[][]const u8 = null,
            severities: ?[][]const u8 = null,
            rules_package_arns: ?[][]const u8 = null,
            attributes: ?[]Attribute = null,
            user_attributes: ?[]Attribute = null,
            creation_time_range: ?TimestampRange = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agent_ids = "agentIds",
                    .auto_scaling_groups = "autoScalingGroups",
                    .rule_names = "ruleNames",
                    .severities = "severities",
                    .rules_package_arns = "rulesPackageArns",
                    .attributes = "attributes",
                    .user_attributes = "userAttributes",
                    .creation_time_range = "creationTimeRange",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arns = "assessmentRunArns",
                .filter = "filter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_findings };
        }
    },
    Response: type = struct {
        finding_arns: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_arns = "findingArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const list_rules_packages: struct {
    action_name: []const u8 = "ListRulesPackages",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rules_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_rules_packages };
        }
    },
    Response: type = struct {
        rules_package_arns: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules_package_arns = "rulesPackageArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const preview_agents: struct {
    action_name: []const u8 = "PreviewAgents",
    Request: type = struct {
        preview_agents_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preview_agents_arn = "previewAgentsArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(preview_agents) } {
            return .{ .service_metadata = service_metadata, .action = preview_agents };
        }
    },
    Response: type = struct {
        agent_previews: []struct {
            hostname: ?[]const u8 = null,
            agent_id: []const u8,
            auto_scaling_group: ?[]const u8 = null,
            agent_health: ?[]const u8 = null,
            agent_version: ?[]const u8 = null,
            operating_system: ?[]const u8 = null,
            kernel_version: ?[]const u8 = null,
            ipv4_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hostname = "hostname",
                    .agent_id = "agentId",
                    .auto_scaling_group = "autoScalingGroup",
                    .agent_health = "agentHealth",
                    .agent_version = "agentVersion",
                    .operating_system = "operatingSystem",
                    .kernel_version = "kernelVersion",
                    .ipv4_address = "ipv4Address",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_previews = "agentPreviews",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidCrossAccountRole,
        InvalidInput,
        NoSuchEntity,
    },
} = .{};
pub const register_cross_account_access_role: struct {
    action_name: []const u8 = "RegisterCrossAccountAccessRole",
    Request: type = struct {
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_cross_account_access_role) } {
            return .{ .service_metadata = service_metadata, .action = register_cross_account_access_role };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidCrossAccountRole,
        InvalidInput,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const remove_attributes_from_findings: struct {
    action_name: []const u8 = "RemoveAttributesFromFindings",
    Request: type = struct {
        finding_arns: [][]const u8,
        attribute_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_arns = "findingArns",
                .attribute_keys = "attributeKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_attributes_from_findings) } {
            return .{ .service_metadata = service_metadata, .action = remove_attributes_from_findings };
        }
    },
    Response: type = struct {
        failed_items: []struct {
            key: ?[]const u8 = null,
            value: ?FailedItemDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_items = "failedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "failed_items", field_name))
                return try serializeMap(self.failed_items, self.fieldNameFor("failed_items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const set_tags_for_resource: struct {
    action_name: []const u8 = "SetTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = set_tags_for_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const start_assessment_run: struct {
    action_name: []const u8 = "StartAssessmentRun",
    Request: type = struct {
        assessment_template_arn: []const u8,
        assessment_run_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_template_arn = "assessmentTemplateArn",
                .assessment_run_name = "assessmentRunName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = start_assessment_run };
        }
    },
    Response: type = struct {
        assessment_run_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arn = "assessmentRunArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AgentsAlreadyRunningAssessment,
        Internal,
        InvalidCrossAccountRole,
        InvalidInput,
        LimitExceeded,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const stop_assessment_run: struct {
    action_name: []const u8 = "StopAssessmentRun",
    Request: type = struct {
        assessment_run_arn: []const u8,
        stop_action: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_run_arn = "assessmentRunArn",
                .stop_action = "stopAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = stop_assessment_run };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const subscribe_to_event: struct {
    action_name: []const u8 = "SubscribeToEvent",
    Request: type = struct {
        resource_arn: []const u8,
        event: []const u8,
        topic_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .event = "event",
                .topic_arn = "topicArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(subscribe_to_event) } {
            return .{ .service_metadata = service_metadata, .action = subscribe_to_event };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        LimitExceeded,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const unsubscribe_from_event: struct {
    action_name: []const u8 = "UnsubscribeFromEvent",
    Request: type = struct {
        resource_arn: []const u8,
        event: []const u8,
        topic_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .event = "event",
                .topic_arn = "topicArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unsubscribe_from_event) } {
            return .{ .service_metadata = service_metadata, .action = unsubscribe_from_event };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};
pub const update_assessment_target: struct {
    action_name: []const u8 = "UpdateAssessmentTarget",
    Request: type = struct {
        assessment_target_arn: []const u8,
        assessment_target_name: []const u8,
        resource_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_target_arn = "assessmentTargetArn",
                .assessment_target_name = "assessmentTargetName",
                .resource_group_arn = "resourceGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_assessment_target) } {
            return .{ .service_metadata = service_metadata, .action = update_assessment_target };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        NoSuchEntity,
        ServiceTemporarilyUnavailable,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedItemDetails = struct {
    failure_code: []const u8,
    retryable: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failure_code = "failureCode",
            .retryable = "retryable",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestampRange = struct {
    begin_date: ?i64 = null,
    end_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin_date = "beginDate",
            .end_date = "endDate",
        };
        return @field(mappings, field_name);
    }
};

pub const Attribute = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DurationRange = struct {
    min_seconds: ?i64 = null,
    max_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_seconds = "minSeconds",
            .max_seconds = "maxSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const TelemetryMetadata = struct {
    message_type: []const u8,
    count: i64,
    data_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_type = "messageType",
            .count = "count",
            .data_size = "dataSize",
        };
        return @field(mappings, field_name);
    }
};

pub const Scope = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceGroupTag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};
