const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-06-08";
pub const sdk_id: []const u8 = "Inspector2";
pub const arn_namespace: ?[]const u8 = "inspector2";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "inspector2";
pub const name: []const u8 = "Inspector2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-06-08",
    sdk_id: []const u8 = "Inspector2",
    arn_namespace: ?[]const u8 = "inspector2",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "inspector2",
    name: []const u8 = "Inspector2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_member: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/associate",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateMember",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_member) } {
            return .{ .service_metadata = service_metadata, .action = associate_member };
        }
    },
    Response: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_get_account_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/status/batch/get",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetAccountStatus",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_account_status) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_account_status };
        }
    },
    Response: type = struct {
        accounts: []struct {
            account_id: []const u8,
            state: State,
            resource_state: struct {
                ec2: State,
                ecr: State,
                lambda: ?State = null,
                lambda_code: ?State = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ec2 = "ec2",
                        .ecr = "ecr",
                        .lambda = "lambda",
                        .lambda_code = "lambdaCode",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .state = "state",
                    .resource_state = "resourceState",
                };
                return @field(mappings, field_name);
            }
        },
        failed_accounts: ?[]FailedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "accounts",
                .failed_accounts = "failedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_get_code_snippet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/codesnippet/batchget",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetCodeSnippet",
    Request: type = struct {
        finding_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_arns = "findingArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_code_snippet) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_code_snippet };
        }
    },
    Response: type = struct {
        code_snippet_results: ?[]struct {
            finding_arn: ?[]const u8 = null,
            start_line: ?i64 = null,
            end_line: ?i64 = null,
            code_snippet: ?[]struct {
                content: []const u8,
                line_number: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .content = "content",
                        .line_number = "lineNumber",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            suggested_fixes: ?[]struct {
                description: ?[]const u8 = null,
                code: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .description = "description",
                        .code = "code",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_arn = "findingArn",
                    .start_line = "startLine",
                    .end_line = "endLine",
                    .code_snippet = "codeSnippet",
                    .suggested_fixes = "suggestedFixes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            finding_arn: []const u8,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_arn = "findingArn",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_snippet_results = "codeSnippetResults",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_get_finding_details: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings/details/batch/get",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetFindingDetails",
    Request: type = struct {
        finding_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_arns = "findingArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_finding_details) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_finding_details };
        }
    },
    Response: type = struct {
        finding_details: ?[]struct {
            finding_arn: ?[]const u8 = null,
            cisa_data: ?CisaData = null,
            risk_score: ?i64 = null,
            evidences: ?[]struct {
                evidence_rule: ?[]const u8 = null,
                evidence_detail: ?[]const u8 = null,
                severity: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .evidence_rule = "evidenceRule",
                        .evidence_detail = "evidenceDetail",
                        .severity = "severity",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ttps: ?[][]const u8 = null,
            tools: ?[][]const u8 = null,
            exploit_observed: ?ExploitObserved = null,
            reference_urls: ?[][]const u8 = null,
            cwes: ?[][]const u8 = null,
            epss_score: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_arn = "findingArn",
                    .cisa_data = "cisaData",
                    .risk_score = "riskScore",
                    .evidences = "evidences",
                    .ttps = "ttps",
                    .tools = "tools",
                    .exploit_observed = "exploitObserved",
                    .reference_urls = "referenceUrls",
                    .cwes = "cwes",
                    .epss_score = "epssScore",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            finding_arn: []const u8,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_arn = "findingArn",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_details = "findingDetails",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_get_free_trial_info: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/freetrialinfo/batchget",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetFreeTrialInfo",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_free_trial_info) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_free_trial_info };
        }
    },
    Response: type = struct {
        accounts: []struct {
            account_id: []const u8,
            free_trial_info: []struct {
                type: []const u8,
                start: i64,
                end: i64,
                status: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .start = "start",
                        .end = "end",
                        .status = "status",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .free_trial_info = "freeTrialInfo",
                };
                return @field(mappings, field_name);
            }
        },
        failed_accounts: []struct {
            account_id: []const u8,
            code: []const u8,
            message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .code = "code",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "accounts",
                .failed_accounts = "failedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_get_member_ec2_deep_inspection_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ec2deepinspectionstatus/member/batch/get",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetMemberEc2DeepInspectionStatus",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_member_ec2_deep_inspection_status) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_member_ec2_deep_inspection_status };
        }
    },
    Response: type = struct {
        account_ids: ?[]MemberAccountEc2DeepInspectionStatusState = null,
        failed_account_ids: ?[]FailedMemberAccountEc2DeepInspectionStatusState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .failed_account_ids = "failedAccountIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_update_member_ec2_deep_inspection_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ec2deepinspectionstatus/member/batch/update",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateMemberEc2DeepInspectionStatus",
    Request: type = struct {
        account_ids: []struct {
            account_id: []const u8,
            activate_deep_inspection: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .activate_deep_inspection = "activateDeepInspection",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_member_ec2_deep_inspection_status) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_member_ec2_deep_inspection_status };
        }
    },
    Response: type = struct {
        account_ids: ?[]MemberAccountEc2DeepInspectionStatusState = null,
        failed_account_ids: ?[]FailedMemberAccountEc2DeepInspectionStatusState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .failed_account_ids = "failedAccountIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_findings_report: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/reporting/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelFindingsReport",
    Request: type = struct {
        report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_findings_report) } {
            return .{ .service_metadata = service_metadata, .action = cancel_findings_report };
        }
    },
    Response: type = struct {
        report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_sbom_export: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sbomexport/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelSbomExport",
    Request: type = struct {
        report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_sbom_export) } {
            return .{ .service_metadata = service_metadata, .action = cancel_sbom_export };
        }
    },
    Response: type = struct {
        report_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_cis_scan_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan-configuration/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCisScanConfiguration",
    Request: type = struct {
        scan_name: []const u8,
        security_level: []const u8,
        schedule: Schedule,
        targets: struct {
            account_ids: [][]const u8,
            target_resource_tags: []struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_ids = "accountIds",
                    .target_resource_tags = "targetResourceTags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "target_resource_tags", field_name))
                    return try serializeMap(self.target_resource_tags, self.fieldNameFor("target_resource_tags"), options, out_stream);
                return false;
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_name = "scanName",
                .security_level = "securityLevel",
                .schedule = "schedule",
                .targets = "targets",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cis_scan_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_cis_scan_configuration };
        }
    },
    Response: type = struct {
        scan_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_configuration_arn = "scanConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/filters/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFilter",
    Request: type = struct {
        action: []const u8,
        description: ?[]const u8 = null,
        filter_criteria: FilterCriteria,
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "action",
                .description = "description",
                .filter_criteria = "filterCriteria",
                .name = "name",
                .tags = "tags",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_filter) } {
            return .{ .service_metadata = service_metadata, .action = create_filter };
        }
    },
    Response: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_findings_report: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/reporting/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFindingsReport",
    Request: type = struct {
        filter_criteria: ?FilterCriteria = null,
        report_format: []const u8,
        s3_destination: Destination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_criteria = "filterCriteria",
                .report_format = "reportFormat",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_findings_report) } {
            return .{ .service_metadata = service_metadata, .action = create_findings_report };
        }
    },
    Response: type = struct {
        report_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_sbom_export: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sbomexport/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSbomExport",
    Request: type = struct {
        resource_filter_criteria: ?ResourceFilterCriteria = null,
        report_format: []const u8,
        s3_destination: Destination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_filter_criteria = "resourceFilterCriteria",
                .report_format = "reportFormat",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sbom_export) } {
            return .{ .service_metadata = service_metadata, .action = create_sbom_export };
        }
    },
    Response: type = struct {
        report_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_cis_scan_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan-configuration/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCisScanConfiguration",
    Request: type = struct {
        scan_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_configuration_arn = "scanConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cis_scan_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_cis_scan_configuration };
        }
    },
    Response: type = struct {
        scan_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_configuration_arn = "scanConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/filters/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFilter",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_filter) } {
            return .{ .service_metadata = service_metadata, .action = delete_filter };
        }
    },
    Response: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_organization_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organizationconfiguration/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_configuration };
        }
    },
    Response: type = struct {
        auto_enable: ?AutoEnable = null,
        max_account_limit_reached: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "autoEnable",
                .max_account_limit_reached = "maxAccountLimitReached",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const disable: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/disable",
        .success_code = 200,
    };

    action_name: []const u8 = "Disable",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        resource_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .resource_types = "resourceTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable) } {
            return .{ .service_metadata = service_metadata, .action = disable };
        }
    },
    Response: type = struct {
        accounts: []Account,
        failed_accounts: ?[]FailedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "accounts",
                .failed_accounts = "failedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disable_delegated_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delegatedadminaccounts/disable",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableDelegatedAdminAccount",
    Request: type = struct {
        delegated_admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_admin_account_id = "delegatedAdminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_delegated_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = disable_delegated_admin_account };
        }
    },
    Response: type = struct {
        delegated_admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_admin_account_id = "delegatedAdminAccountId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_member: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateMember",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_member) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_member };
        }
    },
    Response: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const enable: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/enable",
        .success_code = 200,
    };

    action_name: []const u8 = "Enable",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        resource_types: [][]const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .resource_types = "resourceTypes",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable) } {
            return .{ .service_metadata = service_metadata, .action = enable };
        }
    },
    Response: type = struct {
        accounts: []Account,
        failed_accounts: ?[]FailedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "accounts",
                .failed_accounts = "failedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const enable_delegated_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delegatedadminaccounts/enable",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableDelegatedAdminAccount",
    Request: type = struct {
        delegated_admin_account_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_admin_account_id = "delegatedAdminAccountId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_delegated_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = enable_delegated_admin_account };
        }
    },
    Response: type = struct {
        delegated_admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_admin_account_id = "delegatedAdminAccountId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_cis_scan_report: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan/report/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCisScanReport",
    Request: type = struct {
        scan_arn: []const u8,
        target_accounts: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_arn = "scanArn",
                .target_accounts = "targetAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cis_scan_report) } {
            return .{ .service_metadata = service_metadata, .action = get_cis_scan_report };
        }
    },
    Response: type = struct {
        url: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .url = "url",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_cis_scan_result_details: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan-result/details/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCisScanResultDetails",
    Request: type = struct {
        scan_arn: []const u8,
        target_resource_id: []const u8,
        account_id: []const u8,
        filter_criteria: ?struct {
            finding_status_filters: ?[]struct {
                comparison: []const u8,
                value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .comparison = "comparison",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            check_id_filters: ?[]CisStringFilter = null,
            title_filters: ?[]CisStringFilter = null,
            security_level_filters: ?[]CisSecurityLevelFilter = null,
            finding_arn_filters: ?[]CisStringFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_status_filters = "findingStatusFilters",
                    .check_id_filters = "checkIdFilters",
                    .title_filters = "titleFilters",
                    .security_level_filters = "securityLevelFilters",
                    .finding_arn_filters = "findingArnFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_arn = "scanArn",
                .target_resource_id = "targetResourceId",
                .account_id = "accountId",
                .filter_criteria = "filterCriteria",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cis_scan_result_details) } {
            return .{ .service_metadata = service_metadata, .action = get_cis_scan_result_details };
        }
    },
    Response: type = struct {
        scan_result_details: ?[]struct {
            scan_arn: []const u8,
            account_id: ?[]const u8 = null,
            target_resource_id: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            check_id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            check_description: ?[]const u8 = null,
            remediation: ?[]const u8 = null,
            level: ?[]const u8 = null,
            finding_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_arn = "scanArn",
                    .account_id = "accountId",
                    .target_resource_id = "targetResourceId",
                    .platform = "platform",
                    .status = "status",
                    .status_reason = "statusReason",
                    .check_id = "checkId",
                    .title = "title",
                    .check_description = "checkDescription",
                    .remediation = "remediation",
                    .level = "level",
                    .finding_arn = "findingArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_result_details = "scanResultDetails",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configuration/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration };
        }
    },
    Response: type = struct {
        ecr_configuration: ?struct {
            rescan_duration_state: ?struct {
                rescan_duration: ?[]const u8 = null,
                status: ?[]const u8 = null,
                updated_at: ?i64 = null,
                pull_date_rescan_duration: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rescan_duration = "rescanDuration",
                        .status = "status",
                        .updated_at = "updatedAt",
                        .pull_date_rescan_duration = "pullDateRescanDuration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rescan_duration_state = "rescanDurationState",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ecr_configuration = "ecrConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_delegated_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delegatedadminaccounts/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDelegatedAdminAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_delegated_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = get_delegated_admin_account };
        }
    },
    Response: type = struct {
        delegated_admin: ?struct {
            account_id: ?[]const u8 = null,
            relationship_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .relationship_status = "relationshipStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_admin = "delegatedAdmin",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_ec2_deep_inspection_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ec2deepinspectionconfiguration/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEc2DeepInspectionConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ec2_deep_inspection_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_ec2_deep_inspection_configuration };
        }
    },
    Response: type = struct {
        package_paths: ?[][]const u8 = null,
        org_package_paths: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_paths = "packagePaths",
                .org_package_paths = "orgPackagePaths",
                .status = "status",
                .error_message = "errorMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_encryption_key: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/encryptionkey/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEncryptionKey",
    Request: type = struct {
        scan_type: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .scan_type = "scanType",
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_type = "scanType",
                .resource_type = "resourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_encryption_key) } {
            return .{ .service_metadata = service_metadata, .action = get_encryption_key };
        }
    },
    Response: type = struct {
        kms_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_findings_report_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/reporting/status/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindingsReportStatus",
    Request: type = struct {
        report_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings_report_status) } {
            return .{ .service_metadata = service_metadata, .action = get_findings_report_status };
        }
    },
    Response: type = struct {
        report_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        error_code: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        destination: ?Destination = null,
        filter_criteria: ?FilterCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
                .status = "status",
                .error_code = "errorCode",
                .error_message = "errorMessage",
                .destination = "destination",
                .filter_criteria = "filterCriteria",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_member: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMember",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_member) } {
            return .{ .service_metadata = service_metadata, .action = get_member };
        }
    },
    Response: type = struct {
        member: ?Member = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member = "member",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sbom_export: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sbomexport/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSbomExport",
    Request: type = struct {
        report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sbom_export) } {
            return .{ .service_metadata = service_metadata, .action = get_sbom_export };
        }
    },
    Response: type = struct {
        report_id: ?[]const u8 = null,
        format: ?[]const u8 = null,
        status: ?[]const u8 = null,
        error_code: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        s3_destination: ?Destination = null,
        filter_criteria: ?ResourceFilterCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "reportId",
                .format = "format",
                .status = "status",
                .error_code = "errorCode",
                .error_message = "errorMessage",
                .s3_destination = "s3Destination",
                .filter_criteria = "filterCriteria",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accountpermissions/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccountPermissions",
    Request: type = struct {
        service: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "service",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_account_permissions };
        }
    },
    Response: type = struct {
        permissions: []struct {
            service: []const u8,
            operation: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service = "service",
                    .operation = "operation",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "permissions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_cis_scan_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan-configuration/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCisScanConfigurations",
    Request: type = struct {
        filter_criteria: ?struct {
            scan_name_filters: ?[]CisStringFilter = null,
            target_resource_tag_filters: ?[]TagFilter = null,
            scan_configuration_arn_filters: ?[]CisStringFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_name_filters = "scanNameFilters",
                    .target_resource_tag_filters = "targetResourceTagFilters",
                    .scan_configuration_arn_filters = "scanConfigurationArnFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_criteria = "filterCriteria",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cis_scan_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_cis_scan_configurations };
        }
    },
    Response: type = struct {
        scan_configurations: ?[]struct {
            scan_configuration_arn: []const u8,
            owner_id: ?[]const u8 = null,
            scan_name: ?[]const u8 = null,
            security_level: ?[]const u8 = null,
            schedule: ?Schedule = null,
            targets: ?CisTargets = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_configuration_arn = "scanConfigurationArn",
                    .owner_id = "ownerId",
                    .scan_name = "scanName",
                    .security_level = "securityLevel",
                    .schedule = "schedule",
                    .targets = "targets",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_configurations = "scanConfigurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_cis_scan_results_aggregated_by_checks: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan-result/check/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCisScanResultsAggregatedByChecks",
    Request: type = struct {
        scan_arn: []const u8,
        filter_criteria: ?struct {
            account_id_filters: ?[]CisStringFilter = null,
            check_id_filters: ?[]CisStringFilter = null,
            title_filters: ?[]CisStringFilter = null,
            platform_filters: ?[]CisStringFilter = null,
            failed_resources_filters: ?[]CisNumberFilter = null,
            security_level_filters: ?[]CisSecurityLevelFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id_filters = "accountIdFilters",
                    .check_id_filters = "checkIdFilters",
                    .title_filters = "titleFilters",
                    .platform_filters = "platformFilters",
                    .failed_resources_filters = "failedResourcesFilters",
                    .security_level_filters = "securityLevelFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_arn = "scanArn",
                .filter_criteria = "filterCriteria",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cis_scan_results_aggregated_by_checks) } {
            return .{ .service_metadata = service_metadata, .action = list_cis_scan_results_aggregated_by_checks };
        }
    },
    Response: type = struct {
        check_aggregations: ?[]struct {
            scan_arn: []const u8,
            check_id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            check_description: ?[]const u8 = null,
            level: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            status_counts: ?StatusCounts = null,
            platform: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_arn = "scanArn",
                    .check_id = "checkId",
                    .title = "title",
                    .check_description = "checkDescription",
                    .level = "level",
                    .account_id = "accountId",
                    .status_counts = "statusCounts",
                    .platform = "platform",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_aggregations = "checkAggregations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_cis_scan_results_aggregated_by_target_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan-result/resource/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCisScanResultsAggregatedByTargetResource",
    Request: type = struct {
        scan_arn: []const u8,
        filter_criteria: ?struct {
            account_id_filters: ?[]CisStringFilter = null,
            status_filters: ?[]struct {
                comparison: []const u8,
                value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .comparison = "comparison",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            check_id_filters: ?[]CisStringFilter = null,
            target_resource_id_filters: ?[]CisStringFilter = null,
            target_resource_tag_filters: ?[]TagFilter = null,
            platform_filters: ?[]CisStringFilter = null,
            target_status_filters: ?[]struct {
                comparison: []const u8,
                value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .comparison = "comparison",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            target_status_reason_filters: ?[]struct {
                comparison: []const u8,
                value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .comparison = "comparison",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            failed_checks_filters: ?[]CisNumberFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id_filters = "accountIdFilters",
                    .status_filters = "statusFilters",
                    .check_id_filters = "checkIdFilters",
                    .target_resource_id_filters = "targetResourceIdFilters",
                    .target_resource_tag_filters = "targetResourceTagFilters",
                    .platform_filters = "platformFilters",
                    .target_status_filters = "targetStatusFilters",
                    .target_status_reason_filters = "targetStatusReasonFilters",
                    .failed_checks_filters = "failedChecksFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_arn = "scanArn",
                .filter_criteria = "filterCriteria",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cis_scan_results_aggregated_by_target_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_cis_scan_results_aggregated_by_target_resource };
        }
    },
    Response: type = struct {
        target_resource_aggregations: ?[]struct {
            scan_arn: []const u8,
            target_resource_id: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            target_resource_tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            status_counts: ?StatusCounts = null,
            platform: ?[]const u8 = null,
            target_status: ?[]const u8 = null,
            target_status_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_arn = "scanArn",
                    .target_resource_id = "targetResourceId",
                    .account_id = "accountId",
                    .target_resource_tags = "targetResourceTags",
                    .status_counts = "statusCounts",
                    .platform = "platform",
                    .target_status = "targetStatus",
                    .target_status_reason = "targetStatusReason",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "target_resource_tags", field_name))
                    return try serializeMap(self.target_resource_tags, self.fieldNameFor("target_resource_tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_resource_aggregations = "targetResourceAggregations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_cis_scans: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCisScans",
    Request: type = struct {
        filter_criteria: ?struct {
            scan_name_filters: ?[]CisStringFilter = null,
            target_resource_tag_filters: ?[]TagFilter = null,
            target_resource_id_filters: ?[]CisStringFilter = null,
            scan_status_filters: ?[]struct {
                comparison: []const u8,
                value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .comparison = "comparison",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            scan_at_filters: ?[]struct {
                earliest_scan_start_time: ?i64 = null,
                latest_scan_start_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .earliest_scan_start_time = "earliestScanStartTime",
                        .latest_scan_start_time = "latestScanStartTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            scan_configuration_arn_filters: ?[]CisStringFilter = null,
            scan_arn_filters: ?[]CisStringFilter = null,
            scheduled_by_filters: ?[]CisStringFilter = null,
            failed_checks_filters: ?[]CisNumberFilter = null,
            target_account_id_filters: ?[]CisStringFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_name_filters = "scanNameFilters",
                    .target_resource_tag_filters = "targetResourceTagFilters",
                    .target_resource_id_filters = "targetResourceIdFilters",
                    .scan_status_filters = "scanStatusFilters",
                    .scan_at_filters = "scanAtFilters",
                    .scan_configuration_arn_filters = "scanConfigurationArnFilters",
                    .scan_arn_filters = "scanArnFilters",
                    .scheduled_by_filters = "scheduledByFilters",
                    .failed_checks_filters = "failedChecksFilters",
                    .target_account_id_filters = "targetAccountIdFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        detail_level: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_criteria = "filterCriteria",
                .detail_level = "detailLevel",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cis_scans) } {
            return .{ .service_metadata = service_metadata, .action = list_cis_scans };
        }
    },
    Response: type = struct {
        scans: ?[]struct {
            scan_arn: []const u8,
            scan_configuration_arn: []const u8,
            status: ?[]const u8 = null,
            scan_name: ?[]const u8 = null,
            scan_date: ?i64 = null,
            failed_checks: ?i64 = null,
            total_checks: ?i64 = null,
            targets: ?CisTargets = null,
            scheduled_by: ?[]const u8 = null,
            security_level: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scan_arn = "scanArn",
                    .scan_configuration_arn = "scanConfigurationArn",
                    .status = "status",
                    .scan_name = "scanName",
                    .scan_date = "scanDate",
                    .failed_checks = "failedChecks",
                    .total_checks = "totalChecks",
                    .targets = "targets",
                    .scheduled_by = "scheduledBy",
                    .security_level = "securityLevel",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scans = "scans",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_coverage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/coverage/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCoverage",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter_criteria: ?CoverageFilterCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .filter_criteria = "filterCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_coverage) } {
            return .{ .service_metadata = service_metadata, .action = list_coverage };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        covered_resources: ?[]struct {
            resource_type: []const u8,
            resource_id: []const u8,
            account_id: []const u8,
            scan_type: []const u8,
            scan_status: ?struct {
                status_code: []const u8,
                reason: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status_code = "statusCode",
                        .reason = "reason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            resource_metadata: ?struct {
                ecr_repository: ?struct {
                    name: ?[]const u8 = null,
                    scan_frequency: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .scan_frequency = "scanFrequency",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ecr_image: ?struct {
                    tags: ?[][]const u8 = null,
                    image_pulled_at: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .tags = "tags",
                            .image_pulled_at = "imagePulledAt",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ec2: ?struct {
                    tags: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?[]const u8 = null,
                    } = null,
                    ami_id: ?[]const u8 = null,
                    platform: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .tags = "tags",
                            .ami_id = "amiId",
                            .platform = "platform",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "tags", field_name))
                            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                        return false;
                    }
                } = null,
                lambda_function: ?struct {
                    function_tags: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?[]const u8 = null,
                    } = null,
                    layers: ?[][]const u8 = null,
                    function_name: ?[]const u8 = null,
                    runtime: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .function_tags = "functionTags",
                            .layers = "layers",
                            .function_name = "functionName",
                            .runtime = "runtime",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "function_tags", field_name))
                            return try serializeMap(self.function_tags, self.fieldNameFor("function_tags"), options, out_stream);
                        return false;
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ecr_repository = "ecrRepository",
                        .ecr_image = "ecrImage",
                        .ec2 = "ec2",
                        .lambda_function = "lambdaFunction",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_scanned_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "resourceType",
                    .resource_id = "resourceId",
                    .account_id = "accountId",
                    .scan_type = "scanType",
                    .scan_status = "scanStatus",
                    .resource_metadata = "resourceMetadata",
                    .last_scanned_at = "lastScannedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .covered_resources = "coveredResources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_coverage_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/coverage/statistics/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCoverageStatistics",
    Request: type = struct {
        filter_criteria: ?CoverageFilterCriteria = null,
        group_by: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_criteria = "filterCriteria",
                .group_by = "groupBy",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_coverage_statistics) } {
            return .{ .service_metadata = service_metadata, .action = list_coverage_statistics };
        }
    },
    Response: type = struct {
        counts_by_group: ?[]struct {
            count: ?i64 = null,
            group_key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .count = "count",
                    .group_key = "groupKey",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total_counts: i64,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .counts_by_group = "countsByGroup",
                .total_counts = "totalCounts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_delegated_admin_accounts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delegatedadminaccounts/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDelegatedAdminAccounts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_delegated_admin_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_delegated_admin_accounts };
        }
    },
    Response: type = struct {
        delegated_admin_accounts: ?[]struct {
            account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_admin_accounts = "delegatedAdminAccounts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_filters: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/filters/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFilters",
    Request: type = struct {
        arns: ?[][]const u8 = null,
        action: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arns = "arns",
                .action = "action",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_filters) } {
            return .{ .service_metadata = service_metadata, .action = list_filters };
        }
    },
    Response: type = struct {
        filters: []struct {
            arn: []const u8,
            owner_id: []const u8,
            name: []const u8,
            criteria: FilterCriteria,
            action: []const u8,
            created_at: i64,
            updated_at: i64,
            description: ?[]const u8 = null,
            reason: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .owner_id = "ownerId",
                    .name = "name",
                    .criteria = "criteria",
                    .action = "action",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .description = "description",
                    .reason = "reason",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_finding_aggregations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings/aggregation/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindingAggregations",
    Request: type = struct {
        aggregation_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        account_ids: ?[]StringFilter = null,
        aggregation_request: ?union {
            account_aggregation: ?struct {
                finding_type: ?[]const u8 = null,
                resource_type: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .finding_type = "findingType",
                        .resource_type = "resourceType",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            ami_aggregation: ?struct {
                amis: ?[]StringFilter = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .amis = "amis",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            aws_ecr_container_aggregation: ?struct {
                resource_ids: ?[]StringFilter = null,
                image_shas: ?[]StringFilter = null,
                repositories: ?[]StringFilter = null,
                architectures: ?[]StringFilter = null,
                image_tags: ?[]StringFilter = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_ids = "resourceIds",
                        .image_shas = "imageShas",
                        .repositories = "repositories",
                        .architectures = "architectures",
                        .image_tags = "imageTags",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            ec2_instance_aggregation: ?struct {
                amis: ?[]StringFilter = null,
                operating_systems: ?[]StringFilter = null,
                instance_ids: ?[]StringFilter = null,
                instance_tags: ?[]MapFilter = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .amis = "amis",
                        .operating_systems = "operatingSystems",
                        .instance_ids = "instanceIds",
                        .instance_tags = "instanceTags",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            finding_type_aggregation: ?struct {
                finding_type: ?[]const u8 = null,
                resource_type: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .finding_type = "findingType",
                        .resource_type = "resourceType",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            image_layer_aggregation: ?struct {
                repositories: ?[]StringFilter = null,
                resource_ids: ?[]StringFilter = null,
                layer_hashes: ?[]StringFilter = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .repositories = "repositories",
                        .resource_ids = "resourceIds",
                        .layer_hashes = "layerHashes",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            package_aggregation: ?struct {
                package_names: ?[]StringFilter = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .package_names = "packageNames",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            repository_aggregation: ?struct {
                repositories: ?[]StringFilter = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .repositories = "repositories",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            title_aggregation: ?struct {
                titles: ?[]StringFilter = null,
                vulnerability_ids: ?[]StringFilter = null,
                resource_type: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,
                finding_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .titles = "titles",
                        .vulnerability_ids = "vulnerabilityIds",
                        .resource_type = "resourceType",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                        .finding_type = "findingType",
                    };
                    return @field(mappings, field_name);
                }
            },
            lambda_layer_aggregation: ?struct {
                function_names: ?[]StringFilter = null,
                resource_ids: ?[]StringFilter = null,
                layer_arns: ?[]StringFilter = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .function_names = "functionNames",
                        .resource_ids = "resourceIds",
                        .layer_arns = "layerArns",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },
            lambda_function_aggregation: ?struct {
                resource_ids: ?[]StringFilter = null,
                function_names: ?[]StringFilter = null,
                runtimes: ?[]StringFilter = null,
                function_tags: ?[]MapFilter = null,
                sort_order: ?[]const u8 = null,
                sort_by: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_ids = "resourceIds",
                        .function_names = "functionNames",
                        .runtimes = "runtimes",
                        .function_tags = "functionTags",
                        .sort_order = "sortOrder",
                        .sort_by = "sortBy",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_aggregation = "accountAggregation",
                    .ami_aggregation = "amiAggregation",
                    .aws_ecr_container_aggregation = "awsEcrContainerAggregation",
                    .ec2_instance_aggregation = "ec2InstanceAggregation",
                    .finding_type_aggregation = "findingTypeAggregation",
                    .image_layer_aggregation = "imageLayerAggregation",
                    .package_aggregation = "packageAggregation",
                    .repository_aggregation = "repositoryAggregation",
                    .title_aggregation = "titleAggregation",
                    .lambda_layer_aggregation = "lambdaLayerAggregation",
                    .lambda_function_aggregation = "lambdaFunctionAggregation",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregation_type = "aggregationType",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .account_ids = "accountIds",
                .aggregation_request = "aggregationRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_finding_aggregations) } {
            return .{ .service_metadata = service_metadata, .action = list_finding_aggregations };
        }
    },
    Response: type = struct {
        aggregation_type: []const u8,
        responses: ?[]union {
            account_aggregation: ?struct {
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            },
            ami_aggregation: ?struct {
                ami: []const u8,
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,
                affected_instances: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ami = "ami",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                        .affected_instances = "affectedInstances",
                    };
                    return @field(mappings, field_name);
                }
            },
            aws_ecr_container_aggregation: ?struct {
                resource_id: []const u8,
                image_sha: ?[]const u8 = null,
                repository: ?[]const u8 = null,
                architecture: ?[]const u8 = null,
                image_tags: ?[][]const u8 = null,
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_id = "resourceId",
                        .image_sha = "imageSha",
                        .repository = "repository",
                        .architecture = "architecture",
                        .image_tags = "imageTags",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            },
            ec2_instance_aggregation: ?struct {
                instance_id: []const u8,
                ami: ?[]const u8 = null,
                operating_system: ?[]const u8 = null,
                instance_tags: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,
                network_findings: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .instance_id = "instanceId",
                        .ami = "ami",
                        .operating_system = "operatingSystem",
                        .instance_tags = "instanceTags",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                        .network_findings = "networkFindings",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "instance_tags", field_name))
                        return try serializeMap(self.instance_tags, self.fieldNameFor("instance_tags"), options, out_stream);
                    return false;
                }
            },
            finding_type_aggregation: ?struct {
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            },
            image_layer_aggregation: ?struct {
                repository: []const u8,
                resource_id: []const u8,
                layer_hash: []const u8,
                account_id: []const u8,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .repository = "repository",
                        .resource_id = "resourceId",
                        .layer_hash = "layerHash",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            },
            package_aggregation: ?struct {
                package_name: []const u8,
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .package_name = "packageName",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            },
            repository_aggregation: ?struct {
                repository: []const u8,
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,
                affected_images: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .repository = "repository",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                        .affected_images = "affectedImages",
                    };
                    return @field(mappings, field_name);
                }
            },
            title_aggregation: ?struct {
                title: []const u8,
                vulnerability_id: ?[]const u8 = null,
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .title = "title",
                        .vulnerability_id = "vulnerabilityId",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            },
            lambda_layer_aggregation: ?struct {
                function_name: []const u8,
                resource_id: []const u8,
                layer_arn: []const u8,
                account_id: []const u8,
                severity_counts: ?SeverityCounts = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .function_name = "functionName",
                        .resource_id = "resourceId",
                        .layer_arn = "layerArn",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                    };
                    return @field(mappings, field_name);
                }
            },
            lambda_function_aggregation: ?struct {
                resource_id: []const u8,
                function_name: ?[]const u8 = null,
                runtime: ?[]const u8 = null,
                lambda_tags: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                account_id: ?[]const u8 = null,
                severity_counts: ?SeverityCounts = null,
                last_modified_at: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_id = "resourceId",
                        .function_name = "functionName",
                        .runtime = "runtime",
                        .lambda_tags = "lambdaTags",
                        .account_id = "accountId",
                        .severity_counts = "severityCounts",
                        .last_modified_at = "lastModifiedAt",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "lambda_tags", field_name))
                        return try serializeMap(self.lambda_tags, self.fieldNameFor("lambda_tags"), options, out_stream);
                    return false;
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_aggregation = "accountAggregation",
                    .ami_aggregation = "amiAggregation",
                    .aws_ecr_container_aggregation = "awsEcrContainerAggregation",
                    .ec2_instance_aggregation = "ec2InstanceAggregation",
                    .finding_type_aggregation = "findingTypeAggregation",
                    .image_layer_aggregation = "imageLayerAggregation",
                    .package_aggregation = "packageAggregation",
                    .repository_aggregation = "repositoryAggregation",
                    .title_aggregation = "titleAggregation",
                    .lambda_layer_aggregation = "lambdaLayerAggregation",
                    .lambda_function_aggregation = "lambdaFunctionAggregation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregation_type = "aggregationType",
                .responses = "responses",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindings",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter_criteria: ?FilterCriteria = null,
        sort_criteria: ?struct {
            field: []const u8,
            sort_order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field = "field",
                    .sort_order = "sortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .filter_criteria = "filterCriteria",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_findings };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        findings: ?[]struct {
            finding_arn: []const u8,
            aws_account_id: []const u8,
            type: []const u8,
            description: []const u8,
            title: ?[]const u8 = null,
            remediation: struct {
                recommendation: ?struct {
                    text: ?[]const u8 = null,
                    url: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .text = "text",
                            .url = "Url",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .recommendation = "recommendation",
                    };
                    return @field(mappings, field_name);
                }
            },
            severity: []const u8,
            first_observed_at: i64,
            last_observed_at: i64,
            updated_at: ?i64 = null,
            status: []const u8,
            resources: []struct {
                type: []const u8,
                id: []const u8,
                partition: ?[]const u8 = null,
                region: ?[]const u8 = null,
                tags: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                details: ?struct {
                    aws_ec2_instance: ?struct {
                        type: ?[]const u8 = null,
                        image_id: ?[]const u8 = null,
                        ip_v4_addresses: ?[][]const u8 = null,
                        ip_v6_addresses: ?[][]const u8 = null,
                        key_name: ?[]const u8 = null,
                        iam_instance_profile_arn: ?[]const u8 = null,
                        vpc_id: ?[]const u8 = null,
                        subnet_id: ?[]const u8 = null,
                        launched_at: ?i64 = null,
                        platform: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .type = "type",
                                .image_id = "imageId",
                                .ip_v4_addresses = "ipV4Addresses",
                                .ip_v6_addresses = "ipV6Addresses",
                                .key_name = "keyName",
                                .iam_instance_profile_arn = "iamInstanceProfileArn",
                                .vpc_id = "vpcId",
                                .subnet_id = "subnetId",
                                .launched_at = "launchedAt",
                                .platform = "platform",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    aws_ecr_container_image: ?struct {
                        repository_name: []const u8,
                        image_tags: ?[][]const u8 = null,
                        pushed_at: ?i64 = null,
                        author: ?[]const u8 = null,
                        architecture: ?[]const u8 = null,
                        image_hash: []const u8,
                        registry: []const u8,
                        platform: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .repository_name = "repositoryName",
                                .image_tags = "imageTags",
                                .pushed_at = "pushedAt",
                                .author = "author",
                                .architecture = "architecture",
                                .image_hash = "imageHash",
                                .registry = "registry",
                                .platform = "platform",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    aws_lambda_function: ?struct {
                        function_name: []const u8,
                        runtime: []const u8,
                        code_sha256: []const u8,
                        version: []const u8,
                        execution_role_arn: []const u8,
                        layers: ?[][]const u8 = null,
                        vpc_config: ?struct {
                            subnet_ids: ?[][]const u8 = null,
                            security_group_ids: ?[][]const u8 = null,
                            vpc_id: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .subnet_ids = "subnetIds",
                                    .security_group_ids = "securityGroupIds",
                                    .vpc_id = "vpcId",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        package_type: ?[]const u8 = null,
                        architectures: ?[][]const u8 = null,
                        last_modified_at: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .function_name = "functionName",
                                .runtime = "runtime",
                                .code_sha256 = "codeSha256",
                                .version = "version",
                                .execution_role_arn = "executionRoleArn",
                                .layers = "layers",
                                .vpc_config = "vpcConfig",
                                .package_type = "packageType",
                                .architectures = "architectures",
                                .last_modified_at = "lastModifiedAt",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .aws_ec2_instance = "awsEc2Instance",
                            .aws_ecr_container_image = "awsEcrContainerImage",
                            .aws_lambda_function = "awsLambdaFunction",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .id = "id",
                        .partition = "partition",
                        .region = "region",
                        .tags = "tags",
                        .details = "details",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "tags", field_name))
                        return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                    return false;
                }
            },
            inspector_score: ?f64 = null,
            inspector_score_details: ?struct {
                adjusted_cvss: ?struct {
                    score_source: []const u8,
                    cvss_source: ?[]const u8 = null,
                    version: []const u8,
                    score: f64,
                    scoring_vector: []const u8,
                    adjustments: ?[]struct {
                        metric: []const u8,
                        reason: []const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .metric = "metric",
                                .reason = "reason",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .score_source = "scoreSource",
                            .cvss_source = "cvssSource",
                            .version = "version",
                            .score = "score",
                            .scoring_vector = "scoringVector",
                            .adjustments = "adjustments",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .adjusted_cvss = "adjustedCvss",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            network_reachability_details: ?struct {
                open_port_range: struct {
                    begin: i64,
                    end: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .begin = "begin",
                            .end = "end",
                        };
                        return @field(mappings, field_name);
                    }
                },
                protocol: []const u8,
                network_path: struct {
                    steps: ?[]struct {
                        component_id: []const u8,
                        component_type: []const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .component_id = "componentId",
                                .component_type = "componentType",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .steps = "steps",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .open_port_range = "openPortRange",
                        .protocol = "protocol",
                        .network_path = "networkPath",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            package_vulnerability_details: ?struct {
                vulnerability_id: []const u8,
                vulnerable_packages: ?[]struct {
                    name: []const u8,
                    version: []const u8,
                    source_layer_hash: ?[]const u8 = null,
                    epoch: ?i64 = null,
                    release: ?[]const u8 = null,
                    arch: ?[]const u8 = null,
                    package_manager: ?[]const u8 = null,
                    file_path: ?[]const u8 = null,
                    fixed_in_version: ?[]const u8 = null,
                    remediation: ?[]const u8 = null,
                    source_lambda_layer_arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .version = "version",
                            .source_layer_hash = "sourceLayerHash",
                            .epoch = "epoch",
                            .release = "release",
                            .arch = "arch",
                            .package_manager = "packageManager",
                            .file_path = "filePath",
                            .fixed_in_version = "fixedInVersion",
                            .remediation = "remediation",
                            .source_lambda_layer_arn = "sourceLambdaLayerArn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                source: []const u8,
                cvss: ?[]struct {
                    base_score: f64,
                    scoring_vector: []const u8,
                    version: []const u8,
                    source: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .base_score = "baseScore",
                            .scoring_vector = "scoringVector",
                            .version = "version",
                            .source = "source",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                related_vulnerabilities: ?[][]const u8 = null,
                source_url: ?[]const u8 = null,
                vendor_severity: ?[]const u8 = null,
                vendor_created_at: ?i64 = null,
                vendor_updated_at: ?i64 = null,
                reference_urls: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .vulnerability_id = "vulnerabilityId",
                        .vulnerable_packages = "vulnerablePackages",
                        .source = "source",
                        .cvss = "cvss",
                        .related_vulnerabilities = "relatedVulnerabilities",
                        .source_url = "sourceUrl",
                        .vendor_severity = "vendorSeverity",
                        .vendor_created_at = "vendorCreatedAt",
                        .vendor_updated_at = "vendorUpdatedAt",
                        .reference_urls = "referenceUrls",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            fix_available: ?[]const u8 = null,
            exploit_available: ?[]const u8 = null,
            exploitability_details: ?struct {
                last_known_exploit_at: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .last_known_exploit_at = "lastKnownExploitAt",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            code_vulnerability_details: ?struct {
                file_path: struct {
                    file_name: []const u8,
                    file_path: []const u8,
                    start_line: i64,
                    end_line: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .file_name = "fileName",
                            .file_path = "filePath",
                            .start_line = "startLine",
                            .end_line = "endLine",
                        };
                        return @field(mappings, field_name);
                    }
                },
                detector_tags: ?[][]const u8 = null,
                reference_urls: ?[][]const u8 = null,
                rule_id: ?[]const u8 = null,
                source_lambda_layer_arn: ?[]const u8 = null,
                detector_id: []const u8,
                detector_name: []const u8,
                cwes: [][]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .file_path = "filePath",
                        .detector_tags = "detectorTags",
                        .reference_urls = "referenceUrls",
                        .rule_id = "ruleId",
                        .source_lambda_layer_arn = "sourceLambdaLayerArn",
                        .detector_id = "detectorId",
                        .detector_name = "detectorName",
                        .cwes = "cwes",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            epss: ?struct {
                score: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .score = "score",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_arn = "findingArn",
                    .aws_account_id = "awsAccountId",
                    .type = "type",
                    .description = "description",
                    .title = "title",
                    .remediation = "remediation",
                    .severity = "severity",
                    .first_observed_at = "firstObservedAt",
                    .last_observed_at = "lastObservedAt",
                    .updated_at = "updatedAt",
                    .status = "status",
                    .resources = "resources",
                    .inspector_score = "inspectorScore",
                    .inspector_score_details = "inspectorScoreDetails",
                    .network_reachability_details = "networkReachabilityDetails",
                    .package_vulnerability_details = "packageVulnerabilityDetails",
                    .fix_available = "fixAvailable",
                    .exploit_available = "exploitAvailable",
                    .exploitability_details = "exploitabilityDetails",
                    .code_vulnerability_details = "codeVulnerabilityDetails",
                    .epss = "epss",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .findings = "findings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMembers",
    Request: type = struct {
        only_associated: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .only_associated = "onlyAssociated",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_members) } {
            return .{ .service_metadata = service_metadata, .action = list_members };
        }
    },
    Response: type = struct {
        members: ?[]Member = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "members",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_usage_totals: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/usage/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsageTotals",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_usage_totals) } {
            return .{ .service_metadata = service_metadata, .action = list_usage_totals };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        totals: ?[]struct {
            account_id: ?[]const u8 = null,
            usage: ?[]struct {
                type: ?[]const u8 = null,
                total: ?f64 = null,
                estimated_monthly_cost: ?f64 = null,
                currency: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .total = "total",
                        .estimated_monthly_cost = "estimatedMonthlyCost",
                        .currency = "currency",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .usage = "usage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .totals = "totals",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const reset_encryption_key: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/encryptionkey/reset",
        .success_code = 200,
    };

    action_name: []const u8 = "ResetEncryptionKey",
    Request: type = struct {
        scan_type: []const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_type = "scanType",
                .resource_type = "resourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_encryption_key) } {
            return .{ .service_metadata = service_metadata, .action = reset_encryption_key };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const search_vulnerabilities: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/vulnerabilities/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchVulnerabilities",
    Request: type = struct {
        filter_criteria: struct {
            vulnerability_ids: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vulnerability_ids = "vulnerabilityIds",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_criteria = "filterCriteria",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_vulnerabilities) } {
            return .{ .service_metadata = service_metadata, .action = search_vulnerabilities };
        }
    },
    Response: type = struct {
        vulnerabilities: []struct {
            id: []const u8,
            cwes: ?[][]const u8 = null,
            cisa_data: ?CisaData = null,
            source: ?[]const u8 = null,
            description: ?[]const u8 = null,
            atig_data: ?struct {
                first_seen: ?i64 = null,
                last_seen: ?i64 = null,
                targets: ?[][]const u8 = null,
                ttps: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .first_seen = "firstSeen",
                        .last_seen = "lastSeen",
                        .targets = "targets",
                        .ttps = "ttps",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            vendor_severity: ?[]const u8 = null,
            cvss3: ?struct {
                base_score: ?f64 = null,
                scoring_vector: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .base_score = "baseScore",
                        .scoring_vector = "scoringVector",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            related_vulnerabilities: ?[][]const u8 = null,
            cvss2: ?struct {
                base_score: ?f64 = null,
                scoring_vector: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .base_score = "baseScore",
                        .scoring_vector = "scoringVector",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            vendor_created_at: ?i64 = null,
            vendor_updated_at: ?i64 = null,
            source_url: ?[]const u8 = null,
            reference_urls: ?[][]const u8 = null,
            exploit_observed: ?ExploitObserved = null,
            detection_platforms: ?[][]const u8 = null,
            epss: ?struct {
                score: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .score = "score",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .cwes = "cwes",
                    .cisa_data = "cisaData",
                    .source = "source",
                    .description = "description",
                    .atig_data = "atigData",
                    .vendor_severity = "vendorSeverity",
                    .cvss3 = "cvss3",
                    .related_vulnerabilities = "relatedVulnerabilities",
                    .cvss2 = "cvss2",
                    .vendor_created_at = "vendorCreatedAt",
                    .vendor_updated_at = "vendorUpdatedAt",
                    .source_url = "sourceUrl",
                    .reference_urls = "referenceUrls",
                    .exploit_observed = "exploitObserved",
                    .detection_platforms = "detectionPlatforms",
                    .epss = "epss",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vulnerabilities = "vulnerabilities",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const send_cis_session_health: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cissession/health/send",
        .success_code = 200,
    };

    action_name: []const u8 = "SendCisSessionHealth",
    Request: type = struct {
        scan_job_id: []const u8,
        session_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_job_id = "scanJobId",
                .session_token = "sessionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_cis_session_health) } {
            return .{ .service_metadata = service_metadata, .action = send_cis_session_health };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const send_cis_session_telemetry: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cissession/telemetry/send",
        .success_code = 200,
    };

    action_name: []const u8 = "SendCisSessionTelemetry",
    Request: type = struct {
        scan_job_id: []const u8,
        session_token: []const u8,
        messages: []struct {
            rule_id: []const u8,
            status: []const u8,
            cis_rule_details: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_id = "ruleId",
                    .status = "status",
                    .cis_rule_details = "cisRuleDetails",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_job_id = "scanJobId",
                .session_token = "sessionToken",
                .messages = "messages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_cis_session_telemetry) } {
            return .{ .service_metadata = service_metadata, .action = send_cis_session_telemetry };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const start_cis_session: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cissession/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartCisSession",
    Request: type = struct {
        scan_job_id: []const u8,
        message: struct {
            session_token: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_token = "sessionToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_job_id = "scanJobId",
                .message = "message",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_cis_session) } {
            return .{ .service_metadata = service_metadata, .action = start_cis_session };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_cis_session: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cissession/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopCisSession",
    Request: type = struct {
        scan_job_id: []const u8,
        session_token: []const u8,
        message: struct {
            status: []const u8,
            reason: ?[]const u8 = null,
            progress: struct {
                total_checks: ?i64 = null,
                successful_checks: ?i64 = null,
                failed_checks: ?i64 = null,
                not_evaluated_checks: ?i64 = null,
                unknown_checks: ?i64 = null,
                not_applicable_checks: ?i64 = null,
                informational_checks: ?i64 = null,
                error_checks: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total_checks = "totalChecks",
                        .successful_checks = "successfulChecks",
                        .failed_checks = "failedChecks",
                        .not_evaluated_checks = "notEvaluatedChecks",
                        .unknown_checks = "unknownChecks",
                        .not_applicable_checks = "notApplicableChecks",
                        .informational_checks = "informationalChecks",
                        .error_checks = "errorChecks",
                    };
                    return @field(mappings, field_name);
                }
            },
            compute_platform: ?struct {
                vendor: ?[]const u8 = null,
                product: ?[]const u8 = null,
                version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .vendor = "vendor",
                        .product = "product",
                        .version = "version",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            benchmark_version: ?[]const u8 = null,
            benchmark_profile: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "status",
                    .reason = "reason",
                    .progress = "progress",
                    .compute_platform = "computePlatform",
                    .benchmark_version = "benchmarkVersion",
                    .benchmark_profile = "benchmarkProfile",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_job_id = "scanJobId",
                .session_token = "sessionToken",
                .message = "message",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_cis_session) } {
            return .{ .service_metadata = service_metadata, .action = stop_cis_session };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_cis_scan_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cis/scan-configuration/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCisScanConfiguration",
    Request: type = struct {
        scan_configuration_arn: []const u8,
        scan_name: ?[]const u8 = null,
        security_level: ?[]const u8 = null,
        schedule: ?Schedule = null,
        targets: ?struct {
            account_ids: ?[][]const u8 = null,
            target_resource_tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_ids = "accountIds",
                    .target_resource_tags = "targetResourceTags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "target_resource_tags", field_name))
                    return try serializeMap(self.target_resource_tags, self.fieldNameFor("target_resource_tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_configuration_arn = "scanConfigurationArn",
                .scan_name = "scanName",
                .security_level = "securityLevel",
                .schedule = "schedule",
                .targets = "targets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cis_scan_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_cis_scan_configuration };
        }
    },
    Response: type = struct {
        scan_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scan_configuration_arn = "scanConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configuration/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConfiguration",
    Request: type = struct {
        ecr_configuration: struct {
            rescan_duration: []const u8,
            pull_date_rescan_duration: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rescan_duration = "rescanDuration",
                    .pull_date_rescan_duration = "pullDateRescanDuration",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ecr_configuration = "ecrConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_ec2_deep_inspection_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ec2deepinspectionconfiguration/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEc2DeepInspectionConfiguration",
    Request: type = struct {
        activate_deep_inspection: ?bool = null,
        package_paths: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activate_deep_inspection = "activateDeepInspection",
                .package_paths = "packagePaths",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ec2_deep_inspection_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_ec2_deep_inspection_configuration };
        }
    },
    Response: type = struct {
        package_paths: ?[][]const u8 = null,
        org_package_paths: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_paths = "packagePaths",
                .org_package_paths = "orgPackagePaths",
                .status = "status",
                .error_message = "errorMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_encryption_key: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/encryptionkey/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEncryptionKey",
    Request: type = struct {
        kms_key_id: []const u8,
        scan_type: []const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "kmsKeyId",
                .scan_type = "scanType",
                .resource_type = "resourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_encryption_key) } {
            return .{ .service_metadata = service_metadata, .action = update_encryption_key };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/filters/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFilter",
    Request: type = struct {
        action: ?[]const u8 = null,
        description: ?[]const u8 = null,
        filter_criteria: ?FilterCriteria = null,
        name: ?[]const u8 = null,
        filter_arn: []const u8,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "action",
                .description = "description",
                .filter_criteria = "filterCriteria",
                .name = "name",
                .filter_arn = "filterArn",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_filter) } {
            return .{ .service_metadata = service_metadata, .action = update_filter };
        }
    },
    Response: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_organization_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organizationconfiguration/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOrganizationConfiguration",
    Request: type = struct {
        auto_enable: AutoEnable,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "autoEnable",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_organization_configuration };
        }
    },
    Response: type = struct {
        auto_enable: AutoEnable,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "autoEnable",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_org_ec2_deep_inspection_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ec2deepinspectionconfiguration/org/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOrgEc2DeepInspectionConfiguration",
    Request: type = struct {
        org_package_paths: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .org_package_paths = "orgPackagePaths",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_org_ec2_deep_inspection_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_org_ec2_deep_inspection_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const AutoEnable = struct {
    ec2: bool,
    ecr: bool,
    lambda: ?bool = null,
    lambda_code: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ec2 = "ec2",
            .ecr = "ecr",
            .lambda = "lambda",
            .lambda_code = "lambdaCode",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterCriteria = struct {
    finding_arn: ?[]StringFilter = null,
    aws_account_id: ?[]StringFilter = null,
    finding_type: ?[]StringFilter = null,
    severity: ?[]StringFilter = null,
    first_observed_at: ?[]DateFilter = null,
    last_observed_at: ?[]DateFilter = null,
    updated_at: ?[]DateFilter = null,
    finding_status: ?[]StringFilter = null,
    title: ?[]StringFilter = null,
    inspector_score: ?[]NumberFilter = null,
    resource_type: ?[]StringFilter = null,
    resource_id: ?[]StringFilter = null,
    resource_tags: ?[]MapFilter = null,
    ec2_instance_image_id: ?[]StringFilter = null,
    ec2_instance_vpc_id: ?[]StringFilter = null,
    ec2_instance_subnet_id: ?[]StringFilter = null,
    ecr_image_pushed_at: ?[]DateFilter = null,
    ecr_image_architecture: ?[]StringFilter = null,
    ecr_image_registry: ?[]StringFilter = null,
    ecr_image_repository_name: ?[]StringFilter = null,
    ecr_image_tags: ?[]StringFilter = null,
    ecr_image_hash: ?[]StringFilter = null,
    port_range: ?[]PortRangeFilter = null,
    network_protocol: ?[]StringFilter = null,
    component_id: ?[]StringFilter = null,
    component_type: ?[]StringFilter = null,
    vulnerability_id: ?[]StringFilter = null,
    vulnerability_source: ?[]StringFilter = null,
    vendor_severity: ?[]StringFilter = null,
    vulnerable_packages: ?[]PackageFilter = null,
    related_vulnerabilities: ?[]StringFilter = null,
    fix_available: ?[]StringFilter = null,
    lambda_function_name: ?[]StringFilter = null,
    lambda_function_layers: ?[]StringFilter = null,
    lambda_function_runtime: ?[]StringFilter = null,
    lambda_function_last_modified_at: ?[]DateFilter = null,
    lambda_function_execution_role_arn: ?[]StringFilter = null,
    exploit_available: ?[]StringFilter = null,
    code_vulnerability_detector_name: ?[]StringFilter = null,
    code_vulnerability_detector_tags: ?[]StringFilter = null,
    code_vulnerability_file_path: ?[]StringFilter = null,
    epss_score: ?[]NumberFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .finding_arn = "findingArn",
            .aws_account_id = "awsAccountId",
            .finding_type = "findingType",
            .severity = "severity",
            .first_observed_at = "firstObservedAt",
            .last_observed_at = "lastObservedAt",
            .updated_at = "updatedAt",
            .finding_status = "findingStatus",
            .title = "title",
            .inspector_score = "inspectorScore",
            .resource_type = "resourceType",
            .resource_id = "resourceId",
            .resource_tags = "resourceTags",
            .ec2_instance_image_id = "ec2InstanceImageId",
            .ec2_instance_vpc_id = "ec2InstanceVpcId",
            .ec2_instance_subnet_id = "ec2InstanceSubnetId",
            .ecr_image_pushed_at = "ecrImagePushedAt",
            .ecr_image_architecture = "ecrImageArchitecture",
            .ecr_image_registry = "ecrImageRegistry",
            .ecr_image_repository_name = "ecrImageRepositoryName",
            .ecr_image_tags = "ecrImageTags",
            .ecr_image_hash = "ecrImageHash",
            .port_range = "portRange",
            .network_protocol = "networkProtocol",
            .component_id = "componentId",
            .component_type = "componentType",
            .vulnerability_id = "vulnerabilityId",
            .vulnerability_source = "vulnerabilitySource",
            .vendor_severity = "vendorSeverity",
            .vulnerable_packages = "vulnerablePackages",
            .related_vulnerabilities = "relatedVulnerabilities",
            .fix_available = "fixAvailable",
            .lambda_function_name = "lambdaFunctionName",
            .lambda_function_layers = "lambdaFunctionLayers",
            .lambda_function_runtime = "lambdaFunctionRuntime",
            .lambda_function_last_modified_at = "lambdaFunctionLastModifiedAt",
            .lambda_function_execution_role_arn = "lambdaFunctionExecutionRoleArn",
            .exploit_available = "exploitAvailable",
            .code_vulnerability_detector_name = "codeVulnerabilityDetectorName",
            .code_vulnerability_detector_tags = "codeVulnerabilityDetectorTags",
            .code_vulnerability_file_path = "codeVulnerabilityFilePath",
            .epss_score = "epssScore",
        };
        return @field(mappings, field_name);
    }
};

pub const NumberFilter = struct {
    upper_inclusive: ?f64 = null,
    lower_inclusive: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .upper_inclusive = "upperInclusive",
            .lower_inclusive = "lowerInclusive",
        };
        return @field(mappings, field_name);
    }
};

pub const StringFilter = struct {
    comparison: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DateFilter = struct {
    start_inclusive: ?i64 = null,
    end_inclusive: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_inclusive = "startInclusive",
            .end_inclusive = "endInclusive",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageFilter = struct {
    name: ?StringFilter = null,
    version: ?StringFilter = null,
    epoch: ?NumberFilter = null,
    release: ?StringFilter = null,
    architecture: ?StringFilter = null,
    source_layer_hash: ?StringFilter = null,
    source_lambda_layer_arn: ?StringFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .version = "version",
            .epoch = "epoch",
            .release = "release",
            .architecture = "architecture",
            .source_layer_hash = "sourceLayerHash",
            .source_lambda_layer_arn = "sourceLambdaLayerArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRangeFilter = struct {
    begin_inclusive: ?i64 = null,
    end_inclusive: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin_inclusive = "beginInclusive",
            .end_inclusive = "endInclusive",
        };
        return @field(mappings, field_name);
    }
};

pub const MapFilter = struct {
    comparison: []const u8,
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Schedule = union {
    one_time: ?OneTimeSchedule,
    daily: ?DailySchedule,
    weekly: ?WeeklySchedule,
    monthly: ?MonthlySchedule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .one_time = "oneTime",
            .daily = "daily",
            .weekly = "weekly",
            .monthly = "monthly",
        };
        return @field(mappings, field_name);
    }
};

pub const MonthlySchedule = struct {
    start_time: Time,
    day: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "startTime",
            .day = "day",
        };
        return @field(mappings, field_name);
    }
};

pub const Time = struct {
    time_of_day: []const u8,
    timezone: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_of_day = "timeOfDay",
            .timezone = "timezone",
        };
        return @field(mappings, field_name);
    }
};

pub const WeeklySchedule = struct {
    start_time: Time,
    days: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "startTime",
            .days = "days",
        };
        return @field(mappings, field_name);
    }
};

pub const DailySchedule = struct {
    start_time: Time,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "startTime",
        };
        return @field(mappings, field_name);
    }
};

pub const OneTimeSchedule = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const ExploitObserved = struct {
    last_seen: ?i64 = null,
    first_seen: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_seen = "lastSeen",
            .first_seen = "firstSeen",
        };
        return @field(mappings, field_name);
    }
};

pub const CisaData = struct {
    date_added: ?i64 = null,
    date_due: ?i64 = null,
    action: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date_added = "dateAdded",
            .date_due = "dateDue",
            .action = "action",
        };
        return @field(mappings, field_name);
    }
};

pub const Member = struct {
    account_id: ?[]const u8 = null,
    relationship_status: ?[]const u8 = null,
    delegated_admin_account_id: ?[]const u8 = null,
    updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .relationship_status = "relationshipStatus",
            .delegated_admin_account_id = "delegatedAdminAccountId",
            .updated_at = "updatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const SeverityCounts = struct {
    all: ?i64 = null,
    medium: ?i64 = null,
    high: ?i64 = null,
    critical: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .all = "all",
            .medium = "medium",
            .high = "high",
            .critical = "critical",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageFilterCriteria = struct {
    scan_status_code: ?[]CoverageStringFilter = null,
    scan_status_reason: ?[]CoverageStringFilter = null,
    account_id: ?[]CoverageStringFilter = null,
    resource_id: ?[]CoverageStringFilter = null,
    resource_type: ?[]CoverageStringFilter = null,
    scan_type: ?[]CoverageStringFilter = null,
    ecr_repository_name: ?[]CoverageStringFilter = null,
    ecr_image_tags: ?[]CoverageStringFilter = null,
    ec2_instance_tags: ?[]CoverageMapFilter = null,
    lambda_function_name: ?[]CoverageStringFilter = null,
    lambda_function_tags: ?[]CoverageMapFilter = null,
    lambda_function_runtime: ?[]CoverageStringFilter = null,
    last_scanned_at: ?[]CoverageDateFilter = null,
    image_pulled_at: ?[]CoverageDateFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scan_status_code = "scanStatusCode",
            .scan_status_reason = "scanStatusReason",
            .account_id = "accountId",
            .resource_id = "resourceId",
            .resource_type = "resourceType",
            .scan_type = "scanType",
            .ecr_repository_name = "ecrRepositoryName",
            .ecr_image_tags = "ecrImageTags",
            .ec2_instance_tags = "ec2InstanceTags",
            .lambda_function_name = "lambdaFunctionName",
            .lambda_function_tags = "lambdaFunctionTags",
            .lambda_function_runtime = "lambdaFunctionRuntime",
            .last_scanned_at = "lastScannedAt",
            .image_pulled_at = "imagePulledAt",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageDateFilter = struct {
    start_inclusive: ?i64 = null,
    end_inclusive: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_inclusive = "startInclusive",
            .end_inclusive = "endInclusive",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageStringFilter = struct {
    comparison: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const CoverageMapFilter = struct {
    comparison: []const u8,
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const CisTargets = struct {
    account_ids: ?[][]const u8 = null,
    target_resource_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_ids = "accountIds",
            .target_resource_tags = "targetResourceTags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "target_resource_tags", field_name))
            return try serializeMap(self.target_resource_tags, self.fieldNameFor("target_resource_tags"), options, out_stream);
        return false;
    }
};

pub const CisStringFilter = struct {
    comparison: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const CisNumberFilter = struct {
    upper_inclusive: ?i64 = null,
    lower_inclusive: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .upper_inclusive = "upperInclusive",
            .lower_inclusive = "lowerInclusive",
        };
        return @field(mappings, field_name);
    }
};

pub const TagFilter = struct {
    comparison: []const u8,
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const StatusCounts = struct {
    failed: ?i64 = null,
    skipped: ?i64 = null,
    passed: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failed = "failed",
            .skipped = "skipped",
            .passed = "passed",
        };
        return @field(mappings, field_name);
    }
};

pub const CisSecurityLevelFilter = struct {
    comparison: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceFilterCriteria = struct {
    account_id: ?[]ResourceStringFilter = null,
    resource_id: ?[]ResourceStringFilter = null,
    resource_type: ?[]ResourceStringFilter = null,
    ecr_repository_name: ?[]ResourceStringFilter = null,
    lambda_function_name: ?[]ResourceStringFilter = null,
    ecr_image_tags: ?[]ResourceStringFilter = null,
    ec2_instance_tags: ?[]ResourceMapFilter = null,
    lambda_function_tags: ?[]ResourceMapFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .resource_id = "resourceId",
            .resource_type = "resourceType",
            .ecr_repository_name = "ecrRepositoryName",
            .lambda_function_name = "lambdaFunctionName",
            .ecr_image_tags = "ecrImageTags",
            .ec2_instance_tags = "ec2InstanceTags",
            .lambda_function_tags = "lambdaFunctionTags",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceMapFilter = struct {
    comparison: []const u8,
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceStringFilter = struct {
    comparison: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "comparison",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = struct {
    bucket_name: []const u8,
    key_prefix: ?[]const u8 = null,
    kms_key_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .key_prefix = "keyPrefix",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedAccount = struct {
    account_id: []const u8,
    status: ?[]const u8 = null,
    resource_status: ?ResourceStatus = null,
    error_code: []const u8,
    error_message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .status = "status",
            .resource_status = "resourceStatus",
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceStatus = struct {
    ec2: []const u8,
    ecr: []const u8,
    lambda: ?[]const u8 = null,
    lambda_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ec2 = "ec2",
            .ecr = "ecr",
            .lambda = "lambda",
            .lambda_code = "lambdaCode",
        };
        return @field(mappings, field_name);
    }
};

pub const Account = struct {
    account_id: []const u8,
    status: []const u8,
    resource_status: ResourceStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .status = "status",
            .resource_status = "resourceStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedMemberAccountEc2DeepInspectionStatusState = struct {
    account_id: []const u8,
    ec2_scan_status: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .ec2_scan_status = "ec2ScanStatus",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const MemberAccountEc2DeepInspectionStatusState = struct {
    account_id: []const u8,
    status: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .status = "status",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const State = struct {
    status: []const u8,
    error_code: []const u8,
    error_message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};
