const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-11-27";
pub const sdk_id: []const u8 = "IoTAnalytics";
pub const arn_namespace: ?[]const u8 = "iotanalytics";
pub const endpoint_prefix: []const u8 = "iotanalytics";
pub const sigv4_name: []const u8 = "iotanalytics";
pub const name: []const u8 = "AWSIoTAnalytics";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-11-27",
    sdk_id: []const u8 = "IoTAnalytics",
    arn_namespace: ?[]const u8 = "iotanalytics",
    endpoint_prefix: []const u8 = "iotanalytics",
    sigv4_name: []const u8 = "iotanalytics",
    name: []const u8 = "AWSIoTAnalytics",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_put_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/messages/batch",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchPutMessage",
    Request: type = struct {
        channel_name: []const u8,
        messages: []struct {
            message_id: []const u8,
            payload: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .payload = "payload",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "channelName",
                .messages = "messages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_message) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_message };
        }
    },
    Response: type = struct {
        batch_put_message_error_entries: ?[]struct {
            message_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_put_message_error_entries = "batchPutMessageErrorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const cancel_pipeline_reprocessing: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/pipelines/{pipelineName}/reprocessing/{reprocessingId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelPipelineReprocessing",
    Request: type = struct {
        pipeline_name: []const u8,
        reprocessing_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .reprocessing_id = "reprocessingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_pipeline_reprocessing) } {
            return .{ .service_metadata = service_metadata, .action = cancel_pipeline_reprocessing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannel",
    Request: type = struct {
        channel_name: []const u8,
        channel_storage: ?ChannelStorage = null,
        retention_period: ?RetentionPeriod = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "channelName",
                .channel_storage = "channelStorage",
                .retention_period = "retentionPeriod",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_channel };
        }
    },
    Response: type = struct {
        channel_name: ?[]const u8 = null,
        channel_arn: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "channelName",
                .channel_arn = "channelArn",
                .retention_period = "retentionPeriod",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_dataset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasets",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        dataset_name: []const u8,
        actions: []DatasetAction,
        triggers: ?[]DatasetTrigger = null,
        content_delivery_rules: ?[]DatasetContentDeliveryRule = null,
        retention_period: ?RetentionPeriod = null,
        versioning_configuration: ?VersioningConfiguration = null,
        tags: ?[]Tag = null,
        late_data_rules: ?[]LateDataRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
                .actions = "actions",
                .triggers = "triggers",
                .content_delivery_rules = "contentDeliveryRules",
                .retention_period = "retentionPeriod",
                .versioning_configuration = "versioningConfiguration",
                .tags = "tags",
                .late_data_rules = "lateDataRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
                .dataset_arn = "datasetArn",
                .retention_period = "retentionPeriod",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_dataset_content: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasets/{datasetName}/content",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDatasetContent",
    Request: type = struct {
        dataset_name: []const u8,
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
                .version_id = "versionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset_content) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset_content };
        }
    },
    Response: type = struct {
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_id = "versionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_datastore: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastores",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDatastore",
    Request: type = struct {
        datastore_name: []const u8,
        datastore_storage: ?DatastoreStorage = null,
        retention_period: ?RetentionPeriod = null,
        tags: ?[]Tag = null,
        file_format_configuration: ?FileFormatConfiguration = null,
        datastore_partitions: ?DatastorePartitions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_name = "datastoreName",
                .datastore_storage = "datastoreStorage",
                .retention_period = "retentionPeriod",
                .tags = "tags",
                .file_format_configuration = "fileFormatConfiguration",
                .datastore_partitions = "datastorePartitions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_datastore) } {
            return .{ .service_metadata = service_metadata, .action = create_datastore };
        }
    },
    Response: type = struct {
        datastore_name: ?[]const u8 = null,
        datastore_arn: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_name = "datastoreName",
                .datastore_arn = "datastoreArn",
                .retention_period = "retentionPeriod",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/pipelines",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePipeline",
    Request: type = struct {
        pipeline_name: []const u8,
        pipeline_activities: []PipelineActivity,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .pipeline_activities = "pipelineActivities",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_pipeline };
        }
    },
    Response: type = struct {
        pipeline_name: ?[]const u8 = null,
        pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .pipeline_arn = "pipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{channelName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannel",
    Request: type = struct {
        channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "channelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_dataset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/datasets/{datasetName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        dataset_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_dataset_content: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/datasets/{datasetName}/content",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDatasetContent",
    Request: type = struct {
        dataset_name: []const u8,
        version_id: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
                .version_id = "versionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset_content) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset_content };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_datastore: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/datastores/{datastoreName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDatastore",
    Request: type = struct {
        datastore_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_name = "datastoreName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_datastore) } {
            return .{ .service_metadata = service_metadata, .action = delete_datastore };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_pipeline: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/pipelines/{pipelineName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeletePipeline",
    Request: type = struct {
        pipeline_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_pipeline };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{channelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannel",
    Request: type = struct {
        channel_name: []const u8,
        include_statistics: ?bool = null,

        pub const http_query = .{
            .include_statistics = "includeStatistics",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "channelName",
                .include_statistics = "includeStatistics",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel };
        }
    },
    Response: type = struct {
        channel: ?struct {
            name: ?[]const u8 = null,
            storage: ?ChannelStorage = null,
            arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            retention_period: ?RetentionPeriod = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            last_message_arrival_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .storage = "storage",
                    .arn = "arn",
                    .status = "status",
                    .retention_period = "retentionPeriod",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .last_message_arrival_time = "lastMessageArrivalTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        statistics: ?struct {
            size: ?EstimatedResourceSize = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .size = "size",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "channel",
                .statistics = "statistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_dataset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets/{datasetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        dataset_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        dataset: ?struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            actions: ?[]DatasetAction = null,
            triggers: ?[]DatasetTrigger = null,
            content_delivery_rules: ?[]DatasetContentDeliveryRule = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            retention_period: ?RetentionPeriod = null,
            versioning_configuration: ?VersioningConfiguration = null,
            late_data_rules: ?[]LateDataRule = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .actions = "actions",
                    .triggers = "triggers",
                    .content_delivery_rules = "contentDeliveryRules",
                    .status = "status",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .retention_period = "retentionPeriod",
                    .versioning_configuration = "versioningConfiguration",
                    .late_data_rules = "lateDataRules",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset = "dataset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_datastore: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datastores/{datastoreName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDatastore",
    Request: type = struct {
        datastore_name: []const u8,
        include_statistics: ?bool = null,

        pub const http_query = .{
            .include_statistics = "includeStatistics",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_name = "datastoreName",
                .include_statistics = "includeStatistics",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_datastore) } {
            return .{ .service_metadata = service_metadata, .action = describe_datastore };
        }
    },
    Response: type = struct {
        datastore: ?struct {
            name: ?[]const u8 = null,
            storage: ?DatastoreStorage = null,
            arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            retention_period: ?RetentionPeriod = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            last_message_arrival_time: ?i64 = null,
            file_format_configuration: ?FileFormatConfiguration = null,
            datastore_partitions: ?DatastorePartitions = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .storage = "storage",
                    .arn = "arn",
                    .status = "status",
                    .retention_period = "retentionPeriod",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .last_message_arrival_time = "lastMessageArrivalTime",
                    .file_format_configuration = "fileFormatConfiguration",
                    .datastore_partitions = "datastorePartitions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        statistics: ?struct {
            size: ?EstimatedResourceSize = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .size = "size",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore = "datastore",
                .statistics = "statistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_logging_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/logging",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeLoggingOptions",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_logging_options };
        }
    },
    Response: type = struct {
        logging_options: ?LoggingOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_options = "loggingOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/pipelines/{pipelineName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePipeline",
    Request: type = struct {
        pipeline_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = describe_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            activities: ?[]PipelineActivity = null,
            reprocessing_summaries: ?[]ReprocessingSummary = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .activities = "activities",
                    .reprocessing_summaries = "reprocessingSummaries",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_dataset_content: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets/{datasetName}/content",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDatasetContent",
    Request: type = struct {
        dataset_name: []const u8,
        version_id: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
                .version_id = "versionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dataset_content) } {
            return .{ .service_metadata = service_metadata, .action = get_dataset_content };
        }
    },
    Response: type = struct {
        entries: ?[]struct {
            entry_name: ?[]const u8 = null,
            data_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_name = "entryName",
                    .data_uri = "dataURI",
                };
                return @field(mappings, field_name);
            }
        } = null,
        timestamp: ?i64 = null,
        status: ?DatasetContentStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "entries",
                .timestamp = "timestamp",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_channels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannels",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_channels };
        }
    },
    Response: type = struct {
        channel_summaries: ?[]struct {
            channel_name: ?[]const u8 = null,
            channel_storage: ?struct {
                service_managed_s3: ?struct {

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{};
                        return @field(mappings, field_name);
                    }
                } = null,
                customer_managed_s3: ?struct {
                    bucket: ?[]const u8 = null,
                    key_prefix: ?[]const u8 = null,
                    role_arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bucket = "bucket",
                            .key_prefix = "keyPrefix",
                            .role_arn = "roleArn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .service_managed_s3 = "serviceManagedS3",
                        .customer_managed_s3 = "customerManagedS3",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            last_message_arrival_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_name = "channelName",
                    .channel_storage = "channelStorage",
                    .status = "status",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .last_message_arrival_time = "lastMessageArrivalTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_summaries = "channelSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_dataset_contents: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets/{datasetName}/contents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatasetContents",
    Request: type = struct {
        dataset_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        scheduled_on_or_after: ?i64 = null,
        scheduled_before: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .scheduled_on_or_after = "scheduledOnOrAfter",
            .scheduled_before = "scheduledBefore",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .scheduled_on_or_after = "scheduledOnOrAfter",
                .scheduled_before = "scheduledBefore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_contents) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_contents };
        }
    },
    Response: type = struct {
        dataset_content_summaries: ?[]struct {
            version: ?[]const u8 = null,
            status: ?DatasetContentStatus = null,
            creation_time: ?i64 = null,
            schedule_time: ?i64 = null,
            completion_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "version",
                    .status = "status",
                    .creation_time = "creationTime",
                    .schedule_time = "scheduleTime",
                    .completion_time = "completionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_content_summaries = "datasetContentSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_datasets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datasets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatasets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasets) } {
            return .{ .service_metadata = service_metadata, .action = list_datasets };
        }
    },
    Response: type = struct {
        dataset_summaries: ?[]struct {
            dataset_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            triggers: ?[]DatasetTrigger = null,
            actions: ?[]struct {
                action_name: ?[]const u8 = null,
                action_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action_name = "actionName",
                        .action_type = "actionType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_name = "datasetName",
                    .status = "status",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .triggers = "triggers",
                    .actions = "actions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_summaries = "datasetSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_datastores: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/datastores",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatastores",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datastores) } {
            return .{ .service_metadata = service_metadata, .action = list_datastores };
        }
    },
    Response: type = struct {
        datastore_summaries: ?[]struct {
            datastore_name: ?[]const u8 = null,
            datastore_storage: ?struct {
                service_managed_s3: ?struct {

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{};
                        return @field(mappings, field_name);
                    }
                } = null,
                customer_managed_s3: ?struct {
                    bucket: ?[]const u8 = null,
                    key_prefix: ?[]const u8 = null,
                    role_arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bucket = "bucket",
                            .key_prefix = "keyPrefix",
                            .role_arn = "roleArn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                iot_site_wise_multi_layer_storage: ?struct {
                    customer_managed_s3_storage: ?struct {
                        bucket: ?[]const u8 = null,
                        key_prefix: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .bucket = "bucket",
                                .key_prefix = "keyPrefix",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .customer_managed_s3_storage = "customerManagedS3Storage",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .service_managed_s3 = "serviceManagedS3",
                        .customer_managed_s3 = "customerManagedS3",
                        .iot_site_wise_multi_layer_storage = "iotSiteWiseMultiLayerStorage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            last_message_arrival_time: ?i64 = null,
            file_format_type: ?[]const u8 = null,
            datastore_partitions: ?DatastorePartitions = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .datastore_name = "datastoreName",
                    .datastore_storage = "datastoreStorage",
                    .status = "status",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .last_message_arrival_time = "lastMessageArrivalTime",
                    .file_format_type = "fileFormatType",
                    .datastore_partitions = "datastorePartitions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_summaries = "datastoreSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_pipelines: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/pipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPipelines",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_pipelines };
        }
    },
    Response: type = struct {
        pipeline_summaries: ?[]struct {
            pipeline_name: ?[]const u8 = null,
            reprocessing_summaries: ?[]ReprocessingSummary = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_name = "pipelineName",
                    .reprocessing_summaries = "reprocessingSummaries",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_summaries = "pipelineSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const put_logging_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/logging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutLoggingOptions",
    Request: type = struct {
        logging_options: LoggingOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_options = "loggingOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = put_logging_options };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const run_pipeline_activity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/pipelineactivities/run",
        .success_code = 200,
    };

    action_name: []const u8 = "RunPipelineActivity",
    Request: type = struct {
        pipeline_activity: PipelineActivity,
        payloads: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_activity = "pipelineActivity",
                .payloads = "payloads",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(run_pipeline_activity) } {
            return .{ .service_metadata = service_metadata, .action = run_pipeline_activity };
        }
    },
    Response: type = struct {
        payloads: ?[][]const u8 = null,
        log_result: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payloads = "payloads",
                .log_result = "logResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const sample_channel_data: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{channelName}/sample",
        .success_code = 200,
    };

    action_name: []const u8 = "SampleChannelData",
    Request: type = struct {
        channel_name: []const u8,
        max_messages: ?i64 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,

        pub const http_query = .{
            .max_messages = "maxMessages",
            .start_time = "startTime",
            .end_time = "endTime",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "channelName",
                .max_messages = "maxMessages",
                .start_time = "startTime",
                .end_time = "endTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(sample_channel_data) } {
            return .{ .service_metadata = service_metadata, .action = sample_channel_data };
        }
    },
    Response: type = struct {
        payloads: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payloads = "payloads",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const start_pipeline_reprocessing: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/pipelines/{pipelineName}/reprocessing",
        .success_code = 200,
    };

    action_name: []const u8 = "StartPipelineReprocessing",
    Request: type = struct {
        pipeline_name: []const u8,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        channel_messages: ?struct {
            s3_paths: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_paths = "s3Paths",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .start_time = "startTime",
                .end_time = "endTime",
                .channel_messages = "channelMessages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_pipeline_reprocessing) } {
            return .{ .service_metadata = service_metadata, .action = start_pipeline_reprocessing };
        }
    },
    Response: type = struct {
        reprocessing_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reprocessing_id = "reprocessingId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{channelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannel",
    Request: type = struct {
        channel_name: []const u8,
        channel_storage: ?ChannelStorage = null,
        retention_period: ?RetentionPeriod = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "channelName",
                .channel_storage = "channelStorage",
                .retention_period = "retentionPeriod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_channel };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_dataset: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/datasets/{datasetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataset",
    Request: type = struct {
        dataset_name: []const u8,
        actions: []DatasetAction,
        triggers: ?[]DatasetTrigger = null,
        content_delivery_rules: ?[]DatasetContentDeliveryRule = null,
        retention_period: ?RetentionPeriod = null,
        versioning_configuration: ?VersioningConfiguration = null,
        late_data_rules: ?[]LateDataRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "datasetName",
                .actions = "actions",
                .triggers = "triggers",
                .content_delivery_rules = "contentDeliveryRules",
                .retention_period = "retentionPeriod",
                .versioning_configuration = "versioningConfiguration",
                .late_data_rules = "lateDataRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dataset) } {
            return .{ .service_metadata = service_metadata, .action = update_dataset };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_datastore: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/datastores/{datastoreName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDatastore",
    Request: type = struct {
        datastore_name: []const u8,
        retention_period: ?RetentionPeriod = null,
        datastore_storage: ?DatastoreStorage = null,
        file_format_configuration: ?FileFormatConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_name = "datastoreName",
                .retention_period = "retentionPeriod",
                .datastore_storage = "datastoreStorage",
                .file_format_configuration = "fileFormatConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_datastore) } {
            return .{ .service_metadata = service_metadata, .action = update_datastore };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/pipelines/{pipelineName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePipeline",
    Request: type = struct {
        pipeline_name: []const u8,
        pipeline_activities: []PipelineActivity,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "pipelineName",
                .pipeline_activities = "pipelineActivities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = update_pipeline };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const PipelineActivity = struct {
    channel: ?ChannelActivity = null,
    lambda: ?LambdaActivity = null,
    datastore: ?DatastoreActivity = null,
    add_attributes: ?AddAttributesActivity = null,
    remove_attributes: ?RemoveAttributesActivity = null,
    select_attributes: ?SelectAttributesActivity = null,
    filter: ?FilterActivity = null,
    math: ?MathActivity = null,
    device_registry_enrich: ?DeviceRegistryEnrichActivity = null,
    device_shadow_enrich: ?DeviceShadowEnrichActivity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel = "channel",
            .lambda = "lambda",
            .datastore = "datastore",
            .add_attributes = "addAttributes",
            .remove_attributes = "removeAttributes",
            .select_attributes = "selectAttributes",
            .filter = "filter",
            .math = "math",
            .device_registry_enrich = "deviceRegistryEnrich",
            .device_shadow_enrich = "deviceShadowEnrich",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceShadowEnrichActivity = struct {
    name: []const u8,
    attribute: []const u8,
    thing_name: []const u8,
    role_arn: []const u8,
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .attribute = "attribute",
            .thing_name = "thingName",
            .role_arn = "roleArn",
            .next = "next",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceRegistryEnrichActivity = struct {
    name: []const u8,
    attribute: []const u8,
    thing_name: []const u8,
    role_arn: []const u8,
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .attribute = "attribute",
            .thing_name = "thingName",
            .role_arn = "roleArn",
            .next = "next",
        };
        return @field(mappings, field_name);
    }
};

pub const MathActivity = struct {
    name: []const u8,
    attribute: []const u8,
    math: []const u8,
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .attribute = "attribute",
            .math = "math",
            .next = "next",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterActivity = struct {
    name: []const u8,
    filter: []const u8,
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .filter = "filter",
            .next = "next",
        };
        return @field(mappings, field_name);
    }
};

pub const SelectAttributesActivity = struct {
    name: []const u8,
    attributes: [][]const u8,
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .attributes = "attributes",
            .next = "next",
        };
        return @field(mappings, field_name);
    }
};

pub const RemoveAttributesActivity = struct {
    name: []const u8,
    attributes: [][]const u8,
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .attributes = "attributes",
            .next = "next",
        };
        return @field(mappings, field_name);
    }
};

pub const AddAttributesActivity = struct {
    name: []const u8,
    attributes: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .attributes = "attributes",
            .next = "next",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const DatastoreActivity = struct {
    name: []const u8,
    datastore_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .datastore_name = "datastoreName",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaActivity = struct {
    name: []const u8,
    lambda_name: []const u8,
    batch_size: i64,
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .lambda_name = "lambdaName",
            .batch_size = "batchSize",
            .next = "next",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelActivity = struct {
    name: []const u8,
    channel_name: []const u8,
    next: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .channel_name = "channelName",
            .next = "next",
        };
        return @field(mappings, field_name);
    }
};

pub const FileFormatConfiguration = struct {
    json_configuration: ?JsonConfiguration = null,
    parquet_configuration: ?ParquetConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .json_configuration = "jsonConfiguration",
            .parquet_configuration = "parquetConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ParquetConfiguration = struct {
    schema_definition: ?SchemaDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_definition = "schemaDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaDefinition = struct {
    columns: ?[]Column = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .columns = "columns",
        };
        return @field(mappings, field_name);
    }
};

pub const Column = struct {
    name: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonConfiguration = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const DatastoreStorage = union {
    service_managed_s3: ?ServiceManagedDatastoreS3Storage,
    customer_managed_s3: ?CustomerManagedDatastoreS3Storage,
    iot_site_wise_multi_layer_storage: ?DatastoreIotSiteWiseMultiLayerStorage,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_managed_s3 = "serviceManagedS3",
            .customer_managed_s3 = "customerManagedS3",
            .iot_site_wise_multi_layer_storage = "iotSiteWiseMultiLayerStorage",
        };
        return @field(mappings, field_name);
    }
};

pub const DatastoreIotSiteWiseMultiLayerStorage = struct {
    customer_managed_s3_storage: IotSiteWiseCustomerManagedDatastoreS3Storage,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_managed_s3_storage = "customerManagedS3Storage",
        };
        return @field(mappings, field_name);
    }
};

pub const IotSiteWiseCustomerManagedDatastoreS3Storage = struct {
    bucket: []const u8,
    key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key_prefix = "keyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerManagedDatastoreS3Storage = struct {
    bucket: []const u8,
    key_prefix: ?[]const u8 = null,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key_prefix = "keyPrefix",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceManagedDatastoreS3Storage = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const RetentionPeriod = struct {
    unlimited: ?bool = null,
    number_of_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unlimited = "unlimited",
            .number_of_days = "numberOfDays",
        };
        return @field(mappings, field_name);
    }
};

pub const LateDataRule = struct {
    rule_name: ?[]const u8 = null,
    rule_configuration: LateDataRuleConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_name = "ruleName",
            .rule_configuration = "ruleConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LateDataRuleConfiguration = struct {
    delta_time_session_window_configuration: ?DeltaTimeSessionWindowConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delta_time_session_window_configuration = "deltaTimeSessionWindowConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const DeltaTimeSessionWindowConfiguration = struct {
    timeout_in_minutes: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_in_minutes = "timeoutInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const VersioningConfiguration = struct {
    unlimited: ?bool = null,
    max_versions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unlimited = "unlimited",
            .max_versions = "maxVersions",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetContentDeliveryRule = struct {
    entry_name: ?[]const u8 = null,
    destination: DatasetContentDeliveryDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entry_name = "entryName",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetContentDeliveryDestination = struct {
    iot_events_destination_configuration: ?IotEventsDestinationConfiguration = null,
    s3_destination_configuration: ?S3DestinationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iot_events_destination_configuration = "iotEventsDestinationConfiguration",
            .s3_destination_configuration = "s3DestinationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationConfiguration = struct {
    bucket: []const u8,
    key: []const u8,
    glue_configuration: ?GlueConfiguration = null,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key = "key",
            .glue_configuration = "glueConfiguration",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const GlueConfiguration = struct {
    table_name: []const u8,
    database_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "tableName",
            .database_name = "databaseName",
        };
        return @field(mappings, field_name);
    }
};

pub const IotEventsDestinationConfiguration = struct {
    input_name: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_name = "inputName",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetTrigger = struct {
    schedule: ?Schedule = null,
    dataset: ?TriggeringDataset = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule = "schedule",
            .dataset = "dataset",
        };
        return @field(mappings, field_name);
    }
};

pub const TriggeringDataset = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const Schedule = struct {
    expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "expression",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetAction = struct {
    action_name: ?[]const u8 = null,
    query_action: ?SqlQueryDatasetAction = null,
    container_action: ?ContainerDatasetAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_name = "actionName",
            .query_action = "queryAction",
            .container_action = "containerAction",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerDatasetAction = struct {
    image: []const u8,
    execution_role_arn: []const u8,
    resource_configuration: ResourceConfiguration,
    variables: ?[]Variable = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image = "image",
            .execution_role_arn = "executionRoleArn",
            .resource_configuration = "resourceConfiguration",
            .variables = "variables",
        };
        return @field(mappings, field_name);
    }
};

pub const Variable = struct {
    name: []const u8,
    string_value: ?[]const u8 = null,
    double_value: ?f64 = null,
    dataset_content_version_value: ?DatasetContentVersionValue = null,
    output_file_uri_value: ?OutputFileUriValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .string_value = "stringValue",
            .double_value = "doubleValue",
            .dataset_content_version_value = "datasetContentVersionValue",
            .output_file_uri_value = "outputFileUriValue",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputFileUriValue = struct {
    file_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_name = "fileName",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetContentVersionValue = struct {
    dataset_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dataset_name = "datasetName",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceConfiguration = struct {
    compute_type: []const u8,
    volume_size_in_gb: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compute_type = "computeType",
            .volume_size_in_gb = "volumeSizeInGB",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlQueryDatasetAction = struct {
    sql_query: []const u8,
    filters: ?[]QueryFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sql_query = "sqlQuery",
            .filters = "filters",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryFilter = struct {
    delta_time: ?DeltaTime = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delta_time = "deltaTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DeltaTime = struct {
    offset_seconds: i64,
    time_expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .offset_seconds = "offsetSeconds",
            .time_expression = "timeExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelStorage = struct {
    service_managed_s3: ?ServiceManagedChannelS3Storage = null,
    customer_managed_s3: ?CustomerManagedChannelS3Storage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_managed_s3 = "serviceManagedS3",
            .customer_managed_s3 = "customerManagedS3",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerManagedChannelS3Storage = struct {
    bucket: []const u8,
    key_prefix: ?[]const u8 = null,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key_prefix = "keyPrefix",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceManagedChannelS3Storage = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingOptions = struct {
    role_arn: []const u8,
    level: []const u8,
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .level = "level",
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ReprocessingSummary = struct {
    id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    creation_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .status = "status",
            .creation_time = "creationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DatastorePartitions = struct {
    partitions: ?[]DatastorePartition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .partitions = "partitions",
        };
        return @field(mappings, field_name);
    }
};

pub const DatastorePartition = struct {
    attribute_partition: ?Partition = null,
    timestamp_partition: ?TimestampPartition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_partition = "attributePartition",
            .timestamp_partition = "timestampPartition",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestampPartition = struct {
    attribute_name: []const u8,
    timestamp_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "attributeName",
            .timestamp_format = "timestampFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const Partition = struct {
    attribute_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "attributeName",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetContentStatus = struct {
    state: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const EstimatedResourceSize = struct {
    estimated_size_in_bytes: ?f64 = null,
    estimated_on: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .estimated_size_in_bytes = "estimatedSizeInBytes",
            .estimated_on = "estimatedOn",
        };
        return @field(mappings, field_name);
    }
};
