const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-06-17";
pub const sdk_id: []const u8 = "IoTFleetWise";
pub const arn_namespace: ?[]const u8 = "iotfleetwise";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "iotfleetwise";
pub const name: []const u8 = "IoTAutobahnControlPlane";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2021-06-17",
    sdk_id: []const u8 = "IoTFleetWise",
    arn_namespace: ?[]const u8 = "iotfleetwise",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "iotfleetwise",
    name: []const u8 = "IoTAutobahnControlPlane",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const batch_create_vehicle: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/vehicles",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchCreateVehicle",
    Request: type = struct {
        vehicles: []struct {
            vehicle_name: []const u8,
            model_manifest_arn: []const u8,
            decoder_manifest_arn: []const u8,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            association_behavior: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vehicle_name = "vehicleName",
                    .model_manifest_arn = "modelManifestArn",
                    .decoder_manifest_arn = "decoderManifestArn",
                    .attributes = "attributes",
                    .association_behavior = "associationBehavior",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vehicles = "vehicles",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_vehicle) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_vehicle };
        }
    },
    Response: type = struct {
        vehicles: ?[]struct {
            vehicle_name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            thing_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vehicle_name = "vehicleName",
                    .arn = "arn",
                    .thing_arn = "thingArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            vehicle_name: ?[]const u8 = null,
            code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vehicle_name = "vehicleName",
                    .code = "code",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vehicles = "vehicles",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        LimitExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_update_vehicle: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/vehicles",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateVehicle",
    Request: type = struct {
        vehicles: []struct {
            vehicle_name: []const u8,
            model_manifest_arn: ?[]const u8 = null,
            decoder_manifest_arn: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            attribute_update_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vehicle_name = "vehicleName",
                    .model_manifest_arn = "modelManifestArn",
                    .decoder_manifest_arn = "decoderManifestArn",
                    .attributes = "attributes",
                    .attribute_update_mode = "attributeUpdateMode",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vehicles = "vehicles",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_vehicle) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_vehicle };
        }
    },
    Response: type = struct {
        vehicles: ?[]struct {
            vehicle_name: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vehicle_name = "vehicleName",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            vehicle_name: ?[]const u8 = null,
            code: ?i64 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vehicle_name = "vehicleName",
                    .code = "code",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vehicles = "vehicles",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_encryption_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/encryptionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEncryptionConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_encryption_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_encryption_configuration };
        }
    },
    Response: type = struct {
        kms_key_id: ?[]const u8 = null,
        encryption_status: []const u8,
        encryption_type: []const u8,
        error_message: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "kmsKeyId",
                .encryption_status = "encryptionStatus",
                .encryption_type = "encryptionType",
                .error_message = "errorMessage",
                .creation_time = "creationTime",
                .last_modification_time = "lastModificationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_logging_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/loggingOptions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLoggingOptions",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = get_logging_options };
        }
    },
    Response: type = struct {
        cloud_watch_log_delivery: CloudWatchLogDeliveryOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_watch_log_delivery = "cloudWatchLogDelivery",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Throttling,
    },
} = .{};
pub const get_register_account_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/account/registration_status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRegisterAccountStatus",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_register_account_status) } {
            return .{ .service_metadata = service_metadata, .action = get_register_account_status };
        }
    },
    Response: type = struct {
        customer_account_id: []const u8,
        account_status: []const u8,
        timestream_registration_response: ?struct {
            timestream_database_name: []const u8,
            timestream_table_name: []const u8,
            timestream_database_arn: ?[]const u8 = null,
            timestream_table_arn: ?[]const u8 = null,
            registration_status: []const u8,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestream_database_name = "timestreamDatabaseName",
                    .timestream_table_name = "timestreamTableName",
                    .timestream_database_arn = "timestreamDatabaseArn",
                    .timestream_table_arn = "timestreamTableArn",
                    .registration_status = "registrationStatus",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        iam_registration_response: struct {
            role_arn: []const u8,
            registration_status: []const u8,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .role_arn = "roleArn",
                    .registration_status = "registrationStatus",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        },
        creation_time: i64,
        last_modification_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_account_id = "customerAccountId",
                .account_status = "accountStatus",
                .timestream_registration_response = "timestreamRegistrationResponse",
                .iam_registration_response = "iamRegistrationResponse",
                .creation_time = "creationTime",
                .last_modification_time = "lastModificationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_vehicle_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vehicles/{vehicleName}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVehicleStatus",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        vehicle_name: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .vehicle_name = "vehicleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vehicle_status) } {
            return .{ .service_metadata = service_metadata, .action = get_vehicle_status };
        }
    },
    Response: type = struct {
        campaigns: ?[]struct {
            campaign_name: ?[]const u8 = null,
            vehicle_name: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .campaign_name = "campaignName",
                    .vehicle_name = "vehicleName",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaigns = "campaigns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_encryption_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/encryptionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEncryptionConfiguration",
    Request: type = struct {
        kms_key_id: ?[]const u8 = null,
        encryption_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "kmsKeyId",
                .encryption_type = "encryptionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_encryption_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_encryption_configuration };
        }
    },
    Response: type = struct {
        kms_key_id: ?[]const u8 = null,
        encryption_status: []const u8,
        encryption_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "kmsKeyId",
                .encryption_status = "encryptionStatus",
                .encryption_type = "encryptionType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_logging_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/loggingOptions",
        .success_code = 204,
    };

    action_name: []const u8 = "PutLoggingOptions",
    Request: type = struct {
        cloud_watch_log_delivery: CloudWatchLogDeliveryOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_watch_log_delivery = "cloudWatchLogDelivery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = put_logging_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const register_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/account/registration",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterAccount",
    Request: type = struct {
        timestream_resources: ?TimestreamResources = null,
        iam_resources: ?IamResources = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .timestream_resources = "timestreamResources",
                .iam_resources = "iamResources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_account) } {
            return .{ .service_metadata = service_metadata, .action = register_account };
        }
    },
    Response: type = struct {
        register_account_status: []const u8,
        timestream_resources: ?TimestreamResources = null,
        iam_resources: IamResources,
        creation_time: i64,
        last_modification_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .register_account_status = "registerAccountStatus",
                .timestream_resources = "timestreamResources",
                .iam_resources = "iamResources",
                .creation_time = "creationTime",
                .last_modification_time = "lastModificationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const IamResources = struct {
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestreamResources = struct {
    timestream_database_name: []const u8,
    timestream_table_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestream_database_name = "timestreamDatabaseName",
            .timestream_table_name = "timestreamTableName",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogDeliveryOptions = struct {
    log_type: []const u8,
    log_group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_type = "logType",
            .log_group_name = "logGroupName",
        };
        return @field(mappings, field_name);
    }
};
