const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-11-29";
pub const sdk_id: []const u8 = "IoTTwinMaker";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "iottwinmaker";
pub const sigv4_name: []const u8 = "iottwinmaker";
pub const name: []const u8 = "AWSIoTTwinMaker";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-11-29",
    sdk_id: []const u8 = "IoTTwinMaker",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "iottwinmaker",
    sigv4_name: []const u8 = "iottwinmaker",
    name: []const u8 = "AWSIoTTwinMaker",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_put_property_values: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/entity-properties",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchPutPropertyValues",
    Request: type = struct {
        workspace_id: []const u8,
        entries: []PropertyValueEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .entries = "entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_property_values) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_property_values };
        }
    },
    Response: type = struct {
        error_entries: []struct {
            errors: []struct {
                error_code: []const u8,
                error_message: []const u8,
                entry: PropertyValueEntry,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "errorCode",
                        .error_message = "errorMessage",
                        .entry = "entry",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .errors = "errors",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_metadata_transfer_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/metadata-transfer-jobs/{metadataTransferJobId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelMetadataTransferJob",
    Request: type = struct {
        metadata_transfer_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_transfer_job_id = "metadataTransferJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_metadata_transfer_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_metadata_transfer_job };
        }
    },
    Response: type = struct {
        metadata_transfer_job_id: []const u8,
        arn: []const u8,
        update_date_time: i64,
        status: MetadataTransferJobStatus,
        progress: ?MetadataTransferJobProgress = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_transfer_job_id = "metadataTransferJobId",
                .arn = "arn",
                .update_date_time = "updateDateTime",
                .status = "status",
                .progress = "progress",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_component_type: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/component-types/{componentTypeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateComponentType",
    Request: type = struct {
        workspace_id: []const u8,
        is_singleton: ?bool = null,
        component_type_id: []const u8,
        description: ?[]const u8 = null,
        property_definitions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PropertyDefinitionRequest = null,
        } = null,
        extends_from: ?[][]const u8 = null,
        functions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?FunctionRequest = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        property_groups: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PropertyGroupRequest = null,
        } = null,
        component_type_name: ?[]const u8 = null,
        composite_component_types: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CompositeComponentTypeRequest = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .is_singleton = "isSingleton",
                .component_type_id = "componentTypeId",
                .description = "description",
                .property_definitions = "propertyDefinitions",
                .extends_from = "extendsFrom",
                .functions = "functions",
                .tags = "tags",
                .property_groups = "propertyGroups",
                .component_type_name = "componentTypeName",
                .composite_component_types = "compositeComponentTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "property_definitions", field_name))
                return try serializeMap(self.property_definitions, self.fieldNameFor("property_definitions"), options, out_stream);
            if (std.mem.eql(u8, "functions", field_name))
                return try serializeMap(self.functions, self.fieldNameFor("functions"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "property_groups", field_name))
                return try serializeMap(self.property_groups, self.fieldNameFor("property_groups"), options, out_stream);
            if (std.mem.eql(u8, "composite_component_types", field_name))
                return try serializeMap(self.composite_component_types, self.fieldNameFor("composite_component_types"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_component_type) } {
            return .{ .service_metadata = service_metadata, .action = create_component_type };
        }
    },
    Response: type = struct {
        arn: []const u8,
        creation_date_time: i64,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .creation_date_time = "creationDateTime",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_entity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/entities",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEntity",
    Request: type = struct {
        workspace_id: []const u8,
        entity_id: ?[]const u8 = null,
        entity_name: []const u8,
        description: ?[]const u8 = null,
        components: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                description: ?[]const u8 = null,
                component_type_id: ?[]const u8 = null,
                properties: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?PropertyRequest = null,
                } = null,
                property_groups: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?ComponentPropertyGroupRequest = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .description = "description",
                        .component_type_id = "componentTypeId",
                        .properties = "properties",
                        .property_groups = "propertyGroups",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "properties", field_name))
                        return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
                    if (std.mem.eql(u8, "property_groups", field_name))
                        return try serializeMap(self.property_groups, self.fieldNameFor("property_groups"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        composite_components: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                description: ?[]const u8 = null,
                properties: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?PropertyRequest = null,
                } = null,
                property_groups: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?ComponentPropertyGroupRequest = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .description = "description",
                        .properties = "properties",
                        .property_groups = "propertyGroups",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "properties", field_name))
                        return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
                    if (std.mem.eql(u8, "property_groups", field_name))
                        return try serializeMap(self.property_groups, self.fieldNameFor("property_groups"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        parent_entity_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .entity_id = "entityId",
                .entity_name = "entityName",
                .description = "description",
                .components = "components",
                .composite_components = "compositeComponents",
                .parent_entity_id = "parentEntityId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "components", field_name))
                return try serializeMap(self.components, self.fieldNameFor("components"), options, out_stream);
            if (std.mem.eql(u8, "composite_components", field_name))
                return try serializeMap(self.composite_components, self.fieldNameFor("composite_components"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_entity) } {
            return .{ .service_metadata = service_metadata, .action = create_entity };
        }
    },
    Response: type = struct {
        entity_id: []const u8,
        arn: []const u8,
        creation_date_time: i64,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_id = "entityId",
                .arn = "arn",
                .creation_date_time = "creationDateTime",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_metadata_transfer_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metadata-transfer-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMetadataTransferJob",
    Request: type = struct {
        metadata_transfer_job_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        sources: []SourceConfiguration,
        destination: DestinationConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_transfer_job_id = "metadataTransferJobId",
                .description = "description",
                .sources = "sources",
                .destination = "destination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_metadata_transfer_job) } {
            return .{ .service_metadata = service_metadata, .action = create_metadata_transfer_job };
        }
    },
    Response: type = struct {
        metadata_transfer_job_id: []const u8,
        arn: []const u8,
        creation_date_time: i64,
        status: MetadataTransferJobStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_transfer_job_id = "metadataTransferJobId",
                .arn = "arn",
                .creation_date_time = "creationDateTime",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_scene: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/scenes",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateScene",
    Request: type = struct {
        workspace_id: []const u8,
        scene_id: []const u8,
        content_location: []const u8,
        description: ?[]const u8 = null,
        capabilities: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        scene_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .scene_id = "sceneId",
                .content_location = "contentLocation",
                .description = "description",
                .capabilities = "capabilities",
                .tags = "tags",
                .scene_metadata = "sceneMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "scene_metadata", field_name))
                return try serializeMap(self.scene_metadata, self.fieldNameFor("scene_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_scene) } {
            return .{ .service_metadata = service_metadata, .action = create_scene };
        }
    },
    Response: type = struct {
        arn: []const u8,
        creation_date_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_sync_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/sync-jobs/{syncSource}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSyncJob",
    Request: type = struct {
        workspace_id: []const u8,
        sync_source: []const u8,
        sync_role: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .sync_source = "syncSource",
                .sync_role = "syncRole",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = create_sync_job };
        }
    },
    Response: type = struct {
        arn: []const u8,
        creation_date_time: i64,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .creation_date_time = "creationDateTime",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_workspace: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorkspace",
    Request: type = struct {
        workspace_id: []const u8,
        description: ?[]const u8 = null,
        s3_location: ?[]const u8 = null,
        role: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .description = "description",
                .s3_location = "s3Location",
                .role = "role",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workspace) } {
            return .{ .service_metadata = service_metadata, .action = create_workspace };
        }
    },
    Response: type = struct {
        arn: []const u8,
        creation_date_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_component_type: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workspaces/{workspaceId}/component-types/{componentTypeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteComponentType",
    Request: type = struct {
        workspace_id: []const u8,
        component_type_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .component_type_id = "componentTypeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_component_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_component_type };
        }
    },
    Response: type = struct {
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_entity: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workspaces/{workspaceId}/entities/{entityId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEntity",
    Request: type = struct {
        workspace_id: []const u8,
        entity_id: []const u8,
        is_recursive: ?bool = null,

        pub const http_query = .{
            .is_recursive = "isRecursive",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .entity_id = "entityId",
                .is_recursive = "isRecursive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_entity) } {
            return .{ .service_metadata = service_metadata, .action = delete_entity };
        }
    },
    Response: type = struct {
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_scene: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workspaces/{workspaceId}/scenes/{sceneId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteScene",
    Request: type = struct {
        workspace_id: []const u8,
        scene_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .scene_id = "sceneId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scene) } {
            return .{ .service_metadata = service_metadata, .action = delete_scene };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_sync_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workspaces/{workspaceId}/sync-jobs/{syncSource}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSyncJob",
    Request: type = struct {
        workspace_id: []const u8,
        sync_source: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .sync_source = "syncSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_sync_job };
        }
    },
    Response: type = struct {
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_workspace: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workspaces/{workspaceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkspace",
    Request: type = struct {
        workspace_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workspace) } {
            return .{ .service_metadata = service_metadata, .action = delete_workspace };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const execute_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queries/execution",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteQuery",
    Request: type = struct {
        workspace_id: []const u8,
        query_statement: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .query_statement = "queryStatement",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_query };
        }
    },
    Response: type = struct {
        column_descriptions: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        rows: ?[]struct {
            row_data: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .row_data = "rowData",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_descriptions = "columnDescriptions",
                .rows = "rows",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        QueryTimeout,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_component_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workspaces/{workspaceId}/component-types/{componentTypeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComponentType",
    Request: type = struct {
        workspace_id: []const u8,
        component_type_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .component_type_id = "componentTypeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_component_type) } {
            return .{ .service_metadata = service_metadata, .action = get_component_type };
        }
    },
    Response: type = struct {
        workspace_id: []const u8,
        is_singleton: ?bool = null,
        component_type_id: []const u8,
        description: ?[]const u8 = null,
        property_definitions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PropertyDefinitionResponse = null,
        } = null,
        extends_from: ?[][]const u8 = null,
        functions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                required_properties: ?[][]const u8 = null,
                scope: ?[]const u8 = null,
                implemented_by: ?DataConnector = null,
                is_inherited: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .required_properties = "requiredProperties",
                        .scope = "scope",
                        .implemented_by = "implementedBy",
                        .is_inherited = "isInherited",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        creation_date_time: i64,
        update_date_time: i64,
        arn: []const u8,
        is_abstract: ?bool = null,
        is_schema_initialized: ?bool = null,
        status: ?Status = null,
        property_groups: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                group_type: []const u8,
                property_names: [][]const u8,
                is_inherited: bool,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group_type = "groupType",
                        .property_names = "propertyNames",
                        .is_inherited = "isInherited",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        sync_source: ?[]const u8 = null,
        component_type_name: ?[]const u8 = null,
        composite_component_types: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                component_type_id: ?[]const u8 = null,
                is_inherited: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .component_type_id = "componentTypeId",
                        .is_inherited = "isInherited",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .is_singleton = "isSingleton",
                .component_type_id = "componentTypeId",
                .description = "description",
                .property_definitions = "propertyDefinitions",
                .extends_from = "extendsFrom",
                .functions = "functions",
                .creation_date_time = "creationDateTime",
                .update_date_time = "updateDateTime",
                .arn = "arn",
                .is_abstract = "isAbstract",
                .is_schema_initialized = "isSchemaInitialized",
                .status = "status",
                .property_groups = "propertyGroups",
                .sync_source = "syncSource",
                .component_type_name = "componentTypeName",
                .composite_component_types = "compositeComponentTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "property_definitions", field_name))
                return try serializeMap(self.property_definitions, self.fieldNameFor("property_definitions"), options, out_stream);
            if (std.mem.eql(u8, "functions", field_name))
                return try serializeMap(self.functions, self.fieldNameFor("functions"), options, out_stream);
            if (std.mem.eql(u8, "property_groups", field_name))
                return try serializeMap(self.property_groups, self.fieldNameFor("property_groups"), options, out_stream);
            if (std.mem.eql(u8, "composite_component_types", field_name))
                return try serializeMap(self.composite_component_types, self.fieldNameFor("composite_component_types"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_entity: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workspaces/{workspaceId}/entities/{entityId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEntity",
    Request: type = struct {
        workspace_id: []const u8,
        entity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .entity_id = "entityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_entity) } {
            return .{ .service_metadata = service_metadata, .action = get_entity };
        }
    },
    Response: type = struct {
        entity_id: []const u8,
        entity_name: []const u8,
        arn: []const u8,
        status: Status,
        workspace_id: []const u8,
        description: ?[]const u8 = null,
        components: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                component_name: ?[]const u8 = null,
                description: ?[]const u8 = null,
                component_type_id: ?[]const u8 = null,
                status: ?Status = null,
                defined_in: ?[]const u8 = null,
                properties: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?struct {
                        definition: ?PropertyDefinitionResponse = null,
                        value: ?DataValue = null,
                        are_all_property_values_returned: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .definition = "definition",
                                .value = "value",
                                .are_all_property_values_returned = "areAllPropertyValuesReturned",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                } = null,
                property_groups: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?ComponentPropertyGroupResponse = null,
                } = null,
                sync_source: ?[]const u8 = null,
                are_all_properties_returned: ?bool = null,
                composite_components: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?ComponentSummary = null,
                } = null,
                are_all_composite_components_returned: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .component_name = "componentName",
                        .description = "description",
                        .component_type_id = "componentTypeId",
                        .status = "status",
                        .defined_in = "definedIn",
                        .properties = "properties",
                        .property_groups = "propertyGroups",
                        .sync_source = "syncSource",
                        .are_all_properties_returned = "areAllPropertiesReturned",
                        .composite_components = "compositeComponents",
                        .are_all_composite_components_returned = "areAllCompositeComponentsReturned",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "properties", field_name))
                        return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
                    if (std.mem.eql(u8, "property_groups", field_name))
                        return try serializeMap(self.property_groups, self.fieldNameFor("property_groups"), options, out_stream);
                    if (std.mem.eql(u8, "composite_components", field_name))
                        return try serializeMap(self.composite_components, self.fieldNameFor("composite_components"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        parent_entity_id: []const u8,
        has_child_entities: bool,
        creation_date_time: i64,
        update_date_time: i64,
        sync_source: ?[]const u8 = null,
        are_all_components_returned: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_id = "entityId",
                .entity_name = "entityName",
                .arn = "arn",
                .status = "status",
                .workspace_id = "workspaceId",
                .description = "description",
                .components = "components",
                .parent_entity_id = "parentEntityId",
                .has_child_entities = "hasChildEntities",
                .creation_date_time = "creationDateTime",
                .update_date_time = "updateDateTime",
                .sync_source = "syncSource",
                .are_all_components_returned = "areAllComponentsReturned",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "components", field_name))
                return try serializeMap(self.components, self.fieldNameFor("components"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_metadata_transfer_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/metadata-transfer-jobs/{metadataTransferJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMetadataTransferJob",
    Request: type = struct {
        metadata_transfer_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_transfer_job_id = "metadataTransferJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_metadata_transfer_job) } {
            return .{ .service_metadata = service_metadata, .action = get_metadata_transfer_job };
        }
    },
    Response: type = struct {
        metadata_transfer_job_id: []const u8,
        arn: []const u8,
        description: ?[]const u8 = null,
        sources: []SourceConfiguration,
        destination: DestinationConfiguration,
        metadata_transfer_job_role: []const u8,
        report_url: ?[]const u8 = null,
        creation_date_time: i64,
        update_date_time: i64,
        status: MetadataTransferJobStatus,
        progress: ?MetadataTransferJobProgress = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_transfer_job_id = "metadataTransferJobId",
                .arn = "arn",
                .description = "description",
                .sources = "sources",
                .destination = "destination",
                .metadata_transfer_job_role = "metadataTransferJobRole",
                .report_url = "reportUrl",
                .creation_date_time = "creationDateTime",
                .update_date_time = "updateDateTime",
                .status = "status",
                .progress = "progress",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_pricing_plan: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/pricingplan",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPricingPlan",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pricing_plan) } {
            return .{ .service_metadata = service_metadata, .action = get_pricing_plan };
        }
    },
    Response: type = struct {
        current_pricing_plan: PricingPlan,
        pending_pricing_plan: ?PricingPlan = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .current_pricing_plan = "currentPricingPlan",
                .pending_pricing_plan = "pendingPricingPlan",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_property_value: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/entity-properties/value",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPropertyValue",
    Request: type = struct {
        component_name: ?[]const u8 = null,
        component_path: ?[]const u8 = null,
        component_type_id: ?[]const u8 = null,
        entity_id: ?[]const u8 = null,
        selected_properties: [][]const u8,
        workspace_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        property_group_name: ?[]const u8 = null,
        tabular_conditions: ?struct {
            order_by: ?[]struct {
                order: ?[]const u8 = null,
                property_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .order = "order",
                        .property_name = "propertyName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            property_filters: ?[]PropertyFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .order_by = "orderBy",
                    .property_filters = "propertyFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_name = "componentName",
                .component_path = "componentPath",
                .component_type_id = "componentTypeId",
                .entity_id = "entityId",
                .selected_properties = "selectedProperties",
                .workspace_id = "workspaceId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .property_group_name = "propertyGroupName",
                .tabular_conditions = "tabularConditions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_property_value) } {
            return .{ .service_metadata = service_metadata, .action = get_property_value };
        }
    },
    Response: type = struct {
        property_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                property_reference: EntityPropertyReference,
                property_value: ?DataValue = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .property_reference = "propertyReference",
                        .property_value = "propertyValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        next_token: ?[]const u8 = null,
        tabular_property_values: ?[][][]struct {
            key: ?[]const u8 = null,
            value: ?DataValue = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .property_values = "propertyValues",
                .next_token = "nextToken",
                .tabular_property_values = "tabularPropertyValues",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "property_values", field_name))
                return try serializeMap(self.property_values, self.fieldNameFor("property_values"), options, out_stream);
            if (std.mem.eql(u8, "tabular_property_values", field_name))
                return try serializeMap(self.tabular_property_values, self.fieldNameFor("tabular_property_values"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConnectorFailure,
        ConnectorTimeout,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_property_value_history: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/entity-properties/history",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPropertyValueHistory",
    Request: type = struct {
        workspace_id: []const u8,
        entity_id: ?[]const u8 = null,
        component_name: ?[]const u8 = null,
        component_path: ?[]const u8 = null,
        component_type_id: ?[]const u8 = null,
        selected_properties: [][]const u8,
        property_filters: ?[]PropertyFilter = null,
        start_date_time: ?i64 = null,
        end_date_time: ?i64 = null,
        interpolation: ?struct {
            interpolation_type: ?[]const u8 = null,
            interval_in_seconds: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .interpolation_type = "interpolationType",
                    .interval_in_seconds = "intervalInSeconds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        order_by_time: ?[]const u8 = null,
        start_time: ?[]const u8 = null,
        end_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .entity_id = "entityId",
                .component_name = "componentName",
                .component_path = "componentPath",
                .component_type_id = "componentTypeId",
                .selected_properties = "selectedProperties",
                .property_filters = "propertyFilters",
                .start_date_time = "startDateTime",
                .end_date_time = "endDateTime",
                .interpolation = "interpolation",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .order_by_time = "orderByTime",
                .start_time = "startTime",
                .end_time = "endTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_property_value_history) } {
            return .{ .service_metadata = service_metadata, .action = get_property_value_history };
        }
    },
    Response: type = struct {
        property_values: []struct {
            entity_property_reference: EntityPropertyReference,
            values: ?[]PropertyValue = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entity_property_reference = "entityPropertyReference",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .property_values = "propertyValues",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConnectorFailure,
        ConnectorTimeout,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_scene: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workspaces/{workspaceId}/scenes/{sceneId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetScene",
    Request: type = struct {
        workspace_id: []const u8,
        scene_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .scene_id = "sceneId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_scene) } {
            return .{ .service_metadata = service_metadata, .action = get_scene };
        }
    },
    Response: type = struct {
        workspace_id: []const u8,
        scene_id: []const u8,
        content_location: []const u8,
        arn: []const u8,
        creation_date_time: i64,
        update_date_time: i64,
        description: ?[]const u8 = null,
        capabilities: ?[][]const u8 = null,
        scene_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        generated_scene_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        @"error": ?struct {
            code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "code",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .scene_id = "sceneId",
                .content_location = "contentLocation",
                .arn = "arn",
                .creation_date_time = "creationDateTime",
                .update_date_time = "updateDateTime",
                .description = "description",
                .capabilities = "capabilities",
                .scene_metadata = "sceneMetadata",
                .generated_scene_metadata = "generatedSceneMetadata",
                .@"error" = "error",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "scene_metadata", field_name))
                return try serializeMap(self.scene_metadata, self.fieldNameFor("scene_metadata"), options, out_stream);
            if (std.mem.eql(u8, "generated_scene_metadata", field_name))
                return try serializeMap(self.generated_scene_metadata, self.fieldNameFor("generated_scene_metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sync_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sync-jobs/{syncSource}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSyncJob",
    Request: type = struct {
        sync_source: []const u8,
        workspace_id: ?[]const u8 = null,

        pub const http_query = .{
            .workspace_id = "workspace",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_source = "syncSource",
                .workspace_id = "workspaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = get_sync_job };
        }
    },
    Response: type = struct {
        arn: []const u8,
        workspace_id: []const u8,
        sync_source: []const u8,
        sync_role: []const u8,
        status: SyncJobStatus,
        creation_date_time: i64,
        update_date_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .workspace_id = "workspaceId",
                .sync_source = "syncSource",
                .sync_role = "syncRole",
                .status = "status",
                .creation_date_time = "creationDateTime",
                .update_date_time = "updateDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_workspace: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workspaces/{workspaceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkspace",
    Request: type = struct {
        workspace_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workspace) } {
            return .{ .service_metadata = service_metadata, .action = get_workspace };
        }
    },
    Response: type = struct {
        workspace_id: []const u8,
        arn: []const u8,
        description: ?[]const u8 = null,
        linked_services: ?[][]const u8 = null,
        s3_location: ?[]const u8 = null,
        role: ?[]const u8 = null,
        creation_date_time: i64,
        update_date_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .arn = "arn",
                .description = "description",
                .linked_services = "linkedServices",
                .s3_location = "s3Location",
                .role = "role",
                .creation_date_time = "creationDateTime",
                .update_date_time = "updateDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_components: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/entities/{entityId}/components-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponents",
    Request: type = struct {
        workspace_id: []const u8,
        entity_id: []const u8,
        component_path: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .entity_id = "entityId",
                .component_path = "componentPath",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_components) } {
            return .{ .service_metadata = service_metadata, .action = list_components };
        }
    },
    Response: type = struct {
        component_summaries: []ComponentSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_summaries = "componentSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_component_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/component-types-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponentTypes",
    Request: type = struct {
        workspace_id: []const u8,
        filters: ?[]union {
            extends_from: ?[]const u8,
            namespace: ?[]const u8,
            is_abstract: ?bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .extends_from = "extendsFrom",
                    .namespace = "namespace",
                    .is_abstract = "isAbstract",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_component_types) } {
            return .{ .service_metadata = service_metadata, .action = list_component_types };
        }
    },
    Response: type = struct {
        workspace_id: []const u8,
        component_type_summaries: []struct {
            arn: []const u8,
            component_type_id: []const u8,
            creation_date_time: i64,
            update_date_time: i64,
            description: ?[]const u8 = null,
            status: ?Status = null,
            component_type_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .component_type_id = "componentTypeId",
                    .creation_date_time = "creationDateTime",
                    .update_date_time = "updateDateTime",
                    .description = "description",
                    .status = "status",
                    .component_type_name = "componentTypeName",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .component_type_summaries = "componentTypeSummaries",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_entities: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/entities-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEntities",
    Request: type = struct {
        workspace_id: []const u8,
        filters: ?[]union {
            parent_entity_id: ?[]const u8,
            component_type_id: ?[]const u8,
            external_id: ?[]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .parent_entity_id = "parentEntityId",
                    .component_type_id = "componentTypeId",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_entities) } {
            return .{ .service_metadata = service_metadata, .action = list_entities };
        }
    },
    Response: type = struct {
        entity_summaries: ?[]struct {
            entity_id: []const u8,
            entity_name: []const u8,
            arn: []const u8,
            parent_entity_id: ?[]const u8 = null,
            status: Status,
            description: ?[]const u8 = null,
            has_child_entities: ?bool = null,
            creation_date_time: i64,
            update_date_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entity_id = "entityId",
                    .entity_name = "entityName",
                    .arn = "arn",
                    .parent_entity_id = "parentEntityId",
                    .status = "status",
                    .description = "description",
                    .has_child_entities = "hasChildEntities",
                    .creation_date_time = "creationDateTime",
                    .update_date_time = "updateDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_summaries = "entitySummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_metadata_transfer_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metadata-transfer-jobs-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMetadataTransferJobs",
    Request: type = struct {
        source_type: []const u8,
        destination_type: []const u8,
        filters: ?[]union {
            workspace_id: ?[]const u8,
            state: ?[]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "workspaceId",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_type = "sourceType",
                .destination_type = "destinationType",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_metadata_transfer_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_metadata_transfer_jobs };
        }
    },
    Response: type = struct {
        metadata_transfer_job_summaries: []struct {
            metadata_transfer_job_id: []const u8,
            arn: []const u8,
            creation_date_time: i64,
            update_date_time: i64,
            status: MetadataTransferJobStatus,
            progress: ?MetadataTransferJobProgress = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metadata_transfer_job_id = "metadataTransferJobId",
                    .arn = "arn",
                    .creation_date_time = "creationDateTime",
                    .update_date_time = "updateDateTime",
                    .status = "status",
                    .progress = "progress",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_transfer_job_summaries = "metadataTransferJobSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_properties: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/properties-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProperties",
    Request: type = struct {
        workspace_id: []const u8,
        component_name: ?[]const u8 = null,
        component_path: ?[]const u8 = null,
        entity_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .component_name = "componentName",
                .component_path = "componentPath",
                .entity_id = "entityId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_properties) } {
            return .{ .service_metadata = service_metadata, .action = list_properties };
        }
    },
    Response: type = struct {
        property_summaries: []struct {
            definition: ?PropertyDefinitionResponse = null,
            property_name: []const u8,
            value: ?DataValue = null,
            are_all_property_values_returned: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .definition = "definition",
                    .property_name = "propertyName",
                    .value = "value",
                    .are_all_property_values_returned = "areAllPropertyValuesReturned",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .property_summaries = "propertySummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_scenes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/scenes-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListScenes",
    Request: type = struct {
        workspace_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_scenes) } {
            return .{ .service_metadata = service_metadata, .action = list_scenes };
        }
    },
    Response: type = struct {
        scene_summaries: ?[]struct {
            scene_id: []const u8,
            content_location: []const u8,
            arn: []const u8,
            creation_date_time: i64,
            update_date_time: i64,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scene_id = "sceneId",
                    .content_location = "contentLocation",
                    .arn = "arn",
                    .creation_date_time = "creationDateTime",
                    .update_date_time = "updateDateTime",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scene_summaries = "sceneSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sync_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/sync-jobs-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSyncJobs",
    Request: type = struct {
        workspace_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sync_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_sync_jobs };
        }
    },
    Response: type = struct {
        sync_job_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            workspace_id: ?[]const u8 = null,
            sync_source: ?[]const u8 = null,
            status: ?SyncJobStatus = null,
            creation_date_time: ?i64 = null,
            update_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .workspace_id = "workspaceId",
                    .sync_source = "syncSource",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .update_date_time = "updateDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_job_summaries = "syncJobSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sync_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces/{workspaceId}/sync-jobs/{syncSource}/resources-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSyncResources",
    Request: type = struct {
        workspace_id: []const u8,
        sync_source: []const u8,
        filters: ?[]union {
            state: ?[]const u8,
            resource_type: ?[]const u8,
            resource_id: ?[]const u8,
            external_id: ?[]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .state = "state",
                    .resource_type = "resourceType",
                    .resource_id = "resourceId",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .sync_source = "syncSource",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sync_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_sync_resources };
        }
    },
    Response: type = struct {
        sync_resources: ?[]struct {
            resource_type: ?[]const u8 = null,
            external_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            status: ?struct {
                state: ?[]const u8 = null,
                @"error": ?ErrorDetails = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state = "state",
                        .@"error" = "error",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            update_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "resourceType",
                    .external_id = "externalId",
                    .resource_id = "resourceId",
                    .status = "status",
                    .update_date_time = "updateDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_resources = "syncResources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
    },
} = .{};
pub const list_workspaces: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workspaces-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkspaces",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = list_workspaces };
        }
    },
    Response: type = struct {
        workspace_summaries: ?[]struct {
            workspace_id: []const u8,
            arn: []const u8,
            description: ?[]const u8 = null,
            linked_services: ?[][]const u8 = null,
            creation_date_time: i64,
            update_date_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "workspaceId",
                    .arn = "arn",
                    .description = "description",
                    .linked_services = "linkedServices",
                    .creation_date_time = "creationDateTime",
                    .update_date_time = "updateDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_summaries = "workspaceSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceARN",
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
    },
} = .{};
pub const update_component_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/workspaces/{workspaceId}/component-types/{componentTypeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateComponentType",
    Request: type = struct {
        workspace_id: []const u8,
        is_singleton: ?bool = null,
        component_type_id: []const u8,
        description: ?[]const u8 = null,
        property_definitions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PropertyDefinitionRequest = null,
        } = null,
        extends_from: ?[][]const u8 = null,
        functions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?FunctionRequest = null,
        } = null,
        property_groups: ?[]struct {
            key: ?[]const u8 = null,
            value: ?PropertyGroupRequest = null,
        } = null,
        component_type_name: ?[]const u8 = null,
        composite_component_types: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CompositeComponentTypeRequest = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .is_singleton = "isSingleton",
                .component_type_id = "componentTypeId",
                .description = "description",
                .property_definitions = "propertyDefinitions",
                .extends_from = "extendsFrom",
                .functions = "functions",
                .property_groups = "propertyGroups",
                .component_type_name = "componentTypeName",
                .composite_component_types = "compositeComponentTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "property_definitions", field_name))
                return try serializeMap(self.property_definitions, self.fieldNameFor("property_definitions"), options, out_stream);
            if (std.mem.eql(u8, "functions", field_name))
                return try serializeMap(self.functions, self.fieldNameFor("functions"), options, out_stream);
            if (std.mem.eql(u8, "property_groups", field_name))
                return try serializeMap(self.property_groups, self.fieldNameFor("property_groups"), options, out_stream);
            if (std.mem.eql(u8, "composite_component_types", field_name))
                return try serializeMap(self.composite_component_types, self.fieldNameFor("composite_component_types"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_component_type) } {
            return .{ .service_metadata = service_metadata, .action = update_component_type };
        }
    },
    Response: type = struct {
        workspace_id: []const u8,
        arn: []const u8,
        component_type_id: []const u8,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .arn = "arn",
                .component_type_id = "componentTypeId",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_entity: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/workspaces/{workspaceId}/entities/{entityId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEntity",
    Request: type = struct {
        workspace_id: []const u8,
        entity_id: []const u8,
        entity_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        component_updates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                update_type: ?[]const u8 = null,
                description: ?[]const u8 = null,
                component_type_id: ?[]const u8 = null,
                property_updates: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?PropertyRequest = null,
                } = null,
                property_group_updates: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?ComponentPropertyGroupRequest = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .update_type = "updateType",
                        .description = "description",
                        .component_type_id = "componentTypeId",
                        .property_updates = "propertyUpdates",
                        .property_group_updates = "propertyGroupUpdates",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "property_updates", field_name))
                        return try serializeMap(self.property_updates, self.fieldNameFor("property_updates"), options, out_stream);
                    if (std.mem.eql(u8, "property_group_updates", field_name))
                        return try serializeMap(self.property_group_updates, self.fieldNameFor("property_group_updates"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        composite_component_updates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                update_type: ?[]const u8 = null,
                description: ?[]const u8 = null,
                property_updates: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?PropertyRequest = null,
                } = null,
                property_group_updates: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?ComponentPropertyGroupRequest = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .update_type = "updateType",
                        .description = "description",
                        .property_updates = "propertyUpdates",
                        .property_group_updates = "propertyGroupUpdates",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "property_updates", field_name))
                        return try serializeMap(self.property_updates, self.fieldNameFor("property_updates"), options, out_stream);
                    if (std.mem.eql(u8, "property_group_updates", field_name))
                        return try serializeMap(self.property_group_updates, self.fieldNameFor("property_group_updates"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        parent_entity_update: ?struct {
            update_type: []const u8,
            parent_entity_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .update_type = "updateType",
                    .parent_entity_id = "parentEntityId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .entity_id = "entityId",
                .entity_name = "entityName",
                .description = "description",
                .component_updates = "componentUpdates",
                .composite_component_updates = "compositeComponentUpdates",
                .parent_entity_update = "parentEntityUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "component_updates", field_name))
                return try serializeMap(self.component_updates, self.fieldNameFor("component_updates"), options, out_stream);
            if (std.mem.eql(u8, "composite_component_updates", field_name))
                return try serializeMap(self.composite_component_updates, self.fieldNameFor("composite_component_updates"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_entity) } {
            return .{ .service_metadata = service_metadata, .action = update_entity };
        }
    },
    Response: type = struct {
        update_date_time: i64,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_date_time = "updateDateTime",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_pricing_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/pricingplan",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePricingPlan",
    Request: type = struct {
        pricing_mode: []const u8,
        bundle_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pricing_mode = "pricingMode",
                .bundle_names = "bundleNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pricing_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_pricing_plan };
        }
    },
    Response: type = struct {
        current_pricing_plan: PricingPlan,
        pending_pricing_plan: ?PricingPlan = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .current_pricing_plan = "currentPricingPlan",
                .pending_pricing_plan = "pendingPricingPlan",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_scene: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/workspaces/{workspaceId}/scenes/{sceneId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateScene",
    Request: type = struct {
        workspace_id: []const u8,
        scene_id: []const u8,
        content_location: ?[]const u8 = null,
        description: ?[]const u8 = null,
        capabilities: ?[][]const u8 = null,
        scene_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .scene_id = "sceneId",
                .content_location = "contentLocation",
                .description = "description",
                .capabilities = "capabilities",
                .scene_metadata = "sceneMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "scene_metadata", field_name))
                return try serializeMap(self.scene_metadata, self.fieldNameFor("scene_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_scene) } {
            return .{ .service_metadata = service_metadata, .action = update_scene };
        }
    },
    Response: type = struct {
        update_date_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_date_time = "updateDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_workspace: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/workspaces/{workspaceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWorkspace",
    Request: type = struct {
        workspace_id: []const u8,
        description: ?[]const u8 = null,
        role: ?[]const u8 = null,
        s3_location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "workspaceId",
                .description = "description",
                .role = "role",
                .s3_location = "s3Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workspace) } {
            return .{ .service_metadata = service_metadata, .action = update_workspace };
        }
    },
    Response: type = struct {
        update_date_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_date_time = "updateDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const PricingPlan = struct {
    billable_entity_count: ?i64 = null,
    bundle_information: ?BundleInformation = null,
    effective_date_time: i64,
    pricing_mode: []const u8,
    update_date_time: i64,
    update_reason: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .billable_entity_count = "billableEntityCount",
            .bundle_information = "bundleInformation",
            .effective_date_time = "effectiveDateTime",
            .pricing_mode = "pricingMode",
            .update_date_time = "updateDateTime",
            .update_reason = "updateReason",
        };
        return @field(mappings, field_name);
    }
};

pub const BundleInformation = struct {
    bundle_names: [][]const u8,
    pricing_tier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bundle_names = "bundleNames",
            .pricing_tier = "pricingTier",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentPropertyGroupRequest = struct {
    group_type: ?[]const u8 = null,
    property_names: ?[][]const u8 = null,
    update_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_type = "groupType",
            .property_names = "propertyNames",
            .update_type = "updateType",
        };
        return @field(mappings, field_name);
    }
};

pub const PropertyRequest = struct {
    definition: ?PropertyDefinitionRequest = null,
    value: ?DataValue = null,
    update_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .definition = "definition",
            .value = "value",
            .update_type = "updateType",
        };
        return @field(mappings, field_name);
    }
};

pub const DataValue = struct {
    boolean_value: ?bool = null,
    double_value: ?f64 = null,
    integer_value: ?i64 = null,
    long_value: ?i64 = null,
    string_value: ?[]const u8 = null,
    list_value: ?[]DataValue = null,
    map_value: ?[]struct {
        key: ?[]const u8 = null,
        value: ?DataValue = null,
    } = null,
    relationship_value: ?RelationshipValue = null,
    expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .boolean_value = "booleanValue",
            .double_value = "doubleValue",
            .integer_value = "integerValue",
            .long_value = "longValue",
            .string_value = "stringValue",
            .list_value = "listValue",
            .map_value = "mapValue",
            .relationship_value = "relationshipValue",
            .expression = "expression",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "map_value", field_name))
            return try serializeMap(self.map_value, self.fieldNameFor("map_value"), options, out_stream);
        return false;
    }
};

pub const RelationshipValue = struct {
    target_entity_id: ?[]const u8 = null,
    target_component_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_entity_id = "targetEntityId",
            .target_component_name = "targetComponentName",
        };
        return @field(mappings, field_name);
    }
};

pub const PropertyDefinitionRequest = struct {
    data_type: ?DataType = null,
    is_required_in_entity: ?bool = null,
    is_external_id: ?bool = null,
    is_stored_externally: ?bool = null,
    is_time_series: ?bool = null,
    default_value: ?DataValue = null,
    configuration: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_type = "dataType",
            .is_required_in_entity = "isRequiredInEntity",
            .is_external_id = "isExternalId",
            .is_stored_externally = "isStoredExternally",
            .is_time_series = "isTimeSeries",
            .default_value = "defaultValue",
            .configuration = "configuration",
            .display_name = "displayName",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "configuration", field_name))
            return try serializeMap(self.configuration, self.fieldNameFor("configuration"), options, out_stream);
        return false;
    }
};

pub const DataType = struct {
    type: []const u8,
    nested_type: ?DataType = null,
    allowed_values: ?[]DataValue = null,
    unit_of_measure: ?[]const u8 = null,
    relationship: ?Relationship = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .nested_type = "nestedType",
            .allowed_values = "allowedValues",
            .unit_of_measure = "unitOfMeasure",
            .relationship = "relationship",
        };
        return @field(mappings, field_name);
    }
};

pub const Relationship = struct {
    target_component_type_id: ?[]const u8 = null,
    relationship_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_component_type_id = "targetComponentTypeId",
            .relationship_type = "relationshipType",
        };
        return @field(mappings, field_name);
    }
};

pub const CompositeComponentTypeRequest = struct {
    component_type_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_type_id = "componentTypeId",
        };
        return @field(mappings, field_name);
    }
};

pub const PropertyGroupRequest = struct {
    group_type: ?[]const u8 = null,
    property_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_type = "groupType",
            .property_names = "propertyNames",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionRequest = struct {
    required_properties: ?[][]const u8 = null,
    scope: ?[]const u8 = null,
    implemented_by: ?DataConnector = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .required_properties = "requiredProperties",
            .scope = "scope",
            .implemented_by = "implementedBy",
        };
        return @field(mappings, field_name);
    }
};

pub const DataConnector = struct {
    lambda: ?LambdaFunction = null,
    is_native: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda = "lambda",
            .is_native = "isNative",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunction = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetails = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const SyncJobStatus = struct {
    state: ?[]const u8 = null,
    @"error": ?ErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const PropertyDefinitionResponse = struct {
    data_type: DataType,
    is_time_series: bool,
    is_required_in_entity: bool,
    is_external_id: bool,
    is_stored_externally: bool,
    is_imported: bool,
    is_final: bool,
    is_inherited: bool,
    default_value: ?DataValue = null,
    configuration: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_type = "dataType",
            .is_time_series = "isTimeSeries",
            .is_required_in_entity = "isRequiredInEntity",
            .is_external_id = "isExternalId",
            .is_stored_externally = "isStoredExternally",
            .is_imported = "isImported",
            .is_final = "isFinal",
            .is_inherited = "isInherited",
            .default_value = "defaultValue",
            .configuration = "configuration",
            .display_name = "displayName",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "configuration", field_name))
            return try serializeMap(self.configuration, self.fieldNameFor("configuration"), options, out_stream);
        return false;
    }
};

pub const MetadataTransferJobProgress = struct {
    total_count: ?i64 = null,
    succeeded_count: ?i64 = null,
    skipped_count: ?i64 = null,
    failed_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_count = "totalCount",
            .succeeded_count = "succeededCount",
            .skipped_count = "skippedCount",
            .failed_count = "failedCount",
        };
        return @field(mappings, field_name);
    }
};

pub const MetadataTransferJobStatus = struct {
    state: ?[]const u8 = null,
    @"error": ?ErrorDetails = null,
    queued_position: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .@"error" = "error",
            .queued_position = "queuedPosition",
        };
        return @field(mappings, field_name);
    }
};

pub const Status = struct {
    state: ?[]const u8 = null,
    @"error": ?ErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentSummary = struct {
    component_name: []const u8,
    component_type_id: []const u8,
    defined_in: ?[]const u8 = null,
    description: ?[]const u8 = null,
    property_groups: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ComponentPropertyGroupResponse = null,
    } = null,
    status: Status,
    sync_source: ?[]const u8 = null,
    component_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_name = "componentName",
            .component_type_id = "componentTypeId",
            .defined_in = "definedIn",
            .description = "description",
            .property_groups = "propertyGroups",
            .status = "status",
            .sync_source = "syncSource",
            .component_path = "componentPath",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "property_groups", field_name))
            return try serializeMap(self.property_groups, self.fieldNameFor("property_groups"), options, out_stream);
        return false;
    }
};

pub const ComponentPropertyGroupResponse = struct {
    group_type: []const u8,
    property_names: [][]const u8,
    is_inherited: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_type = "groupType",
            .property_names = "propertyNames",
            .is_inherited = "isInherited",
        };
        return @field(mappings, field_name);
    }
};

pub const PropertyValue = struct {
    timestamp: ?i64 = null,
    value: DataValue,
    time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp = "timestamp",
            .value = "value",
            .time = "time",
        };
        return @field(mappings, field_name);
    }
};

pub const EntityPropertyReference = struct {
    component_name: ?[]const u8 = null,
    component_path: ?[]const u8 = null,
    external_id_property: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    entity_id: ?[]const u8 = null,
    property_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_name = "componentName",
            .component_path = "componentPath",
            .external_id_property = "externalIdProperty",
            .entity_id = "entityId",
            .property_name = "propertyName",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "external_id_property", field_name))
            return try serializeMap(self.external_id_property, self.fieldNameFor("external_id_property"), options, out_stream);
        return false;
    }
};

pub const PropertyFilter = struct {
    property_name: ?[]const u8 = null,
    operator: ?[]const u8 = null,
    value: ?DataValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .property_name = "propertyName",
            .operator = "operator",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfiguration = struct {
    type: []const u8,
    s3_configuration: ?S3DestinationConfiguration = null,
    iot_twin_maker_configuration: ?IotTwinMakerDestinationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .s3_configuration = "s3Configuration",
            .iot_twin_maker_configuration = "iotTwinMakerConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IotTwinMakerDestinationConfiguration = struct {
    workspace: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workspace = "workspace",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationConfiguration = struct {
    location: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .location = "location",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConfiguration = struct {
    type: []const u8,
    s3_configuration: ?S3SourceConfiguration = null,
    iot_site_wise_configuration: ?IotSiteWiseSourceConfiguration = null,
    iot_twin_maker_configuration: ?IotTwinMakerSourceConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .s3_configuration = "s3Configuration",
            .iot_site_wise_configuration = "iotSiteWiseConfiguration",
            .iot_twin_maker_configuration = "iotTwinMakerConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IotTwinMakerSourceConfiguration = struct {
    workspace: []const u8,
    filters: ?[]IotTwinMakerSourceConfigurationFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workspace = "workspace",
            .filters = "filters",
        };
        return @field(mappings, field_name);
    }
};

pub const IotTwinMakerSourceConfigurationFilter = union {
    filter_by_component_type: ?FilterByComponentType,
    filter_by_entity: ?FilterByEntity,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_by_component_type = "filterByComponentType",
            .filter_by_entity = "filterByEntity",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterByEntity = struct {
    entity_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_id = "entityId",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterByComponentType = struct {
    component_type_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_type_id = "componentTypeId",
        };
        return @field(mappings, field_name);
    }
};

pub const IotSiteWiseSourceConfiguration = struct {
    filters: ?[]IotSiteWiseSourceConfigurationFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filters = "filters",
        };
        return @field(mappings, field_name);
    }
};

pub const IotSiteWiseSourceConfigurationFilter = union {
    filter_by_asset_model: ?FilterByAssetModel,
    filter_by_asset: ?FilterByAsset,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_by_asset_model = "filterByAssetModel",
            .filter_by_asset = "filterByAsset",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterByAsset = struct {
    asset_id: ?[]const u8 = null,
    asset_external_id: ?[]const u8 = null,
    include_offspring: ?bool = null,
    include_asset_model: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_id = "assetId",
            .asset_external_id = "assetExternalId",
            .include_offspring = "includeOffspring",
            .include_asset_model = "includeAssetModel",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterByAssetModel = struct {
    asset_model_id: ?[]const u8 = null,
    asset_model_external_id: ?[]const u8 = null,
    include_offspring: ?bool = null,
    include_assets: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_model_id = "assetModelId",
            .asset_model_external_id = "assetModelExternalId",
            .include_offspring = "includeOffspring",
            .include_assets = "includeAssets",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SourceConfiguration = struct {
    location: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .location = "location",
        };
        return @field(mappings, field_name);
    }
};

pub const PropertyValueEntry = struct {
    entity_property_reference: EntityPropertyReference,
    property_values: ?[]PropertyValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_property_reference = "entityPropertyReference",
            .property_values = "propertyValues",
        };
        return @field(mappings, field_name);
    }
};
