const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-14";
pub const sdk_id: []const u8 = "IoT 1Click Devices Service";
pub const arn_namespace: ?[]const u8 = "iot1click";
pub const endpoint_prefix: []const u8 = "devices.iot1click";
pub const sigv4_name: []const u8 = "iot1click";
pub const name: []const u8 = "IoT1ClickDevicesService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-14",
    sdk_id: []const u8 = "IoT 1Click Devices Service",
    arn_namespace: ?[]const u8 = "iot1click",
    endpoint_prefix: []const u8 = "devices.iot1click",
    sigv4_name: []const u8 = "iot1click",
    name: []const u8 = "IoT1ClickDevicesService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const claim_devices_by_claim_code: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/claims/{ClaimCode}",
        .success_code = 200,
    };

    action_name: []const u8 = "ClaimDevicesByClaimCode",
    Request: type = struct {
        claim_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .claim_code = "ClaimCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(claim_devices_by_claim_code) } {
            return .{ .service_metadata = service_metadata, .action = claim_devices_by_claim_code };
        }
    },
    Response: type = struct {
        claim_code: ?[]const u8 = null,
        total: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .claim_code = "claimCode",
                .total = "total",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalFailure,
        InvalidRequest,
    },
} = .{};
pub const describe_device: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/devices/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDevice",
    Request: type = struct {
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_device) } {
            return .{ .service_metadata = service_metadata, .action = describe_device };
        }
    },
    Response: type = struct {
        device_description: ?DeviceDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_description = "deviceDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const finalize_device_claim: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/devices/{DeviceId}/finalize-claim",
        .success_code = 200,
    };

    action_name: []const u8 = "FinalizeDeviceClaim",
    Request: type = struct {
        device_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(finalize_device_claim) } {
            return .{ .service_metadata = service_metadata, .action = finalize_device_claim };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        PreconditionFailed,
        ResourceConflict,
        ResourceNotFound,
    },
} = .{};
pub const get_device_methods: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/devices/{DeviceId}/methods",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeviceMethods",
    Request: type = struct {
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_methods) } {
            return .{ .service_metadata = service_metadata, .action = get_device_methods };
        }
    },
    Response: type = struct {
        device_methods: ?[]DeviceMethod = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_methods = "deviceMethods",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const initiate_device_claim: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/devices/{DeviceId}/initiate-claim",
        .success_code = 200,
    };

    action_name: []const u8 = "InitiateDeviceClaim",
    Request: type = struct {
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initiate_device_claim) } {
            return .{ .service_metadata = service_metadata, .action = initiate_device_claim };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
    },
} = .{};
pub const invoke_device_method: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/devices/{DeviceId}/methods",
        .success_code = 200,
    };

    action_name: []const u8 = "InvokeDeviceMethod",
    Request: type = struct {
        device_id: []const u8,
        device_method: ?DeviceMethod = null,
        device_method_parameters: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .device_method = "deviceMethod",
                .device_method_parameters = "deviceMethodParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invoke_device_method) } {
            return .{ .service_metadata = service_metadata, .action = invoke_device_method };
        }
    },
    Response: type = struct {
        device_method_response: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_method_response = "deviceMethodResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        PreconditionFailed,
        RangeNotSatisfiable,
        ResourceConflict,
        ResourceNotFound,
    },
} = .{};
pub const list_device_events: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/devices/{DeviceId}/events",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeviceEvents",
    Request: type = struct {
        device_id: []const u8,
        from_time_stamp: i64,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        to_time_stamp: i64,

        pub const http_query = .{
            .from_time_stamp = "fromTimeStamp",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .to_time_stamp = "toTimeStamp",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .from_time_stamp = "FromTimeStamp",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .to_time_stamp = "ToTimeStamp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_events) } {
            return .{ .service_metadata = service_metadata, .action = list_device_events };
        }
    },
    Response: type = struct {
        events: ?[]struct {
            device: ?struct {
                attributes: ?struct {

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{};
                        return @field(mappings, field_name);
                    }
                } = null,
                device_id: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attributes = "attributes",
                        .device_id = "deviceId",
                        .type = "type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            std_event: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device = "device",
                    .std_event = "stdEvent",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "events",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        RangeNotSatisfiable,
        ResourceNotFound,
    },
} = .{};
pub const list_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDevices",
    Request: type = struct {
        device_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .device_type = "deviceType",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_type = "DeviceType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_devices };
        }
    },
    Response: type = struct {
        devices: ?[]DeviceDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "devices",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        RangeNotSatisfiable,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const unclaim_device: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/devices/{DeviceId}/unclaim",
        .success_code = 200,
    };

    action_name: []const u8 = "UnclaimDevice",
    Request: type = struct {
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unclaim_device) } {
            return .{ .service_metadata = service_metadata, .action = unclaim_device };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_device_state: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/devices/{DeviceId}/state",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDeviceState",
    Request: type = struct {
        device_id: []const u8,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .enabled = "enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device_state) } {
            return .{ .service_metadata = service_metadata, .action = update_device_state };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};

pub const DeviceDescription = struct {
    arn: ?[]const u8 = null,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    device_id: ?[]const u8 = null,
    enabled: ?bool = null,
    remaining_life: ?f64 = null,
    type: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .attributes = "attributes",
            .device_id = "deviceId",
            .enabled = "enabled",
            .remaining_life = "remainingLife",
            .type = "type",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const DeviceMethod = struct {
    device_type: ?[]const u8 = null,
    method_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_type = "deviceType",
            .method_name = "methodName",
        };
        return @field(mappings, field_name);
    }
};
