const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-14";
pub const sdk_id: []const u8 = "IoT 1Click Projects";
pub const arn_namespace: ?[]const u8 = "iot1click";
pub const endpoint_prefix: []const u8 = "projects.iot1click";
pub const sigv4_name: []const u8 = "iot1click";
pub const name: []const u8 = "AWSIoT1ClickProjects";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-14",
    sdk_id: []const u8 = "IoT 1Click Projects",
    arn_namespace: ?[]const u8 = "iot1click",
    endpoint_prefix: []const u8 = "projects.iot1click",
    sigv4_name: []const u8 = "iot1click",
    name: []const u8 = "AWSIoT1ClickProjects",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_device_with_placement: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/projects/{projectName}/placements/{placementName}/devices/{deviceTemplateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateDeviceWithPlacement",
    Request: type = struct {
        project_name: []const u8,
        placement_name: []const u8,
        device_id: []const u8,
        device_template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "projectName",
                .placement_name = "placementName",
                .device_id = "deviceId",
                .device_template_name = "deviceTemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_device_with_placement) } {
            return .{ .service_metadata = service_metadata, .action = associate_device_with_placement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
    },
} = .{};
pub const create_placement: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/projects/{projectName}/placements",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePlacement",
    Request: type = struct {
        placement_name: []const u8,
        project_name: []const u8,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_name = "placementName",
                .project_name = "projectName",
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_placement) } {
            return .{ .service_metadata = service_metadata, .action = create_placement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
    },
} = .{};
pub const create_project: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        project_name: []const u8,
        description: ?[]const u8 = null,
        placement_template: ?PlacementTemplate = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "projectName",
                .description = "description",
                .placement_template = "placementTemplate",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceConflict,
    },
} = .{};
pub const delete_placement: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/projects/{projectName}/placements/{placementName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePlacement",
    Request: type = struct {
        placement_name: []const u8,
        project_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_name = "placementName",
                .project_name = "projectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_placement) } {
            return .{ .service_metadata = service_metadata, .action = delete_placement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_project: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/projects/{projectName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        project_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "projectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_placement: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects/{projectName}/placements/{placementName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePlacement",
    Request: type = struct {
        placement_name: []const u8,
        project_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_name = "placementName",
                .project_name = "projectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_placement) } {
            return .{ .service_metadata = service_metadata, .action = describe_placement };
        }
    },
    Response: type = struct {
        placement: struct {
            project_name: []const u8,
            placement_name: []const u8,
            attributes: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            created_date: i64,
            updated_date: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_name = "projectName",
                    .placement_name = "placementName",
                    .attributes = "attributes",
                    .created_date = "createdDate",
                    .updated_date = "updatedDate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement = "placement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_project: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects/{projectName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProject",
    Request: type = struct {
        project_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "projectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project) } {
            return .{ .service_metadata = service_metadata, .action = describe_project };
        }
    },
    Response: type = struct {
        project: struct {
            arn: ?[]const u8 = null,
            project_name: []const u8,
            description: ?[]const u8 = null,
            created_date: i64,
            updated_date: i64,
            placement_template: ?PlacementTemplate = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .project_name = "projectName",
                    .description = "description",
                    .created_date = "createdDate",
                    .updated_date = "updatedDate",
                    .placement_template = "placementTemplate",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project = "project",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_device_from_placement: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/projects/{projectName}/placements/{placementName}/devices/{deviceTemplateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateDeviceFromPlacement",
    Request: type = struct {
        project_name: []const u8,
        placement_name: []const u8,
        device_template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "projectName",
                .placement_name = "placementName",
                .device_template_name = "deviceTemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_device_from_placement) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_device_from_placement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_devices_in_placement: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects/{projectName}/placements/{placementName}/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDevicesInPlacement",
    Request: type = struct {
        project_name: []const u8,
        placement_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "projectName",
                .placement_name = "placementName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_devices_in_placement) } {
            return .{ .service_metadata = service_metadata, .action = get_devices_in_placement };
        }
    },
    Response: type = struct {
        devices: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "devices",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "devices", field_name))
                return try serializeMap(self.devices, self.fieldNameFor("devices"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_placements: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects/{projectName}/placements",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPlacements",
    Request: type = struct {
        project_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "projectName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_placements) } {
            return .{ .service_metadata = service_metadata, .action = list_placements };
        }
    },
    Response: type = struct {
        placements: []struct {
            project_name: []const u8,
            placement_name: []const u8,
            created_date: i64,
            updated_date: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_name = "projectName",
                    .placement_name = "placementName",
                    .created_date = "createdDate",
                    .updated_date = "updatedDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placements = "placements",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_projects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        projects: []struct {
            arn: ?[]const u8 = null,
            project_name: []const u8,
            created_date: i64,
            updated_date: i64,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .project_name = "projectName",
                    .created_date = "createdDate",
                    .updated_date = "updatedDate",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .projects = "projects",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_placement: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/projects/{projectName}/placements/{placementName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePlacement",
    Request: type = struct {
        placement_name: []const u8,
        project_name: []const u8,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_name = "placementName",
                .project_name = "projectName",
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_placement) } {
            return .{ .service_metadata = service_metadata, .action = update_placement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const update_project: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/projects/{projectName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProject",
    Request: type = struct {
        project_name: []const u8,
        description: ?[]const u8 = null,
        placement_template: ?PlacementTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "projectName",
                .description = "description",
                .placement_template = "placementTemplate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_project) } {
            return .{ .service_metadata = service_metadata, .action = update_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};

pub const PlacementTemplate = struct {
    default_attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    device_templates: ?[]struct {
        key: ?[]const u8 = null,
        value: ?DeviceTemplate = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_attributes = "defaultAttributes",
            .device_templates = "deviceTemplates",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "default_attributes", field_name))
            return try serializeMap(self.default_attributes, self.fieldNameFor("default_attributes"), options, out_stream);
        if (std.mem.eql(u8, "device_templates", field_name))
            return try serializeMap(self.device_templates, self.fieldNameFor("device_templates"), options, out_stream);
        return false;
    }
};

pub const DeviceTemplate = struct {
    device_type: ?[]const u8 = null,
    callback_overrides: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_type = "deviceType",
            .callback_overrides = "callbackOverrides",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "callback_overrides", field_name))
            return try serializeMap(self.callback_overrides, self.fieldNameFor("callback_overrides"), options, out_stream);
        return false;
    }
};
