const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-05-28";
pub const sdk_id: []const u8 = "IoT Data Plane";
pub const arn_namespace: ?[]const u8 = "iotdata";
pub const endpoint_prefix: []const u8 = "data-ats.iot";
pub const sigv4_name: []const u8 = "iotdata";
pub const name: []const u8 = "IotMoonrakerService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-05-28",
    sdk_id: []const u8 = "IoT Data Plane",
    arn_namespace: ?[]const u8 = "iotdata",
    endpoint_prefix: []const u8 = "data-ats.iot",
    sigv4_name: []const u8 = "iotdata",
    name: []const u8 = "IotMoonrakerService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_thing_shadow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/things/{thingName}/shadow",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteThingShadow",
    Request: type = struct {
        thing_name: []const u8,
        shadow_name: ?[]const u8 = null,

        pub const http_query = .{
            .shadow_name = "name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .shadow_name = "shadowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_thing_shadow) } {
            return .{ .service_metadata = service_metadata, .action = delete_thing_shadow };
        }
    },
    Response: type = struct {
        payload: []const u8,

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        MethodNotAllowed,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        UnsupportedDocumentEncoding,
    },
} = .{};
pub const get_retained_message: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/retainedMessage/{topic}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRetainedMessage",
    Request: type = struct {
        topic: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic = "topic",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_retained_message) } {
            return .{ .service_metadata = service_metadata, .action = get_retained_message };
        }
    },
    Response: type = struct {
        topic: ?[]const u8 = null,
        payload: ?[]const u8 = null,
        qos: ?i64 = null,
        last_modified_time: ?i64 = null,
        user_properties: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic = "topic",
                .payload = "payload",
                .qos = "qos",
                .last_modified_time = "lastModifiedTime",
                .user_properties = "userProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        MethodNotAllowed,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_thing_shadow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things/{thingName}/shadow",
        .success_code = 200,
    };

    action_name: []const u8 = "GetThingShadow",
    Request: type = struct {
        thing_name: []const u8,
        shadow_name: ?[]const u8 = null,

        pub const http_query = .{
            .shadow_name = "name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .shadow_name = "shadowName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_thing_shadow) } {
            return .{ .service_metadata = service_metadata, .action = get_thing_shadow };
        }
    },
    Response: type = struct {
        payload: ?[]const u8 = null,

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        MethodNotAllowed,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        UnsupportedDocumentEncoding,
    },
} = .{};
pub const list_named_shadows_for_thing: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/things/shadow/ListNamedShadowsForThing/{thingName}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNamedShadowsForThing",
    Request: type = struct {
        thing_name: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .page_size = "pageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .next_token = "nextToken",
                .page_size = "pageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_named_shadows_for_thing) } {
            return .{ .service_metadata = service_metadata, .action = list_named_shadows_for_thing };
        }
    },
    Response: type = struct {
        results: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "results",
                .next_token = "nextToken",
                .timestamp = "timestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        MethodNotAllowed,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_retained_messages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/retainedMessage",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRetainedMessages",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_retained_messages) } {
            return .{ .service_metadata = service_metadata, .action = list_retained_messages };
        }
    },
    Response: type = struct {
        retained_topics: ?[]struct {
            topic: ?[]const u8 = null,
            payload_size: ?i64 = null,
            qos: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .topic = "topic",
                    .payload_size = "payloadSize",
                    .qos = "qos",
                    .last_modified_time = "lastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retained_topics = "retainedTopics",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        MethodNotAllowed,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const publish: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/topics/{topic}",
        .success_code = 200,
    };

    action_name: []const u8 = "Publish",
    Request: type = struct {
        topic: []const u8,
        qos: ?i64 = null,
        retain: ?bool = null,
        payload: ?[]const u8 = null,
        user_properties: ?[]const u8 = null,
        payload_format_indicator: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        response_topic: ?[]const u8 = null,
        correlation_data: ?[]const u8 = null,
        message_expiry: ?i64 = null,

        pub const http_query = .{
            .qos = "qos",
            .retain = "retain",
            .content_type = "contentType",
            .response_topic = "responseTopic",
            .message_expiry = "messageExpiry",
        };

        pub const http_header = .{
            .user_properties = "x-amz-mqtt5-user-properties",
            .payload_format_indicator = "x-amz-mqtt5-payload-format-indicator",
            .correlation_data = "x-amz-mqtt5-correlation-data",
        };

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic = "topic",
                .qos = "qos",
                .retain = "retain",
                .payload = "payload",
                .user_properties = "userProperties",
                .payload_format_indicator = "payloadFormatIndicator",
                .content_type = "contentType",
                .response_topic = "responseTopic",
                .correlation_data = "correlationData",
                .message_expiry = "messageExpiry",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish) } {
            return .{ .service_metadata = service_metadata, .action = publish };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        MethodNotAllowed,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_thing_shadow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/things/{thingName}/shadow",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThingShadow",
    Request: type = struct {
        thing_name: []const u8,
        shadow_name: ?[]const u8 = null,
        payload: []const u8,

        pub const http_query = .{
            .shadow_name = "name",
        };

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .shadow_name = "shadowName",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_thing_shadow) } {
            return .{ .service_metadata = service_metadata, .action = update_thing_shadow };
        }
    },
    Response: type = struct {
        payload: ?[]const u8 = null,

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidRequest,
        MethodNotAllowed,
        RequestEntityTooLarge,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        UnsupportedDocumentEncoding,
    },
} = .{};
