const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-09-18";
pub const sdk_id: []const u8 = "IotDeviceAdvisor";
pub const arn_namespace: ?[]const u8 = "iotdeviceadvisor";
pub const endpoint_prefix: []const u8 = "api.iotdeviceadvisor";
pub const sigv4_name: []const u8 = "iotdeviceadvisor";
pub const name: []const u8 = "IotSenateService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-09-18",
    sdk_id: []const u8 = "IotDeviceAdvisor",
    arn_namespace: ?[]const u8 = "iotdeviceadvisor",
    endpoint_prefix: []const u8 = "api.iotdeviceadvisor",
    sigv4_name: []const u8 = "iotdeviceadvisor",
    name: []const u8 = "IotSenateService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_suite_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/suiteDefinitions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSuiteDefinition",
    Request: type = struct {
        suite_definition_configuration: SuiteDefinitionConfiguration,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_configuration = "suiteDefinitionConfiguration",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_suite_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_suite_definition };
        }
    },
    Response: type = struct {
        suite_definition_id: ?[]const u8 = null,
        suite_definition_arn: ?[]const u8 = null,
        suite_definition_name: ?[]const u8 = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_definition_arn = "suiteDefinitionArn",
                .suite_definition_name = "suiteDefinitionName",
                .created_at = "createdAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const delete_suite_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/suiteDefinitions/{suiteDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSuiteDefinition",
    Request: type = struct {
        suite_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_suite_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_suite_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const get_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/endpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEndpoint",
    Request: type = struct {
        thing_arn: ?[]const u8 = null,
        certificate_arn: ?[]const u8 = null,
        device_role_arn: ?[]const u8 = null,
        authentication_method: ?[]const u8 = null,

        pub const http_query = .{
            .thing_arn = "thingArn",
            .certificate_arn = "certificateArn",
            .device_role_arn = "deviceRoleArn",
            .authentication_method = "authenticationMethod",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_arn = "thingArn",
                .certificate_arn = "certificateArn",
                .device_role_arn = "deviceRoleArn",
                .authentication_method = "authenticationMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_suite_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/suiteDefinitions/{suiteDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSuiteDefinition",
    Request: type = struct {
        suite_definition_id: []const u8,
        suite_definition_version: ?[]const u8 = null,

        pub const http_query = .{
            .suite_definition_version = "suiteDefinitionVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_definition_version = "suiteDefinitionVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_suite_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_suite_definition };
        }
    },
    Response: type = struct {
        suite_definition_id: ?[]const u8 = null,
        suite_definition_arn: ?[]const u8 = null,
        suite_definition_version: ?[]const u8 = null,
        latest_version: ?[]const u8 = null,
        suite_definition_configuration: ?SuiteDefinitionConfiguration = null,
        created_at: ?i64 = null,
        last_modified_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_definition_arn = "suiteDefinitionArn",
                .suite_definition_version = "suiteDefinitionVersion",
                .latest_version = "latestVersion",
                .suite_definition_configuration = "suiteDefinitionConfiguration",
                .created_at = "createdAt",
                .last_modified_at = "lastModifiedAt",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_suite_run: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/suiteDefinitions/{suiteDefinitionId}/suiteRuns/{suiteRunId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSuiteRun",
    Request: type = struct {
        suite_definition_id: []const u8,
        suite_run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_run_id = "suiteRunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_suite_run) } {
            return .{ .service_metadata = service_metadata, .action = get_suite_run };
        }
    },
    Response: type = struct {
        suite_definition_id: ?[]const u8 = null,
        suite_definition_version: ?[]const u8 = null,
        suite_run_id: ?[]const u8 = null,
        suite_run_arn: ?[]const u8 = null,
        suite_run_configuration: ?SuiteRunConfiguration = null,
        test_result: ?struct {
            groups: ?[]struct {
                group_id: ?[]const u8 = null,
                group_name: ?[]const u8 = null,
                tests: ?[]struct {
                    test_case_run_id: ?[]const u8 = null,
                    test_case_definition_id: ?[]const u8 = null,
                    test_case_definition_name: ?[]const u8 = null,
                    status: ?[]const u8 = null,
                    start_time: ?i64 = null,
                    end_time: ?i64 = null,
                    log_url: ?[]const u8 = null,
                    warnings: ?[]const u8 = null,
                    failure: ?[]const u8 = null,
                    test_scenarios: ?[]struct {
                        test_case_scenario_id: ?[]const u8 = null,
                        test_case_scenario_type: ?[]const u8 = null,
                        status: ?[]const u8 = null,
                        failure: ?[]const u8 = null,
                        system_message: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .test_case_scenario_id = "testCaseScenarioId",
                                .test_case_scenario_type = "testCaseScenarioType",
                                .status = "status",
                                .failure = "failure",
                                .system_message = "systemMessage",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .test_case_run_id = "testCaseRunId",
                            .test_case_definition_id = "testCaseDefinitionId",
                            .test_case_definition_name = "testCaseDefinitionName",
                            .status = "status",
                            .start_time = "startTime",
                            .end_time = "endTime",
                            .log_url = "logUrl",
                            .warnings = "warnings",
                            .failure = "failure",
                            .test_scenarios = "testScenarios",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group_id = "groupId",
                        .group_name = "groupName",
                        .tests = "tests",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .groups = "groups",
                };
                return @field(mappings, field_name);
            }
        } = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        status: ?[]const u8 = null,
        error_reason: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_definition_version = "suiteDefinitionVersion",
                .suite_run_id = "suiteRunId",
                .suite_run_arn = "suiteRunArn",
                .suite_run_configuration = "suiteRunConfiguration",
                .test_result = "testResult",
                .start_time = "startTime",
                .end_time = "endTime",
                .status = "status",
                .error_reason = "errorReason",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_suite_run_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/suiteDefinitions/{suiteDefinitionId}/suiteRuns/{suiteRunId}/report",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSuiteRunReport",
    Request: type = struct {
        suite_definition_id: []const u8,
        suite_run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_run_id = "suiteRunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_suite_run_report) } {
            return .{ .service_metadata = service_metadata, .action = get_suite_run_report };
        }
    },
    Response: type = struct {
        qualification_report_download_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .qualification_report_download_url = "qualificationReportDownloadUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_suite_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/suiteDefinitions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSuiteDefinitions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_suite_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_suite_definitions };
        }
    },
    Response: type = struct {
        suite_definition_information_list: ?[]struct {
            suite_definition_id: ?[]const u8 = null,
            suite_definition_name: ?[]const u8 = null,
            default_devices: ?[]DeviceUnderTest = null,
            intended_for_qualification: ?bool = null,
            is_long_duration_test: ?bool = null,
            protocol: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .suite_definition_id = "suiteDefinitionId",
                    .suite_definition_name = "suiteDefinitionName",
                    .default_devices = "defaultDevices",
                    .intended_for_qualification = "intendedForQualification",
                    .is_long_duration_test = "isLongDurationTest",
                    .protocol = "protocol",
                    .created_at = "createdAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_information_list = "suiteDefinitionInformationList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_suite_runs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/suiteRuns",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSuiteRuns",
    Request: type = struct {
        suite_definition_id: ?[]const u8 = null,
        suite_definition_version: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .suite_definition_id = "suiteDefinitionId",
            .suite_definition_version = "suiteDefinitionVersion",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_definition_version = "suiteDefinitionVersion",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_suite_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_suite_runs };
        }
    },
    Response: type = struct {
        suite_runs_list: ?[]struct {
            suite_definition_id: ?[]const u8 = null,
            suite_definition_version: ?[]const u8 = null,
            suite_definition_name: ?[]const u8 = null,
            suite_run_id: ?[]const u8 = null,
            created_at: ?i64 = null,
            started_at: ?i64 = null,
            end_at: ?i64 = null,
            status: ?[]const u8 = null,
            passed: ?i64 = null,
            failed: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .suite_definition_id = "suiteDefinitionId",
                    .suite_definition_version = "suiteDefinitionVersion",
                    .suite_definition_name = "suiteDefinitionName",
                    .suite_run_id = "suiteRunId",
                    .created_at = "createdAt",
                    .started_at = "startedAt",
                    .end_at = "endAt",
                    .status = "status",
                    .passed = "passed",
                    .failed = "failed",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_runs_list = "suiteRunsList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_suite_run: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/suiteDefinitions/{suiteDefinitionId}/suiteRuns",
        .success_code = 200,
    };

    action_name: []const u8 = "StartSuiteRun",
    Request: type = struct {
        suite_definition_id: []const u8,
        suite_definition_version: ?[]const u8 = null,
        suite_run_configuration: SuiteRunConfiguration,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_definition_version = "suiteDefinitionVersion",
                .suite_run_configuration = "suiteRunConfiguration",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_suite_run) } {
            return .{ .service_metadata = service_metadata, .action = start_suite_run };
        }
    },
    Response: type = struct {
        suite_run_id: ?[]const u8 = null,
        suite_run_arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        endpoint: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_run_id = "suiteRunId",
                .suite_run_arn = "suiteRunArn",
                .created_at = "createdAt",
                .endpoint = "endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const stop_suite_run: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/suiteDefinitions/{suiteDefinitionId}/suiteRuns/{suiteRunId}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopSuiteRun",
    Request: type = struct {
        suite_definition_id: []const u8,
        suite_run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_run_id = "suiteRunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_suite_run) } {
            return .{ .service_metadata = service_metadata, .action = stop_suite_run };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_suite_definition: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/suiteDefinitions/{suiteDefinitionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSuiteDefinition",
    Request: type = struct {
        suite_definition_id: []const u8,
        suite_definition_configuration: SuiteDefinitionConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_definition_configuration = "suiteDefinitionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_suite_definition) } {
            return .{ .service_metadata = service_metadata, .action = update_suite_definition };
        }
    },
    Response: type = struct {
        suite_definition_id: ?[]const u8 = null,
        suite_definition_arn: ?[]const u8 = null,
        suite_definition_name: ?[]const u8 = null,
        suite_definition_version: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suite_definition_id = "suiteDefinitionId",
                .suite_definition_arn = "suiteDefinitionArn",
                .suite_definition_name = "suiteDefinitionName",
                .suite_definition_version = "suiteDefinitionVersion",
                .created_at = "createdAt",
                .last_updated_at = "lastUpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};

pub const SuiteDefinitionConfiguration = struct {
    suite_definition_name: []const u8,
    devices: ?[]DeviceUnderTest = null,
    intended_for_qualification: ?bool = null,
    is_long_duration_test: ?bool = null,
    root_group: []const u8,
    device_permission_role_arn: []const u8,
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .suite_definition_name = "suiteDefinitionName",
            .devices = "devices",
            .intended_for_qualification = "intendedForQualification",
            .is_long_duration_test = "isLongDurationTest",
            .root_group = "rootGroup",
            .device_permission_role_arn = "devicePermissionRoleArn",
            .protocol = "protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceUnderTest = struct {
    thing_arn: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    device_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .thing_arn = "thingArn",
            .certificate_arn = "certificateArn",
            .device_role_arn = "deviceRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SuiteRunConfiguration = struct {
    primary_device: DeviceUnderTest,
    selected_test_list: ?[][]const u8 = null,
    parallel_run: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_device = "primaryDevice",
            .selected_test_list = "selectedTestList",
            .parallel_run = "parallelRun",
        };
        return @field(mappings, field_name);
    }
};
