const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-07-27";
pub const sdk_id: []const u8 = "IoT Events";
pub const arn_namespace: ?[]const u8 = "iotevents";
pub const endpoint_prefix: []const u8 = "iotevents";
pub const sigv4_name: []const u8 = "iotevents";
pub const name: []const u8 = "IotColumboService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-07-27",
    sdk_id: []const u8 = "IoT Events",
    arn_namespace: ?[]const u8 = "iotevents",
    endpoint_prefix: []const u8 = "iotevents",
    sigv4_name: []const u8 = "iotevents",
    name: []const u8 = "IotColumboService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_alarm_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/alarm-models",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAlarmModel",
    Request: type = struct {
        alarm_model_name: []const u8,
        alarm_model_description: ?[]const u8 = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        key: ?[]const u8 = null,
        severity: ?i64 = null,
        alarm_rule: AlarmRule,
        alarm_notification: ?AlarmNotification = null,
        alarm_event_actions: ?AlarmEventActions = null,
        alarm_capabilities: ?AlarmCapabilities = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_name = "alarmModelName",
                .alarm_model_description = "alarmModelDescription",
                .role_arn = "roleArn",
                .tags = "tags",
                .key = "key",
                .severity = "severity",
                .alarm_rule = "alarmRule",
                .alarm_notification = "alarmNotification",
                .alarm_event_actions = "alarmEventActions",
                .alarm_capabilities = "alarmCapabilities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_alarm_model) } {
            return .{ .service_metadata = service_metadata, .action = create_alarm_model };
        }
    },
    Response: type = struct {
        creation_time: ?i64 = null,
        alarm_model_arn: ?[]const u8 = null,
        alarm_model_version: ?[]const u8 = null,
        last_update_time: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "creationTime",
                .alarm_model_arn = "alarmModelArn",
                .alarm_model_version = "alarmModelVersion",
                .last_update_time = "lastUpdateTime",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_detector_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector-models",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDetectorModel",
    Request: type = struct {
        detector_model_name: []const u8,
        detector_model_definition: DetectorModelDefinition,
        detector_model_description: ?[]const u8 = null,
        key: ?[]const u8 = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        evaluation_method: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
                .detector_model_definition = "detectorModelDefinition",
                .detector_model_description = "detectorModelDescription",
                .key = "key",
                .role_arn = "roleArn",
                .tags = "tags",
                .evaluation_method = "evaluationMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_detector_model) } {
            return .{ .service_metadata = service_metadata, .action = create_detector_model };
        }
    },
    Response: type = struct {
        detector_model_configuration: ?DetectorModelConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_configuration = "detectorModelConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_input: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/inputs",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateInput",
    Request: type = struct {
        input_name: []const u8,
        input_description: ?[]const u8 = null,
        input_definition: InputDefinition,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_name = "inputName",
                .input_description = "inputDescription",
                .input_definition = "inputDefinition",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_input) } {
            return .{ .service_metadata = service_metadata, .action = create_input };
        }
    },
    Response: type = struct {
        input_configuration: ?InputConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_configuration = "inputConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_alarm_model: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/alarm-models/{alarmModelName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAlarmModel",
    Request: type = struct {
        alarm_model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_name = "alarmModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_alarm_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_alarm_model };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_detector_model: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/detector-models/{detectorModelName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDetectorModel",
    Request: type = struct {
        detector_model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_detector_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_detector_model };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_input: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/inputs/{inputName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInput",
    Request: type = struct {
        input_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_name = "inputName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_input) } {
            return .{ .service_metadata = service_metadata, .action = delete_input };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_alarm_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/alarm-models/{alarmModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAlarmModel",
    Request: type = struct {
        alarm_model_name: []const u8,
        alarm_model_version: ?[]const u8 = null,

        pub const http_query = .{
            .alarm_model_version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_name = "alarmModelName",
                .alarm_model_version = "alarmModelVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_alarm_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_alarm_model };
        }
    },
    Response: type = struct {
        creation_time: ?i64 = null,
        alarm_model_arn: ?[]const u8 = null,
        alarm_model_version: ?[]const u8 = null,
        last_update_time: ?i64 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        alarm_model_name: ?[]const u8 = null,
        alarm_model_description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        key: ?[]const u8 = null,
        severity: ?i64 = null,
        alarm_rule: ?AlarmRule = null,
        alarm_notification: ?AlarmNotification = null,
        alarm_event_actions: ?AlarmEventActions = null,
        alarm_capabilities: ?AlarmCapabilities = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "creationTime",
                .alarm_model_arn = "alarmModelArn",
                .alarm_model_version = "alarmModelVersion",
                .last_update_time = "lastUpdateTime",
                .status = "status",
                .status_message = "statusMessage",
                .alarm_model_name = "alarmModelName",
                .alarm_model_description = "alarmModelDescription",
                .role_arn = "roleArn",
                .key = "key",
                .severity = "severity",
                .alarm_rule = "alarmRule",
                .alarm_notification = "alarmNotification",
                .alarm_event_actions = "alarmEventActions",
                .alarm_capabilities = "alarmCapabilities",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_detector_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector-models/{detectorModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDetectorModel",
    Request: type = struct {
        detector_model_name: []const u8,
        detector_model_version: ?[]const u8 = null,

        pub const http_query = .{
            .detector_model_version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
                .detector_model_version = "detectorModelVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_detector_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_detector_model };
        }
    },
    Response: type = struct {
        detector_model: ?struct {
            detector_model_definition: ?DetectorModelDefinition = null,
            detector_model_configuration: ?DetectorModelConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .detector_model_definition = "detectorModelDefinition",
                    .detector_model_configuration = "detectorModelConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model = "detectorModel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_detector_model_analysis: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/analysis/detector-models/{analysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDetectorModelAnalysis",
    Request: type = struct {
        analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_id = "analysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_detector_model_analysis) } {
            return .{ .service_metadata = service_metadata, .action = describe_detector_model_analysis };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_input: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/inputs/{inputName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInput",
    Request: type = struct {
        input_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_name = "inputName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_input) } {
            return .{ .service_metadata = service_metadata, .action = describe_input };
        }
    },
    Response: type = struct {
        input: ?struct {
            input_configuration: ?InputConfiguration = null,
            input_definition: ?InputDefinition = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .input_configuration = "inputConfiguration",
                    .input_definition = "inputDefinition",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input = "input",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_logging_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/logging",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeLoggingOptions",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_logging_options };
        }
    },
    Response: type = struct {
        logging_options: ?LoggingOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_options = "loggingOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnsupportedOperation,
    },
} = .{};
pub const get_detector_model_analysis_results: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/analysis/detector-models/{analysisId}/results",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDetectorModelAnalysisResults",
    Request: type = struct {
        analysis_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_id = "analysisId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_detector_model_analysis_results) } {
            return .{ .service_metadata = service_metadata, .action = get_detector_model_analysis_results };
        }
    },
    Response: type = struct {
        analysis_results: ?[]struct {
            type: ?[]const u8 = null,
            level: ?[]const u8 = null,
            message: ?[]const u8 = null,
            locations: ?[]struct {
                path: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .path = "path",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .level = "level",
                    .message = "message",
                    .locations = "locations",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_results = "analysisResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_alarm_models: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/alarm-models",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAlarmModels",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_alarm_models) } {
            return .{ .service_metadata = service_metadata, .action = list_alarm_models };
        }
    },
    Response: type = struct {
        alarm_model_summaries: ?[]struct {
            creation_time: ?i64 = null,
            alarm_model_description: ?[]const u8 = null,
            alarm_model_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "creationTime",
                    .alarm_model_description = "alarmModelDescription",
                    .alarm_model_name = "alarmModelName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_summaries = "alarmModelSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_alarm_model_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/alarm-models/{alarmModelName}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAlarmModelVersions",
    Request: type = struct {
        alarm_model_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_name = "alarmModelName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_alarm_model_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_alarm_model_versions };
        }
    },
    Response: type = struct {
        alarm_model_version_summaries: ?[]struct {
            alarm_model_name: ?[]const u8 = null,
            alarm_model_arn: ?[]const u8 = null,
            alarm_model_version: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .alarm_model_name = "alarmModelName",
                    .alarm_model_arn = "alarmModelArn",
                    .alarm_model_version = "alarmModelVersion",
                    .role_arn = "roleArn",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .status = "status",
                    .status_message = "statusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_version_summaries = "alarmModelVersionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_detector_models: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector-models",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDetectorModels",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_detector_models) } {
            return .{ .service_metadata = service_metadata, .action = list_detector_models };
        }
    },
    Response: type = struct {
        detector_model_summaries: ?[]struct {
            detector_model_name: ?[]const u8 = null,
            detector_model_description: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .detector_model_name = "detectorModelName",
                    .detector_model_description = "detectorModelDescription",
                    .creation_time = "creationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_summaries = "detectorModelSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_detector_model_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detector-models/{detectorModelName}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDetectorModelVersions",
    Request: type = struct {
        detector_model_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_detector_model_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_detector_model_versions };
        }
    },
    Response: type = struct {
        detector_model_version_summaries: ?[]struct {
            detector_model_name: ?[]const u8 = null,
            detector_model_version: ?[]const u8 = null,
            detector_model_arn: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            status: ?[]const u8 = null,
            evaluation_method: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .detector_model_name = "detectorModelName",
                    .detector_model_version = "detectorModelVersion",
                    .detector_model_arn = "detectorModelArn",
                    .role_arn = "roleArn",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .status = "status",
                    .evaluation_method = "evaluationMethod",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_version_summaries = "detectorModelVersionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_input_routings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/input-routings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInputRoutings",
    Request: type = struct {
        input_identifier: struct {
            iot_events_input_identifier: ?struct {
                input_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input_name = "inputName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            iot_site_wise_input_identifier: ?struct {
                iot_site_wise_asset_model_property_identifier: ?struct {
                    asset_model_id: []const u8,
                    property_id: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .asset_model_id = "assetModelId",
                            .property_id = "propertyId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .iot_site_wise_asset_model_property_identifier = "iotSiteWiseAssetModelPropertyIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .iot_events_input_identifier = "iotEventsInputIdentifier",
                    .iot_site_wise_input_identifier = "iotSiteWiseInputIdentifier",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_identifier = "inputIdentifier",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_input_routings) } {
            return .{ .service_metadata = service_metadata, .action = list_input_routings };
        }
    },
    Response: type = struct {
        routed_resources: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routed_resources = "routedResources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_inputs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/inputs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInputs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_inputs) } {
            return .{ .service_metadata = service_metadata, .action = list_inputs };
        }
    },
    Response: type = struct {
        input_summaries: ?[]struct {
            input_name: ?[]const u8 = null,
            input_description: ?[]const u8 = null,
            input_arn: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .input_name = "inputName",
                    .input_description = "inputDescription",
                    .input_arn = "inputArn",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_summaries = "inputSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_logging_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/logging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutLoggingOptions",
    Request: type = struct {
        logging_options: LoggingOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_options = "loggingOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = put_logging_options };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ServiceUnavailable,
        Throttling,
        UnsupportedOperation,
    },
} = .{};
pub const start_detector_model_analysis: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/analysis/detector-models",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDetectorModelAnalysis",
    Request: type = struct {
        detector_model_definition: DetectorModelDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_definition = "detectorModelDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_detector_model_analysis) } {
            return .{ .service_metadata = service_metadata, .action = start_detector_model_analysis };
        }
    },
    Response: type = struct {
        analysis_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_id = "analysisId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_alarm_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/alarm-models/{alarmModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAlarmModel",
    Request: type = struct {
        alarm_model_name: []const u8,
        alarm_model_description: ?[]const u8 = null,
        role_arn: []const u8,
        severity: ?i64 = null,
        alarm_rule: AlarmRule,
        alarm_notification: ?AlarmNotification = null,
        alarm_event_actions: ?AlarmEventActions = null,
        alarm_capabilities: ?AlarmCapabilities = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_name = "alarmModelName",
                .alarm_model_description = "alarmModelDescription",
                .role_arn = "roleArn",
                .severity = "severity",
                .alarm_rule = "alarmRule",
                .alarm_notification = "alarmNotification",
                .alarm_event_actions = "alarmEventActions",
                .alarm_capabilities = "alarmCapabilities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_alarm_model) } {
            return .{ .service_metadata = service_metadata, .action = update_alarm_model };
        }
    },
    Response: type = struct {
        creation_time: ?i64 = null,
        alarm_model_arn: ?[]const u8 = null,
        alarm_model_version: ?[]const u8 = null,
        last_update_time: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "creationTime",
                .alarm_model_arn = "alarmModelArn",
                .alarm_model_version = "alarmModelVersion",
                .last_update_time = "lastUpdateTime",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_detector_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detector-models/{detectorModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDetectorModel",
    Request: type = struct {
        detector_model_name: []const u8,
        detector_model_definition: DetectorModelDefinition,
        detector_model_description: ?[]const u8 = null,
        role_arn: []const u8,
        evaluation_method: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
                .detector_model_definition = "detectorModelDefinition",
                .detector_model_description = "detectorModelDescription",
                .role_arn = "roleArn",
                .evaluation_method = "evaluationMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_detector_model) } {
            return .{ .service_metadata = service_metadata, .action = update_detector_model };
        }
    },
    Response: type = struct {
        detector_model_configuration: ?DetectorModelConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_configuration = "detectorModelConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_input: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/inputs/{inputName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInput",
    Request: type = struct {
        input_name: []const u8,
        input_description: ?[]const u8 = null,
        input_definition: InputDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_name = "inputName",
                .input_description = "inputDescription",
                .input_definition = "inputDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_input) } {
            return .{ .service_metadata = service_metadata, .action = update_input };
        }
    },
    Response: type = struct {
        input_configuration: ?InputConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_configuration = "inputConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const InputConfiguration = struct {
    input_name: []const u8,
    input_description: ?[]const u8 = null,
    input_arn: []const u8,
    creation_time: i64,
    last_update_time: i64,
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_name = "inputName",
            .input_description = "inputDescription",
            .input_arn = "inputArn",
            .creation_time = "creationTime",
            .last_update_time = "lastUpdateTime",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDefinition = struct {
    attributes: []Attribute,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "attributes",
        };
        return @field(mappings, field_name);
    }
};

pub const Attribute = struct {
    json_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .json_path = "jsonPath",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectorModelConfiguration = struct {
    detector_model_name: ?[]const u8 = null,
    detector_model_version: ?[]const u8 = null,
    detector_model_description: ?[]const u8 = null,
    detector_model_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_update_time: ?i64 = null,
    status: ?[]const u8 = null,
    key: ?[]const u8 = null,
    evaluation_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detector_model_name = "detectorModelName",
            .detector_model_version = "detectorModelVersion",
            .detector_model_description = "detectorModelDescription",
            .detector_model_arn = "detectorModelArn",
            .role_arn = "roleArn",
            .creation_time = "creationTime",
            .last_update_time = "lastUpdateTime",
            .status = "status",
            .key = "key",
            .evaluation_method = "evaluationMethod",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectorModelDefinition = struct {
    states: []State,
    initial_state_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .states = "states",
            .initial_state_name = "initialStateName",
        };
        return @field(mappings, field_name);
    }
};

pub const State = struct {
    state_name: []const u8,
    on_input: ?OnInputLifecycle = null,
    on_enter: ?OnEnterLifecycle = null,
    on_exit: ?OnExitLifecycle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state_name = "stateName",
            .on_input = "onInput",
            .on_enter = "onEnter",
            .on_exit = "onExit",
        };
        return @field(mappings, field_name);
    }
};

pub const OnExitLifecycle = struct {
    events: ?[]Event = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .events = "events",
        };
        return @field(mappings, field_name);
    }
};

pub const Event = struct {
    event_name: []const u8,
    condition: ?[]const u8 = null,
    actions: ?[]Action = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_name = "eventName",
            .condition = "condition",
            .actions = "actions",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    set_variable: ?SetVariableAction = null,
    sns: ?SNSTopicPublishAction = null,
    iot_topic_publish: ?IotTopicPublishAction = null,
    set_timer: ?SetTimerAction = null,
    clear_timer: ?ClearTimerAction = null,
    reset_timer: ?ResetTimerAction = null,
    lambda: ?LambdaAction = null,
    iot_events: ?IotEventsAction = null,
    sqs: ?SqsAction = null,
    firehose: ?FirehoseAction = null,
    dynamo_db: ?DynamoDBAction = null,
    dynamo_d_bv2: ?DynamoDBv2Action = null,
    iot_site_wise: ?IotSiteWiseAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .set_variable = "setVariable",
            .sns = "sns",
            .iot_topic_publish = "iotTopicPublish",
            .set_timer = "setTimer",
            .clear_timer = "clearTimer",
            .reset_timer = "resetTimer",
            .lambda = "lambda",
            .iot_events = "iotEvents",
            .sqs = "sqs",
            .firehose = "firehose",
            .dynamo_db = "dynamoDB",
            .dynamo_d_bv2 = "dynamoDBv2",
            .iot_site_wise = "iotSiteWise",
        };
        return @field(mappings, field_name);
    }
};

pub const IotSiteWiseAction = struct {
    entry_id: ?[]const u8 = null,
    asset_id: ?[]const u8 = null,
    property_id: ?[]const u8 = null,
    property_alias: ?[]const u8 = null,
    property_value: ?AssetPropertyValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entry_id = "entryId",
            .asset_id = "assetId",
            .property_id = "propertyId",
            .property_alias = "propertyAlias",
            .property_value = "propertyValue",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetPropertyValue = struct {
    value: ?AssetPropertyVariant = null,
    timestamp: ?AssetPropertyTimestamp = null,
    quality: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .timestamp = "timestamp",
            .quality = "quality",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetPropertyTimestamp = struct {
    time_in_seconds: []const u8,
    offset_in_nanos: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_in_seconds = "timeInSeconds",
            .offset_in_nanos = "offsetInNanos",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetPropertyVariant = struct {
    string_value: ?[]const u8 = null,
    integer_value: ?[]const u8 = null,
    double_value: ?[]const u8 = null,
    boolean_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "stringValue",
            .integer_value = "integerValue",
            .double_value = "doubleValue",
            .boolean_value = "booleanValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamoDBv2Action = struct {
    table_name: []const u8,
    payload: ?Payload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "tableName",
            .payload = "payload",
        };
        return @field(mappings, field_name);
    }
};

pub const Payload = struct {
    content_expression: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_expression = "contentExpression",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamoDBAction = struct {
    hash_key_type: ?[]const u8 = null,
    hash_key_field: []const u8,
    hash_key_value: []const u8,
    range_key_type: ?[]const u8 = null,
    range_key_field: ?[]const u8 = null,
    range_key_value: ?[]const u8 = null,
    operation: ?[]const u8 = null,
    payload_field: ?[]const u8 = null,
    table_name: []const u8,
    payload: ?Payload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hash_key_type = "hashKeyType",
            .hash_key_field = "hashKeyField",
            .hash_key_value = "hashKeyValue",
            .range_key_type = "rangeKeyType",
            .range_key_field = "rangeKeyField",
            .range_key_value = "rangeKeyValue",
            .operation = "operation",
            .payload_field = "payloadField",
            .table_name = "tableName",
            .payload = "payload",
        };
        return @field(mappings, field_name);
    }
};

pub const FirehoseAction = struct {
    delivery_stream_name: []const u8,
    separator: ?[]const u8 = null,
    payload: ?Payload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_stream_name = "deliveryStreamName",
            .separator = "separator",
            .payload = "payload",
        };
        return @field(mappings, field_name);
    }
};

pub const SqsAction = struct {
    queue_url: []const u8,
    use_base64: ?bool = null,
    payload: ?Payload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue_url = "queueUrl",
            .use_base64 = "useBase64",
            .payload = "payload",
        };
        return @field(mappings, field_name);
    }
};

pub const IotEventsAction = struct {
    input_name: []const u8,
    payload: ?Payload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_name = "inputName",
            .payload = "payload",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaAction = struct {
    function_arn: []const u8,
    payload: ?Payload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "functionArn",
            .payload = "payload",
        };
        return @field(mappings, field_name);
    }
};

pub const ResetTimerAction = struct {
    timer_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timer_name = "timerName",
        };
        return @field(mappings, field_name);
    }
};

pub const ClearTimerAction = struct {
    timer_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timer_name = "timerName",
        };
        return @field(mappings, field_name);
    }
};

pub const SetTimerAction = struct {
    timer_name: []const u8,
    seconds: ?i64 = null,
    duration_expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timer_name = "timerName",
            .seconds = "seconds",
            .duration_expression = "durationExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const IotTopicPublishAction = struct {
    mqtt_topic: []const u8,
    payload: ?Payload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mqtt_topic = "mqttTopic",
            .payload = "payload",
        };
        return @field(mappings, field_name);
    }
};

pub const SNSTopicPublishAction = struct {
    target_arn: []const u8,
    payload: ?Payload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_arn = "targetArn",
            .payload = "payload",
        };
        return @field(mappings, field_name);
    }
};

pub const SetVariableAction = struct {
    variable_name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .variable_name = "variableName",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const OnEnterLifecycle = struct {
    events: ?[]Event = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .events = "events",
        };
        return @field(mappings, field_name);
    }
};

pub const OnInputLifecycle = struct {
    events: ?[]Event = null,
    transition_events: ?[]TransitionEvent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .events = "events",
            .transition_events = "transitionEvents",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitionEvent = struct {
    event_name: []const u8,
    condition: []const u8,
    actions: ?[]Action = null,
    next_state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_name = "eventName",
            .condition = "condition",
            .actions = "actions",
            .next_state = "nextState",
        };
        return @field(mappings, field_name);
    }
};

pub const AlarmCapabilities = struct {
    initialization_configuration: ?InitializationConfiguration = null,
    acknowledge_flow: ?AcknowledgeFlow = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .initialization_configuration = "initializationConfiguration",
            .acknowledge_flow = "acknowledgeFlow",
        };
        return @field(mappings, field_name);
    }
};

pub const AcknowledgeFlow = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const InitializationConfiguration = struct {
    disabled_on_initialization: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disabled_on_initialization = "disabledOnInitialization",
        };
        return @field(mappings, field_name);
    }
};

pub const AlarmEventActions = struct {
    alarm_actions: ?[]AlarmAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alarm_actions = "alarmActions",
        };
        return @field(mappings, field_name);
    }
};

pub const AlarmAction = struct {
    sns: ?SNSTopicPublishAction = null,
    iot_topic_publish: ?IotTopicPublishAction = null,
    lambda: ?LambdaAction = null,
    iot_events: ?IotEventsAction = null,
    sqs: ?SqsAction = null,
    firehose: ?FirehoseAction = null,
    dynamo_db: ?DynamoDBAction = null,
    dynamo_d_bv2: ?DynamoDBv2Action = null,
    iot_site_wise: ?IotSiteWiseAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns = "sns",
            .iot_topic_publish = "iotTopicPublish",
            .lambda = "lambda",
            .iot_events = "iotEvents",
            .sqs = "sqs",
            .firehose = "firehose",
            .dynamo_db = "dynamoDB",
            .dynamo_d_bv2 = "dynamoDBv2",
            .iot_site_wise = "iotSiteWise",
        };
        return @field(mappings, field_name);
    }
};

pub const AlarmNotification = struct {
    notification_actions: ?[]NotificationAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notification_actions = "notificationActions",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationAction = struct {
    action: NotificationTargetActions,
    sms_configurations: ?[]SMSConfiguration = null,
    email_configurations: ?[]EmailConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "action",
            .sms_configurations = "smsConfigurations",
            .email_configurations = "emailConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailConfiguration = struct {
    from: []const u8,
    content: ?EmailContent = null,
    recipients: EmailRecipients,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "from",
            .content = "content",
            .recipients = "recipients",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailRecipients = struct {
    to: ?[]RecipientDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .to = "to",
        };
        return @field(mappings, field_name);
    }
};

pub const RecipientDetail = struct {
    sso_identity: ?SSOIdentity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sso_identity = "ssoIdentity",
        };
        return @field(mappings, field_name);
    }
};

pub const SSOIdentity = struct {
    identity_store_id: []const u8,
    user_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_store_id = "identityStoreId",
            .user_id = "userId",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailContent = struct {
    subject: ?[]const u8 = null,
    additional_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subject = "subject",
            .additional_message = "additionalMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const SMSConfiguration = struct {
    sender_id: ?[]const u8 = null,
    additional_message: ?[]const u8 = null,
    recipients: []RecipientDetail,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sender_id = "senderId",
            .additional_message = "additionalMessage",
            .recipients = "recipients",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationTargetActions = struct {
    lambda_action: ?LambdaAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_action = "lambdaAction",
        };
        return @field(mappings, field_name);
    }
};

pub const AlarmRule = struct {
    simple_rule: ?SimpleRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_rule = "simpleRule",
        };
        return @field(mappings, field_name);
    }
};

pub const SimpleRule = struct {
    input_property: []const u8,
    comparison_operator: []const u8,
    threshold: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_property = "inputProperty",
            .comparison_operator = "comparisonOperator",
            .threshold = "threshold",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingOptions = struct {
    role_arn: []const u8,
    level: []const u8,
    enabled: bool,
    detector_debug_options: ?[]DetectorDebugOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .level = "level",
            .enabled = "enabled",
            .detector_debug_options = "detectorDebugOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectorDebugOption = struct {
    detector_model_name: []const u8,
    key_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detector_model_name = "detectorModelName",
            .key_value = "keyValue",
        };
        return @field(mappings, field_name);
    }
};
