const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-10-23";
pub const sdk_id: []const u8 = "IoT Events Data";
pub const arn_namespace: ?[]const u8 = "ioteventsdata";
pub const endpoint_prefix: []const u8 = "data.iotevents";
pub const sigv4_name: []const u8 = "ioteventsdata";
pub const name: []const u8 = "IotColumboDataService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-10-23",
    sdk_id: []const u8 = "IoT Events Data",
    arn_namespace: ?[]const u8 = "ioteventsdata",
    endpoint_prefix: []const u8 = "data.iotevents",
    sigv4_name: []const u8 = "ioteventsdata",
    name: []const u8 = "IotColumboDataService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_acknowledge_alarm: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/alarms/acknowledge",
        .success_code = 202,
    };

    action_name: []const u8 = "BatchAcknowledgeAlarm",
    Request: type = struct {
        acknowledge_action_requests: []struct {
            request_id: []const u8,
            alarm_model_name: []const u8,
            key_value: ?[]const u8 = null,
            note: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request_id = "requestId",
                    .alarm_model_name = "alarmModelName",
                    .key_value = "keyValue",
                    .note = "note",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acknowledge_action_requests = "acknowledgeActionRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_acknowledge_alarm) } {
            return .{ .service_metadata = service_metadata, .action = batch_acknowledge_alarm };
        }
    },
    Response: type = struct {
        error_entries: ?[]BatchAlarmActionErrorEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_delete_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detectors/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeleteDetector",
    Request: type = struct {
        detectors: []struct {
            message_id: []const u8,
            detector_model_name: []const u8,
            key_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .detector_model_name = "detectorModelName",
                    .key_value = "keyValue",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detectors = "detectors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_detector) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_detector };
        }
    },
    Response: type = struct {
        batch_delete_detector_error_entries: ?[]struct {
            message_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_delete_detector_error_entries = "batchDeleteDetectorErrorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_disable_alarm: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/alarms/disable",
        .success_code = 202,
    };

    action_name: []const u8 = "BatchDisableAlarm",
    Request: type = struct {
        disable_action_requests: []struct {
            request_id: []const u8,
            alarm_model_name: []const u8,
            key_value: ?[]const u8 = null,
            note: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request_id = "requestId",
                    .alarm_model_name = "alarmModelName",
                    .key_value = "keyValue",
                    .note = "note",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .disable_action_requests = "disableActionRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disable_alarm) } {
            return .{ .service_metadata = service_metadata, .action = batch_disable_alarm };
        }
    },
    Response: type = struct {
        error_entries: ?[]BatchAlarmActionErrorEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_enable_alarm: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/alarms/enable",
        .success_code = 202,
    };

    action_name: []const u8 = "BatchEnableAlarm",
    Request: type = struct {
        enable_action_requests: []struct {
            request_id: []const u8,
            alarm_model_name: []const u8,
            key_value: ?[]const u8 = null,
            note: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request_id = "requestId",
                    .alarm_model_name = "alarmModelName",
                    .key_value = "keyValue",
                    .note = "note",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enable_action_requests = "enableActionRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_enable_alarm) } {
            return .{ .service_metadata = service_metadata, .action = batch_enable_alarm };
        }
    },
    Response: type = struct {
        error_entries: ?[]BatchAlarmActionErrorEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_put_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/inputs/messages",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchPutMessage",
    Request: type = struct {
        messages: []struct {
            message_id: []const u8,
            input_name: []const u8,
            payload: []const u8,
            timestamp: ?struct {
                time_in_millis: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .time_in_millis = "timeInMillis",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .input_name = "inputName",
                    .payload = "payload",
                    .timestamp = "timestamp",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .messages = "messages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_message) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_message };
        }
    },
    Response: type = struct {
        batch_put_message_error_entries: ?[]struct {
            message_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_put_message_error_entries = "BatchPutMessageErrorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_reset_alarm: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/alarms/reset",
        .success_code = 202,
    };

    action_name: []const u8 = "BatchResetAlarm",
    Request: type = struct {
        reset_action_requests: []struct {
            request_id: []const u8,
            alarm_model_name: []const u8,
            key_value: ?[]const u8 = null,
            note: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request_id = "requestId",
                    .alarm_model_name = "alarmModelName",
                    .key_value = "keyValue",
                    .note = "note",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reset_action_requests = "resetActionRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_reset_alarm) } {
            return .{ .service_metadata = service_metadata, .action = batch_reset_alarm };
        }
    },
    Response: type = struct {
        error_entries: ?[]BatchAlarmActionErrorEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_snooze_alarm: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/alarms/snooze",
        .success_code = 202,
    };

    action_name: []const u8 = "BatchSnoozeAlarm",
    Request: type = struct {
        snooze_action_requests: []struct {
            request_id: []const u8,
            alarm_model_name: []const u8,
            key_value: ?[]const u8 = null,
            note: ?[]const u8 = null,
            snooze_duration: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request_id = "requestId",
                    .alarm_model_name = "alarmModelName",
                    .key_value = "keyValue",
                    .note = "note",
                    .snooze_duration = "snoozeDuration",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snooze_action_requests = "snoozeActionRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_snooze_alarm) } {
            return .{ .service_metadata = service_metadata, .action = batch_snooze_alarm };
        }
    },
    Response: type = struct {
        error_entries: ?[]BatchAlarmActionErrorEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_update_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detectors",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateDetector",
    Request: type = struct {
        detectors: []struct {
            message_id: []const u8,
            detector_model_name: []const u8,
            key_value: ?[]const u8 = null,
            state: struct {
                state_name: []const u8,
                variables: []struct {
                    name: []const u8,
                    value: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                },
                timers: []struct {
                    name: []const u8,
                    seconds: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .seconds = "seconds",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state_name = "stateName",
                        .variables = "variables",
                        .timers = "timers",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .detector_model_name = "detectorModelName",
                    .key_value = "keyValue",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detectors = "detectors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_detector) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_detector };
        }
    },
    Response: type = struct {
        batch_update_detector_error_entries: ?[]struct {
            message_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_update_detector_error_entries = "batchUpdateDetectorErrorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_alarm: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/alarms/{alarmModelName}/keyValues",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAlarm",
    Request: type = struct {
        alarm_model_name: []const u8,
        key_value: ?[]const u8 = null,

        pub const http_query = .{
            .key_value = "keyValue",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_name = "alarmModelName",
                .key_value = "keyValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_alarm) } {
            return .{ .service_metadata = service_metadata, .action = describe_alarm };
        }
    },
    Response: type = struct {
        alarm: ?struct {
            alarm_model_name: ?[]const u8 = null,
            alarm_model_version: ?[]const u8 = null,
            key_value: ?[]const u8 = null,
            alarm_state: ?struct {
                state_name: ?[]const u8 = null,
                rule_evaluation: ?struct {
                    simple_rule_evaluation: ?struct {
                        input_property_value: ?[]const u8 = null,
                        operator: ?[]const u8 = null,
                        threshold_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .input_property_value = "inputPropertyValue",
                                .operator = "operator",
                                .threshold_value = "thresholdValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .simple_rule_evaluation = "simpleRuleEvaluation",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                customer_action: ?struct {
                    action_name: ?[]const u8 = null,
                    snooze_action_configuration: ?struct {
                        snooze_duration: ?i64 = null,
                        note: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .snooze_duration = "snoozeDuration",
                                .note = "note",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    enable_action_configuration: ?struct {
                        note: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .note = "note",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    disable_action_configuration: ?struct {
                        note: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .note = "note",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    acknowledge_action_configuration: ?struct {
                        note: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .note = "note",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    reset_action_configuration: ?struct {
                        note: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .note = "note",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .action_name = "actionName",
                            .snooze_action_configuration = "snoozeActionConfiguration",
                            .enable_action_configuration = "enableActionConfiguration",
                            .disable_action_configuration = "disableActionConfiguration",
                            .acknowledge_action_configuration = "acknowledgeActionConfiguration",
                            .reset_action_configuration = "resetActionConfiguration",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                system_event: ?struct {
                    event_type: ?[]const u8 = null,
                    state_change_configuration: ?struct {
                        trigger_type: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .trigger_type = "triggerType",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .event_type = "eventType",
                            .state_change_configuration = "stateChangeConfiguration",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state_name = "stateName",
                        .rule_evaluation = "ruleEvaluation",
                        .customer_action = "customerAction",
                        .system_event = "systemEvent",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            severity: ?i64 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .alarm_model_name = "alarmModelName",
                    .alarm_model_version = "alarmModelVersion",
                    .key_value = "keyValue",
                    .alarm_state = "alarmState",
                    .severity = "severity",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm = "alarm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_detector: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detectors/{detectorModelName}/keyValues",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDetector",
    Request: type = struct {
        detector_model_name: []const u8,
        key_value: ?[]const u8 = null,

        pub const http_query = .{
            .key_value = "keyValue",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
                .key_value = "keyValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_detector) } {
            return .{ .service_metadata = service_metadata, .action = describe_detector };
        }
    },
    Response: type = struct {
        detector: ?struct {
            detector_model_name: ?[]const u8 = null,
            key_value: ?[]const u8 = null,
            detector_model_version: ?[]const u8 = null,
            state: ?struct {
                state_name: []const u8,
                variables: []struct {
                    name: []const u8,
                    value: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                },
                timers: []struct {
                    name: []const u8,
                    timestamp: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .timestamp = "timestamp",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state_name = "stateName",
                        .variables = "variables",
                        .timers = "timers",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .detector_model_name = "detectorModelName",
                    .key_value = "keyValue",
                    .detector_model_version = "detectorModelVersion",
                    .state = "state",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector = "detector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_alarms: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/alarms/{alarmModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAlarms",
    Request: type = struct {
        alarm_model_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_model_name = "alarmModelName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_alarms) } {
            return .{ .service_metadata = service_metadata, .action = list_alarms };
        }
    },
    Response: type = struct {
        alarm_summaries: ?[]struct {
            alarm_model_name: ?[]const u8 = null,
            alarm_model_version: ?[]const u8 = null,
            key_value: ?[]const u8 = null,
            state_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .alarm_model_name = "alarmModelName",
                    .alarm_model_version = "alarmModelVersion",
                    .key_value = "keyValue",
                    .state_name = "stateName",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_summaries = "alarmSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_detectors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detectors/{detectorModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDetectors",
    Request: type = struct {
        detector_model_name: []const u8,
        state_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .state_name = "stateName",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
                .state_name = "stateName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_detectors) } {
            return .{ .service_metadata = service_metadata, .action = list_detectors };
        }
    },
    Response: type = struct {
        detector_summaries: ?[]struct {
            detector_model_name: ?[]const u8 = null,
            key_value: ?[]const u8 = null,
            detector_model_version: ?[]const u8 = null,
            state: ?struct {
                state_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state_name = "stateName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .detector_model_name = "detectorModelName",
                    .key_value = "keyValue",
                    .detector_model_version = "detectorModelVersion",
                    .state = "state",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_summaries = "detectorSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const BatchAlarmActionErrorEntry = struct {
    request_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .request_id = "requestId",
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};
