const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-11-03";
pub const sdk_id: []const u8 = "IoTFleetHub";
pub const arn_namespace: ?[]const u8 = "iotfleethub";
pub const endpoint_prefix: []const u8 = "api.fleethub.iot";
pub const sigv4_name: []const u8 = "iotfleethub";
pub const name: []const u8 = "AWSIoTFleetHub";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-11-03",
    sdk_id: []const u8 = "IoTFleetHub",
    arn_namespace: ?[]const u8 = "iotfleethub",
    endpoint_prefix: []const u8 = "api.fleethub.iot",
    sigv4_name: []const u8 = "iotfleethub",
    name: []const u8 = "AWSIoTFleetHub",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        application_name: []const u8,
        application_description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_name = "applicationName",
                .application_description = "applicationDescription",
                .client_token = "clientToken",
                .role_arn = "roleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        application_id: []const u8,
        application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .application_arn = "applicationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const delete_application: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{applicationId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        application_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeApplication",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application) } {
            return .{ .service_metadata = service_metadata, .action = describe_application };
        }
    },
    Response: type = struct {
        application_id: []const u8,
        application_arn: []const u8,
        application_name: []const u8,
        application_description: ?[]const u8 = null,
        application_url: []const u8,
        application_state: []const u8,
        application_creation_date: i64,
        application_last_update_date: i64,
        role_arn: []const u8,
        sso_client_id: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .application_arn = "applicationArn",
                .application_name = "applicationName",
                .application_description = "applicationDescription",
                .application_url = "applicationUrl",
                .application_state = "applicationState",
                .application_creation_date = "applicationCreationDate",
                .application_last_update_date = "applicationLastUpdateDate",
                .role_arn = "roleArn",
                .sso_client_id = "ssoClientId",
                .error_message = "errorMessage",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        application_summaries: ?[]struct {
            application_id: []const u8,
            application_name: []const u8,
            application_description: ?[]const u8 = null,
            application_url: []const u8,
            application_creation_date: ?i64 = null,
            application_last_update_date: ?i64 = null,
            application_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "applicationId",
                    .application_name = "applicationName",
                    .application_description = "applicationDescription",
                    .application_url = "applicationUrl",
                    .application_creation_date = "applicationCreationDate",
                    .application_last_update_date = "applicationLastUpdateDate",
                    .application_state = "applicationState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_summaries = "applicationSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_application: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/applications/{applicationId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        application_id: []const u8,
        application_name: ?[]const u8 = null,
        application_description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .application_name = "applicationName",
                .application_description = "applicationDescription",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
