const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-09-29";
pub const sdk_id: []const u8 = "IoT Jobs Data Plane";
pub const arn_namespace: ?[]const u8 = "iot-jobs-data";
pub const endpoint_prefix: []const u8 = "data.jobs.iot";
pub const sigv4_name: []const u8 = "iot-jobs-data";
pub const name: []const u8 = "IotLaserThingJobManagerExternalService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-09-29",
    sdk_id: []const u8 = "IoT Jobs Data Plane",
    arn_namespace: ?[]const u8 = "iot-jobs-data",
    endpoint_prefix: []const u8 = "data.jobs.iot",
    sigv4_name: []const u8 = "iot-jobs-data",
    name: []const u8 = "IotLaserThingJobManagerExternalService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const describe_job_execution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things/{thingName}/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobExecution",
    Request: type = struct {
        job_id: []const u8,
        thing_name: []const u8,
        include_job_document: ?bool = null,
        execution_number: ?i64 = null,

        pub const http_query = .{
            .include_job_document = "includeJobDocument",
            .execution_number = "executionNumber",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .thing_name = "thingName",
                .include_job_document = "includeJobDocument",
                .execution_number = "executionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_execution };
        }
    },
    Response: type = struct {
        execution: ?JobExecution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution = "execution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateValidation,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        TerminalState,
        Throttling,
    },
} = .{};
pub const get_pending_job_executions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things/{thingName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPendingJobExecutions",
    Request: type = struct {
        thing_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pending_job_executions) } {
            return .{ .service_metadata = service_metadata, .action = get_pending_job_executions };
        }
    },
    Response: type = struct {
        in_progress_jobs: ?[]JobExecutionSummary = null,
        queued_jobs: ?[]JobExecutionSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .in_progress_jobs = "inProgressJobs",
                .queued_jobs = "queuedJobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateValidation,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const start_next_pending_job_execution: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/things/{thingName}/jobs/$next",
        .success_code = 200,
    };

    action_name: []const u8 = "StartNextPendingJobExecution",
    Request: type = struct {
        thing_name: []const u8,
        status_details: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        step_timeout_in_minutes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .status_details = "statusDetails",
                .step_timeout_in_minutes = "stepTimeoutInMinutes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "status_details", field_name))
                return try serializeMap(self.status_details, self.fieldNameFor("status_details"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_next_pending_job_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_next_pending_job_execution };
        }
    },
    Response: type = struct {
        execution: ?JobExecution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution = "execution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateValidation,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_job_execution: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/things/{thingName}/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJobExecution",
    Request: type = struct {
        job_id: []const u8,
        thing_name: []const u8,
        status: []const u8,
        status_details: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        step_timeout_in_minutes: ?i64 = null,
        expected_version: ?i64 = null,
        include_job_execution_state: ?bool = null,
        include_job_document: ?bool = null,
        execution_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .thing_name = "thingName",
                .status = "status",
                .status_details = "statusDetails",
                .step_timeout_in_minutes = "stepTimeoutInMinutes",
                .expected_version = "expectedVersion",
                .include_job_execution_state = "includeJobExecutionState",
                .include_job_document = "includeJobDocument",
                .execution_number = "executionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "status_details", field_name))
                return try serializeMap(self.status_details, self.fieldNameFor("status_details"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_execution) } {
            return .{ .service_metadata = service_metadata, .action = update_job_execution };
        }
    },
    Response: type = struct {
        execution_state: ?struct {
            status: ?[]const u8 = null,
            status_details: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            version_number: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "status",
                    .status_details = "statusDetails",
                    .version_number = "versionNumber",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "status_details", field_name))
                    return try serializeMap(self.status_details, self.fieldNameFor("status_details"), options, out_stream);
                return false;
            }
        } = null,
        job_document: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_state = "executionState",
                .job_document = "jobDocument",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateValidation,
        InvalidRequest,
        InvalidStateTransition,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const JobExecution = struct {
    job_id: ?[]const u8 = null,
    thing_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_details: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    queued_at: ?i64 = null,
    started_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    approximate_seconds_before_timed_out: ?i64 = null,
    version_number: ?i64 = null,
    execution_number: ?i64 = null,
    job_document: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "jobId",
            .thing_name = "thingName",
            .status = "status",
            .status_details = "statusDetails",
            .queued_at = "queuedAt",
            .started_at = "startedAt",
            .last_updated_at = "lastUpdatedAt",
            .approximate_seconds_before_timed_out = "approximateSecondsBeforeTimedOut",
            .version_number = "versionNumber",
            .execution_number = "executionNumber",
            .job_document = "jobDocument",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "status_details", field_name))
            return try serializeMap(self.status_details, self.fieldNameFor("status_details"), options, out_stream);
        return false;
    }
};

pub const JobExecutionSummary = struct {
    job_id: ?[]const u8 = null,
    queued_at: ?i64 = null,
    started_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    version_number: ?i64 = null,
    execution_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "jobId",
            .queued_at = "queuedAt",
            .started_at = "startedAt",
            .last_updated_at = "lastUpdatedAt",
            .version_number = "versionNumber",
            .execution_number = "executionNumber",
        };
        return @field(mappings, field_name);
    }
};
