const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "IoT RoboRunner";
pub const arn_namespace: ?[]const u8 = "iotroborunner";
pub const endpoint_prefix: []const u8 = "iotroborunner";
pub const sigv4_name: []const u8 = "iotroborunner";
pub const name: []const u8 = "IoTRoboRunner";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "IoT RoboRunner",
    arn_namespace: ?[]const u8 = "iotroborunner",
    endpoint_prefix: []const u8 = "iotroborunner",
    sigv4_name: []const u8 = "iotroborunner",
    name: []const u8 = "IoTRoboRunner",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_worker: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createWorker",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorker",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        name: []const u8,
        fleet: []const u8,
        additional_transient_properties: ?[]const u8 = null,
        additional_fixed_properties: ?[]const u8 = null,
        vendor_properties: ?VendorProperties = null,
        position: ?PositionCoordinates = null,
        orientation: ?Orientation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .name = "name",
                .fleet = "fleet",
                .additional_transient_properties = "additionalTransientProperties",
                .additional_fixed_properties = "additionalFixedProperties",
                .vendor_properties = "vendorProperties",
                .position = "position",
                .orientation = "orientation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_worker) } {
            return .{ .service_metadata = service_metadata, .action = create_worker };
        }
    },
    Response: type = struct {
        arn: []const u8,
        id: []const u8,
        created_at: i64,
        updated_at: i64,
        site: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .site = "site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_worker: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteWorker",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorker",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_worker) } {
            return .{ .service_metadata = service_metadata, .action = delete_worker };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_worker_fleet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteWorkerFleet",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkerFleet",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_worker_fleet) } {
            return .{ .service_metadata = service_metadata, .action = delete_worker_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_worker: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/getWorker",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorker",
    Request: type = struct {
        id: []const u8,

        pub const http_query = .{
            .id = "id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_worker) } {
            return .{ .service_metadata = service_metadata, .action = get_worker };
        }
    },
    Response: type = struct {
        arn: []const u8,
        id: []const u8,
        fleet: []const u8,
        site: []const u8,
        created_at: i64,
        updated_at: i64,
        name: []const u8,
        additional_transient_properties: ?[]const u8 = null,
        additional_fixed_properties: ?[]const u8 = null,
        vendor_properties: ?VendorProperties = null,
        position: ?PositionCoordinates = null,
        orientation: ?Orientation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .fleet = "fleet",
                .site = "site",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .name = "name",
                .additional_transient_properties = "additionalTransientProperties",
                .additional_fixed_properties = "additionalFixedProperties",
                .vendor_properties = "vendorProperties",
                .position = "position",
                .orientation = "orientation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_worker_fleet: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/getWorkerFleet",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkerFleet",
    Request: type = struct {
        id: []const u8,

        pub const http_query = .{
            .id = "id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_worker_fleet) } {
            return .{ .service_metadata = service_metadata, .action = get_worker_fleet };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        name: []const u8,
        site: []const u8,
        created_at: i64,
        updated_at: i64,
        additional_fixed_properties: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .name = "name",
                .site = "site",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .additional_fixed_properties = "additionalFixedProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_workers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/listWorkers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkers",
    Request: type = struct {
        site: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        fleet: ?[]const u8 = null,

        pub const http_query = .{
            .site = "site",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .fleet = "fleet",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "site",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .fleet = "fleet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workers) } {
            return .{ .service_metadata = service_metadata, .action = list_workers };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        workers: ?[]struct {
            arn: []const u8,
            id: []const u8,
            fleet: []const u8,
            created_at: i64,
            updated_at: i64,
            name: []const u8,
            site: []const u8,
            additional_transient_properties: ?[]const u8 = null,
            additional_fixed_properties: ?[]const u8 = null,
            vendor_properties: ?VendorProperties = null,
            position: ?PositionCoordinates = null,
            orientation: ?Orientation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .id = "id",
                    .fleet = "fleet",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .name = "name",
                    .site = "site",
                    .additional_transient_properties = "additionalTransientProperties",
                    .additional_fixed_properties = "additionalFixedProperties",
                    .vendor_properties = "vendorProperties",
                    .position = "position",
                    .orientation = "orientation",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .workers = "workers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_worker: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateWorker",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWorker",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        additional_transient_properties: ?[]const u8 = null,
        additional_fixed_properties: ?[]const u8 = null,
        vendor_properties: ?VendorProperties = null,
        position: ?PositionCoordinates = null,
        orientation: ?Orientation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .additional_transient_properties = "additionalTransientProperties",
                .additional_fixed_properties = "additionalFixedProperties",
                .vendor_properties = "vendorProperties",
                .position = "position",
                .orientation = "orientation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_worker) } {
            return .{ .service_metadata = service_metadata, .action = update_worker };
        }
    },
    Response: type = struct {
        arn: []const u8,
        id: []const u8,
        fleet: []const u8,
        updated_at: i64,
        name: []const u8,
        additional_transient_properties: ?[]const u8 = null,
        additional_fixed_properties: ?[]const u8 = null,
        orientation: ?Orientation = null,
        vendor_properties: ?VendorProperties = null,
        position: ?PositionCoordinates = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .fleet = "fleet",
                .updated_at = "updatedAt",
                .name = "name",
                .additional_transient_properties = "additionalTransientProperties",
                .additional_fixed_properties = "additionalFixedProperties",
                .orientation = "orientation",
                .vendor_properties = "vendorProperties",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_worker_fleet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateWorkerFleet",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWorkerFleet",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        additional_fixed_properties: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .additional_fixed_properties = "additionalFixedProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_worker_fleet) } {
            return .{ .service_metadata = service_metadata, .action = update_worker_fleet };
        }
    },
    Response: type = struct {
        arn: []const u8,
        id: []const u8,
        name: []const u8,
        updated_at: i64,
        additional_fixed_properties: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .name = "name",
                .updated_at = "updatedAt",
                .additional_fixed_properties = "additionalFixedProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const PositionCoordinates = union {
    cartesian_coordinates: ?CartesianCoordinates,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cartesian_coordinates = "cartesianCoordinates",
        };
        return @field(mappings, field_name);
    }
};

pub const CartesianCoordinates = struct {
    x: f64,
    y: f64,
    z: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .x = "x",
            .y = "y",
            .z = "z",
        };
        return @field(mappings, field_name);
    }
};

pub const VendorProperties = struct {
    vendor_worker_id: []const u8,
    vendor_worker_ip_address: ?[]const u8 = null,
    vendor_additional_transient_properties: ?[]const u8 = null,
    vendor_additional_fixed_properties: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vendor_worker_id = "vendorWorkerId",
            .vendor_worker_ip_address = "vendorWorkerIpAddress",
            .vendor_additional_transient_properties = "vendorAdditionalTransientProperties",
            .vendor_additional_fixed_properties = "vendorAdditionalFixedProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const Orientation = union {
    degrees: ?f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .degrees = "degrees",
        };
        return @field(mappings, field_name);
    }
};
