const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-10-05";
pub const sdk_id: []const u8 = "IoTSecureTunneling";
pub const arn_namespace: ?[]const u8 = "iotsecuredtunneling";
pub const endpoint_prefix: []const u8 = "api.tunneling.iot";
pub const sigv4_name: []const u8 = "IoTSecuredTunneling";
pub const name: []const u8 = "IoTSecuredTunneling";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-10-05",
    sdk_id: []const u8 = "IoTSecureTunneling",
    arn_namespace: ?[]const u8 = "iotsecuredtunneling",
    endpoint_prefix: []const u8 = "api.tunneling.iot",
    sigv4_name: []const u8 = "IoTSecuredTunneling",
    name: []const u8 = "IoTSecuredTunneling",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const close_tunnel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tunnels/{tunnelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CloseTunnel",
    Request: type = struct {
        tunnel_id: []const u8,
        delete: ?bool = null,

        pub const http_query = .{
            .delete = "delete",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tunnel_id = "tunnelId",
                .delete = "delete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(close_tunnel) } {
            return .{ .service_metadata = service_metadata, .action = close_tunnel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_tunnel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tunnels/{tunnelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTunnel",
    Request: type = struct {
        tunnel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tunnel_id = "tunnelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tunnel) } {
            return .{ .service_metadata = service_metadata, .action = describe_tunnel };
        }
    },
    Response: type = struct {
        tunnel: ?struct {
            tunnel_id: ?[]const u8 = null,
            tunnel_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            source_connection_state: ?ConnectionState = null,
            destination_connection_state: ?ConnectionState = null,
            description: ?[]const u8 = null,
            destination_config: ?DestinationConfig = null,
            timeout_config: ?TimeoutConfig = null,
            tags: ?[]Tag = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tunnel_id = "tunnelId",
                    .tunnel_arn = "tunnelArn",
                    .status = "status",
                    .source_connection_state = "sourceConnectionState",
                    .destination_connection_state = "destinationConnectionState",
                    .description = "description",
                    .destination_config = "destinationConfig",
                    .timeout_config = "timeoutConfig",
                    .tags = "tags",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tunnel = "tunnel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_tunnels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tunnels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTunnels",
    Request: type = struct {
        thing_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .thing_name = "thingName",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tunnels) } {
            return .{ .service_metadata = service_metadata, .action = list_tunnels };
        }
    },
    Response: type = struct {
        tunnel_summaries: ?[]struct {
            tunnel_id: ?[]const u8 = null,
            tunnel_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tunnel_id = "tunnelId",
                    .tunnel_arn = "tunnelArn",
                    .status = "status",
                    .description = "description",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tunnel_summaries = "tunnelSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const open_tunnel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tunnels",
        .success_code = 200,
    };

    action_name: []const u8 = "OpenTunnel",
    Request: type = struct {
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        destination_config: ?DestinationConfig = null,
        timeout_config: ?TimeoutConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .tags = "tags",
                .destination_config = "destinationConfig",
                .timeout_config = "timeoutConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(open_tunnel) } {
            return .{ .service_metadata = service_metadata, .action = open_tunnel };
        }
    },
    Response: type = struct {
        tunnel_id: ?[]const u8 = null,
        tunnel_arn: ?[]const u8 = null,
        source_access_token: ?[]const u8 = null,
        destination_access_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tunnel_id = "tunnelId",
                .tunnel_arn = "tunnelArn",
                .source_access_token = "sourceAccessToken",
                .destination_access_token = "destinationAccessToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const rotate_tunnel_access_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tunnel/{tunnelId}/rotate",
        .success_code = 200,
    };

    action_name: []const u8 = "RotateTunnelAccessToken",
    Request: type = struct {
        tunnel_id: []const u8,
        client_mode: []const u8,
        destination_config: ?DestinationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tunnel_id = "tunnelId",
                .client_mode = "clientMode",
                .destination_config = "destinationConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rotate_tunnel_access_token) } {
            return .{ .service_metadata = service_metadata, .action = rotate_tunnel_access_token };
        }
    },
    Response: type = struct {
        tunnel_arn: ?[]const u8 = null,
        source_access_token: ?[]const u8 = null,
        destination_access_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tunnel_arn = "tunnelArn",
                .source_access_token = "sourceAccessToken",
                .destination_access_token = "destinationAccessToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/untag",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfig = struct {
    thing_name: ?[]const u8 = null,
    services: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .thing_name = "thingName",
            .services = "services",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeoutConfig = struct {
    max_lifetime_timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_lifetime_timeout_minutes = "maxLifetimeTimeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionState = struct {
    status: ?[]const u8 = null,
    last_updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .last_updated_at = "lastUpdatedAt",
        };
        return @field(mappings, field_name);
    }
};
