const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-02";
pub const sdk_id: []const u8 = "IoTSiteWise";
pub const arn_namespace: ?[]const u8 = "iotsitewise";
pub const endpoint_prefix: []const u8 = "iotsitewise";
pub const sigv4_name: []const u8 = "iotsitewise";
pub const name: []const u8 = "AWSIoTSiteWise";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-02",
    sdk_id: []const u8 = "IoTSiteWise",
    arn_namespace: ?[]const u8 = "iotsitewise",
    endpoint_prefix: []const u8 = "iotsitewise",
    sigv4_name: []const u8 = "iotsitewise",
    name: []const u8 = "AWSIoTSiteWise",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_assets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assets/{assetId}/associate",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateAssets",
    Request: type = struct {
        asset_id: []const u8,
        hierarchy_id: []const u8,
        child_asset_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .hierarchy_id = "hierarchyId",
                .child_asset_id = "childAssetId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_assets) } {
            return .{ .service_metadata = service_metadata, .action = associate_assets };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_time_series_to_asset_property: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/timeseries/associate",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateTimeSeriesToAssetProperty",
    Request: type = struct {
        alias: []const u8,
        asset_id: []const u8,
        property_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .alias = "alias",
            .asset_id = "assetId",
            .property_id = "propertyId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias = "alias",
                .asset_id = "assetId",
                .property_id = "propertyId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_time_series_to_asset_property) } {
            return .{ .service_metadata = service_metadata, .action = associate_time_series_to_asset_property };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const batch_associate_project_assets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/projects/{projectId}/assets/associate",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchAssociateProjectAssets",
    Request: type = struct {
        project_id: []const u8,
        asset_ids: [][]const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .asset_ids = "assetIds",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_associate_project_assets) } {
            return .{ .service_metadata = service_metadata, .action = batch_associate_project_assets };
        }
    },
    Response: type = struct {
        errors: ?[]AssetErrorDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const batch_disassociate_project_assets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/projects/{projectId}/assets/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDisassociateProjectAssets",
    Request: type = struct {
        project_id: []const u8,
        asset_ids: [][]const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .asset_ids = "assetIds",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disassociate_project_assets) } {
            return .{ .service_metadata = service_metadata, .action = batch_disassociate_project_assets };
        }
    },
    Response: type = struct {
        errors: ?[]AssetErrorDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const batch_get_asset_property_aggregates: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/properties/batch/aggregates",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetAssetPropertyAggregates",
    Request: type = struct {
        entries: []struct {
            entry_id: []const u8,
            asset_id: ?[]const u8 = null,
            property_id: ?[]const u8 = null,
            property_alias: ?[]const u8 = null,
            aggregate_types: [][]const u8,
            resolution: []const u8,
            start_date: i64,
            end_date: i64,
            qualities: ?[][]const u8 = null,
            time_ordering: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .asset_id = "assetId",
                    .property_id = "propertyId",
                    .property_alias = "propertyAlias",
                    .aggregate_types = "aggregateTypes",
                    .resolution = "resolution",
                    .start_date = "startDate",
                    .end_date = "endDate",
                    .qualities = "qualities",
                    .time_ordering = "timeOrdering",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "entries",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_asset_property_aggregates) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_asset_property_aggregates };
        }
    },
    Response: type = struct {
        error_entries: []struct {
            error_code: []const u8,
            error_message: []const u8,
            entry_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                    .entry_id = "entryId",
                };
                return @field(mappings, field_name);
            }
        },
        success_entries: []struct {
            entry_id: []const u8,
            aggregated_values: []AggregatedValue,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .aggregated_values = "aggregatedValues",
                };
                return @field(mappings, field_name);
            }
        },
        skipped_entries: []struct {
            entry_id: []const u8,
            completion_status: []const u8,
            error_info: ?struct {
                error_code: []const u8,
                error_timestamp: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "errorCode",
                        .error_timestamp = "errorTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .completion_status = "completionStatus",
                    .error_info = "errorInfo",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
                .success_entries = "successEntries",
                .skipped_entries = "skippedEntries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_get_asset_property_value: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/properties/batch/latest",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetAssetPropertyValue",
    Request: type = struct {
        entries: []struct {
            entry_id: []const u8,
            asset_id: ?[]const u8 = null,
            property_id: ?[]const u8 = null,
            property_alias: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .asset_id = "assetId",
                    .property_id = "propertyId",
                    .property_alias = "propertyAlias",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "entries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_asset_property_value) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_asset_property_value };
        }
    },
    Response: type = struct {
        error_entries: []struct {
            error_code: []const u8,
            error_message: []const u8,
            entry_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                    .entry_id = "entryId",
                };
                return @field(mappings, field_name);
            }
        },
        success_entries: []struct {
            entry_id: []const u8,
            asset_property_value: ?AssetPropertyValue = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .asset_property_value = "assetPropertyValue",
                };
                return @field(mappings, field_name);
            }
        },
        skipped_entries: []struct {
            entry_id: []const u8,
            completion_status: []const u8,
            error_info: ?struct {
                error_code: []const u8,
                error_timestamp: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "errorCode",
                        .error_timestamp = "errorTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .completion_status = "completionStatus",
                    .error_info = "errorInfo",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
                .success_entries = "successEntries",
                .skipped_entries = "skippedEntries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_get_asset_property_value_history: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/properties/batch/history",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetAssetPropertyValueHistory",
    Request: type = struct {
        entries: []struct {
            entry_id: []const u8,
            asset_id: ?[]const u8 = null,
            property_id: ?[]const u8 = null,
            property_alias: ?[]const u8 = null,
            start_date: ?i64 = null,
            end_date: ?i64 = null,
            qualities: ?[][]const u8 = null,
            time_ordering: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .asset_id = "assetId",
                    .property_id = "propertyId",
                    .property_alias = "propertyAlias",
                    .start_date = "startDate",
                    .end_date = "endDate",
                    .qualities = "qualities",
                    .time_ordering = "timeOrdering",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "entries",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_asset_property_value_history) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_asset_property_value_history };
        }
    },
    Response: type = struct {
        error_entries: []struct {
            error_code: []const u8,
            error_message: []const u8,
            entry_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                    .entry_id = "entryId",
                };
                return @field(mappings, field_name);
            }
        },
        success_entries: []struct {
            entry_id: []const u8,
            asset_property_value_history: []AssetPropertyValue,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .asset_property_value_history = "assetPropertyValueHistory",
                };
                return @field(mappings, field_name);
            }
        },
        skipped_entries: []struct {
            entry_id: []const u8,
            completion_status: []const u8,
            error_info: ?struct {
                error_code: []const u8,
                error_timestamp: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "errorCode",
                        .error_timestamp = "errorTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .completion_status = "completionStatus",
                    .error_info = "errorInfo",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
                .success_entries = "successEntries",
                .skipped_entries = "skippedEntries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_put_asset_property_value: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/properties",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchPutAssetPropertyValue",
    Request: type = struct {
        entries: []struct {
            entry_id: []const u8,
            asset_id: ?[]const u8 = null,
            property_id: ?[]const u8 = null,
            property_alias: ?[]const u8 = null,
            property_values: []AssetPropertyValue,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .asset_id = "assetId",
                    .property_id = "propertyId",
                    .property_alias = "propertyAlias",
                    .property_values = "propertyValues",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_asset_property_value) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_asset_property_value };
        }
    },
    Response: type = struct {
        error_entries: []struct {
            entry_id: []const u8,
            errors: []struct {
                error_code: []const u8,
                error_message: []const u8,
                timestamps: []TimeInNanos,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "errorCode",
                        .error_message = "errorMessage",
                        .timestamps = "timestamps",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .errors = "errors",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "errorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_access_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/access-policies",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAccessPolicy",
    Request: type = struct {
        access_policy_identity: Identity,
        access_policy_resource: Resource,
        access_policy_permission: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policy_identity = "accessPolicyIdentity",
                .access_policy_resource = "accessPolicyResource",
                .access_policy_permission = "accessPolicyPermission",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_access_policy };
        }
    },
    Response: type = struct {
        access_policy_id: []const u8,
        access_policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policy_id = "accessPolicyId",
                .access_policy_arn = "accessPolicyArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_asset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assets",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateAsset",
    Request: type = struct {
        asset_name: []const u8,
        asset_model_id: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        asset_description: ?[]const u8 = null,
        asset_id: ?[]const u8 = null,
        asset_external_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_name = "assetName",
                .asset_model_id = "assetModelId",
                .client_token = "clientToken",
                .tags = "tags",
                .asset_description = "assetDescription",
                .asset_id = "assetId",
                .asset_external_id = "assetExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_asset) } {
            return .{ .service_metadata = service_metadata, .action = create_asset };
        }
    },
    Response: type = struct {
        asset_id: []const u8,
        asset_arn: []const u8,
        asset_status: AssetStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .asset_arn = "assetArn",
                .asset_status = "assetStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_asset_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/asset-models",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateAssetModel",
    Request: type = struct {
        asset_model_name: []const u8,
        asset_model_description: ?[]const u8 = null,
        asset_model_properties: ?[]AssetModelPropertyDefinition = null,
        asset_model_hierarchies: ?[]struct {
            name: []const u8,
            child_asset_model_id: []const u8,
            id: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .child_asset_model_id = "childAssetModelId",
                    .id = "id",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        asset_model_composite_models: ?[]struct {
            name: []const u8,
            description: ?[]const u8 = null,
            type: []const u8,
            properties: ?[]AssetModelPropertyDefinition = null,
            id: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .description = "description",
                    .type = "type",
                    .properties = "properties",
                    .id = "id",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        asset_model_id: ?[]const u8 = null,
        asset_model_external_id: ?[]const u8 = null,
        asset_model_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_name = "assetModelName",
                .asset_model_description = "assetModelDescription",
                .asset_model_properties = "assetModelProperties",
                .asset_model_hierarchies = "assetModelHierarchies",
                .asset_model_composite_models = "assetModelCompositeModels",
                .client_token = "clientToken",
                .tags = "tags",
                .asset_model_id = "assetModelId",
                .asset_model_external_id = "assetModelExternalId",
                .asset_model_type = "assetModelType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_asset_model) } {
            return .{ .service_metadata = service_metadata, .action = create_asset_model };
        }
    },
    Response: type = struct {
        asset_model_id: []const u8,
        asset_model_arn: []const u8,
        asset_model_status: AssetModelStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .asset_model_arn = "assetModelArn",
                .asset_model_status = "assetModelStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_asset_model_composite_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/asset-models/{assetModelId}/composite-models",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateAssetModelCompositeModel",
    Request: type = struct {
        asset_model_id: []const u8,
        parent_asset_model_composite_model_id: ?[]const u8 = null,
        asset_model_composite_model_external_id: ?[]const u8 = null,
        asset_model_composite_model_id: ?[]const u8 = null,
        asset_model_composite_model_description: ?[]const u8 = null,
        asset_model_composite_model_name: []const u8,
        asset_model_composite_model_type: []const u8,
        client_token: ?[]const u8 = null,
        composed_asset_model_id: ?[]const u8 = null,
        asset_model_composite_model_properties: ?[]AssetModelPropertyDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .parent_asset_model_composite_model_id = "parentAssetModelCompositeModelId",
                .asset_model_composite_model_external_id = "assetModelCompositeModelExternalId",
                .asset_model_composite_model_id = "assetModelCompositeModelId",
                .asset_model_composite_model_description = "assetModelCompositeModelDescription",
                .asset_model_composite_model_name = "assetModelCompositeModelName",
                .asset_model_composite_model_type = "assetModelCompositeModelType",
                .client_token = "clientToken",
                .composed_asset_model_id = "composedAssetModelId",
                .asset_model_composite_model_properties = "assetModelCompositeModelProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_asset_model_composite_model) } {
            return .{ .service_metadata = service_metadata, .action = create_asset_model_composite_model };
        }
    },
    Response: type = struct {
        asset_model_composite_model_id: []const u8,
        asset_model_composite_model_path: []AssetModelCompositeModelPathSegment,
        asset_model_status: AssetModelStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_composite_model_id = "assetModelCompositeModelId",
                .asset_model_composite_model_path = "assetModelCompositeModelPath",
                .asset_model_status = "assetModelStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_bulk_import_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/jobs",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBulkImportJob",
    Request: type = struct {
        job_name: []const u8,
        job_role_arn: []const u8,
        files: []File,
        error_report_location: ErrorReportLocation,
        job_configuration: JobConfiguration,
        adaptive_ingestion: ?bool = null,
        delete_files_after_import: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "jobName",
                .job_role_arn = "jobRoleArn",
                .files = "files",
                .error_report_location = "errorReportLocation",
                .job_configuration = "jobConfiguration",
                .adaptive_ingestion = "adaptiveIngestion",
                .delete_files_after_import = "deleteFilesAfterImport",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bulk_import_job) } {
            return .{ .service_metadata = service_metadata, .action = create_bulk_import_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        job_name: []const u8,
        job_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .job_name = "jobName",
                .job_status = "jobStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_dashboard: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/dashboards",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDashboard",
    Request: type = struct {
        project_id: []const u8,
        dashboard_name: []const u8,
        dashboard_description: ?[]const u8 = null,
        dashboard_definition: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .dashboard_name = "dashboardName",
                .dashboard_description = "dashboardDescription",
                .dashboard_definition = "dashboardDefinition",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = create_dashboard };
        }
    },
    Response: type = struct {
        dashboard_id: []const u8,
        dashboard_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "dashboardId",
                .dashboard_arn = "dashboardArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_gateway: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/20200301/gateways",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateGateway",
    Request: type = struct {
        gateway_name: []const u8,
        gateway_platform: GatewayPlatform,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_name = "gatewayName",
                .gateway_platform = "gatewayPlatform",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_gateway };
        }
    },
    Response: type = struct {
        gateway_id: []const u8,
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "gatewayId",
                .gateway_arn = "gatewayArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_portal: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/portals",
        .success_code = 202,
    };

    action_name: []const u8 = "CreatePortal",
    Request: type = struct {
        portal_name: []const u8,
        portal_description: ?[]const u8 = null,
        portal_contact_email: []const u8,
        client_token: ?[]const u8 = null,
        portal_logo_image_file: ?ImageFile = null,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        portal_auth_mode: ?[]const u8 = null,
        notification_sender_email: ?[]const u8 = null,
        alarms: ?Alarms = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_name = "portalName",
                .portal_description = "portalDescription",
                .portal_contact_email = "portalContactEmail",
                .client_token = "clientToken",
                .portal_logo_image_file = "portalLogoImageFile",
                .role_arn = "roleArn",
                .tags = "tags",
                .portal_auth_mode = "portalAuthMode",
                .notification_sender_email = "notificationSenderEmail",
                .alarms = "alarms",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_portal) } {
            return .{ .service_metadata = service_metadata, .action = create_portal };
        }
    },
    Response: type = struct {
        portal_id: []const u8,
        portal_arn: []const u8,
        portal_start_url: []const u8,
        portal_status: PortalStatus,
        sso_application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_id = "portalId",
                .portal_arn = "portalArn",
                .portal_start_url = "portalStartUrl",
                .portal_status = "portalStatus",
                .sso_application_id = "ssoApplicationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_project: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/projects",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        portal_id: []const u8,
        project_name: []const u8,
        project_description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_id = "portalId",
                .project_name = "projectName",
                .project_description = "projectDescription",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        project_id: []const u8,
        project_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .project_arn = "projectArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_access_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/access-policies/{accessPolicyId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAccessPolicy",
    Request: type = struct {
        access_policy_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policy_id = "accessPolicyId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_asset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/assets/{assetId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteAsset",
    Request: type = struct {
        asset_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_asset) } {
            return .{ .service_metadata = service_metadata, .action = delete_asset };
        }
    },
    Response: type = struct {
        asset_status: AssetStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_status = "assetStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_asset_model: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/asset-models/{assetModelId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteAssetModel",
    Request: type = struct {
        asset_model_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_asset_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_asset_model };
        }
    },
    Response: type = struct {
        asset_model_status: AssetModelStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_status = "assetModelStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_asset_model_composite_model: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/asset-models/{assetModelId}/composite-models/{assetModelCompositeModelId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteAssetModelCompositeModel",
    Request: type = struct {
        asset_model_id: []const u8,
        asset_model_composite_model_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .asset_model_composite_model_id = "assetModelCompositeModelId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_asset_model_composite_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_asset_model_composite_model };
        }
    },
    Response: type = struct {
        asset_model_status: AssetModelStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_status = "assetModelStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_dashboard: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/dashboards/{dashboardId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDashboard",
    Request: type = struct {
        dashboard_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "dashboardId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = delete_dashboard };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_gateway: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/20200301/gateways/{gatewayId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGateway",
    Request: type = struct {
        gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "gatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_gateway };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_portal: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/portals/{portalId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeletePortal",
    Request: type = struct {
        portal_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_id = "portalId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_portal) } {
            return .{ .service_metadata = service_metadata, .action = delete_portal };
        }
    },
    Response: type = struct {
        portal_status: PortalStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_status = "portalStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_project: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/projects/{projectId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        project_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_time_series: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/timeseries/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTimeSeries",
    Request: type = struct {
        alias: ?[]const u8 = null,
        asset_id: ?[]const u8 = null,
        property_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .alias = "alias",
            .asset_id = "assetId",
            .property_id = "propertyId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias = "alias",
                .asset_id = "assetId",
                .property_id = "propertyId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_time_series) } {
            return .{ .service_metadata = service_metadata, .action = delete_time_series };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_access_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/access-policies/{accessPolicyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccessPolicy",
    Request: type = struct {
        access_policy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policy_id = "accessPolicyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_access_policy };
        }
    },
    Response: type = struct {
        access_policy_id: []const u8,
        access_policy_arn: []const u8,
        access_policy_identity: Identity,
        access_policy_resource: Resource,
        access_policy_permission: []const u8,
        access_policy_creation_date: i64,
        access_policy_last_update_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policy_id = "accessPolicyId",
                .access_policy_arn = "accessPolicyArn",
                .access_policy_identity = "accessPolicyIdentity",
                .access_policy_resource = "accessPolicyResource",
                .access_policy_permission = "accessPolicyPermission",
                .access_policy_creation_date = "accessPolicyCreationDate",
                .access_policy_last_update_date = "accessPolicyLastUpdateDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_action: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/actions/{actionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAction",
    Request: type = struct {
        action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_id = "actionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_action) } {
            return .{ .service_metadata = service_metadata, .action = describe_action };
        }
    },
    Response: type = struct {
        action_id: []const u8,
        target_resource: TargetResource,
        action_definition_id: []const u8,
        action_payload: ActionPayload,
        execution_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_id = "actionId",
                .target_resource = "targetResource",
                .action_definition_id = "actionDefinitionId",
                .action_payload = "actionPayload",
                .execution_time = "executionTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_asset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets/{assetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAsset",
    Request: type = struct {
        asset_id: []const u8,
        exclude_properties: ?bool = null,

        pub const http_query = .{
            .exclude_properties = "excludeProperties",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .exclude_properties = "excludeProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_asset) } {
            return .{ .service_metadata = service_metadata, .action = describe_asset };
        }
    },
    Response: type = struct {
        asset_id: []const u8,
        asset_arn: []const u8,
        asset_name: []const u8,
        asset_model_id: []const u8,
        asset_properties: []AssetProperty,
        asset_hierarchies: []AssetHierarchy,
        asset_composite_models: ?[]struct {
            name: []const u8,
            description: ?[]const u8 = null,
            type: []const u8,
            properties: []AssetProperty,
            id: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .description = "description",
                    .type = "type",
                    .properties = "properties",
                    .id = "id",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        asset_creation_date: i64,
        asset_last_update_date: i64,
        asset_status: AssetStatus,
        asset_description: ?[]const u8 = null,
        asset_composite_model_summaries: ?[]AssetCompositeModelSummary = null,
        asset_external_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .asset_arn = "assetArn",
                .asset_name = "assetName",
                .asset_model_id = "assetModelId",
                .asset_properties = "assetProperties",
                .asset_hierarchies = "assetHierarchies",
                .asset_composite_models = "assetCompositeModels",
                .asset_creation_date = "assetCreationDate",
                .asset_last_update_date = "assetLastUpdateDate",
                .asset_status = "assetStatus",
                .asset_description = "assetDescription",
                .asset_composite_model_summaries = "assetCompositeModelSummaries",
                .asset_external_id = "assetExternalId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_asset_composite_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets/{assetId}/composite-models/{assetCompositeModelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAssetCompositeModel",
    Request: type = struct {
        asset_id: []const u8,
        asset_composite_model_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .asset_composite_model_id = "assetCompositeModelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_asset_composite_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_asset_composite_model };
        }
    },
    Response: type = struct {
        asset_id: []const u8,
        asset_composite_model_id: []const u8,
        asset_composite_model_external_id: ?[]const u8 = null,
        asset_composite_model_path: []AssetCompositeModelPathSegment,
        asset_composite_model_name: []const u8,
        asset_composite_model_description: []const u8,
        asset_composite_model_type: []const u8,
        asset_composite_model_properties: []AssetProperty,
        asset_composite_model_summaries: []AssetCompositeModelSummary,
        action_definitions: ?[]ActionDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .asset_composite_model_id = "assetCompositeModelId",
                .asset_composite_model_external_id = "assetCompositeModelExternalId",
                .asset_composite_model_path = "assetCompositeModelPath",
                .asset_composite_model_name = "assetCompositeModelName",
                .asset_composite_model_description = "assetCompositeModelDescription",
                .asset_composite_model_type = "assetCompositeModelType",
                .asset_composite_model_properties = "assetCompositeModelProperties",
                .asset_composite_model_summaries = "assetCompositeModelSummaries",
                .action_definitions = "actionDefinitions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_asset_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/asset-models/{assetModelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAssetModel",
    Request: type = struct {
        asset_model_id: []const u8,
        exclude_properties: ?bool = null,

        pub const http_query = .{
            .exclude_properties = "excludeProperties",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .exclude_properties = "excludeProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_asset_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_asset_model };
        }
    },
    Response: type = struct {
        asset_model_id: []const u8,
        asset_model_arn: []const u8,
        asset_model_name: []const u8,
        asset_model_description: []const u8,
        asset_model_properties: []AssetModelProperty,
        asset_model_hierarchies: []AssetModelHierarchy,
        asset_model_composite_models: ?[]AssetModelCompositeModel = null,
        asset_model_creation_date: i64,
        asset_model_last_update_date: i64,
        asset_model_status: AssetModelStatus,
        asset_model_type: ?[]const u8 = null,
        asset_model_composite_model_summaries: ?[]AssetModelCompositeModelSummary = null,
        asset_model_external_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .asset_model_arn = "assetModelArn",
                .asset_model_name = "assetModelName",
                .asset_model_description = "assetModelDescription",
                .asset_model_properties = "assetModelProperties",
                .asset_model_hierarchies = "assetModelHierarchies",
                .asset_model_composite_models = "assetModelCompositeModels",
                .asset_model_creation_date = "assetModelCreationDate",
                .asset_model_last_update_date = "assetModelLastUpdateDate",
                .asset_model_status = "assetModelStatus",
                .asset_model_type = "assetModelType",
                .asset_model_composite_model_summaries = "assetModelCompositeModelSummaries",
                .asset_model_external_id = "assetModelExternalId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_asset_model_composite_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/asset-models/{assetModelId}/composite-models/{assetModelCompositeModelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAssetModelCompositeModel",
    Request: type = struct {
        asset_model_id: []const u8,
        asset_model_composite_model_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .asset_model_composite_model_id = "assetModelCompositeModelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_asset_model_composite_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_asset_model_composite_model };
        }
    },
    Response: type = struct {
        asset_model_id: []const u8,
        asset_model_composite_model_id: []const u8,
        asset_model_composite_model_external_id: ?[]const u8 = null,
        asset_model_composite_model_path: []AssetModelCompositeModelPathSegment,
        asset_model_composite_model_name: []const u8,
        asset_model_composite_model_description: []const u8,
        asset_model_composite_model_type: []const u8,
        asset_model_composite_model_properties: []AssetModelProperty,
        composition_details: ?struct {
            composition_relationship: ?[]struct {
                id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "id",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .composition_relationship = "compositionRelationship",
                };
                return @field(mappings, field_name);
            }
        } = null,
        asset_model_composite_model_summaries: []AssetModelCompositeModelSummary,
        action_definitions: ?[]ActionDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .asset_model_composite_model_id = "assetModelCompositeModelId",
                .asset_model_composite_model_external_id = "assetModelCompositeModelExternalId",
                .asset_model_composite_model_path = "assetModelCompositeModelPath",
                .asset_model_composite_model_name = "assetModelCompositeModelName",
                .asset_model_composite_model_description = "assetModelCompositeModelDescription",
                .asset_model_composite_model_type = "assetModelCompositeModelType",
                .asset_model_composite_model_properties = "assetModelCompositeModelProperties",
                .composition_details = "compositionDetails",
                .asset_model_composite_model_summaries = "assetModelCompositeModelSummaries",
                .action_definitions = "actionDefinitions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_asset_property: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets/{assetId}/properties/{propertyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAssetProperty",
    Request: type = struct {
        asset_id: []const u8,
        property_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .property_id = "propertyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_asset_property) } {
            return .{ .service_metadata = service_metadata, .action = describe_asset_property };
        }
    },
    Response: type = struct {
        asset_id: []const u8,
        asset_name: []const u8,
        asset_model_id: []const u8,
        asset_property: ?Property = null,
        composite_model: ?struct {
            name: []const u8,
            type: []const u8,
            asset_property: Property,
            id: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .type = "type",
                    .asset_property = "assetProperty",
                    .id = "id",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        asset_external_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .asset_name = "assetName",
                .asset_model_id = "assetModelId",
                .asset_property = "assetProperty",
                .composite_model = "compositeModel",
                .asset_external_id = "assetExternalId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_bulk_import_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBulkImportJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bulk_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_bulk_import_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        job_name: []const u8,
        job_status: []const u8,
        job_role_arn: []const u8,
        files: []File,
        error_report_location: ErrorReportLocation,
        job_configuration: JobConfiguration,
        job_creation_date: i64,
        job_last_update_date: i64,
        adaptive_ingestion: ?bool = null,
        delete_files_after_import: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .job_name = "jobName",
                .job_status = "jobStatus",
                .job_role_arn = "jobRoleArn",
                .files = "files",
                .error_report_location = "errorReportLocation",
                .job_configuration = "jobConfiguration",
                .job_creation_date = "jobCreationDate",
                .job_last_update_date = "jobLastUpdateDate",
                .adaptive_ingestion = "adaptiveIngestion",
                .delete_files_after_import = "deleteFilesAfterImport",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_dashboard: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/dashboards/{dashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDashboard",
    Request: type = struct {
        dashboard_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "dashboardId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = describe_dashboard };
        }
    },
    Response: type = struct {
        dashboard_id: []const u8,
        dashboard_arn: []const u8,
        dashboard_name: []const u8,
        project_id: []const u8,
        dashboard_description: ?[]const u8 = null,
        dashboard_definition: []const u8,
        dashboard_creation_date: i64,
        dashboard_last_update_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "dashboardId",
                .dashboard_arn = "dashboardArn",
                .dashboard_name = "dashboardName",
                .project_id = "projectId",
                .dashboard_description = "dashboardDescription",
                .dashboard_definition = "dashboardDefinition",
                .dashboard_creation_date = "dashboardCreationDate",
                .dashboard_last_update_date = "dashboardLastUpdateDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_default_encryption_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/configuration/account/encryption",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDefaultEncryptionConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_default_encryption_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_default_encryption_configuration };
        }
    },
    Response: type = struct {
        encryption_type: []const u8,
        kms_key_arn: ?[]const u8 = null,
        configuration_status: ConfigurationStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_type = "encryptionType",
                .kms_key_arn = "kmsKeyArn",
                .configuration_status = "configurationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const describe_gateway: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/20200301/gateways/{gatewayId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGateway",
    Request: type = struct {
        gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "gatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_gateway) } {
            return .{ .service_metadata = service_metadata, .action = describe_gateway };
        }
    },
    Response: type = struct {
        gateway_id: []const u8,
        gateway_name: []const u8,
        gateway_arn: []const u8,
        gateway_platform: ?GatewayPlatform = null,
        gateway_capability_summaries: []GatewayCapabilitySummary,
        creation_date: i64,
        last_update_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "gatewayId",
                .gateway_name = "gatewayName",
                .gateway_arn = "gatewayArn",
                .gateway_platform = "gatewayPlatform",
                .gateway_capability_summaries = "gatewayCapabilitySummaries",
                .creation_date = "creationDate",
                .last_update_date = "lastUpdateDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_gateway_capability_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/20200301/gateways/{gatewayId}/capability/{capabilityNamespace}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGatewayCapabilityConfiguration",
    Request: type = struct {
        gateway_id: []const u8,
        capability_namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "gatewayId",
                .capability_namespace = "capabilityNamespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_gateway_capability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_gateway_capability_configuration };
        }
    },
    Response: type = struct {
        gateway_id: []const u8,
        capability_namespace: []const u8,
        capability_configuration: []const u8,
        capability_sync_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "gatewayId",
                .capability_namespace = "capabilityNamespace",
                .capability_configuration = "capabilityConfiguration",
                .capability_sync_status = "capabilitySyncStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_logging_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/logging",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeLoggingOptions",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_logging_options };
        }
    },
    Response: type = struct {
        logging_options: LoggingOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_options = "loggingOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_portal: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/portals/{portalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePortal",
    Request: type = struct {
        portal_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_id = "portalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_portal) } {
            return .{ .service_metadata = service_metadata, .action = describe_portal };
        }
    },
    Response: type = struct {
        portal_id: []const u8,
        portal_arn: []const u8,
        portal_name: []const u8,
        portal_description: ?[]const u8 = null,
        portal_client_id: []const u8,
        portal_start_url: []const u8,
        portal_contact_email: []const u8,
        portal_status: PortalStatus,
        portal_creation_date: i64,
        portal_last_update_date: i64,
        portal_logo_image_location: ?struct {
            id: []const u8,
            url: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .url = "url",
                };
                return @field(mappings, field_name);
            }
        } = null,
        role_arn: ?[]const u8 = null,
        portal_auth_mode: ?[]const u8 = null,
        notification_sender_email: ?[]const u8 = null,
        alarms: ?Alarms = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_id = "portalId",
                .portal_arn = "portalArn",
                .portal_name = "portalName",
                .portal_description = "portalDescription",
                .portal_client_id = "portalClientId",
                .portal_start_url = "portalStartUrl",
                .portal_contact_email = "portalContactEmail",
                .portal_status = "portalStatus",
                .portal_creation_date = "portalCreationDate",
                .portal_last_update_date = "portalLastUpdateDate",
                .portal_logo_image_location = "portalLogoImageLocation",
                .role_arn = "roleArn",
                .portal_auth_mode = "portalAuthMode",
                .notification_sender_email = "notificationSenderEmail",
                .alarms = "alarms",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_project: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects/{projectId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProject",
    Request: type = struct {
        project_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project) } {
            return .{ .service_metadata = service_metadata, .action = describe_project };
        }
    },
    Response: type = struct {
        project_id: []const u8,
        project_arn: []const u8,
        project_name: []const u8,
        portal_id: []const u8,
        project_description: ?[]const u8 = null,
        project_creation_date: i64,
        project_last_update_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .project_arn = "projectArn",
                .project_name = "projectName",
                .portal_id = "portalId",
                .project_description = "projectDescription",
                .project_creation_date = "projectCreationDate",
                .project_last_update_date = "projectLastUpdateDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_storage_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/configuration/account/storage",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeStorageConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_storage_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_storage_configuration };
        }
    },
    Response: type = struct {
        storage_type: []const u8,
        multi_layer_storage: ?MultiLayerStorage = null,
        disassociated_data_storage: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,
        configuration_status: ConfigurationStatus,
        last_update_date: ?i64 = null,
        warm_tier: ?[]const u8 = null,
        warm_tier_retention_period: ?WarmTierRetentionPeriod = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_type = "storageType",
                .multi_layer_storage = "multiLayerStorage",
                .disassociated_data_storage = "disassociatedDataStorage",
                .retention_period = "retentionPeriod",
                .configuration_status = "configurationStatus",
                .last_update_date = "lastUpdateDate",
                .warm_tier = "warmTier",
                .warm_tier_retention_period = "warmTierRetentionPeriod",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_time_series: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/timeseries/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTimeSeries",
    Request: type = struct {
        alias: ?[]const u8 = null,
        asset_id: ?[]const u8 = null,
        property_id: ?[]const u8 = null,

        pub const http_query = .{
            .alias = "alias",
            .asset_id = "assetId",
            .property_id = "propertyId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias = "alias",
                .asset_id = "assetId",
                .property_id = "propertyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_time_series) } {
            return .{ .service_metadata = service_metadata, .action = describe_time_series };
        }
    },
    Response: type = struct {
        asset_id: ?[]const u8 = null,
        property_id: ?[]const u8 = null,
        alias: ?[]const u8 = null,
        time_series_id: []const u8,
        data_type: []const u8,
        data_type_spec: ?[]const u8 = null,
        time_series_creation_date: i64,
        time_series_last_update_date: i64,
        time_series_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .property_id = "propertyId",
                .alias = "alias",
                .time_series_id = "timeSeriesId",
                .data_type = "dataType",
                .data_type_spec = "dataTypeSpec",
                .time_series_creation_date = "timeSeriesCreationDate",
                .time_series_last_update_date = "timeSeriesLastUpdateDate",
                .time_series_arn = "timeSeriesArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_assets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assets/{assetId}/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateAssets",
    Request: type = struct {
        asset_id: []const u8,
        hierarchy_id: []const u8,
        child_asset_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .hierarchy_id = "hierarchyId",
                .child_asset_id = "childAssetId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_assets) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_assets };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_time_series_from_asset_property: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/timeseries/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateTimeSeriesFromAssetProperty",
    Request: type = struct {
        alias: []const u8,
        asset_id: []const u8,
        property_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .alias = "alias",
            .asset_id = "assetId",
            .property_id = "propertyId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias = "alias",
                .asset_id = "assetId",
                .property_id = "propertyId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_time_series_from_asset_property) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_time_series_from_asset_property };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const execute_action: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/actions",
        .success_code = 202,
    };

    action_name: []const u8 = "ExecuteAction",
    Request: type = struct {
        target_resource: TargetResource,
        action_definition_id: []const u8,
        action_payload: ActionPayload,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_resource = "targetResource",
                .action_definition_id = "actionDefinitionId",
                .action_payload = "actionPayload",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_action) } {
            return .{ .service_metadata = service_metadata, .action = execute_action };
        }
    },
    Response: type = struct {
        action_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_id = "actionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const execute_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queries/execution",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteQuery",
    Request: type = struct {
        query_statement: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_statement = "queryStatement",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_query };
        }
    },
    Response: type = struct {
        columns: ?[]struct {
            name: ?[]const u8 = null,
            type: ?struct {
                scalar_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .scalar_type = "scalarType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        rows: ?[]Row = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .columns = "columns",
                .rows = "rows",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidRequest,
        QueryTimeout,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const get_asset_property_aggregates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/properties/aggregates",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssetPropertyAggregates",
    Request: type = struct {
        asset_id: ?[]const u8 = null,
        property_id: ?[]const u8 = null,
        property_alias: ?[]const u8 = null,
        aggregate_types: [][]const u8,
        resolution: []const u8,
        qualities: ?[][]const u8 = null,
        start_date: i64,
        end_date: i64,
        time_ordering: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .asset_id = "assetId",
            .property_id = "propertyId",
            .property_alias = "propertyAlias",
            .aggregate_types = "aggregateTypes",
            .resolution = "resolution",
            .qualities = "qualities",
            .start_date = "startDate",
            .end_date = "endDate",
            .time_ordering = "timeOrdering",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .property_id = "propertyId",
                .property_alias = "propertyAlias",
                .aggregate_types = "aggregateTypes",
                .resolution = "resolution",
                .qualities = "qualities",
                .start_date = "startDate",
                .end_date = "endDate",
                .time_ordering = "timeOrdering",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_asset_property_aggregates) } {
            return .{ .service_metadata = service_metadata, .action = get_asset_property_aggregates };
        }
    },
    Response: type = struct {
        aggregated_values: []AggregatedValue,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aggregated_values = "aggregatedValues",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_asset_property_value: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/properties/latest",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssetPropertyValue",
    Request: type = struct {
        asset_id: ?[]const u8 = null,
        property_id: ?[]const u8 = null,
        property_alias: ?[]const u8 = null,

        pub const http_query = .{
            .asset_id = "assetId",
            .property_id = "propertyId",
            .property_alias = "propertyAlias",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .property_id = "propertyId",
                .property_alias = "propertyAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_asset_property_value) } {
            return .{ .service_metadata = service_metadata, .action = get_asset_property_value };
        }
    },
    Response: type = struct {
        property_value: ?AssetPropertyValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .property_value = "propertyValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_asset_property_value_history: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/properties/history",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssetPropertyValueHistory",
    Request: type = struct {
        asset_id: ?[]const u8 = null,
        property_id: ?[]const u8 = null,
        property_alias: ?[]const u8 = null,
        start_date: ?i64 = null,
        end_date: ?i64 = null,
        qualities: ?[][]const u8 = null,
        time_ordering: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .asset_id = "assetId",
            .property_id = "propertyId",
            .property_alias = "propertyAlias",
            .start_date = "startDate",
            .end_date = "endDate",
            .qualities = "qualities",
            .time_ordering = "timeOrdering",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .property_id = "propertyId",
                .property_alias = "propertyAlias",
                .start_date = "startDate",
                .end_date = "endDate",
                .qualities = "qualities",
                .time_ordering = "timeOrdering",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_asset_property_value_history) } {
            return .{ .service_metadata = service_metadata, .action = get_asset_property_value_history };
        }
    },
    Response: type = struct {
        asset_property_value_history: []AssetPropertyValue,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_property_value_history = "assetPropertyValueHistory",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_interpolated_asset_property_values: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/properties/interpolated",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInterpolatedAssetPropertyValues",
    Request: type = struct {
        asset_id: ?[]const u8 = null,
        property_id: ?[]const u8 = null,
        property_alias: ?[]const u8 = null,
        start_time_in_seconds: i64,
        start_time_offset_in_nanos: ?i64 = null,
        end_time_in_seconds: i64,
        end_time_offset_in_nanos: ?i64 = null,
        quality: []const u8,
        interval_in_seconds: i64,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        type: []const u8,
        interval_window_in_seconds: ?i64 = null,

        pub const http_query = .{
            .asset_id = "assetId",
            .property_id = "propertyId",
            .property_alias = "propertyAlias",
            .start_time_in_seconds = "startTimeInSeconds",
            .start_time_offset_in_nanos = "startTimeOffsetInNanos",
            .end_time_in_seconds = "endTimeInSeconds",
            .end_time_offset_in_nanos = "endTimeOffsetInNanos",
            .quality = "quality",
            .interval_in_seconds = "intervalInSeconds",
            .next_token = "nextToken",
            .max_results = "maxResults",
            .type = "type",
            .interval_window_in_seconds = "intervalWindowInSeconds",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .property_id = "propertyId",
                .property_alias = "propertyAlias",
                .start_time_in_seconds = "startTimeInSeconds",
                .start_time_offset_in_nanos = "startTimeOffsetInNanos",
                .end_time_in_seconds = "endTimeInSeconds",
                .end_time_offset_in_nanos = "endTimeOffsetInNanos",
                .quality = "quality",
                .interval_in_seconds = "intervalInSeconds",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .type = "type",
                .interval_window_in_seconds = "intervalWindowInSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_interpolated_asset_property_values) } {
            return .{ .service_metadata = service_metadata, .action = get_interpolated_asset_property_values };
        }
    },
    Response: type = struct {
        interpolated_asset_property_values: []struct {
            timestamp: TimeInNanos,
            value: Variant,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "timestamp",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interpolated_asset_property_values = "interpolatedAssetPropertyValues",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_access_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/access-policies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessPolicies",
    Request: type = struct {
        identity_type: ?[]const u8 = null,
        identity_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_id: ?[]const u8 = null,
        iam_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .identity_type = "identityType",
            .identity_id = "identityId",
            .resource_type = "resourceType",
            .resource_id = "resourceId",
            .iam_arn = "iamArn",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_type = "identityType",
                .identity_id = "identityId",
                .resource_type = "resourceType",
                .resource_id = "resourceId",
                .iam_arn = "iamArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_access_policies };
        }
    },
    Response: type = struct {
        access_policy_summaries: []struct {
            id: []const u8,
            identity: Identity,
            resource: Resource,
            permission: []const u8,
            creation_date: ?i64 = null,
            last_update_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .identity = "identity",
                    .resource = "resource",
                    .permission = "permission",
                    .creation_date = "creationDate",
                    .last_update_date = "lastUpdateDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policy_summaries = "accessPolicySummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_actions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/actions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListActions",
    Request: type = struct {
        target_resource_type: []const u8,
        target_resource_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .target_resource_type = "targetResourceType",
            .target_resource_id = "targetResourceId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_resource_type = "targetResourceType",
                .target_resource_id = "targetResourceId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_actions };
        }
    },
    Response: type = struct {
        action_summaries: []struct {
            action_id: ?[]const u8 = null,
            action_definition_id: ?[]const u8 = null,
            target_resource: ?TargetResource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_id = "actionId",
                    .action_definition_id = "actionDefinitionId",
                    .target_resource = "targetResource",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_summaries = "actionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_asset_model_composite_models: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/asset-models/{assetModelId}/composite-models",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetModelCompositeModels",
    Request: type = struct {
        asset_model_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_model_composite_models) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_model_composite_models };
        }
    },
    Response: type = struct {
        asset_model_composite_model_summaries: []AssetModelCompositeModelSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_composite_model_summaries = "assetModelCompositeModelSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_asset_model_properties: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/asset-models/{assetModelId}/properties",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetModelProperties",
    Request: type = struct {
        asset_model_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .filter = "filter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filter = "filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_model_properties) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_model_properties };
        }
    },
    Response: type = struct {
        asset_model_property_summaries: []struct {
            id: ?[]const u8 = null,
            name: []const u8,
            data_type: []const u8,
            data_type_spec: ?[]const u8 = null,
            unit: ?[]const u8 = null,
            type: PropertyType,
            asset_model_composite_model_id: ?[]const u8 = null,
            path: ?[]AssetModelPropertyPathSegment = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .data_type = "dataType",
                    .data_type_spec = "dataTypeSpec",
                    .unit = "unit",
                    .type = "type",
                    .asset_model_composite_model_id = "assetModelCompositeModelId",
                    .path = "path",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_property_summaries = "assetModelPropertySummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_asset_models: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/asset-models",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetModels",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        asset_model_types: ?[][]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .asset_model_types = "assetModelTypes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .asset_model_types = "assetModelTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_models) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_models };
        }
    },
    Response: type = struct {
        asset_model_summaries: []struct {
            id: []const u8,
            arn: []const u8,
            name: []const u8,
            description: []const u8,
            creation_date: i64,
            last_update_date: i64,
            status: AssetModelStatus,
            asset_model_type: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .creation_date = "creationDate",
                    .last_update_date = "lastUpdateDate",
                    .status = "status",
                    .asset_model_type = "assetModelType",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_summaries = "assetModelSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_asset_properties: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets/{assetId}/properties",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetProperties",
    Request: type = struct {
        asset_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .filter = "filter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filter = "filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_properties) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_properties };
        }
    },
    Response: type = struct {
        asset_property_summaries: []struct {
            id: []const u8,
            alias: ?[]const u8 = null,
            unit: ?[]const u8 = null,
            notification: ?PropertyNotification = null,
            asset_composite_model_id: ?[]const u8 = null,
            path: ?[]AssetPropertyPathSegment = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .alias = "alias",
                    .unit = "unit",
                    .notification = "notification",
                    .asset_composite_model_id = "assetCompositeModelId",
                    .path = "path",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_property_summaries = "assetPropertySummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_asset_relationships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets/{assetId}/assetRelationships",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetRelationships",
    Request: type = struct {
        asset_id: []const u8,
        traversal_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .traversal_type = "traversalType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .traversal_type = "traversalType",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_relationships) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_relationships };
        }
    },
    Response: type = struct {
        asset_relationship_summaries: []struct {
            hierarchy_info: ?struct {
                parent_asset_id: ?[]const u8 = null,
                child_asset_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .parent_asset_id = "parentAssetId",
                        .child_asset_id = "childAssetId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            relationship_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hierarchy_info = "hierarchyInfo",
                    .relationship_type = "relationshipType",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_relationship_summaries = "assetRelationshipSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_assets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        asset_model_id: ?[]const u8 = null,
        filter: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .asset_model_id = "assetModelId",
            .filter = "filter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .asset_model_id = "assetModelId",
                .filter = "filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assets) } {
            return .{ .service_metadata = service_metadata, .action = list_assets };
        }
    },
    Response: type = struct {
        asset_summaries: []struct {
            id: []const u8,
            arn: []const u8,
            name: []const u8,
            asset_model_id: []const u8,
            creation_date: i64,
            last_update_date: i64,
            status: AssetStatus,
            hierarchies: []AssetHierarchy,
            description: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .name = "name",
                    .asset_model_id = "assetModelId",
                    .creation_date = "creationDate",
                    .last_update_date = "lastUpdateDate",
                    .status = "status",
                    .hierarchies = "hierarchies",
                    .description = "description",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_summaries = "assetSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_associated_assets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets/{assetId}/hierarchies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssociatedAssets",
    Request: type = struct {
        asset_id: []const u8,
        hierarchy_id: ?[]const u8 = null,
        traversal_direction: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .hierarchy_id = "hierarchyId",
            .traversal_direction = "traversalDirection",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .hierarchy_id = "hierarchyId",
                .traversal_direction = "traversalDirection",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associated_assets) } {
            return .{ .service_metadata = service_metadata, .action = list_associated_assets };
        }
    },
    Response: type = struct {
        asset_summaries: []struct {
            id: []const u8,
            arn: []const u8,
            name: []const u8,
            asset_model_id: []const u8,
            creation_date: i64,
            last_update_date: i64,
            status: AssetStatus,
            hierarchies: []AssetHierarchy,
            description: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .name = "name",
                    .asset_model_id = "assetModelId",
                    .creation_date = "creationDate",
                    .last_update_date = "lastUpdateDate",
                    .status = "status",
                    .hierarchies = "hierarchies",
                    .description = "description",
                    .external_id = "externalId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_summaries = "assetSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_bulk_import_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBulkImportJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .filter = "filter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filter = "filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bulk_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_bulk_import_jobs };
        }
    },
    Response: type = struct {
        job_summaries: []struct {
            id: []const u8,
            name: []const u8,
            status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summaries = "jobSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_composition_relationships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/asset-models/{assetModelId}/composition-relationships",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCompositionRelationships",
    Request: type = struct {
        asset_model_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_composition_relationships) } {
            return .{ .service_metadata = service_metadata, .action = list_composition_relationships };
        }
    },
    Response: type = struct {
        composition_relationship_summaries: []struct {
            asset_model_id: []const u8,
            asset_model_composite_model_id: []const u8,
            asset_model_composite_model_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .asset_model_id = "assetModelId",
                    .asset_model_composite_model_id = "assetModelCompositeModelId",
                    .asset_model_composite_model_type = "assetModelCompositeModelType",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .composition_relationship_summaries = "compositionRelationshipSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_dashboards: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/dashboards",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDashboards",
    Request: type = struct {
        project_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .project_id = "projectId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dashboards) } {
            return .{ .service_metadata = service_metadata, .action = list_dashboards };
        }
    },
    Response: type = struct {
        dashboard_summaries: []struct {
            id: []const u8,
            name: []const u8,
            description: ?[]const u8 = null,
            creation_date: ?i64 = null,
            last_update_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .creation_date = "creationDate",
                    .last_update_date = "lastUpdateDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_summaries = "dashboardSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_gateways: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/20200301/gateways",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGateways",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_gateways) } {
            return .{ .service_metadata = service_metadata, .action = list_gateways };
        }
    },
    Response: type = struct {
        gateway_summaries: []struct {
            gateway_id: []const u8,
            gateway_name: []const u8,
            gateway_platform: ?GatewayPlatform = null,
            gateway_capability_summaries: ?[]GatewayCapabilitySummary = null,
            creation_date: i64,
            last_update_date: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .gateway_id = "gatewayId",
                    .gateway_name = "gatewayName",
                    .gateway_platform = "gatewayPlatform",
                    .gateway_capability_summaries = "gatewayCapabilitySummaries",
                    .creation_date = "creationDate",
                    .last_update_date = "lastUpdateDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_summaries = "gatewaySummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_portals: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/portals",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPortals",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_portals) } {
            return .{ .service_metadata = service_metadata, .action = list_portals };
        }
    },
    Response: type = struct {
        portal_summaries: ?[]struct {
            id: []const u8,
            name: []const u8,
            description: ?[]const u8 = null,
            start_url: []const u8,
            creation_date: ?i64 = null,
            last_update_date: ?i64 = null,
            role_arn: ?[]const u8 = null,
            status: PortalStatus,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .start_url = "startUrl",
                    .creation_date = "creationDate",
                    .last_update_date = "lastUpdateDate",
                    .role_arn = "roleArn",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_summaries = "portalSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_project_assets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects/{projectId}/assets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProjectAssets",
    Request: type = struct {
        project_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_project_assets) } {
            return .{ .service_metadata = service_metadata, .action = list_project_assets };
        }
    },
    Response: type = struct {
        asset_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_ids = "assetIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_projects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        portal_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .portal_id = "portalId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_id = "portalId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        project_summaries: []struct {
            id: []const u8,
            name: []const u8,
            description: ?[]const u8 = null,
            creation_date: ?i64 = null,
            last_update_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .creation_date = "creationDate",
                    .last_update_date = "lastUpdateDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_summaries = "projectSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_time_series: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/timeseries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTimeSeries",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        asset_id: ?[]const u8 = null,
        alias_prefix: ?[]const u8 = null,
        time_series_type: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .asset_id = "assetId",
            .alias_prefix = "aliasPrefix",
            .time_series_type = "timeSeriesType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .asset_id = "assetId",
                .alias_prefix = "aliasPrefix",
                .time_series_type = "timeSeriesType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_time_series) } {
            return .{ .service_metadata = service_metadata, .action = list_time_series };
        }
    },
    Response: type = struct {
        time_series_summaries: []struct {
            asset_id: ?[]const u8 = null,
            property_id: ?[]const u8 = null,
            alias: ?[]const u8 = null,
            time_series_id: []const u8,
            data_type: []const u8,
            data_type_spec: ?[]const u8 = null,
            time_series_creation_date: i64,
            time_series_last_update_date: i64,
            time_series_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .asset_id = "assetId",
                    .property_id = "propertyId",
                    .alias = "alias",
                    .time_series_id = "timeSeriesId",
                    .data_type = "dataType",
                    .data_type_spec = "dataTypeSpec",
                    .time_series_creation_date = "timeSeriesCreationDate",
                    .time_series_last_update_date = "timeSeriesLastUpdateDate",
                    .time_series_arn = "timeSeriesArn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_series_summaries = "TimeSeriesSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_default_encryption_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configuration/account/encryption",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDefaultEncryptionConfiguration",
    Request: type = struct {
        encryption_type: []const u8,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_type = "encryptionType",
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_default_encryption_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_default_encryption_configuration };
        }
    },
    Response: type = struct {
        encryption_type: []const u8,
        kms_key_arn: ?[]const u8 = null,
        configuration_status: ConfigurationStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_type = "encryptionType",
                .kms_key_arn = "kmsKeyArn",
                .configuration_status = "configurationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const put_logging_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/logging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutLoggingOptions",
    Request: type = struct {
        logging_options: LoggingOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_options = "loggingOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = put_logging_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_storage_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configuration/account/storage",
        .success_code = 200,
    };

    action_name: []const u8 = "PutStorageConfiguration",
    Request: type = struct {
        storage_type: []const u8,
        multi_layer_storage: ?MultiLayerStorage = null,
        disassociated_data_storage: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,
        warm_tier: ?[]const u8 = null,
        warm_tier_retention_period: ?WarmTierRetentionPeriod = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_type = "storageType",
                .multi_layer_storage = "multiLayerStorage",
                .disassociated_data_storage = "disassociatedDataStorage",
                .retention_period = "retentionPeriod",
                .warm_tier = "warmTier",
                .warm_tier_retention_period = "warmTierRetentionPeriod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_storage_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_storage_configuration };
        }
    },
    Response: type = struct {
        storage_type: []const u8,
        multi_layer_storage: ?MultiLayerStorage = null,
        disassociated_data_storage: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,
        configuration_status: ConfigurationStatus,
        warm_tier: ?[]const u8 = null,
        warm_tier_retention_period: ?WarmTierRetentionPeriod = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_type = "storageType",
                .multi_layer_storage = "multiLayerStorage",
                .disassociated_data_storage = "disassociatedDataStorage",
                .retention_period = "retentionPeriod",
                .configuration_status = "configurationStatus",
                .warm_tier = "warmTier",
                .warm_tier_retention_period = "warmTierRetentionPeriod",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        TooManyTags,
        Unauthorized,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_access_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/access-policies/{accessPolicyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccessPolicy",
    Request: type = struct {
        access_policy_id: []const u8,
        access_policy_identity: Identity,
        access_policy_resource: Resource,
        access_policy_permission: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policy_id = "accessPolicyId",
                .access_policy_identity = "accessPolicyIdentity",
                .access_policy_resource = "accessPolicyResource",
                .access_policy_permission = "accessPolicyPermission",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_access_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_asset: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assets/{assetId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateAsset",
    Request: type = struct {
        asset_id: []const u8,
        asset_name: []const u8,
        client_token: ?[]const u8 = null,
        asset_description: ?[]const u8 = null,
        asset_external_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .asset_name = "assetName",
                .client_token = "clientToken",
                .asset_description = "assetDescription",
                .asset_external_id = "assetExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_asset) } {
            return .{ .service_metadata = service_metadata, .action = update_asset };
        }
    },
    Response: type = struct {
        asset_status: AssetStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_status = "assetStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_asset_model: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/asset-models/{assetModelId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateAssetModel",
    Request: type = struct {
        asset_model_id: []const u8,
        asset_model_name: []const u8,
        asset_model_description: ?[]const u8 = null,
        asset_model_properties: ?[]AssetModelProperty = null,
        asset_model_hierarchies: ?[]AssetModelHierarchy = null,
        asset_model_composite_models: ?[]AssetModelCompositeModel = null,
        client_token: ?[]const u8 = null,
        asset_model_external_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .asset_model_name = "assetModelName",
                .asset_model_description = "assetModelDescription",
                .asset_model_properties = "assetModelProperties",
                .asset_model_hierarchies = "assetModelHierarchies",
                .asset_model_composite_models = "assetModelCompositeModels",
                .client_token = "clientToken",
                .asset_model_external_id = "assetModelExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_asset_model) } {
            return .{ .service_metadata = service_metadata, .action = update_asset_model };
        }
    },
    Response: type = struct {
        asset_model_status: AssetModelStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_status = "assetModelStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_asset_model_composite_model: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/asset-models/{assetModelId}/composite-models/{assetModelCompositeModelId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateAssetModelCompositeModel",
    Request: type = struct {
        asset_model_id: []const u8,
        asset_model_composite_model_id: []const u8,
        asset_model_composite_model_external_id: ?[]const u8 = null,
        asset_model_composite_model_description: ?[]const u8 = null,
        asset_model_composite_model_name: []const u8,
        client_token: ?[]const u8 = null,
        asset_model_composite_model_properties: ?[]AssetModelProperty = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_id = "assetModelId",
                .asset_model_composite_model_id = "assetModelCompositeModelId",
                .asset_model_composite_model_external_id = "assetModelCompositeModelExternalId",
                .asset_model_composite_model_description = "assetModelCompositeModelDescription",
                .asset_model_composite_model_name = "assetModelCompositeModelName",
                .client_token = "clientToken",
                .asset_model_composite_model_properties = "assetModelCompositeModelProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_asset_model_composite_model) } {
            return .{ .service_metadata = service_metadata, .action = update_asset_model_composite_model };
        }
    },
    Response: type = struct {
        asset_model_composite_model_path: []AssetModelCompositeModelPathSegment,
        asset_model_status: AssetModelStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_model_composite_model_path = "assetModelCompositeModelPath",
                .asset_model_status = "assetModelStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_asset_property: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/assets/{assetId}/properties/{propertyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAssetProperty",
    Request: type = struct {
        asset_id: []const u8,
        property_id: []const u8,
        property_alias: ?[]const u8 = null,
        property_notification_state: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        property_unit: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_id = "assetId",
                .property_id = "propertyId",
                .property_alias = "propertyAlias",
                .property_notification_state = "propertyNotificationState",
                .client_token = "clientToken",
                .property_unit = "propertyUnit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_asset_property) } {
            return .{ .service_metadata = service_metadata, .action = update_asset_property };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_dashboard: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/dashboards/{dashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDashboard",
    Request: type = struct {
        dashboard_id: []const u8,
        dashboard_name: []const u8,
        dashboard_description: ?[]const u8 = null,
        dashboard_definition: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "dashboardId",
                .dashboard_name = "dashboardName",
                .dashboard_description = "dashboardDescription",
                .dashboard_definition = "dashboardDefinition",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = update_dashboard };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_gateway: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/20200301/gateways/{gatewayId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGateway",
    Request: type = struct {
        gateway_id: []const u8,
        gateway_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "gatewayId",
                .gateway_name = "gatewayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_gateway) } {
            return .{ .service_metadata = service_metadata, .action = update_gateway };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_gateway_capability_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/20200301/gateways/{gatewayId}/capability",
        .success_code = 201,
    };

    action_name: []const u8 = "UpdateGatewayCapabilityConfiguration",
    Request: type = struct {
        gateway_id: []const u8,
        capability_namespace: []const u8,
        capability_configuration: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "gatewayId",
                .capability_namespace = "capabilityNamespace",
                .capability_configuration = "capabilityConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_gateway_capability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_gateway_capability_configuration };
        }
    },
    Response: type = struct {
        capability_namespace: []const u8,
        capability_sync_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capability_namespace = "capabilityNamespace",
                .capability_sync_status = "capabilitySyncStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_portal: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/portals/{portalId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdatePortal",
    Request: type = struct {
        portal_id: []const u8,
        portal_name: []const u8,
        portal_description: ?[]const u8 = null,
        portal_contact_email: []const u8,
        portal_logo_image: ?struct {
            id: ?[]const u8 = null,
            file: ?ImageFile = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .file = "file",
                };
                return @field(mappings, field_name);
            }
        } = null,
        role_arn: []const u8,
        client_token: ?[]const u8 = null,
        notification_sender_email: ?[]const u8 = null,
        alarms: ?Alarms = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_id = "portalId",
                .portal_name = "portalName",
                .portal_description = "portalDescription",
                .portal_contact_email = "portalContactEmail",
                .portal_logo_image = "portalLogoImage",
                .role_arn = "roleArn",
                .client_token = "clientToken",
                .notification_sender_email = "notificationSenderEmail",
                .alarms = "alarms",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_portal) } {
            return .{ .service_metadata = service_metadata, .action = update_portal };
        }
    },
    Response: type = struct {
        portal_status: PortalStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portal_status = "portalStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingOperation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_project: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/projects/{projectId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProject",
    Request: type = struct {
        project_id: []const u8,
        project_name: []const u8,
        project_description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .project_name = "projectName",
                .project_description = "projectDescription",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_project) } {
            return .{ .service_metadata = service_metadata, .action = update_project };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const PortalStatus = struct {
    state: []const u8,
    @"error": ?MonitorErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitorErrorDetails = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const Alarms = struct {
    alarm_role_arn: []const u8,
    notification_lambda_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alarm_role_arn = "alarmRoleArn",
            .notification_lambda_arn = "notificationLambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageFile = struct {
    data: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "data",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetModelStatus = struct {
    state: []const u8,
    @"error": ?ErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetails = struct {
    code: []const u8,
    message: []const u8,
    details: ?[]DetailedError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
            .details = "details",
        };
        return @field(mappings, field_name);
    }
};

pub const DetailedError = struct {
    code: []const u8,
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetModelCompositeModelPathSegment = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetModelProperty = struct {
    id: ?[]const u8 = null,
    name: []const u8,
    data_type: []const u8,
    data_type_spec: ?[]const u8 = null,
    unit: ?[]const u8 = null,
    type: PropertyType,
    path: ?[]AssetModelPropertyPathSegment = null,
    external_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .data_type = "dataType",
            .data_type_spec = "dataTypeSpec",
            .unit = "unit",
            .type = "type",
            .path = "path",
            .external_id = "externalId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetModelPropertyPathSegment = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const PropertyType = struct {
    attribute: ?Attribute = null,
    measurement: ?Measurement = null,
    transform: ?Transform = null,
    metric: ?Metric = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute = "attribute",
            .measurement = "measurement",
            .transform = "transform",
            .metric = "metric",
        };
        return @field(mappings, field_name);
    }
};

pub const Metric = struct {
    expression: []const u8,
    variables: []ExpressionVariable,
    window: MetricWindow,
    processing_config: ?MetricProcessingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "expression",
            .variables = "variables",
            .window = "window",
            .processing_config = "processingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricProcessingConfig = struct {
    compute_location: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compute_location = "computeLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricWindow = struct {
    tumbling: ?TumblingWindow = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tumbling = "tumbling",
        };
        return @field(mappings, field_name);
    }
};

pub const TumblingWindow = struct {
    interval: []const u8,
    offset: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interval = "interval",
            .offset = "offset",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpressionVariable = struct {
    name: []const u8,
    value: VariableValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const VariableValue = struct {
    property_id: ?[]const u8 = null,
    hierarchy_id: ?[]const u8 = null,
    property_path: ?[]AssetModelPropertyPathSegment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .property_id = "propertyId",
            .hierarchy_id = "hierarchyId",
            .property_path = "propertyPath",
        };
        return @field(mappings, field_name);
    }
};

pub const Transform = struct {
    expression: []const u8,
    variables: []ExpressionVariable,
    processing_config: ?TransformProcessingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "expression",
            .variables = "variables",
            .processing_config = "processingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformProcessingConfig = struct {
    compute_location: []const u8,
    forwarding_config: ?ForwardingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compute_location = "computeLocation",
            .forwarding_config = "forwardingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ForwardingConfig = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const Measurement = struct {
    processing_config: ?MeasurementProcessingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .processing_config = "processingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const MeasurementProcessingConfig = struct {
    forwarding_config: ForwardingConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .forwarding_config = "forwardingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const Attribute = struct {
    default_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetModelCompositeModel = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    type: []const u8,
    properties: ?[]AssetModelProperty = null,
    id: ?[]const u8 = null,
    external_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .type = "type",
            .properties = "properties",
            .id = "id",
            .external_id = "externalId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetModelHierarchy = struct {
    id: ?[]const u8 = null,
    name: []const u8,
    child_asset_model_id: []const u8,
    external_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .child_asset_model_id = "childAssetModelId",
            .external_id = "externalId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetStatus = struct {
    state: []const u8,
    @"error": ?ErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    portal: ?PortalResource = null,
    project: ?ProjectResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .portal = "portal",
            .project = "project",
        };
        return @field(mappings, field_name);
    }
};

pub const ProjectResource = struct {
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const PortalResource = struct {
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const Identity = struct {
    user: ?UserIdentity = null,
    group: ?GroupIdentity = null,
    iam_user: ?IAMUserIdentity = null,
    iam_role: ?IAMRoleIdentity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user = "user",
            .group = "group",
            .iam_user = "iamUser",
            .iam_role = "iamRole",
        };
        return @field(mappings, field_name);
    }
};

pub const IAMRoleIdentity = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const IAMUserIdentity = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupIdentity = struct {
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const UserIdentity = struct {
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const WarmTierRetentionPeriod = struct {
    number_of_days: ?i64 = null,
    unlimited: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_days = "numberOfDays",
            .unlimited = "unlimited",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationStatus = struct {
    state: []const u8,
    @"error": ?ConfigurationErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationErrorDetails = struct {
    code: []const u8,
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const RetentionPeriod = struct {
    number_of_days: ?i64 = null,
    unlimited: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_days = "numberOfDays",
            .unlimited = "unlimited",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiLayerStorage = struct {
    customer_managed_s3_storage: CustomerManagedS3Storage,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_managed_s3_storage = "customerManagedS3Storage",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerManagedS3Storage = struct {
    s3_resource_arn: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_resource_arn = "s3ResourceArn",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingOptions = struct {
    level: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .level = "level",
        };
        return @field(mappings, field_name);
    }
};

pub const GatewayCapabilitySummary = struct {
    capability_namespace: []const u8,
    capability_sync_status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capability_namespace = "capabilityNamespace",
            .capability_sync_status = "capabilitySyncStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const GatewayPlatform = struct {
    greengrass: ?Greengrass = null,
    greengrass_v2: ?GreengrassV2 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .greengrass = "greengrass",
            .greengrass_v2 = "greengrassV2",
        };
        return @field(mappings, field_name);
    }
};

pub const GreengrassV2 = struct {
    core_device_thing_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_device_thing_name = "coreDeviceThingName",
        };
        return @field(mappings, field_name);
    }
};

pub const Greengrass = struct {
    group_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_arn = "groupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetHierarchy = struct {
    id: ?[]const u8 = null,
    name: []const u8,
    external_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .external_id = "externalId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetPropertyPathSegment = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const PropertyNotification = struct {
    topic: []const u8,
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic = "topic",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetModelCompositeModelSummary = struct {
    id: []const u8,
    external_id: ?[]const u8 = null,
    name: []const u8,
    type: []const u8,
    description: ?[]const u8 = null,
    path: ?[]AssetModelCompositeModelPathSegment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .external_id = "externalId",
            .name = "name",
            .type = "type",
            .description = "description",
            .path = "path",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetResource = struct {
    asset_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_id = "assetId",
        };
        return @field(mappings, field_name);
    }
};

pub const Variant = struct {
    string_value: ?[]const u8 = null,
    integer_value: ?i64 = null,
    double_value: ?f64 = null,
    boolean_value: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "stringValue",
            .integer_value = "integerValue",
            .double_value = "doubleValue",
            .boolean_value = "booleanValue",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeInNanos = struct {
    time_in_seconds: i64,
    offset_in_nanos: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_in_seconds = "timeInSeconds",
            .offset_in_nanos = "offsetInNanos",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetPropertyValue = struct {
    value: Variant,
    timestamp: TimeInNanos,
    quality: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .timestamp = "timestamp",
            .quality = "quality",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregatedValue = struct {
    timestamp: i64,
    quality: ?[]const u8 = null,
    value: Aggregates,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp = "timestamp",
            .quality = "quality",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Aggregates = struct {
    average: ?f64 = null,
    count: ?f64 = null,
    maximum: ?f64 = null,
    minimum: ?f64 = null,
    sum: ?f64 = null,
    standard_deviation: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .average = "average",
            .count = "count",
            .maximum = "maximum",
            .minimum = "minimum",
            .sum = "sum",
            .standard_deviation = "standardDeviation",
        };
        return @field(mappings, field_name);
    }
};

pub const Row = struct {
    data: []struct {
        scalar_value: ?[]const u8 = null,
        array_value: ?[]struct {
            scalar_value: ?[]const u8 = null,
            array_value: ?[]struct {
                scalar_value: ?[]const u8 = null,
                array_value: ?[]const u8 = null,
                row_value: ?Row = null,
                null_value: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .scalar_value = "scalarValue",
                        .array_value = "arrayValue",
                        .row_value = "rowValue",
                        .null_value = "nullValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            row_value: ?Row = null,
            null_value: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scalar_value = "scalarValue",
                    .array_value = "arrayValue",
                    .row_value = "rowValue",
                    .null_value = "nullValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        row_value: ?Row = null,
        null_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scalar_value = "scalarValue",
                .array_value = "arrayValue",
                .row_value = "rowValue",
                .null_value = "nullValue",
            };
            return @field(mappings, field_name);
        }
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "data",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionPayload = struct {
    string_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "stringValue",
        };
        return @field(mappings, field_name);
    }
};

pub const JobConfiguration = struct {
    file_format: FileFormat,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_format = "fileFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const FileFormat = struct {
    csv: ?Csv = null,
    parquet: ?Parquet = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv = "csv",
            .parquet = "parquet",
        };
        return @field(mappings, field_name);
    }
};

pub const Parquet = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Csv = struct {
    column_names: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_names = "columnNames",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorReportLocation = struct {
    bucket: []const u8,
    prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const File = struct {
    bucket: []const u8,
    key: []const u8,
    version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key = "key",
            .version_id = "versionId",
        };
        return @field(mappings, field_name);
    }
};

pub const Property = struct {
    id: []const u8,
    name: []const u8,
    alias: ?[]const u8 = null,
    notification: ?PropertyNotification = null,
    data_type: []const u8,
    unit: ?[]const u8 = null,
    type: ?PropertyType = null,
    path: ?[]AssetPropertyPathSegment = null,
    external_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .alias = "alias",
            .notification = "notification",
            .data_type = "dataType",
            .unit = "unit",
            .type = "type",
            .path = "path",
            .external_id = "externalId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionDefinition = struct {
    action_definition_id: []const u8,
    action_name: []const u8,
    action_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_definition_id = "actionDefinitionId",
            .action_name = "actionName",
            .action_type = "actionType",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetCompositeModelSummary = struct {
    id: []const u8,
    external_id: ?[]const u8 = null,
    name: []const u8,
    type: []const u8,
    description: []const u8,
    path: []AssetCompositeModelPathSegment,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .external_id = "externalId",
            .name = "name",
            .type = "type",
            .description = "description",
            .path = "path",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetCompositeModelPathSegment = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetProperty = struct {
    id: []const u8,
    name: []const u8,
    alias: ?[]const u8 = null,
    notification: ?PropertyNotification = null,
    data_type: []const u8,
    data_type_spec: ?[]const u8 = null,
    unit: ?[]const u8 = null,
    path: ?[]AssetPropertyPathSegment = null,
    external_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .alias = "alias",
            .notification = "notification",
            .data_type = "dataType",
            .data_type_spec = "dataTypeSpec",
            .unit = "unit",
            .path = "path",
            .external_id = "externalId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetModelPropertyDefinition = struct {
    name: []const u8,
    data_type: []const u8,
    data_type_spec: ?[]const u8 = null,
    unit: ?[]const u8 = null,
    type: PropertyType,
    id: ?[]const u8 = null,
    external_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .data_type = "dataType",
            .data_type_spec = "dataTypeSpec",
            .unit = "unit",
            .type = "type",
            .id = "id",
            .external_id = "externalId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetErrorDetails = struct {
    asset_id: []const u8,
    code: []const u8,
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_id = "assetId",
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};
