const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-09-06";
pub const sdk_id: []const u8 = "IoTThingsGraph";
pub const arn_namespace: ?[]const u8 = "iotthingsgraph";
pub const endpoint_prefix: []const u8 = "iotthingsgraph";
pub const sigv4_name: []const u8 = "iotthingsgraph";
pub const name: []const u8 = "IotThingsGraphFrontEndService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-09-06",
    sdk_id: []const u8 = "IoTThingsGraph",
    arn_namespace: ?[]const u8 = "iotthingsgraph",
    endpoint_prefix: []const u8 = "iotthingsgraph",
    sigv4_name: []const u8 = "iotthingsgraph",
    name: []const u8 = "IotThingsGraphFrontEndService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_entity_to_thing: struct {
    action_name: []const u8 = "AssociateEntityToThing",
    Request: type = struct {
        thing_name: []const u8,
        entity_id: []const u8,
        namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .entity_id = "entityId",
                .namespace_version = "namespaceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_entity_to_thing) } {
            return .{ .service_metadata = service_metadata, .action = associate_entity_to_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_flow_template: struct {
    action_name: []const u8 = "CreateFlowTemplate",
    Request: type = struct {
        definition: DefinitionDocument,
        compatible_namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definition = "definition",
                .compatible_namespace_version = "compatibleNamespaceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_flow_template) } {
            return .{ .service_metadata = service_metadata, .action = create_flow_template };
        }
    },
    Response: type = struct {
        summary: ?FlowTemplateSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_system_instance: struct {
    action_name: []const u8 = "CreateSystemInstance",
    Request: type = struct {
        tags: ?[]Tag = null,
        definition: DefinitionDocument,
        target: []const u8,
        greengrass_group_name: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,
        metrics_configuration: ?MetricsConfiguration = null,
        flow_actions_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .definition = "definition",
                .target = "target",
                .greengrass_group_name = "greengrassGroupName",
                .s3_bucket_name = "s3BucketName",
                .metrics_configuration = "metricsConfiguration",
                .flow_actions_role_arn = "flowActionsRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_system_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_system_instance };
        }
    },
    Response: type = struct {
        summary: ?SystemInstanceSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_system_template: struct {
    action_name: []const u8 = "CreateSystemTemplate",
    Request: type = struct {
        definition: DefinitionDocument,
        compatible_namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .definition = "definition",
                .compatible_namespace_version = "compatibleNamespaceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_system_template) } {
            return .{ .service_metadata = service_metadata, .action = create_system_template };
        }
    },
    Response: type = struct {
        summary: ?SystemTemplateSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const delete_flow_template: struct {
    action_name: []const u8 = "DeleteFlowTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_flow_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_flow_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        Throttling,
    },
} = .{};
pub const delete_namespace: struct {
    action_name: []const u8 = "DeleteNamespace",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_namespace) } {
            return .{ .service_metadata = service_metadata, .action = delete_namespace };
        }
    },
    Response: type = struct {
        namespace_arn: ?[]const u8 = null,
        namespace_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace_arn = "namespaceArn",
                .namespace_name = "namespaceName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        Throttling,
    },
} = .{};
pub const delete_system_instance: struct {
    action_name: []const u8 = "DeleteSystemInstance",
    Request: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_system_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_system_instance };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        Throttling,
    },
} = .{};
pub const delete_system_template: struct {
    action_name: []const u8 = "DeleteSystemTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_system_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_system_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        Throttling,
    },
} = .{};
pub const deploy_system_instance: struct {
    action_name: []const u8 = "DeploySystemInstance",
    Request: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deploy_system_instance) } {
            return .{ .service_metadata = service_metadata, .action = deploy_system_instance };
        }
    },
    Response: type = struct {
        summary: SystemInstanceSummary,
        greengrass_deployment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "summary",
                .greengrass_deployment_id = "greengrassDeploymentId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const deprecate_flow_template: struct {
    action_name: []const u8 = "DeprecateFlowTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprecate_flow_template) } {
            return .{ .service_metadata = service_metadata, .action = deprecate_flow_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const deprecate_system_template: struct {
    action_name: []const u8 = "DeprecateSystemTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprecate_system_template) } {
            return .{ .service_metadata = service_metadata, .action = deprecate_system_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_namespace: struct {
    action_name: []const u8 = "DescribeNamespace",
    Request: type = struct {
        namespace_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace_name = "namespaceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_namespace) } {
            return .{ .service_metadata = service_metadata, .action = describe_namespace };
        }
    },
    Response: type = struct {
        namespace_arn: ?[]const u8 = null,
        namespace_name: ?[]const u8 = null,
        tracking_namespace_name: ?[]const u8 = null,
        tracking_namespace_version: ?i64 = null,
        namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace_arn = "namespaceArn",
                .namespace_name = "namespaceName",
                .tracking_namespace_name = "trackingNamespaceName",
                .tracking_namespace_version = "trackingNamespaceVersion",
                .namespace_version = "namespaceVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const dissociate_entity_from_thing: struct {
    action_name: []const u8 = "DissociateEntityFromThing",
    Request: type = struct {
        thing_name: []const u8,
        entity_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .entity_type = "entityType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(dissociate_entity_from_thing) } {
            return .{ .service_metadata = service_metadata, .action = dissociate_entity_from_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_entities: struct {
    action_name: []const u8 = "GetEntities",
    Request: type = struct {
        ids: [][]const u8,
        namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
                .namespace_version = "namespaceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_entities) } {
            return .{ .service_metadata = service_metadata, .action = get_entities };
        }
    },
    Response: type = struct {
        descriptions: ?[]EntityDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .descriptions = "descriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_flow_template: struct {
    action_name: []const u8 = "GetFlowTemplate",
    Request: type = struct {
        id: []const u8,
        revision_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .revision_number = "revisionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_flow_template) } {
            return .{ .service_metadata = service_metadata, .action = get_flow_template };
        }
    },
    Response: type = struct {
        description: ?struct {
            summary: ?FlowTemplateSummary = null,
            definition: ?DefinitionDocument = null,
            validated_namespace_version: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .summary = "summary",
                    .definition = "definition",
                    .validated_namespace_version = "validatedNamespaceVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_flow_template_revisions: struct {
    action_name: []const u8 = "GetFlowTemplateRevisions",
    Request: type = struct {
        id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_flow_template_revisions) } {
            return .{ .service_metadata = service_metadata, .action = get_flow_template_revisions };
        }
    },
    Response: type = struct {
        summaries: ?[]FlowTemplateSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_namespace_deletion_status: struct {
    action_name: []const u8 = "GetNamespaceDeletionStatus",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_namespace_deletion_status) } {
            return .{ .service_metadata = service_metadata, .action = get_namespace_deletion_status };
        }
    },
    Response: type = struct {
        namespace_arn: ?[]const u8 = null,
        namespace_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        error_code: ?[]const u8 = null,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace_arn = "namespaceArn",
                .namespace_name = "namespaceName",
                .status = "status",
                .error_code = "errorCode",
                .error_message = "errorMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const get_system_instance: struct {
    action_name: []const u8 = "GetSystemInstance",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_system_instance) } {
            return .{ .service_metadata = service_metadata, .action = get_system_instance };
        }
    },
    Response: type = struct {
        description: ?struct {
            summary: ?SystemInstanceSummary = null,
            definition: ?DefinitionDocument = null,
            s3_bucket_name: ?[]const u8 = null,
            metrics_configuration: ?MetricsConfiguration = null,
            validated_namespace_version: ?i64 = null,
            validated_dependency_revisions: ?[]struct {
                id: ?[]const u8 = null,
                revision_number: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "id",
                        .revision_number = "revisionNumber",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            flow_actions_role_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .summary = "summary",
                    .definition = "definition",
                    .s3_bucket_name = "s3BucketName",
                    .metrics_configuration = "metricsConfiguration",
                    .validated_namespace_version = "validatedNamespaceVersion",
                    .validated_dependency_revisions = "validatedDependencyRevisions",
                    .flow_actions_role_arn = "flowActionsRoleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_system_template: struct {
    action_name: []const u8 = "GetSystemTemplate",
    Request: type = struct {
        id: []const u8,
        revision_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .revision_number = "revisionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_system_template) } {
            return .{ .service_metadata = service_metadata, .action = get_system_template };
        }
    },
    Response: type = struct {
        description: ?struct {
            summary: ?SystemTemplateSummary = null,
            definition: ?DefinitionDocument = null,
            validated_namespace_version: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .summary = "summary",
                    .definition = "definition",
                    .validated_namespace_version = "validatedNamespaceVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_system_template_revisions: struct {
    action_name: []const u8 = "GetSystemTemplateRevisions",
    Request: type = struct {
        id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_system_template_revisions) } {
            return .{ .service_metadata = service_metadata, .action = get_system_template_revisions };
        }
    },
    Response: type = struct {
        summaries: ?[]SystemTemplateSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_upload_status: struct {
    action_name: []const u8 = "GetUploadStatus",
    Request: type = struct {
        upload_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload_id = "uploadId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_upload_status) } {
            return .{ .service_metadata = service_metadata, .action = get_upload_status };
        }
    },
    Response: type = struct {
        upload_id: []const u8,
        upload_status: []const u8,
        namespace_arn: ?[]const u8 = null,
        namespace_name: ?[]const u8 = null,
        namespace_version: ?i64 = null,
        failure_reason: ?[][]const u8 = null,
        created_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload_id = "uploadId",
                .upload_status = "uploadStatus",
                .namespace_arn = "namespaceArn",
                .namespace_name = "namespaceName",
                .namespace_version = "namespaceVersion",
                .failure_reason = "failureReason",
                .created_date = "createdDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_flow_execution_messages: struct {
    action_name: []const u8 = "ListFlowExecutionMessages",
    Request: type = struct {
        flow_execution_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_execution_id = "flowExecutionId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_flow_execution_messages) } {
            return .{ .service_metadata = service_metadata, .action = list_flow_execution_messages };
        }
    },
    Response: type = struct {
        messages: ?[]struct {
            message_id: ?[]const u8 = null,
            event_type: ?[]const u8 = null,
            timestamp: ?i64 = null,
            payload: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .event_type = "eventType",
                    .timestamp = "timestamp",
                    .payload = "payload",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .messages = "messages",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        max_results: ?i64 = null,
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .resource_arn = "resourceArn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const search_entities: struct {
    action_name: []const u8 = "SearchEntities",
    Request: type = struct {
        entity_types: [][]const u8,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            value: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_types = "entityTypes",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .namespace_version = "namespaceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_entities) } {
            return .{ .service_metadata = service_metadata, .action = search_entities };
        }
    },
    Response: type = struct {
        descriptions: ?[]EntityDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .descriptions = "descriptions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const search_flow_executions: struct {
    action_name: []const u8 = "SearchFlowExecutions",
    Request: type = struct {
        system_instance_id: []const u8,
        flow_execution_id: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .system_instance_id = "systemInstanceId",
                .flow_execution_id = "flowExecutionId",
                .start_time = "startTime",
                .end_time = "endTime",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_flow_executions) } {
            return .{ .service_metadata = service_metadata, .action = search_flow_executions };
        }
    },
    Response: type = struct {
        summaries: ?[]struct {
            flow_execution_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            system_instance_id: ?[]const u8 = null,
            flow_template_id: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .flow_execution_id = "flowExecutionId",
                    .status = "status",
                    .system_instance_id = "systemInstanceId",
                    .flow_template_id = "flowTemplateId",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_flow_templates: struct {
    action_name: []const u8 = "SearchFlowTemplates",
    Request: type = struct {
        filters: ?[]struct {
            name: []const u8,
            value: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_flow_templates) } {
            return .{ .service_metadata = service_metadata, .action = search_flow_templates };
        }
    },
    Response: type = struct {
        summaries: ?[]FlowTemplateSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const search_system_instances: struct {
    action_name: []const u8 = "SearchSystemInstances",
    Request: type = struct {
        filters: ?[]struct {
            name: ?[]const u8 = null,
            value: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_system_instances) } {
            return .{ .service_metadata = service_metadata, .action = search_system_instances };
        }
    },
    Response: type = struct {
        summaries: ?[]SystemInstanceSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const search_system_templates: struct {
    action_name: []const u8 = "SearchSystemTemplates",
    Request: type = struct {
        filters: ?[]struct {
            name: []const u8,
            value: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_system_templates) } {
            return .{ .service_metadata = service_metadata, .action = search_system_templates };
        }
    },
    Response: type = struct {
        summaries: ?[]SystemTemplateSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const search_things: struct {
    action_name: []const u8 = "SearchThings",
    Request: type = struct {
        entity_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_id = "entityId",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .namespace_version = "namespaceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_things) } {
            return .{ .service_metadata = service_metadata, .action = search_things };
        }
    },
    Response: type = struct {
        things: ?[]struct {
            thing_arn: ?[]const u8 = null,
            thing_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .thing_arn = "thingArn",
                    .thing_name = "thingName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .things = "things",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const undeploy_system_instance: struct {
    action_name: []const u8 = "UndeploySystemInstance",
    Request: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(undeploy_system_instance) } {
            return .{ .service_metadata = service_metadata, .action = undeploy_system_instance };
        }
    },
    Response: type = struct {
        summary: ?SystemInstanceSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const update_flow_template: struct {
    action_name: []const u8 = "UpdateFlowTemplate",
    Request: type = struct {
        id: []const u8,
        definition: DefinitionDocument,
        compatible_namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .definition = "definition",
                .compatible_namespace_version = "compatibleNamespaceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_flow_template) } {
            return .{ .service_metadata = service_metadata, .action = update_flow_template };
        }
    },
    Response: type = struct {
        summary: ?FlowTemplateSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_system_template: struct {
    action_name: []const u8 = "UpdateSystemTemplate",
    Request: type = struct {
        id: []const u8,
        definition: DefinitionDocument,
        compatible_namespace_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .definition = "definition",
                .compatible_namespace_version = "compatibleNamespaceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_system_template) } {
            return .{ .service_metadata = service_metadata, .action = update_system_template };
        }
    },
    Response: type = struct {
        summary: ?SystemTemplateSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const upload_entity_definitions: struct {
    action_name: []const u8 = "UploadEntityDefinitions",
    Request: type = struct {
        document: ?DefinitionDocument = null,
        sync_with_public_namespace: ?bool = null,
        deprecate_existing_entities: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document = "document",
                .sync_with_public_namespace = "syncWithPublicNamespace",
                .deprecate_existing_entities = "deprecateExistingEntities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upload_entity_definitions) } {
            return .{ .service_metadata = service_metadata, .action = upload_entity_definitions };
        }
    },
    Response: type = struct {
        upload_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload_id = "uploadId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};

pub const DefinitionDocument = struct {
    language: []const u8,
    text: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .language = "language",
            .text = "text",
        };
        return @field(mappings, field_name);
    }
};

pub const SystemTemplateSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    revision_number: ?i64 = null,
    created_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .revision_number = "revisionNumber",
            .created_at = "createdAt",
        };
        return @field(mappings, field_name);
    }
};

pub const FlowTemplateSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    revision_number: ?i64 = null,
    created_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .revision_number = "revisionNumber",
            .created_at = "createdAt",
        };
        return @field(mappings, field_name);
    }
};

pub const SystemInstanceSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    target: ?[]const u8 = null,
    greengrass_group_name: ?[]const u8 = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,
    greengrass_group_id: ?[]const u8 = null,
    greengrass_group_version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .status = "status",
            .target = "target",
            .greengrass_group_name = "greengrassGroupName",
            .created_at = "createdAt",
            .updated_at = "updatedAt",
            .greengrass_group_id = "greengrassGroupId",
            .greengrass_group_version_id = "greengrassGroupVersionId",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const EntityDescription = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    type: ?[]const u8 = null,
    created_at: ?i64 = null,
    definition: ?DefinitionDocument = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .type = "type",
            .created_at = "createdAt",
            .definition = "definition",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricsConfiguration = struct {
    cloud_metric_enabled: ?bool = null,
    metric_rule_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_metric_enabled = "cloudMetricEnabled",
            .metric_rule_role_arn = "metricRuleRoleArn",
        };
        return @field(mappings, field_name);
    }
};
