const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-14";
pub const sdk_id: []const u8 = "IVS RealTime";
pub const arn_namespace: ?[]const u8 = "ivs";
pub const endpoint_prefix: []const u8 = "ivsrealtime";
pub const sigv4_name: []const u8 = "ivs";
pub const name: []const u8 = "AmazonInteractiveVideoServiceRealTime";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-14",
    sdk_id: []const u8 = "IVS RealTime",
    arn_namespace: ?[]const u8 = "ivs",
    endpoint_prefix: []const u8 = "ivsrealtime",
    sigv4_name: []const u8 = "ivs",
    name: []const u8 = "AmazonInteractiveVideoServiceRealTime",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_encoder_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateEncoderConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEncoderConfiguration",
    Request: type = struct {
        name: ?[]const u8 = null,
        video: ?Video = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .video = "video",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_encoder_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_encoder_configuration };
        }
    },
    Response: type = struct {
        encoder_configuration: ?EncoderConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encoder_configuration = "encoderConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_participant_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateParticipantToken",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateParticipantToken",
    Request: type = struct {
        stage_arn: []const u8,
        duration: ?i64 = null,
        user_id: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        capabilities: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_arn = "stageArn",
                .duration = "duration",
                .user_id = "userId",
                .attributes = "attributes",
                .capabilities = "capabilities",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_participant_token) } {
            return .{ .service_metadata = service_metadata, .action = create_participant_token };
        }
    },
    Response: type = struct {
        participant_token: ?ParticipantToken = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .participant_token = "participantToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_stage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateStage",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStage",
    Request: type = struct {
        name: ?[]const u8 = null,
        participant_token_configurations: ?[]struct {
            duration: ?i64 = null,
            user_id: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            capabilities: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .duration = "duration",
                    .user_id = "userId",
                    .attributes = "attributes",
                    .capabilities = "capabilities",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .participant_token_configurations = "participantTokenConfigurations",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stage) } {
            return .{ .service_metadata = service_metadata, .action = create_stage };
        }
    },
    Response: type = struct {
        stage: ?Stage = null,
        participant_tokens: ?[]ParticipantToken = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage = "stage",
                .participant_tokens = "participantTokens",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_storage_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateStorageConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStorageConfiguration",
    Request: type = struct {
        name: ?[]const u8 = null,
        s3: S3StorageConfiguration,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .s3 = "s3",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_storage_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_storage_configuration };
        }
    },
    Response: type = struct {
        storage_configuration: ?StorageConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_configuration = "storageConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_encoder_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteEncoderConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEncoderConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_encoder_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_encoder_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_stage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteStage",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStage",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stage) } {
            return .{ .service_metadata = service_metadata, .action = delete_stage };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_storage_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteStorageConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStorageConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_storage_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_storage_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const disconnect_participant: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DisconnectParticipant",
        .success_code = 200,
    };

    action_name: []const u8 = "DisconnectParticipant",
    Request: type = struct {
        stage_arn: []const u8,
        participant_id: []const u8,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_arn = "stageArn",
                .participant_id = "participantId",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disconnect_participant) } {
            return .{ .service_metadata = service_metadata, .action = disconnect_participant };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_composition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetComposition",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComposition",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_composition) } {
            return .{ .service_metadata = service_metadata, .action = get_composition };
        }
    },
    Response: type = struct {
        composition: ?Composition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .composition = "composition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const get_encoder_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetEncoderConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEncoderConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_encoder_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_encoder_configuration };
        }
    },
    Response: type = struct {
        encoder_configuration: ?EncoderConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encoder_configuration = "encoderConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const get_participant: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetParticipant",
        .success_code = 200,
    };

    action_name: []const u8 = "GetParticipant",
    Request: type = struct {
        stage_arn: []const u8,
        session_id: []const u8,
        participant_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_arn = "stageArn",
                .session_id = "sessionId",
                .participant_id = "participantId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_participant) } {
            return .{ .service_metadata = service_metadata, .action = get_participant };
        }
    },
    Response: type = struct {
        participant: ?struct {
            participant_id: ?[]const u8 = null,
            user_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            first_join_time: ?i64 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            published: ?bool = null,
            isp_name: ?[]const u8 = null,
            os_name: ?[]const u8 = null,
            os_version: ?[]const u8 = null,
            browser_name: ?[]const u8 = null,
            browser_version: ?[]const u8 = null,
            sdk_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .participant_id = "participantId",
                    .user_id = "userId",
                    .state = "state",
                    .first_join_time = "firstJoinTime",
                    .attributes = "attributes",
                    .published = "published",
                    .isp_name = "ispName",
                    .os_name = "osName",
                    .os_version = "osVersion",
                    .browser_name = "browserName",
                    .browser_version = "browserVersion",
                    .sdk_version = "sdkVersion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .participant = "participant",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_stage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetStage",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStage",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stage) } {
            return .{ .service_metadata = service_metadata, .action = get_stage };
        }
    },
    Response: type = struct {
        stage: ?Stage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_stage_session: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetStageSession",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStageSession",
    Request: type = struct {
        stage_arn: []const u8,
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_arn = "stageArn",
                .session_id = "sessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stage_session) } {
            return .{ .service_metadata = service_metadata, .action = get_stage_session };
        }
    },
    Response: type = struct {
        stage_session: ?struct {
            session_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_id = "sessionId",
                    .start_time = "startTime",
                    .end_time = "endTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_session = "stageSession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_storage_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetStorageConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStorageConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_storage_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_storage_configuration };
        }
    },
    Response: type = struct {
        storage_configuration: ?StorageConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_configuration = "storageConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_compositions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListCompositions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCompositions",
    Request: type = struct {
        filter_by_stage_arn: ?[]const u8 = null,
        filter_by_encoder_configuration_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_by_stage_arn = "filterByStageArn",
                .filter_by_encoder_configuration_arn = "filterByEncoderConfigurationArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_compositions) } {
            return .{ .service_metadata = service_metadata, .action = list_compositions };
        }
    },
    Response: type = struct {
        compositions: []struct {
            arn: []const u8,
            stage_arn: []const u8,
            destinations: []struct {
                id: []const u8,
                state: []const u8,
                start_time: ?i64 = null,
                end_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "id",
                        .state = "state",
                        .start_time = "startTime",
                        .end_time = "endTime",
                    };
                    return @field(mappings, field_name);
                }
            },
            state: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .stage_arn = "stageArn",
                    .destinations = "destinations",
                    .state = "state",
                    .tags = "tags",
                    .start_time = "startTime",
                    .end_time = "endTime",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compositions = "compositions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_encoder_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListEncoderConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEncoderConfigurations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_encoder_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_encoder_configurations };
        }
    },
    Response: type = struct {
        encoder_configurations: []struct {
            arn: []const u8,
            name: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encoder_configurations = "encoderConfigurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_participant_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListParticipantEvents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListParticipantEvents",
    Request: type = struct {
        stage_arn: []const u8,
        session_id: []const u8,
        participant_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_arn = "stageArn",
                .session_id = "sessionId",
                .participant_id = "participantId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_participant_events) } {
            return .{ .service_metadata = service_metadata, .action = list_participant_events };
        }
    },
    Response: type = struct {
        events: []struct {
            name: ?[]const u8 = null,
            participant_id: ?[]const u8 = null,
            event_time: ?i64 = null,
            remote_participant_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .participant_id = "participantId",
                    .event_time = "eventTime",
                    .remote_participant_id = "remoteParticipantId",
                    .error_code = "errorCode",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "events",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Validation,
    },
} = .{};
pub const list_participants: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListParticipants",
        .success_code = 200,
    };

    action_name: []const u8 = "ListParticipants",
    Request: type = struct {
        stage_arn: []const u8,
        session_id: []const u8,
        filter_by_user_id: ?[]const u8 = null,
        filter_by_published: ?bool = null,
        filter_by_state: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_arn = "stageArn",
                .session_id = "sessionId",
                .filter_by_user_id = "filterByUserId",
                .filter_by_published = "filterByPublished",
                .filter_by_state = "filterByState",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_participants) } {
            return .{ .service_metadata = service_metadata, .action = list_participants };
        }
    },
    Response: type = struct {
        participants: []struct {
            participant_id: ?[]const u8 = null,
            user_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            first_join_time: ?i64 = null,
            published: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .participant_id = "participantId",
                    .user_id = "userId",
                    .state = "state",
                    .first_join_time = "firstJoinTime",
                    .published = "published",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .participants = "participants",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Validation,
    },
} = .{};
pub const list_stages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListStages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStages",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_stages) } {
            return .{ .service_metadata = service_metadata, .action = list_stages };
        }
    },
    Response: type = struct {
        stages: []struct {
            arn: []const u8,
            name: ?[]const u8 = null,
            active_session_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .active_session_id = "activeSessionId",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stages = "stages",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        Validation,
    },
} = .{};
pub const list_stage_sessions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListStageSessions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStageSessions",
    Request: type = struct {
        stage_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_arn = "stageArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_stage_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_stage_sessions };
        }
    },
    Response: type = struct {
        stage_sessions: []struct {
            session_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_id = "sessionId",
                    .start_time = "startTime",
                    .end_time = "endTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_sessions = "stageSessions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Validation,
    },
} = .{};
pub const list_storage_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListStorageConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStorageConfigurations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_storage_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_storage_configurations };
        }
    },
    Response: type = struct {
        storage_configurations: []struct {
            arn: []const u8,
            name: ?[]const u8 = null,
            s3: ?S3StorageConfiguration = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .s3 = "s3",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_configurations = "storageConfigurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_composition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/StartComposition",
        .success_code = 200,
    };

    action_name: []const u8 = "StartComposition",
    Request: type = struct {
        stage_arn: []const u8,
        idempotency_token: ?[]const u8 = null,
        layout: ?LayoutConfiguration = null,
        destinations: []DestinationConfiguration,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage_arn = "stageArn",
                .idempotency_token = "idempotencyToken",
                .layout = "layout",
                .destinations = "destinations",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_composition) } {
            return .{ .service_metadata = service_metadata, .action = start_composition };
        }
    },
    Response: type = struct {
        composition: ?Composition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .composition = "composition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const stop_composition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/StopComposition",
        .success_code = 200,
    };

    action_name: []const u8 = "StopComposition",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_composition) } {
            return .{ .service_metadata = service_metadata, .action = stop_composition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_stage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateStage",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStage",
    Request: type = struct {
        arn: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_stage) } {
            return .{ .service_metadata = service_metadata, .action = update_stage };
        }
    },
    Response: type = struct {
        stage: ?Stage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};

pub const Stage = struct {
    arn: []const u8,
    name: ?[]const u8 = null,
    active_session_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .active_session_id = "activeSessionId",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Composition = struct {
    arn: []const u8,
    stage_arn: []const u8,
    state: []const u8,
    layout: LayoutConfiguration,
    destinations: []Destination,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .stage_arn = "stageArn",
            .state = "state",
            .layout = "layout",
            .destinations = "destinations",
            .tags = "tags",
            .start_time = "startTime",
            .end_time = "endTime",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Destination = struct {
    id: []const u8,
    state: []const u8,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    configuration: DestinationConfiguration,
    detail: ?DestinationDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .state = "state",
            .start_time = "startTime",
            .end_time = "endTime",
            .configuration = "configuration",
            .detail = "detail",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationDetail = struct {
    s3: ?S3Detail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "s3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Detail = struct {
    recording_prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recording_prefix = "recordingPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfiguration = struct {
    name: ?[]const u8 = null,
    channel: ?ChannelDestinationConfiguration = null,
    s3: ?S3DestinationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .channel = "channel",
            .s3 = "s3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationConfiguration = struct {
    storage_configuration_arn: []const u8,
    encoder_configuration_arns: [][]const u8,
    recording_configuration: ?RecordingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_configuration_arn = "storageConfigurationArn",
            .encoder_configuration_arns = "encoderConfigurationArns",
            .recording_configuration = "recordingConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordingConfiguration = struct {
    format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "format",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelDestinationConfiguration = struct {
    channel_arn: []const u8,
    encoder_configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_arn = "channelArn",
            .encoder_configuration_arn = "encoderConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LayoutConfiguration = struct {
    grid: ?GridConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grid = "grid",
        };
        return @field(mappings, field_name);
    }
};

pub const GridConfiguration = struct {
    featured_participant_attribute: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .featured_participant_attribute = "featuredParticipantAttribute",
        };
        return @field(mappings, field_name);
    }
};

pub const S3StorageConfiguration = struct {
    bucket_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageConfiguration = struct {
    arn: []const u8,
    name: ?[]const u8 = null,
    s3: ?S3StorageConfiguration = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .s3 = "s3",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const EncoderConfiguration = struct {
    arn: []const u8,
    name: ?[]const u8 = null,
    video: ?Video = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .video = "video",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Video = struct {
    width: ?i64 = null,
    height: ?i64 = null,
    framerate: ?f32 = null,
    bitrate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .width = "width",
            .height = "height",
            .framerate = "framerate",
            .bitrate = "bitrate",
        };
        return @field(mappings, field_name);
    }
};

pub const ParticipantToken = struct {
    participant_id: ?[]const u8 = null,
    token: ?[]const u8 = null,
    user_id: ?[]const u8 = null,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    duration: ?i64 = null,
    capabilities: ?[][]const u8 = null,
    expiration_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .participant_id = "participantId",
            .token = "token",
            .user_id = "userId",
            .attributes = "attributes",
            .duration = "duration",
            .capabilities = "capabilities",
            .expiration_time = "expirationTime",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};
