const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-14";
pub const sdk_id: []const u8 = "ivschat";
pub const arn_namespace: ?[]const u8 = "ivschat";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "ivschat";
pub const name: []const u8 = "AmazonInteractiveVideoServiceChat";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-14",
    sdk_id: []const u8 = "ivschat",
    arn_namespace: ?[]const u8 = "ivschat",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "ivschat",
    name: []const u8 = "AmazonInteractiveVideoServiceChat",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_chat_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateChatToken",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateChatToken",
    Request: type = struct {
        room_identifier: []const u8,
        user_id: []const u8,
        capabilities: ?[][]const u8 = null,
        session_duration_in_minutes: ?i64 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room_identifier = "roomIdentifier",
                .user_id = "userId",
                .capabilities = "capabilities",
                .session_duration_in_minutes = "sessionDurationInMinutes",
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_chat_token) } {
            return .{ .service_metadata = service_metadata, .action = create_chat_token };
        }
    },
    Response: type = struct {
        token: ?[]const u8 = null,
        token_expiration_time: ?i64 = null,
        session_expiration_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token = "token",
                .token_expiration_time = "tokenExpirationTime",
                .session_expiration_time = "sessionExpirationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_logging_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateLoggingConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLoggingConfiguration",
    Request: type = struct {
        name: ?[]const u8 = null,
        destination_configuration: DestinationConfiguration,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .destination_configuration = "destinationConfiguration",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_logging_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        create_time: ?i64 = null,
        update_time: ?i64 = null,
        name: ?[]const u8 = null,
        destination_configuration: ?DestinationConfiguration = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .create_time = "createTime",
                .update_time = "updateTime",
                .name = "name",
                .destination_configuration = "destinationConfiguration",
                .state = "state",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_room: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateRoom",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRoom",
    Request: type = struct {
        name: ?[]const u8 = null,
        maximum_message_rate_per_second: ?i64 = null,
        maximum_message_length: ?i64 = null,
        message_review_handler: ?MessageReviewHandler = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        logging_configuration_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .maximum_message_rate_per_second = "maximumMessageRatePerSecond",
                .maximum_message_length = "maximumMessageLength",
                .message_review_handler = "messageReviewHandler",
                .tags = "tags",
                .logging_configuration_identifiers = "loggingConfigurationIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_room) } {
            return .{ .service_metadata = service_metadata, .action = create_room };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        create_time: ?i64 = null,
        update_time: ?i64 = null,
        maximum_message_rate_per_second: ?i64 = null,
        maximum_message_length: ?i64 = null,
        message_review_handler: ?MessageReviewHandler = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        logging_configuration_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .name = "name",
                .create_time = "createTime",
                .update_time = "updateTime",
                .maximum_message_rate_per_second = "maximumMessageRatePerSecond",
                .maximum_message_length = "maximumMessageLength",
                .message_review_handler = "messageReviewHandler",
                .tags = "tags",
                .logging_configuration_identifiers = "loggingConfigurationIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        PendingVerification,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_logging_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteLoggingConfiguration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteLoggingConfiguration",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_logging_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteMessage",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMessage",
    Request: type = struct {
        room_identifier: []const u8,
        id: []const u8,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room_identifier = "roomIdentifier",
                .id = "id",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_message) } {
            return .{ .service_metadata = service_metadata, .action = delete_message };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_room: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteRoom",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRoom",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_room) } {
            return .{ .service_metadata = service_metadata, .action = delete_room };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const disconnect_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DisconnectUser",
        .success_code = 200,
    };

    action_name: []const u8 = "DisconnectUser",
    Request: type = struct {
        room_identifier: []const u8,
        user_id: []const u8,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room_identifier = "roomIdentifier",
                .user_id = "userId",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disconnect_user) } {
            return .{ .service_metadata = service_metadata, .action = disconnect_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_logging_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetLoggingConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLoggingConfiguration",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_logging_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        create_time: ?i64 = null,
        update_time: ?i64 = null,
        name: ?[]const u8 = null,
        destination_configuration: ?DestinationConfiguration = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .create_time = "createTime",
                .update_time = "updateTime",
                .name = "name",
                .destination_configuration = "destinationConfiguration",
                .state = "state",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_room: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetRoom",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRoom",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_room) } {
            return .{ .service_metadata = service_metadata, .action = get_room };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        create_time: ?i64 = null,
        update_time: ?i64 = null,
        maximum_message_rate_per_second: ?i64 = null,
        maximum_message_length: ?i64 = null,
        message_review_handler: ?MessageReviewHandler = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        logging_configuration_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .name = "name",
                .create_time = "createTime",
                .update_time = "updateTime",
                .maximum_message_rate_per_second = "maximumMessageRatePerSecond",
                .maximum_message_length = "maximumMessageLength",
                .message_review_handler = "messageReviewHandler",
                .tags = "tags",
                .logging_configuration_identifiers = "loggingConfigurationIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_logging_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListLoggingConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLoggingConfigurations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_logging_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_logging_configurations };
        }
    },
    Response: type = struct {
        logging_configurations: []struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            create_time: ?i64 = null,
            update_time: ?i64 = null,
            name: ?[]const u8 = null,
            destination_configuration: ?DestinationConfiguration = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .id = "id",
                    .create_time = "createTime",
                    .update_time = "updateTime",
                    .name = "name",
                    .destination_configuration = "destinationConfiguration",
                    .state = "state",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configurations = "loggingConfigurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Validation,
    },
} = .{};
pub const list_rooms: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListRooms",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRooms",
    Request: type = struct {
        name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        message_review_handler_uri: ?[]const u8 = null,
        logging_configuration_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .message_review_handler_uri = "messageReviewHandlerUri",
                .logging_configuration_identifier = "loggingConfigurationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rooms) } {
            return .{ .service_metadata = service_metadata, .action = list_rooms };
        }
    },
    Response: type = struct {
        rooms: []struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            message_review_handler: ?MessageReviewHandler = null,
            create_time: ?i64 = null,
            update_time: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            logging_configuration_identifiers: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .id = "id",
                    .name = "name",
                    .message_review_handler = "messageReviewHandler",
                    .create_time = "createTime",
                    .update_time = "updateTime",
                    .tags = "tags",
                    .logging_configuration_identifiers = "loggingConfigurationIdentifiers",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rooms = "rooms",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const send_event: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/SendEvent",
        .success_code = 200,
    };

    action_name: []const u8 = "SendEvent",
    Request: type = struct {
        room_identifier: []const u8,
        event_name: []const u8,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room_identifier = "roomIdentifier",
                .event_name = "eventName",
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_event) } {
            return .{ .service_metadata = service_metadata, .action = send_event };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_logging_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateLoggingConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLoggingConfiguration",
    Request: type = struct {
        identifier: []const u8,
        name: ?[]const u8 = null,
        destination_configuration: ?DestinationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "identifier",
                .name = "name",
                .destination_configuration = "destinationConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_logging_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        create_time: ?i64 = null,
        update_time: ?i64 = null,
        name: ?[]const u8 = null,
        destination_configuration: ?DestinationConfiguration = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .create_time = "createTime",
                .update_time = "updateTime",
                .name = "name",
                .destination_configuration = "destinationConfiguration",
                .state = "state",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_room: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateRoom",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoom",
    Request: type = struct {
        identifier: []const u8,
        name: ?[]const u8 = null,
        maximum_message_rate_per_second: ?i64 = null,
        maximum_message_length: ?i64 = null,
        message_review_handler: ?MessageReviewHandler = null,
        logging_configuration_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "identifier",
                .name = "name",
                .maximum_message_rate_per_second = "maximumMessageRatePerSecond",
                .maximum_message_length = "maximumMessageLength",
                .message_review_handler = "messageReviewHandler",
                .logging_configuration_identifiers = "loggingConfigurationIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_room) } {
            return .{ .service_metadata = service_metadata, .action = update_room };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        create_time: ?i64 = null,
        update_time: ?i64 = null,
        maximum_message_rate_per_second: ?i64 = null,
        maximum_message_length: ?i64 = null,
        message_review_handler: ?MessageReviewHandler = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        logging_configuration_identifiers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .name = "name",
                .create_time = "createTime",
                .update_time = "updateTime",
                .maximum_message_rate_per_second = "maximumMessageRatePerSecond",
                .maximum_message_length = "maximumMessageLength",
                .message_review_handler = "messageReviewHandler",
                .tags = "tags",
                .logging_configuration_identifiers = "loggingConfigurationIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        PendingVerification,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const MessageReviewHandler = struct {
    uri: ?[]const u8 = null,
    fallback_result: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uri = "uri",
            .fallback_result = "fallbackResult",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfiguration = union {
    s3: ?S3DestinationConfiguration,
    cloud_watch_logs: ?CloudWatchLogsDestinationConfiguration,
    firehose: ?FirehoseDestinationConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "s3",
            .cloud_watch_logs = "cloudWatchLogs",
            .firehose = "firehose",
        };
        return @field(mappings, field_name);
    }
};

pub const FirehoseDestinationConfiguration = struct {
    delivery_stream_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_stream_name = "deliveryStreamName",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogsDestinationConfiguration = struct {
    log_group_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_name = "logGroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationConfiguration = struct {
    bucket_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
        };
        return @field(mappings, field_name);
    }
};
