const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-09-14";
pub const sdk_id: []const u8 = "KafkaConnect";
pub const arn_namespace: ?[]const u8 = "kafkaconnect";
pub const endpoint_prefix: []const u8 = "kafkaconnect";
pub const sigv4_name: []const u8 = "kafkaconnect";
pub const name: []const u8 = "KafkaConnect";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-09-14",
    sdk_id: []const u8 = "KafkaConnect",
    arn_namespace: ?[]const u8 = "kafkaconnect",
    endpoint_prefix: []const u8 = "kafkaconnect",
    sigv4_name: []const u8 = "kafkaconnect",
    name: []const u8 = "KafkaConnect",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/connectors",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConnector",
    Request: type = struct {
        capacity: struct {
            auto_scaling: ?struct {
                max_worker_count: i64,
                mcu_count: i64,
                min_worker_count: i64,
                scale_in_policy: ?struct {
                    cpu_utilization_percentage: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cpu_utilization_percentage = "cpuUtilizationPercentage",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                scale_out_policy: ?struct {
                    cpu_utilization_percentage: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cpu_utilization_percentage = "cpuUtilizationPercentage",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .max_worker_count = "maxWorkerCount",
                        .mcu_count = "mcuCount",
                        .min_worker_count = "minWorkerCount",
                        .scale_in_policy = "scaleInPolicy",
                        .scale_out_policy = "scaleOutPolicy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            provisioned_capacity: ?struct {
                mcu_count: i64,
                worker_count: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .mcu_count = "mcuCount",
                        .worker_count = "workerCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_scaling = "autoScaling",
                    .provisioned_capacity = "provisionedCapacity",
                };
                return @field(mappings, field_name);
            }
        },
        connector_configuration: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        connector_description: ?[]const u8 = null,
        connector_name: []const u8,
        kafka_cluster: struct {
            apache_kafka_cluster: struct {
                bootstrap_servers: []const u8,
                vpc: struct {
                    security_groups: ?[][]const u8 = null,
                    subnets: [][]const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .security_groups = "securityGroups",
                            .subnets = "subnets",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bootstrap_servers = "bootstrapServers",
                        .vpc = "vpc",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .apache_kafka_cluster = "apacheKafkaCluster",
                };
                return @field(mappings, field_name);
            }
        },
        kafka_cluster_client_authentication: struct {
            authentication_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authentication_type = "authenticationType",
                };
                return @field(mappings, field_name);
            }
        },
        kafka_cluster_encryption_in_transit: struct {
            encryption_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .encryption_type = "encryptionType",
                };
                return @field(mappings, field_name);
            }
        },
        kafka_connect_version: []const u8,
        log_delivery: ?struct {
            worker_log_delivery: struct {
                cloud_watch_logs: ?struct {
                    enabled: bool,
                    log_group: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .enabled = "enabled",
                            .log_group = "logGroup",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                firehose: ?struct {
                    delivery_stream: ?[]const u8 = null,
                    enabled: bool,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .delivery_stream = "deliveryStream",
                            .enabled = "enabled",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                s3: ?struct {
                    bucket: ?[]const u8 = null,
                    enabled: bool,
                    prefix: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bucket = "bucket",
                            .enabled = "enabled",
                            .prefix = "prefix",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cloud_watch_logs = "cloudWatchLogs",
                        .firehose = "firehose",
                        .s3 = "s3",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .worker_log_delivery = "workerLogDelivery",
                };
                return @field(mappings, field_name);
            }
        } = null,
        plugins: []struct {
            custom_plugin: struct {
                custom_plugin_arn: []const u8,
                revision: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .custom_plugin_arn = "customPluginArn",
                        .revision = "revision",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .custom_plugin = "customPlugin",
                };
                return @field(mappings, field_name);
            }
        },
        service_execution_role_arn: []const u8,
        worker_configuration: ?struct {
            revision: i64,
            worker_configuration_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .revision = "revision",
                    .worker_configuration_arn = "workerConfigurationArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity = "capacity",
                .connector_configuration = "connectorConfiguration",
                .connector_description = "connectorDescription",
                .connector_name = "connectorName",
                .kafka_cluster = "kafkaCluster",
                .kafka_cluster_client_authentication = "kafkaClusterClientAuthentication",
                .kafka_cluster_encryption_in_transit = "kafkaClusterEncryptionInTransit",
                .kafka_connect_version = "kafkaConnectVersion",
                .log_delivery = "logDelivery",
                .plugins = "plugins",
                .service_execution_role_arn = "serviceExecutionRoleArn",
                .worker_configuration = "workerConfiguration",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "connector_configuration", field_name))
                return try serializeMap(self.connector_configuration, self.fieldNameFor("connector_configuration"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connector) } {
            return .{ .service_metadata = service_metadata, .action = create_connector };
        }
    },
    Response: type = struct {
        connector_arn: ?[]const u8 = null,
        connector_name: ?[]const u8 = null,
        connector_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_arn = "connectorArn",
                .connector_name = "connectorName",
                .connector_state = "connectorState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_custom_plugin: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/custom-plugins",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCustomPlugin",
    Request: type = struct {
        content_type: []const u8,
        description: ?[]const u8 = null,
        location: struct {
            s3_location: struct {
                bucket_arn: []const u8,
                file_key: []const u8,
                object_version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bucket_arn = "bucketArn",
                        .file_key = "fileKey",
                        .object_version = "objectVersion",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_location = "s3Location",
                };
                return @field(mappings, field_name);
            }
        },
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .description = "description",
                .location = "location",
                .name = "name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_plugin) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_plugin };
        }
    },
    Response: type = struct {
        custom_plugin_arn: ?[]const u8 = null,
        custom_plugin_state: ?[]const u8 = null,
        name: ?[]const u8 = null,
        revision: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_plugin_arn = "customPluginArn",
                .custom_plugin_state = "customPluginState",
                .name = "name",
                .revision = "revision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_worker_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/worker-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorkerConfiguration",
    Request: type = struct {
        description: ?[]const u8 = null,
        name: []const u8,
        properties_file_content: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .name = "name",
                .properties_file_content = "propertiesFileContent",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_worker_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_worker_configuration };
        }
    },
    Response: type = struct {
        creation_time: ?i64 = null,
        latest_revision: ?WorkerConfigurationRevisionSummary = null,
        name: ?[]const u8 = null,
        worker_configuration_arn: ?[]const u8 = null,
        worker_configuration_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "creationTime",
                .latest_revision = "latestRevision",
                .name = "name",
                .worker_configuration_arn = "workerConfigurationArn",
                .worker_configuration_state = "workerConfigurationState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_connector: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/connectors/{connectorArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConnector",
    Request: type = struct {
        connector_arn: []const u8,
        current_version: ?[]const u8 = null,

        pub const http_query = .{
            .current_version = "currentVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_arn = "connectorArn",
                .current_version = "currentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connector) } {
            return .{ .service_metadata = service_metadata, .action = delete_connector };
        }
    },
    Response: type = struct {
        connector_arn: ?[]const u8 = null,
        connector_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_arn = "connectorArn",
                .connector_state = "connectorState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_custom_plugin: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/custom-plugins/{customPluginArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCustomPlugin",
    Request: type = struct {
        custom_plugin_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_plugin_arn = "customPluginArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_plugin) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_plugin };
        }
    },
    Response: type = struct {
        custom_plugin_arn: ?[]const u8 = null,
        custom_plugin_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_plugin_arn = "customPluginArn",
                .custom_plugin_state = "customPluginState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_worker_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/worker-configurations/{workerConfigurationArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkerConfiguration",
    Request: type = struct {
        worker_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .worker_configuration_arn = "workerConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_worker_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_worker_configuration };
        }
    },
    Response: type = struct {
        worker_configuration_arn: ?[]const u8 = null,
        worker_configuration_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .worker_configuration_arn = "workerConfigurationArn",
                .worker_configuration_state = "workerConfigurationState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_connector: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/connectors/{connectorArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConnector",
    Request: type = struct {
        connector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_arn = "connectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connector) } {
            return .{ .service_metadata = service_metadata, .action = describe_connector };
        }
    },
    Response: type = struct {
        capacity: ?CapacityDescription = null,
        connector_arn: ?[]const u8 = null,
        connector_configuration: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        connector_description: ?[]const u8 = null,
        connector_name: ?[]const u8 = null,
        connector_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        current_version: ?[]const u8 = null,
        kafka_cluster: ?KafkaClusterDescription = null,
        kafka_cluster_client_authentication: ?KafkaClusterClientAuthenticationDescription = null,
        kafka_cluster_encryption_in_transit: ?KafkaClusterEncryptionInTransitDescription = null,
        kafka_connect_version: ?[]const u8 = null,
        log_delivery: ?LogDeliveryDescription = null,
        plugins: ?[]PluginDescription = null,
        service_execution_role_arn: ?[]const u8 = null,
        worker_configuration: ?WorkerConfigurationDescription = null,
        state_description: ?StateDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity = "capacity",
                .connector_arn = "connectorArn",
                .connector_configuration = "connectorConfiguration",
                .connector_description = "connectorDescription",
                .connector_name = "connectorName",
                .connector_state = "connectorState",
                .creation_time = "creationTime",
                .current_version = "currentVersion",
                .kafka_cluster = "kafkaCluster",
                .kafka_cluster_client_authentication = "kafkaClusterClientAuthentication",
                .kafka_cluster_encryption_in_transit = "kafkaClusterEncryptionInTransit",
                .kafka_connect_version = "kafkaConnectVersion",
                .log_delivery = "logDelivery",
                .plugins = "plugins",
                .service_execution_role_arn = "serviceExecutionRoleArn",
                .worker_configuration = "workerConfiguration",
                .state_description = "stateDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "connector_configuration", field_name))
                return try serializeMap(self.connector_configuration, self.fieldNameFor("connector_configuration"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_custom_plugin: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/custom-plugins/{customPluginArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCustomPlugin",
    Request: type = struct {
        custom_plugin_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_plugin_arn = "customPluginArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_plugin) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_plugin };
        }
    },
    Response: type = struct {
        creation_time: ?i64 = null,
        custom_plugin_arn: ?[]const u8 = null,
        custom_plugin_state: ?[]const u8 = null,
        description: ?[]const u8 = null,
        latest_revision: ?CustomPluginRevisionSummary = null,
        name: ?[]const u8 = null,
        state_description: ?StateDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "creationTime",
                .custom_plugin_arn = "customPluginArn",
                .custom_plugin_state = "customPluginState",
                .description = "description",
                .latest_revision = "latestRevision",
                .name = "name",
                .state_description = "stateDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_worker_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/worker-configurations/{workerConfigurationArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeWorkerConfiguration",
    Request: type = struct {
        worker_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .worker_configuration_arn = "workerConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_worker_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_worker_configuration };
        }
    },
    Response: type = struct {
        creation_time: ?i64 = null,
        description: ?[]const u8 = null,
        latest_revision: ?struct {
            creation_time: ?i64 = null,
            description: ?[]const u8 = null,
            properties_file_content: ?[]const u8 = null,
            revision: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "creationTime",
                    .description = "description",
                    .properties_file_content = "propertiesFileContent",
                    .revision = "revision",
                };
                return @field(mappings, field_name);
            }
        } = null,
        name: ?[]const u8 = null,
        worker_configuration_arn: ?[]const u8 = null,
        worker_configuration_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "creationTime",
                .description = "description",
                .latest_revision = "latestRevision",
                .name = "name",
                .worker_configuration_arn = "workerConfigurationArn",
                .worker_configuration_state = "workerConfigurationState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_connectors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/connectors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConnectors",
    Request: type = struct {
        connector_name_prefix: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .connector_name_prefix = "connectorNamePrefix",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_name_prefix = "connectorNamePrefix",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connectors) } {
            return .{ .service_metadata = service_metadata, .action = list_connectors };
        }
    },
    Response: type = struct {
        connectors: ?[]struct {
            capacity: ?CapacityDescription = null,
            connector_arn: ?[]const u8 = null,
            connector_description: ?[]const u8 = null,
            connector_name: ?[]const u8 = null,
            connector_state: ?[]const u8 = null,
            creation_time: ?i64 = null,
            current_version: ?[]const u8 = null,
            kafka_cluster: ?KafkaClusterDescription = null,
            kafka_cluster_client_authentication: ?KafkaClusterClientAuthenticationDescription = null,
            kafka_cluster_encryption_in_transit: ?KafkaClusterEncryptionInTransitDescription = null,
            kafka_connect_version: ?[]const u8 = null,
            log_delivery: ?LogDeliveryDescription = null,
            plugins: ?[]PluginDescription = null,
            service_execution_role_arn: ?[]const u8 = null,
            worker_configuration: ?WorkerConfigurationDescription = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .capacity = "capacity",
                    .connector_arn = "connectorArn",
                    .connector_description = "connectorDescription",
                    .connector_name = "connectorName",
                    .connector_state = "connectorState",
                    .creation_time = "creationTime",
                    .current_version = "currentVersion",
                    .kafka_cluster = "kafkaCluster",
                    .kafka_cluster_client_authentication = "kafkaClusterClientAuthentication",
                    .kafka_cluster_encryption_in_transit = "kafkaClusterEncryptionInTransit",
                    .kafka_connect_version = "kafkaConnectVersion",
                    .log_delivery = "logDelivery",
                    .plugins = "plugins",
                    .service_execution_role_arn = "serviceExecutionRoleArn",
                    .worker_configuration = "workerConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connectors = "connectors",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_custom_plugins: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/custom-plugins",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCustomPlugins",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        name_prefix: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .name_prefix = "namePrefix",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .name_prefix = "namePrefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_plugins) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_plugins };
        }
    },
    Response: type = struct {
        custom_plugins: ?[]struct {
            creation_time: ?i64 = null,
            custom_plugin_arn: ?[]const u8 = null,
            custom_plugin_state: ?[]const u8 = null,
            description: ?[]const u8 = null,
            latest_revision: ?CustomPluginRevisionSummary = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "creationTime",
                    .custom_plugin_arn = "customPluginArn",
                    .custom_plugin_state = "customPluginState",
                    .description = "description",
                    .latest_revision = "latestRevision",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_plugins = "customPlugins",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_worker_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/worker-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkerConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        name_prefix: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .name_prefix = "namePrefix",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .name_prefix = "namePrefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_worker_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_worker_configurations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        worker_configurations: ?[]struct {
            creation_time: ?i64 = null,
            description: ?[]const u8 = null,
            latest_revision: ?WorkerConfigurationRevisionSummary = null,
            name: ?[]const u8 = null,
            worker_configuration_arn: ?[]const u8 = null,
            worker_configuration_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "creationTime",
                    .description = "description",
                    .latest_revision = "latestRevision",
                    .name = "name",
                    .worker_configuration_arn = "workerConfigurationArn",
                    .worker_configuration_state = "workerConfigurationState",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .worker_configurations = "workerConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_connector: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/connectors/{connectorArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConnector",
    Request: type = struct {
        capacity: struct {
            auto_scaling: ?struct {
                max_worker_count: i64,
                mcu_count: i64,
                min_worker_count: i64,
                scale_in_policy: struct {
                    cpu_utilization_percentage: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cpu_utilization_percentage = "cpuUtilizationPercentage",
                        };
                        return @field(mappings, field_name);
                    }
                },
                scale_out_policy: struct {
                    cpu_utilization_percentage: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cpu_utilization_percentage = "cpuUtilizationPercentage",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .max_worker_count = "maxWorkerCount",
                        .mcu_count = "mcuCount",
                        .min_worker_count = "minWorkerCount",
                        .scale_in_policy = "scaleInPolicy",
                        .scale_out_policy = "scaleOutPolicy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            provisioned_capacity: ?struct {
                mcu_count: i64,
                worker_count: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .mcu_count = "mcuCount",
                        .worker_count = "workerCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_scaling = "autoScaling",
                    .provisioned_capacity = "provisionedCapacity",
                };
                return @field(mappings, field_name);
            }
        },
        connector_arn: []const u8,
        current_version: []const u8,

        pub const http_query = .{
            .current_version = "currentVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity = "capacity",
                .connector_arn = "connectorArn",
                .current_version = "currentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connector) } {
            return .{ .service_metadata = service_metadata, .action = update_connector };
        }
    },
    Response: type = struct {
        connector_arn: ?[]const u8 = null,
        connector_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_arn = "connectorArn",
                .connector_state = "connectorState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};

pub const WorkerConfigurationRevisionSummary = struct {
    creation_time: ?i64 = null,
    description: ?[]const u8 = null,
    revision: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_time = "creationTime",
            .description = "description",
            .revision = "revision",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomPluginRevisionSummary = struct {
    content_type: ?[]const u8 = null,
    creation_time: ?i64 = null,
    description: ?[]const u8 = null,
    file_description: ?CustomPluginFileDescription = null,
    location: ?CustomPluginLocationDescription = null,
    revision: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_type = "contentType",
            .creation_time = "creationTime",
            .description = "description",
            .file_description = "fileDescription",
            .location = "location",
            .revision = "revision",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomPluginLocationDescription = struct {
    s3_location: ?S3LocationDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_location = "s3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const S3LocationDescription = struct {
    bucket_arn: ?[]const u8 = null,
    file_key: ?[]const u8 = null,
    object_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_arn = "bucketArn",
            .file_key = "fileKey",
            .object_version = "objectVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomPluginFileDescription = struct {
    file_md5: ?[]const u8 = null,
    file_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_md5 = "fileMd5",
            .file_size = "fileSize",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkerConfigurationDescription = struct {
    revision: ?i64 = null,
    worker_configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .revision = "revision",
            .worker_configuration_arn = "workerConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PluginDescription = struct {
    custom_plugin: ?CustomPluginDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_plugin = "customPlugin",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomPluginDescription = struct {
    custom_plugin_arn: ?[]const u8 = null,
    revision: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_plugin_arn = "customPluginArn",
            .revision = "revision",
        };
        return @field(mappings, field_name);
    }
};

pub const LogDeliveryDescription = struct {
    worker_log_delivery: ?WorkerLogDeliveryDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .worker_log_delivery = "workerLogDelivery",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkerLogDeliveryDescription = struct {
    cloud_watch_logs: ?CloudWatchLogsLogDeliveryDescription = null,
    firehose: ?FirehoseLogDeliveryDescription = null,
    s3: ?S3LogDeliveryDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs = "cloudWatchLogs",
            .firehose = "firehose",
            .s3 = "s3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3LogDeliveryDescription = struct {
    bucket: ?[]const u8 = null,
    enabled: ?bool = null,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .enabled = "enabled",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const FirehoseLogDeliveryDescription = struct {
    delivery_stream: ?[]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_stream = "deliveryStream",
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogsLogDeliveryDescription = struct {
    enabled: ?bool = null,
    log_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .log_group = "logGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const KafkaClusterEncryptionInTransitDescription = struct {
    encryption_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_type = "encryptionType",
        };
        return @field(mappings, field_name);
    }
};

pub const KafkaClusterClientAuthenticationDescription = struct {
    authentication_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authentication_type = "authenticationType",
        };
        return @field(mappings, field_name);
    }
};

pub const KafkaClusterDescription = struct {
    apache_kafka_cluster: ?ApacheKafkaClusterDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apache_kafka_cluster = "apacheKafkaCluster",
        };
        return @field(mappings, field_name);
    }
};

pub const ApacheKafkaClusterDescription = struct {
    bootstrap_servers: ?[]const u8 = null,
    vpc: ?VpcDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bootstrap_servers = "bootstrapServers",
            .vpc = "vpc",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcDescription = struct {
    security_groups: ?[][]const u8 = null,
    subnets: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_groups = "securityGroups",
            .subnets = "subnets",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityDescription = struct {
    auto_scaling: ?AutoScalingDescription = null,
    provisioned_capacity: ?ProvisionedCapacityDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_scaling = "autoScaling",
            .provisioned_capacity = "provisionedCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisionedCapacityDescription = struct {
    mcu_count: ?i64 = null,
    worker_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mcu_count = "mcuCount",
            .worker_count = "workerCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingDescription = struct {
    max_worker_count: ?i64 = null,
    mcu_count: ?i64 = null,
    min_worker_count: ?i64 = null,
    scale_in_policy: ?ScaleInPolicyDescription = null,
    scale_out_policy: ?ScaleOutPolicyDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_worker_count = "maxWorkerCount",
            .mcu_count = "mcuCount",
            .min_worker_count = "minWorkerCount",
            .scale_in_policy = "scaleInPolicy",
            .scale_out_policy = "scaleOutPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const ScaleOutPolicyDescription = struct {
    cpu_utilization_percentage: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu_utilization_percentage = "cpuUtilizationPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const ScaleInPolicyDescription = struct {
    cpu_utilization_percentage: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu_utilization_percentage = "cpuUtilizationPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const StateDescription = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};
