const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-02-03";
pub const sdk_id: []const u8 = "kendra";
pub const arn_namespace: ?[]const u8 = "kendra";
pub const endpoint_prefix: []const u8 = "kendra";
pub const sigv4_name: []const u8 = "kendra";
pub const name: []const u8 = "AWSKendraFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-02-03",
    sdk_id: []const u8 = "kendra",
    arn_namespace: ?[]const u8 = "kendra",
    endpoint_prefix: []const u8 = "kendra",
    sigv4_name: []const u8 = "kendra",
    name: []const u8 = "AWSKendraFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_entities_to_experience: struct {
    action_name: []const u8 = "AssociateEntitiesToExperience",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,
        entity_list: []EntityConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .entity_list = "EntityList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_entities_to_experience) } {
            return .{ .service_metadata = service_metadata, .action = associate_entities_to_experience };
        }
    },
    Response: type = struct {
        failed_entity_list: ?[]FailedEntity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_entity_list = "FailedEntityList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceAlreadyExist,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_personas_to_entities: struct {
    action_name: []const u8 = "AssociatePersonasToEntities",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,
        personas: []struct {
            entity_id: []const u8,
            persona: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entity_id = "EntityId",
                    .persona = "Persona",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .personas = "Personas",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_personas_to_entities) } {
            return .{ .service_metadata = service_metadata, .action = associate_personas_to_entities };
        }
    },
    Response: type = struct {
        failed_entity_list: ?[]FailedEntity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_entity_list = "FailedEntityList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceAlreadyExist,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_delete_document: struct {
    action_name: []const u8 = "BatchDeleteDocument",
    Request: type = struct {
        index_id: []const u8,
        document_id_list: [][]const u8,
        data_source_sync_job_metric_target: ?struct {
            data_source_id: []const u8,
            data_source_sync_job_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_source_id = "DataSourceId",
                    .data_source_sync_job_id = "DataSourceSyncJobId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .document_id_list = "DocumentIdList",
                .data_source_sync_job_metric_target = "DataSourceSyncJobMetricTarget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_document) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_document };
        }
    },
    Response: type = struct {
        failed_documents: ?[]struct {
            id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_documents = "FailedDocuments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_delete_featured_results_set: struct {
    action_name: []const u8 = "BatchDeleteFeaturedResultsSet",
    Request: type = struct {
        index_id: []const u8,
        featured_results_set_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .featured_results_set_ids = "FeaturedResultsSetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_featured_results_set) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_featured_results_set };
        }
    },
    Response: type = struct {
        errors: []struct {
            id: []const u8,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_get_document_status: struct {
    action_name: []const u8 = "BatchGetDocumentStatus",
    Request: type = struct {
        index_id: []const u8,
        document_info_list: []struct {
            document_id: []const u8,
            attributes: ?[]DocumentAttribute = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_id = "DocumentId",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .document_info_list = "DocumentInfoList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_document_status) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_document_status };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            document_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_id = "DocumentId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        document_status_list: ?[]struct {
            document_id: ?[]const u8 = null,
            document_status: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_id = "DocumentId",
                    .document_status = "DocumentStatus",
                    .failure_code = "FailureCode",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
                .document_status_list = "DocumentStatusList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_put_document: struct {
    action_name: []const u8 = "BatchPutDocument",
    Request: type = struct {
        index_id: []const u8,
        role_arn: ?[]const u8 = null,
        documents: []struct {
            id: []const u8,
            title: ?[]const u8 = null,
            blob: ?[]const u8 = null,
            s3_path: ?S3Path = null,
            attributes: ?[]DocumentAttribute = null,
            access_control_list: ?[]Principal = null,
            hierarchical_access_control_list: ?[]HierarchicalPrincipal = null,
            content_type: ?[]const u8 = null,
            access_control_configuration_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .title = "Title",
                    .blob = "Blob",
                    .s3_path = "S3Path",
                    .attributes = "Attributes",
                    .access_control_list = "AccessControlList",
                    .hierarchical_access_control_list = "HierarchicalAccessControlList",
                    .content_type = "ContentType",
                    .access_control_configuration_id = "AccessControlConfigurationId",
                };
                return @field(mappings, field_name);
            }
        },
        custom_document_enrichment_configuration: ?CustomDocumentEnrichmentConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .role_arn = "RoleArn",
                .documents = "Documents",
                .custom_document_enrichment_configuration = "CustomDocumentEnrichmentConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_document) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_document };
        }
    },
    Response: type = struct {
        failed_documents: ?[]struct {
            id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_documents = "FailedDocuments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const clear_query_suggestions: struct {
    action_name: []const u8 = "ClearQuerySuggestions",
    Request: type = struct {
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(clear_query_suggestions) } {
            return .{ .service_metadata = service_metadata, .action = clear_query_suggestions };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_access_control_configuration: struct {
    action_name: []const u8 = "CreateAccessControlConfiguration",
    Request: type = struct {
        index_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        access_control_list: ?[]Principal = null,
        hierarchical_access_control_list: ?[]HierarchicalPrincipal = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .access_control_list = "AccessControlList",
                .hierarchical_access_control_list = "HierarchicalAccessControlList",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_control_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_access_control_configuration };
        }
    },
    Response: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_data_source: struct {
    action_name: []const u8 = "CreateDataSource",
    Request: type = struct {
        name: []const u8,
        index_id: []const u8,
        type: []const u8,
        configuration: ?DataSourceConfiguration = null,
        vpc_configuration: ?DataSourceVpcConfiguration = null,
        description: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        custom_document_enrichment_configuration: ?CustomDocumentEnrichmentConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .index_id = "IndexId",
                .type = "Type",
                .configuration = "Configuration",
                .vpc_configuration = "VpcConfiguration",
                .description = "Description",
                .schedule = "Schedule",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .client_token = "ClientToken",
                .language_code = "LanguageCode",
                .custom_document_enrichment_configuration = "CustomDocumentEnrichmentConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_source) } {
            return .{ .service_metadata = service_metadata, .action = create_data_source };
        }
    },
    Response: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceAlreadyExist,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_experience: struct {
    action_name: []const u8 = "CreateExperience",
    Request: type = struct {
        name: []const u8,
        index_id: []const u8,
        role_arn: ?[]const u8 = null,
        configuration: ?ExperienceConfiguration = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .index_id = "IndexId",
                .role_arn = "RoleArn",
                .configuration = "Configuration",
                .description = "Description",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_experience) } {
            return .{ .service_metadata = service_metadata, .action = create_experience };
        }
    },
    Response: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_faq: struct {
    action_name: []const u8 = "CreateFaq",
    Request: type = struct {
        index_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        s3_path: S3Path,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        file_format: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        language_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .s3_path = "S3Path",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .file_format = "FileFormat",
                .client_token = "ClientToken",
                .language_code = "LanguageCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_faq) } {
            return .{ .service_metadata = service_metadata, .action = create_faq };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_featured_results_set: struct {
    action_name: []const u8 = "CreateFeaturedResultsSet",
    Request: type = struct {
        index_id: []const u8,
        featured_results_set_name: []const u8,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        status: ?[]const u8 = null,
        query_texts: ?[][]const u8 = null,
        featured_documents: ?[]FeaturedDocument = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .featured_results_set_name = "FeaturedResultsSetName",
                .description = "Description",
                .client_token = "ClientToken",
                .status = "Status",
                .query_texts = "QueryTexts",
                .featured_documents = "FeaturedDocuments",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_featured_results_set) } {
            return .{ .service_metadata = service_metadata, .action = create_featured_results_set };
        }
    },
    Response: type = struct {
        featured_results_set: ?FeaturedResultsSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .featured_results_set = "FeaturedResultsSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        FeaturedResultsConflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_index: struct {
    action_name: []const u8 = "CreateIndex",
    Request: type = struct {
        name: []const u8,
        edition: ?[]const u8 = null,
        role_arn: []const u8,
        server_side_encryption_configuration: ?ServerSideEncryptionConfiguration = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,
        user_token_configurations: ?[]UserTokenConfiguration = null,
        user_context_policy: ?[]const u8 = null,
        user_group_resolution_configuration: ?UserGroupResolutionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .edition = "Edition",
                .role_arn = "RoleArn",
                .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
                .description = "Description",
                .client_token = "ClientToken",
                .tags = "Tags",
                .user_token_configurations = "UserTokenConfigurations",
                .user_context_policy = "UserContextPolicy",
                .user_group_resolution_configuration = "UserGroupResolutionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_index) } {
            return .{ .service_metadata = service_metadata, .action = create_index };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceAlreadyExist,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_query_suggestions_block_list: struct {
    action_name: []const u8 = "CreateQuerySuggestionsBlockList",
    Request: type = struct {
        index_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        source_s3_path: S3Path,
        client_token: ?[]const u8 = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .source_s3_path = "SourceS3Path",
                .client_token = "ClientToken",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_query_suggestions_block_list) } {
            return .{ .service_metadata = service_metadata, .action = create_query_suggestions_block_list };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_thesaurus: struct {
    action_name: []const u8 = "CreateThesaurus",
    Request: type = struct {
        index_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        source_s3_path: S3Path,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .source_s3_path = "SourceS3Path",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_thesaurus) } {
            return .{ .service_metadata = service_metadata, .action = create_thesaurus };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_access_control_configuration: struct {
    action_name: []const u8 = "DeleteAccessControlConfiguration",
    Request: type = struct {
        index_id: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_control_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_control_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_data_source: struct {
    action_name: []const u8 = "DeleteDataSource",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_source };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_experience: struct {
    action_name: []const u8 = "DeleteExperience",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_experience) } {
            return .{ .service_metadata = service_metadata, .action = delete_experience };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_faq: struct {
    action_name: []const u8 = "DeleteFaq",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_faq) } {
            return .{ .service_metadata = service_metadata, .action = delete_faq };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_index: struct {
    action_name: []const u8 = "DeleteIndex",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_index) } {
            return .{ .service_metadata = service_metadata, .action = delete_index };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_principal_mapping: struct {
    action_name: []const u8 = "DeletePrincipalMapping",
    Request: type = struct {
        index_id: []const u8,
        data_source_id: ?[]const u8 = null,
        group_id: []const u8,
        ordering_id: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .data_source_id = "DataSourceId",
                .group_id = "GroupId",
                .ordering_id = "OrderingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_principal_mapping) } {
            return .{ .service_metadata = service_metadata, .action = delete_principal_mapping };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_query_suggestions_block_list: struct {
    action_name: []const u8 = "DeleteQuerySuggestionsBlockList",
    Request: type = struct {
        index_id: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_query_suggestions_block_list) } {
            return .{ .service_metadata = service_metadata, .action = delete_query_suggestions_block_list };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_thesaurus: struct {
    action_name: []const u8 = "DeleteThesaurus",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_thesaurus) } {
            return .{ .service_metadata = service_metadata, .action = delete_thesaurus };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_access_control_configuration: struct {
    action_name: []const u8 = "DescribeAccessControlConfiguration",
    Request: type = struct {
        index_id: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_access_control_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_access_control_configuration };
        }
    },
    Response: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        access_control_list: ?[]Principal = null,
        hierarchical_access_control_list: ?[]HierarchicalPrincipal = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .error_message = "ErrorMessage",
                .access_control_list = "AccessControlList",
                .hierarchical_access_control_list = "HierarchicalAccessControlList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_data_source: struct {
    action_name: []const u8 = "DescribeDataSource",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_source) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_source };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        index_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        configuration: ?DataSourceConfiguration = null,
        vpc_configuration: ?DataSourceVpcConfiguration = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        custom_document_enrichment_configuration: ?CustomDocumentEnrichmentConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .name = "Name",
                .type = "Type",
                .configuration = "Configuration",
                .vpc_configuration = "VpcConfiguration",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .description = "Description",
                .status = "Status",
                .schedule = "Schedule",
                .role_arn = "RoleArn",
                .error_message = "ErrorMessage",
                .language_code = "LanguageCode",
                .custom_document_enrichment_configuration = "CustomDocumentEnrichmentConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_experience: struct {
    action_name: []const u8 = "DescribeExperience",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_experience) } {
            return .{ .service_metadata = service_metadata, .action = describe_experience };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        index_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        endpoints: ?[]ExperienceEndpoint = null,
        configuration: ?ExperienceConfiguration = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .name = "Name",
                .endpoints = "Endpoints",
                .configuration = "Configuration",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .description = "Description",
                .status = "Status",
                .role_arn = "RoleArn",
                .error_message = "ErrorMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_faq: struct {
    action_name: []const u8 = "DescribeFaq",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_faq) } {
            return .{ .service_metadata = service_metadata, .action = describe_faq };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        index_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        s3_path: ?S3Path = null,
        status: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        file_format: ?[]const u8 = null,
        language_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .s3_path = "S3Path",
                .status = "Status",
                .role_arn = "RoleArn",
                .error_message = "ErrorMessage",
                .file_format = "FileFormat",
                .language_code = "LanguageCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_featured_results_set: struct {
    action_name: []const u8 = "DescribeFeaturedResultsSet",
    Request: type = struct {
        index_id: []const u8,
        featured_results_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .featured_results_set_id = "FeaturedResultsSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_featured_results_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_featured_results_set };
        }
    },
    Response: type = struct {
        featured_results_set_id: ?[]const u8 = null,
        featured_results_set_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        query_texts: ?[][]const u8 = null,
        featured_documents_with_metadata: ?[]struct {
            id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .title = "Title",
                    .uri = "URI",
                };
                return @field(mappings, field_name);
            }
        } = null,
        featured_documents_missing: ?[]struct {
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_updated_timestamp: ?i64 = null,
        creation_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .featured_results_set_id = "FeaturedResultsSetId",
                .featured_results_set_name = "FeaturedResultsSetName",
                .description = "Description",
                .status = "Status",
                .query_texts = "QueryTexts",
                .featured_documents_with_metadata = "FeaturedDocumentsWithMetadata",
                .featured_documents_missing = "FeaturedDocumentsMissing",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .creation_timestamp = "CreationTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_index: struct {
    action_name: []const u8 = "DescribeIndex",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_index) } {
            return .{ .service_metadata = service_metadata, .action = describe_index };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        edition: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        server_side_encryption_configuration: ?ServerSideEncryptionConfiguration = null,
        status: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        document_metadata_configurations: ?[]DocumentMetadataConfiguration = null,
        index_statistics: ?struct {
            faq_statistics: struct {
                indexed_question_answers_count: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .indexed_question_answers_count = "IndexedQuestionAnswersCount",
                    };
                    return @field(mappings, field_name);
                }
            },
            text_document_statistics: struct {
                indexed_text_documents_count: i64,
                indexed_text_bytes: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .indexed_text_documents_count = "IndexedTextDocumentsCount",
                        .indexed_text_bytes = "IndexedTextBytes",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .faq_statistics = "FaqStatistics",
                    .text_document_statistics = "TextDocumentStatistics",
                };
                return @field(mappings, field_name);
            }
        } = null,
        error_message: ?[]const u8 = null,
        capacity_units: ?CapacityUnitsConfiguration = null,
        user_token_configurations: ?[]UserTokenConfiguration = null,
        user_context_policy: ?[]const u8 = null,
        user_group_resolution_configuration: ?UserGroupResolutionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .id = "Id",
                .edition = "Edition",
                .role_arn = "RoleArn",
                .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
                .status = "Status",
                .description = "Description",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .document_metadata_configurations = "DocumentMetadataConfigurations",
                .index_statistics = "IndexStatistics",
                .error_message = "ErrorMessage",
                .capacity_units = "CapacityUnits",
                .user_token_configurations = "UserTokenConfigurations",
                .user_context_policy = "UserContextPolicy",
                .user_group_resolution_configuration = "UserGroupResolutionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_principal_mapping: struct {
    action_name: []const u8 = "DescribePrincipalMapping",
    Request: type = struct {
        index_id: []const u8,
        data_source_id: ?[]const u8 = null,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .data_source_id = "DataSourceId",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_principal_mapping) } {
            return .{ .service_metadata = service_metadata, .action = describe_principal_mapping };
        }
    },
    Response: type = struct {
        index_id: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        group_id: ?[]const u8 = null,
        group_ordering_id_summaries: ?[]struct {
            status: ?[]const u8 = null,
            last_updated_at: ?i64 = null,
            received_at: ?i64 = null,
            ordering_id: ?i64 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                    .last_updated_at = "LastUpdatedAt",
                    .received_at = "ReceivedAt",
                    .ordering_id = "OrderingId",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .data_source_id = "DataSourceId",
                .group_id = "GroupId",
                .group_ordering_id_summaries = "GroupOrderingIdSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_query_suggestions_block_list: struct {
    action_name: []const u8 = "DescribeQuerySuggestionsBlockList",
    Request: type = struct {
        index_id: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_query_suggestions_block_list) } {
            return .{ .service_metadata = service_metadata, .action = describe_query_suggestions_block_list };
        }
    },
    Response: type = struct {
        index_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        source_s3_path: ?S3Path = null,
        item_count: ?i64 = null,
        file_size_bytes: ?i64 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .status = "Status",
                .error_message = "ErrorMessage",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .source_s3_path = "SourceS3Path",
                .item_count = "ItemCount",
                .file_size_bytes = "FileSizeBytes",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_query_suggestions_config: struct {
    action_name: []const u8 = "DescribeQuerySuggestionsConfig",
    Request: type = struct {
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_query_suggestions_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_query_suggestions_config };
        }
    },
    Response: type = struct {
        mode: ?[]const u8 = null,
        status: ?[]const u8 = null,
        query_log_look_back_window_in_days: ?i64 = null,
        include_queries_without_user_information: ?bool = null,
        minimum_number_of_querying_users: ?i64 = null,
        minimum_query_count: ?i64 = null,
        last_suggestions_build_time: ?i64 = null,
        last_clear_time: ?i64 = null,
        total_suggestions_count: ?i64 = null,
        attribute_suggestions_config: ?struct {
            suggestable_config_list: ?[]SuggestableConfig = null,
            attribute_suggestions_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .suggestable_config_list = "SuggestableConfigList",
                    .attribute_suggestions_mode = "AttributeSuggestionsMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mode = "Mode",
                .status = "Status",
                .query_log_look_back_window_in_days = "QueryLogLookBackWindowInDays",
                .include_queries_without_user_information = "IncludeQueriesWithoutUserInformation",
                .minimum_number_of_querying_users = "MinimumNumberOfQueryingUsers",
                .minimum_query_count = "MinimumQueryCount",
                .last_suggestions_build_time = "LastSuggestionsBuildTime",
                .last_clear_time = "LastClearTime",
                .total_suggestions_count = "TotalSuggestionsCount",
                .attribute_suggestions_config = "AttributeSuggestionsConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_thesaurus: struct {
    action_name: []const u8 = "DescribeThesaurus",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_thesaurus) } {
            return .{ .service_metadata = service_metadata, .action = describe_thesaurus };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        index_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        role_arn: ?[]const u8 = null,
        source_s3_path: ?S3Path = null,
        file_size_bytes: ?i64 = null,
        term_count: ?i64 = null,
        synonym_rule_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .name = "Name",
                .description = "Description",
                .status = "Status",
                .error_message = "ErrorMessage",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .role_arn = "RoleArn",
                .source_s3_path = "SourceS3Path",
                .file_size_bytes = "FileSizeBytes",
                .term_count = "TermCount",
                .synonym_rule_count = "SynonymRuleCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_entities_from_experience: struct {
    action_name: []const u8 = "DisassociateEntitiesFromExperience",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,
        entity_list: []EntityConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .entity_list = "EntityList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_entities_from_experience) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_entities_from_experience };
        }
    },
    Response: type = struct {
        failed_entity_list: ?[]FailedEntity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_entity_list = "FailedEntityList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_personas_from_entities: struct {
    action_name: []const u8 = "DisassociatePersonasFromEntities",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,
        entity_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .entity_ids = "EntityIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_personas_from_entities) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_personas_from_entities };
        }
    },
    Response: type = struct {
        failed_entity_list: ?[]FailedEntity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_entity_list = "FailedEntityList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_query_suggestions: struct {
    action_name: []const u8 = "GetQuerySuggestions",
    Request: type = struct {
        index_id: []const u8,
        query_text: []const u8,
        max_suggestions_count: ?i64 = null,
        suggestion_types: ?[][]const u8 = null,
        attribute_suggestions_config: ?struct {
            suggestion_attributes: ?[][]const u8 = null,
            additional_response_attributes: ?[][]const u8 = null,
            attribute_filter: ?AttributeFilter = null,
            user_context: ?UserContext = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .suggestion_attributes = "SuggestionAttributes",
                    .additional_response_attributes = "AdditionalResponseAttributes",
                    .attribute_filter = "AttributeFilter",
                    .user_context = "UserContext",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .query_text = "QueryText",
                .max_suggestions_count = "MaxSuggestionsCount",
                .suggestion_types = "SuggestionTypes",
                .attribute_suggestions_config = "AttributeSuggestionsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_suggestions) } {
            return .{ .service_metadata = service_metadata, .action = get_query_suggestions };
        }
    },
    Response: type = struct {
        query_suggestions_id: ?[]const u8 = null,
        suggestions: ?[]struct {
            id: ?[]const u8 = null,
            value: ?struct {
                text: ?struct {
                    text: ?[]const u8 = null,
                    highlights: ?[]struct {
                        begin_offset: ?i64 = null,
                        end_offset: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .begin_offset = "BeginOffset",
                                .end_offset = "EndOffset",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .text = "Text",
                            .highlights = "Highlights",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .text = "Text",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            source_documents: ?[]struct {
                document_id: ?[]const u8 = null,
                suggestion_attributes: ?[][]const u8 = null,
                additional_attributes: ?[]DocumentAttribute = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .document_id = "DocumentId",
                        .suggestion_attributes = "SuggestionAttributes",
                        .additional_attributes = "AdditionalAttributes",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .value = "Value",
                    .source_documents = "SourceDocuments",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_suggestions_id = "QuerySuggestionsId",
                .suggestions = "Suggestions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_snapshots: struct {
    action_name: []const u8 = "GetSnapshots",
    Request: type = struct {
        index_id: []const u8,
        interval: []const u8,
        metric_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .interval = "Interval",
                .metric_type = "MetricType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = get_snapshots };
        }
    },
    Response: type = struct {
        snap_shot_time_filter: ?TimeRange = null,
        snapshots_data_header: ?[][]const u8 = null,
        snapshots_data: ?[][][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snap_shot_time_filter = "SnapShotTimeFilter",
                .snapshots_data_header = "SnapshotsDataHeader",
                .snapshots_data = "SnapshotsData",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_access_control_configurations: struct {
    action_name: []const u8 = "ListAccessControlConfigurations",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_control_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_access_control_configurations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        access_control_configurations: []struct {
            id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .access_control_configurations = "AccessControlConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_sources: struct {
    action_name: []const u8 = "ListDataSources",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sources };
        }
    },
    Response: type = struct {
        summary_items: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            status: ?[]const u8 = null,
            language_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .type = "Type",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .status = "Status",
                    .language_code = "LanguageCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary_items = "SummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_source_sync_jobs: struct {
    action_name: []const u8 = "ListDataSourceSyncJobs",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        start_time_filter: ?TimeRange = null,
        status_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .start_time_filter = "StartTimeFilter",
                .status_filter = "StatusFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_source_sync_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_source_sync_jobs };
        }
    },
    Response: type = struct {
        history: ?[]struct {
            execution_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            status: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            data_source_error_code: ?[]const u8 = null,
            metrics: ?struct {
                documents_added: ?[]const u8 = null,
                documents_modified: ?[]const u8 = null,
                documents_deleted: ?[]const u8 = null,
                documents_failed: ?[]const u8 = null,
                documents_scanned: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .documents_added = "DocumentsAdded",
                        .documents_modified = "DocumentsModified",
                        .documents_deleted = "DocumentsDeleted",
                        .documents_failed = "DocumentsFailed",
                        .documents_scanned = "DocumentsScanned",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_id = "ExecutionId",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .status = "Status",
                    .error_message = "ErrorMessage",
                    .error_code = "ErrorCode",
                    .data_source_error_code = "DataSourceErrorCode",
                    .metrics = "Metrics",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .history = "History",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_entity_personas: struct {
    action_name: []const u8 = "ListEntityPersonas",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_entity_personas) } {
            return .{ .service_metadata = service_metadata, .action = list_entity_personas };
        }
    },
    Response: type = struct {
        summary_items: ?[]struct {
            entity_id: ?[]const u8 = null,
            persona: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entity_id = "EntityId",
                    .persona = "Persona",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary_items = "SummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_experience_entities: struct {
    action_name: []const u8 = "ListExperienceEntities",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_experience_entities) } {
            return .{ .service_metadata = service_metadata, .action = list_experience_entities };
        }
    },
    Response: type = struct {
        summary_items: ?[]struct {
            entity_id: ?[]const u8 = null,
            entity_type: ?[]const u8 = null,
            display_data: ?struct {
                user_name: ?[]const u8 = null,
                group_name: ?[]const u8 = null,
                identified_user_name: ?[]const u8 = null,
                first_name: ?[]const u8 = null,
                last_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .user_name = "UserName",
                        .group_name = "GroupName",
                        .identified_user_name = "IdentifiedUserName",
                        .first_name = "FirstName",
                        .last_name = "LastName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entity_id = "EntityId",
                    .entity_type = "EntityType",
                    .display_data = "DisplayData",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary_items = "SummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_experiences: struct {
    action_name: []const u8 = "ListExperiences",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_experiences) } {
            return .{ .service_metadata = service_metadata, .action = list_experiences };
        }
    },
    Response: type = struct {
        summary_items: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            created_at: ?i64 = null,
            status: ?[]const u8 = null,
            endpoints: ?[]ExperienceEndpoint = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .created_at = "CreatedAt",
                    .status = "Status",
                    .endpoints = "Endpoints",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary_items = "SummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_faqs: struct {
    action_name: []const u8 = "ListFaqs",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_faqs) } {
            return .{ .service_metadata = service_metadata, .action = list_faqs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        faq_summary_items: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            file_format: ?[]const u8 = null,
            language_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .status = "Status",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .file_format = "FileFormat",
                    .language_code = "LanguageCode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .faq_summary_items = "FaqSummaryItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_featured_results_sets: struct {
    action_name: []const u8 = "ListFeaturedResultsSets",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_featured_results_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_featured_results_sets };
        }
    },
    Response: type = struct {
        featured_results_set_summary_items: ?[]struct {
            featured_results_set_id: ?[]const u8 = null,
            featured_results_set_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            last_updated_timestamp: ?i64 = null,
            creation_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .featured_results_set_id = "FeaturedResultsSetId",
                    .featured_results_set_name = "FeaturedResultsSetName",
                    .status = "Status",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .creation_timestamp = "CreationTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .featured_results_set_summary_items = "FeaturedResultsSetSummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_groups_older_than_ordering_id: struct {
    action_name: []const u8 = "ListGroupsOlderThanOrderingId",
    Request: type = struct {
        index_id: []const u8,
        data_source_id: ?[]const u8 = null,
        ordering_id: i64,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .data_source_id = "DataSourceId",
                .ordering_id = "OrderingId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups_older_than_ordering_id) } {
            return .{ .service_metadata = service_metadata, .action = list_groups_older_than_ordering_id };
        }
    },
    Response: type = struct {
        groups_summaries: ?[]struct {
            group_id: ?[]const u8 = null,
            ordering_id: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_id = "GroupId",
                    .ordering_id = "OrderingId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups_summaries = "GroupsSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_indices: struct {
    action_name: []const u8 = "ListIndices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_indices) } {
            return .{ .service_metadata = service_metadata, .action = list_indices };
        }
    },
    Response: type = struct {
        index_configuration_summary_items: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            edition: ?[]const u8 = null,
            created_at: i64,
            updated_at: i64,
            status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .edition = "Edition",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_configuration_summary_items = "IndexConfigurationSummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_query_suggestions_block_lists: struct {
    action_name: []const u8 = "ListQuerySuggestionsBlockLists",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_query_suggestions_block_lists) } {
            return .{ .service_metadata = service_metadata, .action = list_query_suggestions_block_lists };
        }
    },
    Response: type = struct {
        block_list_summary_items: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            item_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .status = "Status",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .item_count = "ItemCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .block_list_summary_items = "BlockListSummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const list_thesauri: struct {
    action_name: []const u8 = "ListThesauri",
    Request: type = struct {
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_thesauri) } {
            return .{ .service_metadata = service_metadata, .action = list_thesauri };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        thesaurus_summary_items: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .status = "Status",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .thesaurus_summary_items = "ThesaurusSummaryItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_principal_mapping: struct {
    action_name: []const u8 = "PutPrincipalMapping",
    Request: type = struct {
        index_id: []const u8,
        data_source_id: ?[]const u8 = null,
        group_id: []const u8,
        group_members: struct {
            member_groups: ?[]struct {
                group_id: []const u8,
                data_source_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group_id = "GroupId",
                        .data_source_id = "DataSourceId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            member_users: ?[]struct {
                user_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .user_id = "UserId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            s3_pathfor_group_members: ?S3Path = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_groups = "MemberGroups",
                    .member_users = "MemberUsers",
                    .s3_pathfor_group_members = "S3PathforGroupMembers",
                };
                return @field(mappings, field_name);
            }
        },
        ordering_id: ?i64 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .data_source_id = "DataSourceId",
                .group_id = "GroupId",
                .group_members = "GroupMembers",
                .ordering_id = "OrderingId",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_principal_mapping) } {
            return .{ .service_metadata = service_metadata, .action = put_principal_mapping };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const query: struct {
    action_name: []const u8 = "Query",
    Request: type = struct {
        index_id: []const u8,
        query_text: ?[]const u8 = null,
        attribute_filter: ?AttributeFilter = null,
        facets: ?[]struct {
            document_attribute_key: ?[]const u8 = null,
            facets: ?[]struct {
                document_attribute_key: ?[]const u8 = null,
                facets: ?[]struct {
                    document_attribute_key: ?[]const u8 = null,
                    facets: ?[]const u8 = null,
                    max_results: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .document_attribute_key = "DocumentAttributeKey",
                            .facets = "Facets",
                            .max_results = "MaxResults",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                max_results: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .document_attribute_key = "DocumentAttributeKey",
                        .facets = "Facets",
                        .max_results = "MaxResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            max_results: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_attribute_key = "DocumentAttributeKey",
                    .facets = "Facets",
                    .max_results = "MaxResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        requested_document_attributes: ?[][]const u8 = null,
        query_result_type_filter: ?[]const u8 = null,
        document_relevance_override_configurations: ?[]DocumentRelevanceConfiguration = null,
        page_number: ?i64 = null,
        page_size: ?i64 = null,
        sorting_configuration: ?SortingConfiguration = null,
        sorting_configurations: ?[]SortingConfiguration = null,
        user_context: ?UserContext = null,
        visitor_id: ?[]const u8 = null,
        spell_correction_configuration: ?struct {
            include_query_spell_check_suggestions: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .include_query_spell_check_suggestions = "IncludeQuerySpellCheckSuggestions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        collapse_configuration: ?struct {
            document_attribute_key: []const u8,
            sorting_configurations: ?[]SortingConfiguration = null,
            missing_attribute_key_strategy: ?[]const u8 = null,
            expand: ?bool = null,
            expand_configuration: ?struct {
                max_result_items_to_expand: ?i64 = null,
                max_expanded_results_per_item: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .max_result_items_to_expand = "MaxResultItemsToExpand",
                        .max_expanded_results_per_item = "MaxExpandedResultsPerItem",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_attribute_key = "DocumentAttributeKey",
                    .sorting_configurations = "SortingConfigurations",
                    .missing_attribute_key_strategy = "MissingAttributeKeyStrategy",
                    .expand = "Expand",
                    .expand_configuration = "ExpandConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .query_text = "QueryText",
                .attribute_filter = "AttributeFilter",
                .facets = "Facets",
                .requested_document_attributes = "RequestedDocumentAttributes",
                .query_result_type_filter = "QueryResultTypeFilter",
                .document_relevance_override_configurations = "DocumentRelevanceOverrideConfigurations",
                .page_number = "PageNumber",
                .page_size = "PageSize",
                .sorting_configuration = "SortingConfiguration",
                .sorting_configurations = "SortingConfigurations",
                .user_context = "UserContext",
                .visitor_id = "VisitorId",
                .spell_correction_configuration = "SpellCorrectionConfiguration",
                .collapse_configuration = "CollapseConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query) } {
            return .{ .service_metadata = service_metadata, .action = query };
        }
    },
    Response: type = struct {
        query_id: ?[]const u8 = null,
        result_items: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            format: ?[]const u8 = null,
            additional_attributes: ?[]AdditionalResultAttribute = null,
            document_id: ?[]const u8 = null,
            document_title: ?TextWithHighlights = null,
            document_excerpt: ?TextWithHighlights = null,
            document_uri: ?[]const u8 = null,
            document_attributes: ?[]DocumentAttribute = null,
            score_attributes: ?ScoreAttributes = null,
            feedback_token: ?[]const u8 = null,
            table_excerpt: ?struct {
                rows: ?[]struct {
                    cells: ?[]struct {
                        value: ?[]const u8 = null,
                        top_answer: ?bool = null,
                        highlighted: ?bool = null,
                        header: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .value = "Value",
                                .top_answer = "TopAnswer",
                                .highlighted = "Highlighted",
                                .header = "Header",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cells = "Cells",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                total_number_of_rows: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rows = "Rows",
                        .total_number_of_rows = "TotalNumberOfRows",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            collapsed_result_detail: ?struct {
                document_attribute: DocumentAttribute,
                expanded_results: ?[]struct {
                    id: ?[]const u8 = null,
                    document_id: ?[]const u8 = null,
                    document_title: ?TextWithHighlights = null,
                    document_excerpt: ?TextWithHighlights = null,
                    document_uri: ?[]const u8 = null,
                    document_attributes: ?[]DocumentAttribute = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .id = "Id",
                            .document_id = "DocumentId",
                            .document_title = "DocumentTitle",
                            .document_excerpt = "DocumentExcerpt",
                            .document_uri = "DocumentURI",
                            .document_attributes = "DocumentAttributes",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .document_attribute = "DocumentAttribute",
                        .expanded_results = "ExpandedResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .format = "Format",
                    .additional_attributes = "AdditionalAttributes",
                    .document_id = "DocumentId",
                    .document_title = "DocumentTitle",
                    .document_excerpt = "DocumentExcerpt",
                    .document_uri = "DocumentURI",
                    .document_attributes = "DocumentAttributes",
                    .score_attributes = "ScoreAttributes",
                    .feedback_token = "FeedbackToken",
                    .table_excerpt = "TableExcerpt",
                    .collapsed_result_detail = "CollapsedResultDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        facet_results: ?[]struct {
            document_attribute_key: ?[]const u8 = null,
            document_attribute_value_type: ?[]const u8 = null,
            document_attribute_value_count_pairs: ?[]struct {
                document_attribute_value: ?DocumentAttributeValue = null,
                count: ?i64 = null,
                facet_results: ?[]struct {
                    document_attribute_key: ?[]const u8 = null,
                    document_attribute_value_type: ?[]const u8 = null,
                    document_attribute_value_count_pairs: ?[]struct {
                        document_attribute_value: ?DocumentAttributeValue = null,
                        count: ?i64 = null,
                        facet_results: ?[]struct {
                            document_attribute_key: ?[]const u8 = null,
                            document_attribute_value_type: ?[]const u8 = null,
                            document_attribute_value_count_pairs: ?[]struct {
                                document_attribute_value: ?DocumentAttributeValue = null,
                                count: ?i64 = null,
                                facet_results: ?[]const u8 = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .document_attribute_value = "DocumentAttributeValue",
                                        .count = "Count",
                                        .facet_results = "FacetResults",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .document_attribute_key = "DocumentAttributeKey",
                                    .document_attribute_value_type = "DocumentAttributeValueType",
                                    .document_attribute_value_count_pairs = "DocumentAttributeValueCountPairs",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .document_attribute_value = "DocumentAttributeValue",
                                .count = "Count",
                                .facet_results = "FacetResults",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .document_attribute_key = "DocumentAttributeKey",
                            .document_attribute_value_type = "DocumentAttributeValueType",
                            .document_attribute_value_count_pairs = "DocumentAttributeValueCountPairs",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .document_attribute_value = "DocumentAttributeValue",
                        .count = "Count",
                        .facet_results = "FacetResults",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_attribute_key = "DocumentAttributeKey",
                    .document_attribute_value_type = "DocumentAttributeValueType",
                    .document_attribute_value_count_pairs = "DocumentAttributeValueCountPairs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total_number_of_results: ?i64 = null,
        warnings: ?[]struct {
            message: ?[]const u8 = null,
            code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "Message",
                    .code = "Code",
                };
                return @field(mappings, field_name);
            }
        } = null,
        spell_corrected_queries: ?[]struct {
            suggested_query_text: ?[]const u8 = null,
            corrections: ?[]struct {
                begin_offset: ?i64 = null,
                end_offset: ?i64 = null,
                term: ?[]const u8 = null,
                corrected_term: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .begin_offset = "BeginOffset",
                        .end_offset = "EndOffset",
                        .term = "Term",
                        .corrected_term = "CorrectedTerm",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .suggested_query_text = "SuggestedQueryText",
                    .corrections = "Corrections",
                };
                return @field(mappings, field_name);
            }
        } = null,
        featured_results_items: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            additional_attributes: ?[]AdditionalResultAttribute = null,
            document_id: ?[]const u8 = null,
            document_title: ?TextWithHighlights = null,
            document_excerpt: ?TextWithHighlights = null,
            document_uri: ?[]const u8 = null,
            document_attributes: ?[]DocumentAttribute = null,
            feedback_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .additional_attributes = "AdditionalAttributes",
                    .document_id = "DocumentId",
                    .document_title = "DocumentTitle",
                    .document_excerpt = "DocumentExcerpt",
                    .document_uri = "DocumentURI",
                    .document_attributes = "DocumentAttributes",
                    .feedback_token = "FeedbackToken",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
                .result_items = "ResultItems",
                .facet_results = "FacetResults",
                .total_number_of_results = "TotalNumberOfResults",
                .warnings = "Warnings",
                .spell_corrected_queries = "SpellCorrectedQueries",
                .featured_results_items = "FeaturedResultsItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const retrieve: struct {
    action_name: []const u8 = "Retrieve",
    Request: type = struct {
        index_id: []const u8,
        query_text: []const u8,
        attribute_filter: ?AttributeFilter = null,
        requested_document_attributes: ?[][]const u8 = null,
        document_relevance_override_configurations: ?[]DocumentRelevanceConfiguration = null,
        page_number: ?i64 = null,
        page_size: ?i64 = null,
        user_context: ?UserContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .query_text = "QueryText",
                .attribute_filter = "AttributeFilter",
                .requested_document_attributes = "RequestedDocumentAttributes",
                .document_relevance_override_configurations = "DocumentRelevanceOverrideConfigurations",
                .page_number = "PageNumber",
                .page_size = "PageSize",
                .user_context = "UserContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(retrieve) } {
            return .{ .service_metadata = service_metadata, .action = retrieve };
        }
    },
    Response: type = struct {
        query_id: ?[]const u8 = null,
        result_items: ?[]struct {
            id: ?[]const u8 = null,
            document_id: ?[]const u8 = null,
            document_title: ?[]const u8 = null,
            content: ?[]const u8 = null,
            document_uri: ?[]const u8 = null,
            document_attributes: ?[]DocumentAttribute = null,
            score_attributes: ?ScoreAttributes = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .document_id = "DocumentId",
                    .document_title = "DocumentTitle",
                    .content = "Content",
                    .document_uri = "DocumentURI",
                    .document_attributes = "DocumentAttributes",
                    .score_attributes = "ScoreAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
                .result_items = "ResultItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_data_source_sync_job: struct {
    action_name: []const u8 = "StartDataSourceSyncJob",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_data_source_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = start_data_source_sync_job };
        }
    },
    Response: type = struct {
        execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_id = "ExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_data_source_sync_job: struct {
    action_name: []const u8 = "StopDataSourceSyncJob",
    Request: type = struct {
        id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .index_id = "IndexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_data_source_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_data_source_sync_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const submit_feedback: struct {
    action_name: []const u8 = "SubmitFeedback",
    Request: type = struct {
        index_id: []const u8,
        query_id: []const u8,
        click_feedback_items: ?[]struct {
            result_id: []const u8,
            click_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .result_id = "ResultId",
                    .click_time = "ClickTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        relevance_feedback_items: ?[]struct {
            result_id: []const u8,
            relevance_value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .result_id = "ResultId",
                    .relevance_value = "RelevanceValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .query_id = "QueryId",
                .click_feedback_items = "ClickFeedbackItems",
                .relevance_feedback_items = "RelevanceFeedbackItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_feedback) } {
            return .{ .service_metadata = service_metadata, .action = submit_feedback };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const update_access_control_configuration: struct {
    action_name: []const u8 = "UpdateAccessControlConfiguration",
    Request: type = struct {
        index_id: []const u8,
        id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        access_control_list: ?[]Principal = null,
        hierarchical_access_control_list: ?[]HierarchicalPrincipal = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .access_control_list = "AccessControlList",
                .hierarchical_access_control_list = "HierarchicalAccessControlList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_access_control_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_access_control_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_data_source: struct {
    action_name: []const u8 = "UpdateDataSource",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        index_id: []const u8,
        configuration: ?DataSourceConfiguration = null,
        vpc_configuration: ?DataSourceVpcConfiguration = null,
        description: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        custom_document_enrichment_configuration: ?CustomDocumentEnrichmentConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .index_id = "IndexId",
                .configuration = "Configuration",
                .vpc_configuration = "VpcConfiguration",
                .description = "Description",
                .schedule = "Schedule",
                .role_arn = "RoleArn",
                .language_code = "LanguageCode",
                .custom_document_enrichment_configuration = "CustomDocumentEnrichmentConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_experience: struct {
    action_name: []const u8 = "UpdateExperience",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        index_id: []const u8,
        role_arn: ?[]const u8 = null,
        configuration: ?ExperienceConfiguration = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .index_id = "IndexId",
                .role_arn = "RoleArn",
                .configuration = "Configuration",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_experience) } {
            return .{ .service_metadata = service_metadata, .action = update_experience };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_featured_results_set: struct {
    action_name: []const u8 = "UpdateFeaturedResultsSet",
    Request: type = struct {
        index_id: []const u8,
        featured_results_set_id: []const u8,
        featured_results_set_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        query_texts: ?[][]const u8 = null,
        featured_documents: ?[]FeaturedDocument = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .featured_results_set_id = "FeaturedResultsSetId",
                .featured_results_set_name = "FeaturedResultsSetName",
                .description = "Description",
                .status = "Status",
                .query_texts = "QueryTexts",
                .featured_documents = "FeaturedDocuments",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_featured_results_set) } {
            return .{ .service_metadata = service_metadata, .action = update_featured_results_set };
        }
    },
    Response: type = struct {
        featured_results_set: ?FeaturedResultsSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .featured_results_set = "FeaturedResultsSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        FeaturedResultsConflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_index: struct {
    action_name: []const u8 = "UpdateIndex",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        document_metadata_configuration_updates: ?[]DocumentMetadataConfiguration = null,
        capacity_units: ?CapacityUnitsConfiguration = null,
        user_token_configurations: ?[]UserTokenConfiguration = null,
        user_context_policy: ?[]const u8 = null,
        user_group_resolution_configuration: ?UserGroupResolutionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .role_arn = "RoleArn",
                .description = "Description",
                .document_metadata_configuration_updates = "DocumentMetadataConfigurationUpdates",
                .capacity_units = "CapacityUnits",
                .user_token_configurations = "UserTokenConfigurations",
                .user_context_policy = "UserContextPolicy",
                .user_group_resolution_configuration = "UserGroupResolutionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_index) } {
            return .{ .service_metadata = service_metadata, .action = update_index };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_query_suggestions_block_list: struct {
    action_name: []const u8 = "UpdateQuerySuggestionsBlockList",
    Request: type = struct {
        index_id: []const u8,
        id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        source_s3_path: ?S3Path = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .source_s3_path = "SourceS3Path",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_query_suggestions_block_list) } {
            return .{ .service_metadata = service_metadata, .action = update_query_suggestions_block_list };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_query_suggestions_config: struct {
    action_name: []const u8 = "UpdateQuerySuggestionsConfig",
    Request: type = struct {
        index_id: []const u8,
        mode: ?[]const u8 = null,
        query_log_look_back_window_in_days: ?i64 = null,
        include_queries_without_user_information: ?bool = null,
        minimum_number_of_querying_users: ?i64 = null,
        minimum_query_count: ?i64 = null,
        attribute_suggestions_config: ?struct {
            suggestable_config_list: ?[]SuggestableConfig = null,
            attribute_suggestions_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .suggestable_config_list = "SuggestableConfigList",
                    .attribute_suggestions_mode = "AttributeSuggestionsMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_id = "IndexId",
                .mode = "Mode",
                .query_log_look_back_window_in_days = "QueryLogLookBackWindowInDays",
                .include_queries_without_user_information = "IncludeQueriesWithoutUserInformation",
                .minimum_number_of_querying_users = "MinimumNumberOfQueryingUsers",
                .minimum_query_count = "MinimumQueryCount",
                .attribute_suggestions_config = "AttributeSuggestionsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_query_suggestions_config) } {
            return .{ .service_metadata = service_metadata, .action = update_query_suggestions_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_thesaurus: struct {
    action_name: []const u8 = "UpdateThesaurus",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        index_id: []const u8,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        source_s3_path: ?S3Path = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .index_id = "IndexId",
                .description = "Description",
                .role_arn = "RoleArn",
                .source_s3_path = "SourceS3Path",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_thesaurus) } {
            return .{ .service_metadata = service_metadata, .action = update_thesaurus };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const S3Path = struct {
    bucket: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const SuggestableConfig = struct {
    attribute_name: ?[]const u8 = null,
    suggestable: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .suggestable = "Suggestable",
        };
        return @field(mappings, field_name);
    }
};

pub const UserGroupResolutionConfiguration = struct {
    user_group_resolution_mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_group_resolution_mode = "UserGroupResolutionMode",
        };
        return @field(mappings, field_name);
    }
};

pub const UserTokenConfiguration = struct {
    jwt_token_type_configuration: ?JwtTokenTypeConfiguration = null,
    json_token_type_configuration: ?JsonTokenTypeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .jwt_token_type_configuration = "JwtTokenTypeConfiguration",
            .json_token_type_configuration = "JsonTokenTypeConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonTokenTypeConfiguration = struct {
    user_name_attribute_field: []const u8,
    group_attribute_field: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_name_attribute_field = "UserNameAttributeField",
            .group_attribute_field = "GroupAttributeField",
        };
        return @field(mappings, field_name);
    }
};

pub const JwtTokenTypeConfiguration = struct {
    key_location: []const u8,
    url: ?[]const u8 = null,
    secret_manager_arn: ?[]const u8 = null,
    user_name_attribute_field: ?[]const u8 = null,
    group_attribute_field: ?[]const u8 = null,
    issuer: ?[]const u8 = null,
    claim_regex: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_location = "KeyLocation",
            .url = "URL",
            .secret_manager_arn = "SecretManagerArn",
            .user_name_attribute_field = "UserNameAttributeField",
            .group_attribute_field = "GroupAttributeField",
            .issuer = "Issuer",
            .claim_regex = "ClaimRegex",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityUnitsConfiguration = struct {
    storage_capacity_units: i64,
    query_capacity_units: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_capacity_units = "StorageCapacityUnits",
            .query_capacity_units = "QueryCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentMetadataConfiguration = struct {
    name: []const u8,
    type: []const u8,
    relevance: ?Relevance = null,
    search: ?Search = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .relevance = "Relevance",
            .search = "Search",
        };
        return @field(mappings, field_name);
    }
};

pub const Search = struct {
    facetable: ?bool = null,
    searchable: ?bool = null,
    displayable: ?bool = null,
    sortable: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .facetable = "Facetable",
            .searchable = "Searchable",
            .displayable = "Displayable",
            .sortable = "Sortable",
        };
        return @field(mappings, field_name);
    }
};

pub const Relevance = struct {
    freshness: ?bool = null,
    importance: ?i64 = null,
    duration: ?[]const u8 = null,
    rank_order: ?[]const u8 = null,
    value_importance_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .freshness = "Freshness",
            .importance = "Importance",
            .duration = "Duration",
            .rank_order = "RankOrder",
            .value_importance_map = "ValueImportanceMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "value_importance_map", field_name))
            return try serializeMap(self.value_importance_map, self.fieldNameFor("value_importance_map"), options, out_stream);
        return false;
    }
};

pub const FeaturedResultsSet = struct {
    featured_results_set_id: ?[]const u8 = null,
    featured_results_set_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    query_texts: ?[][]const u8 = null,
    featured_documents: ?[]FeaturedDocument = null,
    last_updated_timestamp: ?i64 = null,
    creation_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .featured_results_set_id = "FeaturedResultsSetId",
            .featured_results_set_name = "FeaturedResultsSetName",
            .description = "Description",
            .status = "Status",
            .query_texts = "QueryTexts",
            .featured_documents = "FeaturedDocuments",
            .last_updated_timestamp = "LastUpdatedTimestamp",
            .creation_timestamp = "CreationTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const FeaturedDocument = struct {
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperienceConfiguration = struct {
    content_source_configuration: ?ContentSourceConfiguration = null,
    user_identity_configuration: ?UserIdentityConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_source_configuration = "ContentSourceConfiguration",
            .user_identity_configuration = "UserIdentityConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const UserIdentityConfiguration = struct {
    identity_attribute_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_attribute_name = "IdentityAttributeName",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentSourceConfiguration = struct {
    data_source_ids: ?[][]const u8 = null,
    faq_ids: ?[][]const u8 = null,
    direct_put_content: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_ids = "DataSourceIds",
            .faq_ids = "FaqIds",
            .direct_put_content = "DirectPutContent",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomDocumentEnrichmentConfiguration = struct {
    inline_configurations: ?[]InlineCustomDocumentEnrichmentConfiguration = null,
    pre_extraction_hook_configuration: ?HookConfiguration = null,
    post_extraction_hook_configuration: ?HookConfiguration = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inline_configurations = "InlineConfigurations",
            .pre_extraction_hook_configuration = "PreExtractionHookConfiguration",
            .post_extraction_hook_configuration = "PostExtractionHookConfiguration",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const HookConfiguration = struct {
    invocation_condition: ?DocumentAttributeCondition = null,
    lambda_arn: []const u8,
    s3_bucket: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .invocation_condition = "InvocationCondition",
            .lambda_arn = "LambdaArn",
            .s3_bucket = "S3Bucket",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttributeCondition = struct {
    condition_document_attribute_key: []const u8,
    operator: []const u8,
    condition_on_value: ?DocumentAttributeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition_document_attribute_key = "ConditionDocumentAttributeKey",
            .operator = "Operator",
            .condition_on_value = "ConditionOnValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttributeValue = struct {
    string_value: ?[]const u8 = null,
    string_list_value: ?[][]const u8 = null,
    long_value: ?i64 = null,
    date_value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "StringValue",
            .string_list_value = "StringListValue",
            .long_value = "LongValue",
            .date_value = "DateValue",
        };
        return @field(mappings, field_name);
    }
};

pub const InlineCustomDocumentEnrichmentConfiguration = struct {
    condition: ?DocumentAttributeCondition = null,
    target: ?DocumentAttributeTarget = null,
    document_content_deletion: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition = "Condition",
            .target = "Target",
            .document_content_deletion = "DocumentContentDeletion",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttributeTarget = struct {
    target_document_attribute_key: ?[]const u8 = null,
    target_document_attribute_value_deletion: ?bool = null,
    target_document_attribute_value: ?DocumentAttributeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_document_attribute_key = "TargetDocumentAttributeKey",
            .target_document_attribute_value_deletion = "TargetDocumentAttributeValueDeletion",
            .target_document_attribute_value = "TargetDocumentAttributeValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceVpcConfiguration = struct {
    subnet_ids: [][]const u8,
    security_group_ids: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceConfiguration = struct {
    s3_configuration: ?S3DataSourceConfiguration = null,
    share_point_configuration: ?SharePointConfiguration = null,
    database_configuration: ?DatabaseConfiguration = null,
    salesforce_configuration: ?SalesforceConfiguration = null,
    one_drive_configuration: ?OneDriveConfiguration = null,
    service_now_configuration: ?ServiceNowConfiguration = null,
    confluence_configuration: ?ConfluenceConfiguration = null,
    google_drive_configuration: ?GoogleDriveConfiguration = null,
    web_crawler_configuration: ?WebCrawlerConfiguration = null,
    work_docs_configuration: ?WorkDocsConfiguration = null,
    fsx_configuration: ?FsxConfiguration = null,
    slack_configuration: ?SlackConfiguration = null,
    box_configuration: ?BoxConfiguration = null,
    quip_configuration: ?QuipConfiguration = null,
    jira_configuration: ?JiraConfiguration = null,
    git_hub_configuration: ?GitHubConfiguration = null,
    alfresco_configuration: ?AlfrescoConfiguration = null,
    template_configuration: ?TemplateConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_configuration = "S3Configuration",
            .share_point_configuration = "SharePointConfiguration",
            .database_configuration = "DatabaseConfiguration",
            .salesforce_configuration = "SalesforceConfiguration",
            .one_drive_configuration = "OneDriveConfiguration",
            .service_now_configuration = "ServiceNowConfiguration",
            .confluence_configuration = "ConfluenceConfiguration",
            .google_drive_configuration = "GoogleDriveConfiguration",
            .web_crawler_configuration = "WebCrawlerConfiguration",
            .work_docs_configuration = "WorkDocsConfiguration",
            .fsx_configuration = "FsxConfiguration",
            .slack_configuration = "SlackConfiguration",
            .box_configuration = "BoxConfiguration",
            .quip_configuration = "QuipConfiguration",
            .jira_configuration = "JiraConfiguration",
            .git_hub_configuration = "GitHubConfiguration",
            .alfresco_configuration = "AlfrescoConfiguration",
            .template_configuration = "TemplateConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateConfiguration = struct {
    template: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .template = "Template",
        };
        return @field(mappings, field_name);
    }
};

pub const AlfrescoConfiguration = struct {
    site_url: []const u8,
    site_id: []const u8,
    secret_arn: []const u8,
    ssl_certificate_s3_path: S3Path,
    crawl_system_folders: ?bool = null,
    crawl_comments: ?bool = null,
    entity_filter: ?[][]const u8 = null,
    document_library_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    blog_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    wiki_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_url = "SiteUrl",
            .site_id = "SiteId",
            .secret_arn = "SecretArn",
            .ssl_certificate_s3_path = "SslCertificateS3Path",
            .crawl_system_folders = "CrawlSystemFolders",
            .crawl_comments = "CrawlComments",
            .entity_filter = "EntityFilter",
            .document_library_field_mappings = "DocumentLibraryFieldMappings",
            .blog_field_mappings = "BlogFieldMappings",
            .wiki_field_mappings = "WikiFieldMappings",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .vpc_configuration = "VpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceToIndexFieldMapping = struct {
    data_source_field_name: []const u8,
    date_field_format: ?[]const u8 = null,
    index_field_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const GitHubConfiguration = struct {
    saa_s_configuration: ?SaaSConfiguration = null,
    on_premise_configuration: ?OnPremiseConfiguration = null,
    type: ?[]const u8 = null,
    secret_arn: []const u8,
    use_change_log: ?bool = null,
    git_hub_document_crawl_properties: ?GitHubDocumentCrawlProperties = null,
    repository_filter: ?[][]const u8 = null,
    inclusion_folder_name_patterns: ?[][]const u8 = null,
    inclusion_file_type_patterns: ?[][]const u8 = null,
    inclusion_file_name_patterns: ?[][]const u8 = null,
    exclusion_folder_name_patterns: ?[][]const u8 = null,
    exclusion_file_type_patterns: ?[][]const u8 = null,
    exclusion_file_name_patterns: ?[][]const u8 = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,
    git_hub_repository_configuration_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    git_hub_commit_configuration_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    git_hub_issue_document_configuration_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    git_hub_issue_comment_configuration_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    git_hub_issue_attachment_configuration_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    git_hub_pull_request_comment_configuration_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    git_hub_pull_request_document_configuration_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    git_hub_pull_request_document_attachment_configuration_field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .saa_s_configuration = "SaaSConfiguration",
            .on_premise_configuration = "OnPremiseConfiguration",
            .type = "Type",
            .secret_arn = "SecretArn",
            .use_change_log = "UseChangeLog",
            .git_hub_document_crawl_properties = "GitHubDocumentCrawlProperties",
            .repository_filter = "RepositoryFilter",
            .inclusion_folder_name_patterns = "InclusionFolderNamePatterns",
            .inclusion_file_type_patterns = "InclusionFileTypePatterns",
            .inclusion_file_name_patterns = "InclusionFileNamePatterns",
            .exclusion_folder_name_patterns = "ExclusionFolderNamePatterns",
            .exclusion_file_type_patterns = "ExclusionFileTypePatterns",
            .exclusion_file_name_patterns = "ExclusionFileNamePatterns",
            .vpc_configuration = "VpcConfiguration",
            .git_hub_repository_configuration_field_mappings = "GitHubRepositoryConfigurationFieldMappings",
            .git_hub_commit_configuration_field_mappings = "GitHubCommitConfigurationFieldMappings",
            .git_hub_issue_document_configuration_field_mappings = "GitHubIssueDocumentConfigurationFieldMappings",
            .git_hub_issue_comment_configuration_field_mappings = "GitHubIssueCommentConfigurationFieldMappings",
            .git_hub_issue_attachment_configuration_field_mappings = "GitHubIssueAttachmentConfigurationFieldMappings",
            .git_hub_pull_request_comment_configuration_field_mappings = "GitHubPullRequestCommentConfigurationFieldMappings",
            .git_hub_pull_request_document_configuration_field_mappings = "GitHubPullRequestDocumentConfigurationFieldMappings",
            .git_hub_pull_request_document_attachment_configuration_field_mappings = "GitHubPullRequestDocumentAttachmentConfigurationFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const GitHubDocumentCrawlProperties = struct {
    crawl_repository_documents: ?bool = null,
    crawl_issue: ?bool = null,
    crawl_issue_comment: ?bool = null,
    crawl_issue_comment_attachment: ?bool = null,
    crawl_pull_request: ?bool = null,
    crawl_pull_request_comment: ?bool = null,
    crawl_pull_request_comment_attachment: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_repository_documents = "CrawlRepositoryDocuments",
            .crawl_issue = "CrawlIssue",
            .crawl_issue_comment = "CrawlIssueComment",
            .crawl_issue_comment_attachment = "CrawlIssueCommentAttachment",
            .crawl_pull_request = "CrawlPullRequest",
            .crawl_pull_request_comment = "CrawlPullRequestComment",
            .crawl_pull_request_comment_attachment = "CrawlPullRequestCommentAttachment",
        };
        return @field(mappings, field_name);
    }
};

pub const OnPremiseConfiguration = struct {
    host_url: []const u8,
    organization_name: []const u8,
    ssl_certificate_s3_path: S3Path,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_url = "HostUrl",
            .organization_name = "OrganizationName",
            .ssl_certificate_s3_path = "SslCertificateS3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const SaaSConfiguration = struct {
    organization_name: []const u8,
    host_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .organization_name = "OrganizationName",
            .host_url = "HostUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const JiraConfiguration = struct {
    jira_account_url: []const u8,
    secret_arn: []const u8,
    use_change_log: ?bool = null,
    project: ?[][]const u8 = null,
    issue_type: ?[][]const u8 = null,
    status: ?[][]const u8 = null,
    issue_sub_entity_filter: ?[][]const u8 = null,
    attachment_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    comment_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    issue_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    project_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    work_log_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .jira_account_url = "JiraAccountUrl",
            .secret_arn = "SecretArn",
            .use_change_log = "UseChangeLog",
            .project = "Project",
            .issue_type = "IssueType",
            .status = "Status",
            .issue_sub_entity_filter = "IssueSubEntityFilter",
            .attachment_field_mappings = "AttachmentFieldMappings",
            .comment_field_mappings = "CommentFieldMappings",
            .issue_field_mappings = "IssueFieldMappings",
            .project_field_mappings = "ProjectFieldMappings",
            .work_log_field_mappings = "WorkLogFieldMappings",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .vpc_configuration = "VpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const QuipConfiguration = struct {
    domain: []const u8,
    secret_arn: []const u8,
    crawl_file_comments: ?bool = null,
    crawl_chat_rooms: ?bool = null,
    crawl_attachments: ?bool = null,
    folder_ids: ?[][]const u8 = null,
    thread_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    message_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    attachment_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .secret_arn = "SecretArn",
            .crawl_file_comments = "CrawlFileComments",
            .crawl_chat_rooms = "CrawlChatRooms",
            .crawl_attachments = "CrawlAttachments",
            .folder_ids = "FolderIds",
            .thread_field_mappings = "ThreadFieldMappings",
            .message_field_mappings = "MessageFieldMappings",
            .attachment_field_mappings = "AttachmentFieldMappings",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .vpc_configuration = "VpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const BoxConfiguration = struct {
    enterprise_id: []const u8,
    secret_arn: []const u8,
    use_change_log: ?bool = null,
    crawl_comments: ?bool = null,
    crawl_tasks: ?bool = null,
    crawl_web_links: ?bool = null,
    file_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    task_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    comment_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    web_link_field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enterprise_id = "EnterpriseId",
            .secret_arn = "SecretArn",
            .use_change_log = "UseChangeLog",
            .crawl_comments = "CrawlComments",
            .crawl_tasks = "CrawlTasks",
            .crawl_web_links = "CrawlWebLinks",
            .file_field_mappings = "FileFieldMappings",
            .task_field_mappings = "TaskFieldMappings",
            .comment_field_mappings = "CommentFieldMappings",
            .web_link_field_mappings = "WebLinkFieldMappings",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .vpc_configuration = "VpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SlackConfiguration = struct {
    team_id: []const u8,
    secret_arn: []const u8,
    vpc_configuration: ?DataSourceVpcConfiguration = null,
    slack_entity_list: [][]const u8,
    use_change_log: ?bool = null,
    crawl_bot_message: ?bool = null,
    exclude_archived: ?bool = null,
    since_crawl_date: []const u8,
    look_back_period: ?i64 = null,
    private_channel_filter: ?[][]const u8 = null,
    public_channel_filter: ?[][]const u8 = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .team_id = "TeamId",
            .secret_arn = "SecretArn",
            .vpc_configuration = "VpcConfiguration",
            .slack_entity_list = "SlackEntityList",
            .use_change_log = "UseChangeLog",
            .crawl_bot_message = "CrawlBotMessage",
            .exclude_archived = "ExcludeArchived",
            .since_crawl_date = "SinceCrawlDate",
            .look_back_period = "LookBackPeriod",
            .private_channel_filter = "PrivateChannelFilter",
            .public_channel_filter = "PublicChannelFilter",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const FsxConfiguration = struct {
    file_system_id: []const u8,
    file_system_type: []const u8,
    vpc_configuration: DataSourceVpcConfiguration,
    secret_arn: ?[]const u8 = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_system_id = "FileSystemId",
            .file_system_type = "FileSystemType",
            .vpc_configuration = "VpcConfiguration",
            .secret_arn = "SecretArn",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkDocsConfiguration = struct {
    organization_id: []const u8,
    crawl_comments: ?bool = null,
    use_change_log: ?bool = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .organization_id = "OrganizationId",
            .crawl_comments = "CrawlComments",
            .use_change_log = "UseChangeLog",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const WebCrawlerConfiguration = struct {
    urls: Urls,
    crawl_depth: ?i64 = null,
    max_links_per_page: ?i64 = null,
    max_content_size_per_page_in_mega_bytes: ?f32 = null,
    max_urls_per_minute_crawl_rate: ?i64 = null,
    url_inclusion_patterns: ?[][]const u8 = null,
    url_exclusion_patterns: ?[][]const u8 = null,
    proxy_configuration: ?ProxyConfiguration = null,
    authentication_configuration: ?AuthenticationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .urls = "Urls",
            .crawl_depth = "CrawlDepth",
            .max_links_per_page = "MaxLinksPerPage",
            .max_content_size_per_page_in_mega_bytes = "MaxContentSizePerPageInMegaBytes",
            .max_urls_per_minute_crawl_rate = "MaxUrlsPerMinuteCrawlRate",
            .url_inclusion_patterns = "UrlInclusionPatterns",
            .url_exclusion_patterns = "UrlExclusionPatterns",
            .proxy_configuration = "ProxyConfiguration",
            .authentication_configuration = "AuthenticationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthenticationConfiguration = struct {
    basic_authentication: ?[]BasicAuthenticationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .basic_authentication = "BasicAuthentication",
        };
        return @field(mappings, field_name);
    }
};

pub const BasicAuthenticationConfiguration = struct {
    host: []const u8,
    port: i64,
    credentials: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .credentials = "Credentials",
        };
        return @field(mappings, field_name);
    }
};

pub const ProxyConfiguration = struct {
    host: []const u8,
    port: i64,
    credentials: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .credentials = "Credentials",
        };
        return @field(mappings, field_name);
    }
};

pub const Urls = struct {
    seed_url_configuration: ?SeedUrlConfiguration = null,
    site_maps_configuration: ?SiteMapsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .seed_url_configuration = "SeedUrlConfiguration",
            .site_maps_configuration = "SiteMapsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SiteMapsConfiguration = struct {
    site_maps: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_maps = "SiteMaps",
        };
        return @field(mappings, field_name);
    }
};

pub const SeedUrlConfiguration = struct {
    seed_urls: [][]const u8,
    web_crawler_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .seed_urls = "SeedUrls",
            .web_crawler_mode = "WebCrawlerMode",
        };
        return @field(mappings, field_name);
    }
};

pub const GoogleDriveConfiguration = struct {
    secret_arn: []const u8,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    exclude_mime_types: ?[][]const u8 = null,
    exclude_user_accounts: ?[][]const u8 = null,
    exclude_shared_drives: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .secret_arn = "SecretArn",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .field_mappings = "FieldMappings",
            .exclude_mime_types = "ExcludeMimeTypes",
            .exclude_user_accounts = "ExcludeUserAccounts",
            .exclude_shared_drives = "ExcludeSharedDrives",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceConfiguration = struct {
    server_url: []const u8,
    secret_arn: []const u8,
    version: []const u8,
    space_configuration: ?ConfluenceSpaceConfiguration = null,
    page_configuration: ?ConfluencePageConfiguration = null,
    blog_configuration: ?ConfluenceBlogConfiguration = null,
    attachment_configuration: ?ConfluenceAttachmentConfiguration = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    proxy_configuration: ?ProxyConfiguration = null,
    authentication_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_url = "ServerUrl",
            .secret_arn = "SecretArn",
            .version = "Version",
            .space_configuration = "SpaceConfiguration",
            .page_configuration = "PageConfiguration",
            .blog_configuration = "BlogConfiguration",
            .attachment_configuration = "AttachmentConfiguration",
            .vpc_configuration = "VpcConfiguration",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .proxy_configuration = "ProxyConfiguration",
            .authentication_type = "AuthenticationType",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceAttachmentConfiguration = struct {
    crawl_attachments: ?bool = null,
    attachment_field_mappings: ?[]ConfluenceAttachmentToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_attachments = "CrawlAttachments",
            .attachment_field_mappings = "AttachmentFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceAttachmentToIndexFieldMapping = struct {
    data_source_field_name: ?[]const u8 = null,
    date_field_format: ?[]const u8 = null,
    index_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceBlogConfiguration = struct {
    blog_field_mappings: ?[]ConfluenceBlogToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blog_field_mappings = "BlogFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceBlogToIndexFieldMapping = struct {
    data_source_field_name: ?[]const u8 = null,
    date_field_format: ?[]const u8 = null,
    index_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluencePageConfiguration = struct {
    page_field_mappings: ?[]ConfluencePageToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .page_field_mappings = "PageFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluencePageToIndexFieldMapping = struct {
    data_source_field_name: ?[]const u8 = null,
    date_field_format: ?[]const u8 = null,
    index_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceSpaceConfiguration = struct {
    crawl_personal_spaces: ?bool = null,
    crawl_archived_spaces: ?bool = null,
    include_spaces: ?[][]const u8 = null,
    exclude_spaces: ?[][]const u8 = null,
    space_field_mappings: ?[]ConfluenceSpaceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_personal_spaces = "CrawlPersonalSpaces",
            .crawl_archived_spaces = "CrawlArchivedSpaces",
            .include_spaces = "IncludeSpaces",
            .exclude_spaces = "ExcludeSpaces",
            .space_field_mappings = "SpaceFieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfluenceSpaceToIndexFieldMapping = struct {
    data_source_field_name: ?[]const u8 = null,
    date_field_format: ?[]const u8 = null,
    index_field_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_field_name = "DataSourceFieldName",
            .date_field_format = "DateFieldFormat",
            .index_field_name = "IndexFieldName",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowConfiguration = struct {
    host_url: []const u8,
    secret_arn: []const u8,
    service_now_build_version: []const u8,
    knowledge_article_configuration: ?ServiceNowKnowledgeArticleConfiguration = null,
    service_catalog_configuration: ?ServiceNowServiceCatalogConfiguration = null,
    authentication_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_url = "HostUrl",
            .secret_arn = "SecretArn",
            .service_now_build_version = "ServiceNowBuildVersion",
            .knowledge_article_configuration = "KnowledgeArticleConfiguration",
            .service_catalog_configuration = "ServiceCatalogConfiguration",
            .authentication_type = "AuthenticationType",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowServiceCatalogConfiguration = struct {
    crawl_attachments: ?bool = null,
    include_attachment_file_patterns: ?[][]const u8 = null,
    exclude_attachment_file_patterns: ?[][]const u8 = null,
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_attachments = "CrawlAttachments",
            .include_attachment_file_patterns = "IncludeAttachmentFilePatterns",
            .exclude_attachment_file_patterns = "ExcludeAttachmentFilePatterns",
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowKnowledgeArticleConfiguration = struct {
    crawl_attachments: ?bool = null,
    include_attachment_file_patterns: ?[][]const u8 = null,
    exclude_attachment_file_patterns: ?[][]const u8 = null,
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    filter_query: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawl_attachments = "CrawlAttachments",
            .include_attachment_file_patterns = "IncludeAttachmentFilePatterns",
            .exclude_attachment_file_patterns = "ExcludeAttachmentFilePatterns",
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
            .filter_query = "FilterQuery",
        };
        return @field(mappings, field_name);
    }
};

pub const OneDriveConfiguration = struct {
    tenant_domain: []const u8,
    secret_arn: []const u8,
    one_drive_users: OneDriveUsers,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    disable_local_groups: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tenant_domain = "TenantDomain",
            .secret_arn = "SecretArn",
            .one_drive_users = "OneDriveUsers",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .field_mappings = "FieldMappings",
            .disable_local_groups = "DisableLocalGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const OneDriveUsers = struct {
    one_drive_user_list: ?[][]const u8 = null,
    one_drive_user_s3_path: ?S3Path = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .one_drive_user_list = "OneDriveUserList",
            .one_drive_user_s3_path = "OneDriveUserS3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceConfiguration = struct {
    server_url: []const u8,
    secret_arn: []const u8,
    standard_object_configurations: ?[]SalesforceStandardObjectConfiguration = null,
    knowledge_article_configuration: ?SalesforceKnowledgeArticleConfiguration = null,
    chatter_feed_configuration: ?SalesforceChatterFeedConfiguration = null,
    crawl_attachments: ?bool = null,
    standard_object_attachment_configuration: ?SalesforceStandardObjectAttachmentConfiguration = null,
    include_attachment_file_patterns: ?[][]const u8 = null,
    exclude_attachment_file_patterns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_url = "ServerUrl",
            .secret_arn = "SecretArn",
            .standard_object_configurations = "StandardObjectConfigurations",
            .knowledge_article_configuration = "KnowledgeArticleConfiguration",
            .chatter_feed_configuration = "ChatterFeedConfiguration",
            .crawl_attachments = "CrawlAttachments",
            .standard_object_attachment_configuration = "StandardObjectAttachmentConfiguration",
            .include_attachment_file_patterns = "IncludeAttachmentFilePatterns",
            .exclude_attachment_file_patterns = "ExcludeAttachmentFilePatterns",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceStandardObjectAttachmentConfiguration = struct {
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceChatterFeedConfiguration = struct {
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    include_filter_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
            .include_filter_types = "IncludeFilterTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceKnowledgeArticleConfiguration = struct {
    included_states: [][]const u8,
    standard_knowledge_article_type_configuration: ?SalesforceStandardKnowledgeArticleTypeConfiguration = null,
    custom_knowledge_article_type_configurations: ?[]SalesforceCustomKnowledgeArticleTypeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .included_states = "IncludedStates",
            .standard_knowledge_article_type_configuration = "StandardKnowledgeArticleTypeConfiguration",
            .custom_knowledge_article_type_configurations = "CustomKnowledgeArticleTypeConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceCustomKnowledgeArticleTypeConfiguration = struct {
    name: []const u8,
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceStandardKnowledgeArticleTypeConfiguration = struct {
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceStandardObjectConfiguration = struct {
    name: []const u8,
    document_data_field_name: []const u8,
    document_title_field_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .document_data_field_name = "DocumentDataFieldName",
            .document_title_field_name = "DocumentTitleFieldName",
            .field_mappings = "FieldMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseConfiguration = struct {
    database_engine_type: []const u8,
    connection_configuration: ConnectionConfiguration,
    vpc_configuration: ?DataSourceVpcConfiguration = null,
    column_configuration: ColumnConfiguration,
    acl_configuration: ?AclConfiguration = null,
    sql_configuration: ?SqlConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_engine_type = "DatabaseEngineType",
            .connection_configuration = "ConnectionConfiguration",
            .vpc_configuration = "VpcConfiguration",
            .column_configuration = "ColumnConfiguration",
            .acl_configuration = "AclConfiguration",
            .sql_configuration = "SqlConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlConfiguration = struct {
    query_identifiers_enclosing_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_identifiers_enclosing_option = "QueryIdentifiersEnclosingOption",
        };
        return @field(mappings, field_name);
    }
};

pub const AclConfiguration = struct {
    allowed_groups_column_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_groups_column_name = "AllowedGroupsColumnName",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnConfiguration = struct {
    document_id_column_name: []const u8,
    document_data_column_name: []const u8,
    document_title_column_name: ?[]const u8 = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    change_detecting_columns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_id_column_name = "DocumentIdColumnName",
            .document_data_column_name = "DocumentDataColumnName",
            .document_title_column_name = "DocumentTitleColumnName",
            .field_mappings = "FieldMappings",
            .change_detecting_columns = "ChangeDetectingColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionConfiguration = struct {
    database_host: []const u8,
    database_port: i64,
    database_name: []const u8,
    table_name: []const u8,
    secret_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_host = "DatabaseHost",
            .database_port = "DatabasePort",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .secret_arn = "SecretArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SharePointConfiguration = struct {
    share_point_version: []const u8,
    urls: [][]const u8,
    secret_arn: []const u8,
    crawl_attachments: ?bool = null,
    use_change_log: ?bool = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    vpc_configuration: ?DataSourceVpcConfiguration = null,
    field_mappings: ?[]DataSourceToIndexFieldMapping = null,
    document_title_field_name: ?[]const u8 = null,
    disable_local_groups: ?bool = null,
    ssl_certificate_s3_path: ?S3Path = null,
    authentication_type: ?[]const u8 = null,
    proxy_configuration: ?ProxyConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .share_point_version = "SharePointVersion",
            .urls = "Urls",
            .secret_arn = "SecretArn",
            .crawl_attachments = "CrawlAttachments",
            .use_change_log = "UseChangeLog",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .vpc_configuration = "VpcConfiguration",
            .field_mappings = "FieldMappings",
            .document_title_field_name = "DocumentTitleFieldName",
            .disable_local_groups = "DisableLocalGroups",
            .ssl_certificate_s3_path = "SslCertificateS3Path",
            .authentication_type = "AuthenticationType",
            .proxy_configuration = "ProxyConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DataSourceConfiguration = struct {
    bucket_name: []const u8,
    inclusion_prefixes: ?[][]const u8 = null,
    inclusion_patterns: ?[][]const u8 = null,
    exclusion_patterns: ?[][]const u8 = null,
    documents_metadata_configuration: ?DocumentsMetadataConfiguration = null,
    access_control_list_configuration: ?AccessControlListConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .inclusion_prefixes = "InclusionPrefixes",
            .inclusion_patterns = "InclusionPatterns",
            .exclusion_patterns = "ExclusionPatterns",
            .documents_metadata_configuration = "DocumentsMetadataConfiguration",
            .access_control_list_configuration = "AccessControlListConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlListConfiguration = struct {
    key_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_path = "KeyPath",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentsMetadataConfiguration = struct {
    s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_prefix = "S3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const HierarchicalPrincipal = struct {
    principal_list: []Principal,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal_list = "PrincipalList",
        };
        return @field(mappings, field_name);
    }
};

pub const Principal = struct {
    name: []const u8,
    type: []const u8,
    access: []const u8,
    data_source_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .access = "Access",
            .data_source_id = "DataSourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ScoreAttributes = struct {
    score_confidence: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .score_confidence = "ScoreConfidence",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttribute = struct {
    key: []const u8,
    value: DocumentAttributeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const UserContext = struct {
    token: ?[]const u8 = null,
    user_id: ?[]const u8 = null,
    groups: ?[][]const u8 = null,
    data_source_groups: ?[]DataSourceGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .token = "Token",
            .user_id = "UserId",
            .groups = "Groups",
            .data_source_groups = "DataSourceGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceGroup = struct {
    group_id: []const u8,
    data_source_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_id = "GroupId",
            .data_source_id = "DataSourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentRelevanceConfiguration = struct {
    name: []const u8,
    relevance: Relevance,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .relevance = "Relevance",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeFilter = struct {
    and_all_filters: ?[]AttributeFilter = null,
    or_all_filters: ?[]AttributeFilter = null,
    not_filter: ?AttributeFilter = null,
    equals_to: ?DocumentAttribute = null,
    contains_all: ?DocumentAttribute = null,
    contains_any: ?DocumentAttribute = null,
    greater_than: ?DocumentAttribute = null,
    greater_than_or_equals: ?DocumentAttribute = null,
    less_than: ?DocumentAttribute = null,
    less_than_or_equals: ?DocumentAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .and_all_filters = "AndAllFilters",
            .or_all_filters = "OrAllFilters",
            .not_filter = "NotFilter",
            .equals_to = "EqualsTo",
            .contains_all = "ContainsAll",
            .contains_any = "ContainsAny",
            .greater_than = "GreaterThan",
            .greater_than_or_equals = "GreaterThanOrEquals",
            .less_than = "LessThan",
            .less_than_or_equals = "LessThanOrEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const TextWithHighlights = struct {
    text: ?[]const u8 = null,
    highlights: ?[]Highlight = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .highlights = "Highlights",
        };
        return @field(mappings, field_name);
    }
};

pub const Highlight = struct {
    begin_offset: i64,
    end_offset: i64,
    top_answer: ?bool = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin_offset = "BeginOffset",
            .end_offset = "EndOffset",
            .top_answer = "TopAnswer",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AdditionalResultAttribute = struct {
    key: []const u8,
    value_type: []const u8,
    value: AdditionalResultAttributeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value_type = "ValueType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AdditionalResultAttributeValue = struct {
    text_with_highlights_value: ?TextWithHighlights = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_with_highlights_value = "TextWithHighlightsValue",
        };
        return @field(mappings, field_name);
    }
};

pub const SortingConfiguration = struct {
    document_attribute_key: []const u8,
    sort_order: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_attribute_key = "DocumentAttributeKey",
            .sort_order = "SortOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperienceEndpoint = struct {
    endpoint_type: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_type = "EndpointType",
            .endpoint = "Endpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeRange = struct {
    start_time: ?i64 = null,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedEntity = struct {
    entity_id: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_id = "EntityId",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const EntityConfiguration = struct {
    entity_id: []const u8,
    entity_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_id = "EntityId",
            .entity_type = "EntityType",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerSideEncryptionConfiguration = struct {
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};
