const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-10-19";
pub const sdk_id: []const u8 = "Kendra Ranking";
pub const arn_namespace: ?[]const u8 = "kendra-ranking";
pub const endpoint_prefix: []const u8 = "kendra-ranking";
pub const sigv4_name: []const u8 = "kendra-ranking";
pub const name: []const u8 = "AWSKendraRerankingFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2022-10-19",
    sdk_id: []const u8 = "Kendra Ranking",
    arn_namespace: ?[]const u8 = "kendra-ranking",
    endpoint_prefix: []const u8 = "kendra-ranking",
    sigv4_name: []const u8 = "kendra-ranking",
    name: []const u8 = "AWSKendraRerankingFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_rescore_execution_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rescore-execution-plans",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRescoreExecutionPlan",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        capacity_units: ?CapacityUnitsConfiguration = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .capacity_units = "CapacityUnits",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rescore_execution_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_rescore_execution_plan };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_rescore_execution_plan: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/rescore-execution-plans/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRescoreExecutionPlan",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rescore_execution_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_rescore_execution_plan };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_rescore_execution_plan: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rescore-execution-plans/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRescoreExecutionPlan",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_rescore_execution_plan) } {
            return .{ .service_metadata = service_metadata, .action = describe_rescore_execution_plan };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        capacity_units: ?CapacityUnitsConfiguration = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        status: ?[]const u8 = null,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
                .name = "Name",
                .description = "Description",
                .capacity_units = "CapacityUnits",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .status = "Status",
                .error_message = "ErrorMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_rescore_execution_plans: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rescore-execution-plans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRescoreExecutionPlans",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rescore_execution_plans) } {
            return .{ .service_metadata = service_metadata, .action = list_rescore_execution_plans };
        }
    },
    Response: type = struct {
        summary_items: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary_items = "SummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const rescore: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rescore-execution-plans/{RescoreExecutionPlanId}/rescore",
        .success_code = 200,
    };

    action_name: []const u8 = "Rescore",
    Request: type = struct {
        rescore_execution_plan_id: []const u8,
        search_query: []const u8,
        documents: []struct {
            id: []const u8,
            group_id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            body: ?[]const u8 = null,
            tokenized_title: ?[][]const u8 = null,
            tokenized_body: ?[][]const u8 = null,
            original_score: f32,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .group_id = "GroupId",
                    .title = "Title",
                    .body = "Body",
                    .tokenized_title = "TokenizedTitle",
                    .tokenized_body = "TokenizedBody",
                    .original_score = "OriginalScore",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rescore_execution_plan_id = "RescoreExecutionPlanId",
                .search_query = "SearchQuery",
                .documents = "Documents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rescore) } {
            return .{ .service_metadata = service_metadata, .action = rescore };
        }
    },
    Response: type = struct {
        rescore_id: ?[]const u8 = null,
        result_items: ?[]struct {
            document_id: ?[]const u8 = null,
            score: ?f32 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_id = "DocumentId",
                    .score = "Score",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rescore_id = "RescoreId",
                .result_items = "ResultItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const update_rescore_execution_plan: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/rescore-execution-plans/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRescoreExecutionPlan",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        capacity_units: ?CapacityUnitsConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .capacity_units = "CapacityUnits",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rescore_execution_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_rescore_execution_plan };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const CapacityUnitsConfiguration = struct {
    rescore_capacity_units: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rescore_capacity_units = "RescoreCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
