const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-02-10";
pub const sdk_id: []const u8 = "Keyspaces";
pub const arn_namespace: ?[]const u8 = "cassandra";
pub const endpoint_prefix: []const u8 = "cassandra";
pub const sigv4_name: []const u8 = "cassandra";
pub const name: []const u8 = "KeyspacesService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2022-02-10",
    sdk_id: []const u8 = "Keyspaces",
    arn_namespace: ?[]const u8 = "cassandra",
    endpoint_prefix: []const u8 = "cassandra",
    sigv4_name: []const u8 = "cassandra",
    name: []const u8 = "KeyspacesService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_keyspace: struct {
    action_name: []const u8 = "CreateKeyspace",
    Request: type = struct {
        keyspace_name: []const u8,
        tags: ?[]Tag = null,
        replication_specification: ?struct {
            replication_strategy: []const u8,
            region_list: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_strategy = "replicationStrategy",
                    .region_list = "regionList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .tags = "tags",
                .replication_specification = "replicationSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_keyspace) } {
            return .{ .service_metadata = service_metadata, .action = create_keyspace };
        }
    },
    Response: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_table: struct {
    action_name: []const u8 = "CreateTable",
    Request: type = struct {
        keyspace_name: []const u8,
        table_name: []const u8,
        schema_definition: SchemaDefinition,
        comment: ?Comment = null,
        capacity_specification: ?CapacitySpecification = null,
        encryption_specification: ?EncryptionSpecification = null,
        point_in_time_recovery: ?PointInTimeRecovery = null,
        ttl: ?TimeToLive = null,
        default_time_to_live: ?i64 = null,
        tags: ?[]Tag = null,
        client_side_timestamps: ?ClientSideTimestamps = null,
        auto_scaling_specification: ?AutoScalingSpecification = null,
        replica_specifications: ?[]ReplicaSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .table_name = "tableName",
                .schema_definition = "schemaDefinition",
                .comment = "comment",
                .capacity_specification = "capacitySpecification",
                .encryption_specification = "encryptionSpecification",
                .point_in_time_recovery = "pointInTimeRecovery",
                .ttl = "ttl",
                .default_time_to_live = "defaultTimeToLive",
                .tags = "tags",
                .client_side_timestamps = "clientSideTimestamps",
                .auto_scaling_specification = "autoScalingSpecification",
                .replica_specifications = "replicaSpecifications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_table) } {
            return .{ .service_metadata = service_metadata, .action = create_table };
        }
    },
    Response: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_keyspace: struct {
    action_name: []const u8 = "DeleteKeyspace",
    Request: type = struct {
        keyspace_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_keyspace) } {
            return .{ .service_metadata = service_metadata, .action = delete_keyspace };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_table: struct {
    action_name: []const u8 = "DeleteTable",
    Request: type = struct {
        keyspace_name: []const u8,
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .table_name = "tableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const get_keyspace: struct {
    action_name: []const u8 = "GetKeyspace",
    Request: type = struct {
        keyspace_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_keyspace) } {
            return .{ .service_metadata = service_metadata, .action = get_keyspace };
        }
    },
    Response: type = struct {
        keyspace_name: []const u8,
        resource_arn: []const u8,
        replication_strategy: []const u8,
        replication_regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .resource_arn = "resourceArn",
                .replication_strategy = "replicationStrategy",
                .replication_regions = "replicationRegions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const get_table: struct {
    action_name: []const u8 = "GetTable",
    Request: type = struct {
        keyspace_name: []const u8,
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .table_name = "tableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table) } {
            return .{ .service_metadata = service_metadata, .action = get_table };
        }
    },
    Response: type = struct {
        keyspace_name: []const u8,
        table_name: []const u8,
        resource_arn: []const u8,
        creation_timestamp: ?i64 = null,
        status: ?[]const u8 = null,
        schema_definition: ?SchemaDefinition = null,
        capacity_specification: ?CapacitySpecificationSummary = null,
        encryption_specification: ?EncryptionSpecification = null,
        point_in_time_recovery: ?struct {
            status: []const u8,
            earliest_restorable_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "status",
                    .earliest_restorable_timestamp = "earliestRestorableTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        ttl: ?TimeToLive = null,
        default_time_to_live: ?i64 = null,
        comment: ?Comment = null,
        client_side_timestamps: ?ClientSideTimestamps = null,
        replica_specifications: ?[]struct {
            region: ?[]const u8 = null,
            status: ?[]const u8 = null,
            capacity_specification: ?CapacitySpecificationSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "region",
                    .status = "status",
                    .capacity_specification = "capacitySpecification",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .table_name = "tableName",
                .resource_arn = "resourceArn",
                .creation_timestamp = "creationTimestamp",
                .status = "status",
                .schema_definition = "schemaDefinition",
                .capacity_specification = "capacitySpecification",
                .encryption_specification = "encryptionSpecification",
                .point_in_time_recovery = "pointInTimeRecovery",
                .ttl = "ttl",
                .default_time_to_live = "defaultTimeToLive",
                .comment = "comment",
                .client_side_timestamps = "clientSideTimestamps",
                .replica_specifications = "replicaSpecifications",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const get_table_auto_scaling_settings: struct {
    action_name: []const u8 = "GetTableAutoScalingSettings",
    Request: type = struct {
        keyspace_name: []const u8,
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .table_name = "tableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_auto_scaling_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_table_auto_scaling_settings };
        }
    },
    Response: type = struct {
        keyspace_name: []const u8,
        table_name: []const u8,
        resource_arn: []const u8,
        auto_scaling_specification: ?AutoScalingSpecification = null,
        replica_specifications: ?[]struct {
            region: ?[]const u8 = null,
            auto_scaling_specification: ?AutoScalingSpecification = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "region",
                    .auto_scaling_specification = "autoScalingSpecification",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .table_name = "tableName",
                .resource_arn = "resourceArn",
                .auto_scaling_specification = "autoScalingSpecification",
                .replica_specifications = "replicaSpecifications",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_keyspaces: struct {
    action_name: []const u8 = "ListKeyspaces",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_keyspaces) } {
            return .{ .service_metadata = service_metadata, .action = list_keyspaces };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        keyspaces: []struct {
            keyspace_name: []const u8,
            resource_arn: []const u8,
            replication_strategy: []const u8,
            replication_regions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .keyspace_name = "keyspaceName",
                    .resource_arn = "resourceArn",
                    .replication_strategy = "replicationStrategy",
                    .replication_regions = "replicationRegions",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .keyspaces = "keyspaces",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_tables: struct {
    action_name: []const u8 = "ListTables",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        keyspace_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .keyspace_name = "keyspaceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tables) } {
            return .{ .service_metadata = service_metadata, .action = list_tables };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        tables: ?[]struct {
            keyspace_name: []const u8,
            table_name: []const u8,
            resource_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .keyspace_name = "keyspaceName",
                    .table_name = "tableName",
                    .resource_arn = "resourceArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .tables = "tables",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const restore_table: struct {
    action_name: []const u8 = "RestoreTable",
    Request: type = struct {
        source_keyspace_name: []const u8,
        source_table_name: []const u8,
        target_keyspace_name: []const u8,
        target_table_name: []const u8,
        restore_timestamp: ?i64 = null,
        capacity_specification_override: ?CapacitySpecification = null,
        encryption_specification_override: ?EncryptionSpecification = null,
        point_in_time_recovery_override: ?PointInTimeRecovery = null,
        tags_override: ?[]Tag = null,
        auto_scaling_specification: ?AutoScalingSpecification = null,
        replica_specifications: ?[]ReplicaSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_keyspace_name = "sourceKeyspaceName",
                .source_table_name = "sourceTableName",
                .target_keyspace_name = "targetKeyspaceName",
                .target_table_name = "targetTableName",
                .restore_timestamp = "restoreTimestamp",
                .capacity_specification_override = "capacitySpecificationOverride",
                .encryption_specification_override = "encryptionSpecificationOverride",
                .point_in_time_recovery_override = "pointInTimeRecoveryOverride",
                .tags_override = "tagsOverride",
                .auto_scaling_specification = "autoScalingSpecification",
                .replica_specifications = "replicaSpecifications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_table) } {
            return .{ .service_metadata = service_metadata, .action = restore_table };
        }
    },
    Response: type = struct {
        restored_table_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restored_table_arn = "restoredTableARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const update_table: struct {
    action_name: []const u8 = "UpdateTable",
    Request: type = struct {
        keyspace_name: []const u8,
        table_name: []const u8,
        add_columns: ?[]ColumnDefinition = null,
        capacity_specification: ?CapacitySpecification = null,
        encryption_specification: ?EncryptionSpecification = null,
        point_in_time_recovery: ?PointInTimeRecovery = null,
        ttl: ?TimeToLive = null,
        default_time_to_live: ?i64 = null,
        client_side_timestamps: ?ClientSideTimestamps = null,
        auto_scaling_specification: ?AutoScalingSpecification = null,
        replica_specifications: ?[]ReplicaSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keyspace_name = "keyspaceName",
                .table_name = "tableName",
                .add_columns = "addColumns",
                .capacity_specification = "capacitySpecification",
                .encryption_specification = "encryptionSpecification",
                .point_in_time_recovery = "pointInTimeRecovery",
                .ttl = "ttl",
                .default_time_to_live = "defaultTimeToLive",
                .client_side_timestamps = "clientSideTimestamps",
                .auto_scaling_specification = "autoScalingSpecification",
                .replica_specifications = "replicaSpecifications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table) } {
            return .{ .service_metadata = service_metadata, .action = update_table };
        }
    },
    Response: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};

pub const ReplicaSpecification = struct {
    region: []const u8,
    read_capacity_units: ?i64 = null,
    read_capacity_auto_scaling: ?AutoScalingSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "region",
            .read_capacity_units = "readCapacityUnits",
            .read_capacity_auto_scaling = "readCapacityAutoScaling",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingSettings = struct {
    auto_scaling_disabled: ?bool = null,
    minimum_units: ?i64 = null,
    maximum_units: ?i64 = null,
    scaling_policy: ?AutoScalingPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_scaling_disabled = "autoScalingDisabled",
            .minimum_units = "minimumUnits",
            .maximum_units = "maximumUnits",
            .scaling_policy = "scalingPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingPolicy = struct {
    target_tracking_scaling_policy_configuration: ?TargetTrackingScalingPolicyConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_tracking_scaling_policy_configuration = "targetTrackingScalingPolicyConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetTrackingScalingPolicyConfiguration = struct {
    disable_scale_in: ?bool = null,
    scale_in_cooldown: ?i64 = null,
    scale_out_cooldown: ?i64 = null,
    target_value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disable_scale_in = "disableScaleIn",
            .scale_in_cooldown = "scaleInCooldown",
            .scale_out_cooldown = "scaleOutCooldown",
            .target_value = "targetValue",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingSpecification = struct {
    write_capacity_auto_scaling: ?AutoScalingSettings = null,
    read_capacity_auto_scaling: ?AutoScalingSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .write_capacity_auto_scaling = "writeCapacityAutoScaling",
            .read_capacity_auto_scaling = "readCapacityAutoScaling",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientSideTimestamps = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeToLive = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const PointInTimeRecovery = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionSpecification = struct {
    type: []const u8,
    kms_key_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .kms_key_identifier = "kmsKeyIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacitySpecification = struct {
    throughput_mode: []const u8,
    read_capacity_units: ?i64 = null,
    write_capacity_units: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .throughput_mode = "throughputMode",
            .read_capacity_units = "readCapacityUnits",
            .write_capacity_units = "writeCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnDefinition = struct {
    name: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacitySpecificationSummary = struct {
    throughput_mode: []const u8,
    read_capacity_units: ?i64 = null,
    write_capacity_units: ?i64 = null,
    last_update_to_pay_per_request_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .throughput_mode = "throughputMode",
            .read_capacity_units = "readCapacityUnits",
            .write_capacity_units = "writeCapacityUnits",
            .last_update_to_pay_per_request_timestamp = "lastUpdateToPayPerRequestTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const Comment = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaDefinition = struct {
    all_columns: []ColumnDefinition,
    partition_keys: []PartitionKey,
    clustering_keys: ?[]ClusteringKey = null,
    static_columns: ?[]StaticColumn = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .all_columns = "allColumns",
            .partition_keys = "partitionKeys",
            .clustering_keys = "clusteringKeys",
            .static_columns = "staticColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticColumn = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusteringKey = struct {
    name: []const u8,
    order_by: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .order_by = "orderBy",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionKey = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};
