const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2013-12-02";
pub const sdk_id: []const u8 = "Kinesis";
pub const arn_namespace: ?[]const u8 = "kinesis";
pub const endpoint_prefix: []const u8 = "kinesis";
pub const sigv4_name: []const u8 = "kinesis";
pub const name: []const u8 = "Kinesis_20131202";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2013-12-02",
    sdk_id: []const u8 = "Kinesis",
    arn_namespace: ?[]const u8 = "kinesis",
    endpoint_prefix: []const u8 = "kinesis",
    sigv4_name: []const u8 = "kinesis",
    name: []const u8 = "Kinesis_20131202",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags_to_stream: struct {
    action_name: []const u8 = "AddTagsToStream",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .tags = "Tags",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_stream) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_stream };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const create_stream: struct {
    action_name: []const u8 = "CreateStream",
    Request: type = struct {
        stream_name: []const u8,
        shard_count: ?i64 = null,
        stream_mode_details: ?StreamModeDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .shard_count = "ShardCount",
                .stream_mode_details = "StreamModeDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stream) } {
            return .{ .service_metadata = service_metadata, .action = create_stream };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
    },
} = .{};
pub const decrease_stream_retention_period: struct {
    action_name: []const u8 = "DecreaseStreamRetentionPeriod",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        retention_period_hours: i64,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .retention_period_hours = "RetentionPeriodHours",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decrease_stream_retention_period) } {
            return .{ .service_metadata = service_metadata, .action = decrease_stream_retention_period };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_stream: struct {
    action_name: []const u8 = "DeleteStream",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        enforce_consumer_deletion: ?bool = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .enforce_consumer_deletion = "EnforceConsumerDeletion",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stream) } {
            return .{ .service_metadata = service_metadata, .action = delete_stream };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const deregister_stream_consumer: struct {
    action_name: []const u8 = "DeregisterStreamConsumer",
    Request: type = struct {
        stream_arn: ?[]const u8 = null,
        consumer_name: ?[]const u8 = null,
        consumer_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
                .consumer_name = "ConsumerName",
                .consumer_arn = "ConsumerARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_stream_consumer) } {
            return .{ .service_metadata = service_metadata, .action = deregister_stream_consumer };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArgument,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const describe_limits: struct {
    action_name: []const u8 = "DescribeLimits",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_limits };
        }
    },
    Response: type = struct {
        shard_limit: i64,
        open_shard_count: i64,
        on_demand_stream_count: i64,
        on_demand_stream_count_limit: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shard_limit = "ShardLimit",
                .open_shard_count = "OpenShardCount",
                .on_demand_stream_count = "OnDemandStreamCount",
                .on_demand_stream_count_limit = "OnDemandStreamCountLimit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const describe_stream: struct {
    action_name: []const u8 = "DescribeStream",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        limit: ?i64 = null,
        exclusive_start_shard_id: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .limit = "Limit",
                .exclusive_start_shard_id = "ExclusiveStartShardId",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stream) } {
            return .{ .service_metadata = service_metadata, .action = describe_stream };
        }
    },
    Response: type = struct {
        stream_description: struct {
            stream_name: []const u8,
            stream_arn: []const u8,
            stream_status: []const u8,
            stream_mode_details: ?StreamModeDetails = null,
            shards: []Shard,
            has_more_shards: bool,
            retention_period_hours: i64,
            stream_creation_timestamp: i64,
            enhanced_monitoring: []EnhancedMetrics,
            encryption_type: ?[]const u8 = null,
            key_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stream_name = "StreamName",
                    .stream_arn = "StreamARN",
                    .stream_status = "StreamStatus",
                    .stream_mode_details = "StreamModeDetails",
                    .shards = "Shards",
                    .has_more_shards = "HasMoreShards",
                    .retention_period_hours = "RetentionPeriodHours",
                    .stream_creation_timestamp = "StreamCreationTimestamp",
                    .enhanced_monitoring = "EnhancedMonitoring",
                    .encryption_type = "EncryptionType",
                    .key_id = "KeyId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_description = "StreamDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const describe_stream_consumer: struct {
    action_name: []const u8 = "DescribeStreamConsumer",
    Request: type = struct {
        stream_arn: ?[]const u8 = null,
        consumer_name: ?[]const u8 = null,
        consumer_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
                .consumer_name = "ConsumerName",
                .consumer_arn = "ConsumerARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stream_consumer) } {
            return .{ .service_metadata = service_metadata, .action = describe_stream_consumer };
        }
    },
    Response: type = struct {
        consumer_description: struct {
            consumer_name: []const u8,
            consumer_arn: []const u8,
            consumer_status: []const u8,
            consumer_creation_timestamp: i64,
            stream_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .consumer_name = "ConsumerName",
                    .consumer_arn = "ConsumerARN",
                    .consumer_status = "ConsumerStatus",
                    .consumer_creation_timestamp = "ConsumerCreationTimestamp",
                    .stream_arn = "StreamARN",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .consumer_description = "ConsumerDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const describe_stream_summary: struct {
    action_name: []const u8 = "DescribeStreamSummary",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stream_summary) } {
            return .{ .service_metadata = service_metadata, .action = describe_stream_summary };
        }
    },
    Response: type = struct {
        stream_description_summary: struct {
            stream_name: []const u8,
            stream_arn: []const u8,
            stream_status: []const u8,
            stream_mode_details: ?StreamModeDetails = null,
            retention_period_hours: i64,
            stream_creation_timestamp: i64,
            enhanced_monitoring: []EnhancedMetrics,
            encryption_type: ?[]const u8 = null,
            key_id: ?[]const u8 = null,
            open_shard_count: i64,
            consumer_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stream_name = "StreamName",
                    .stream_arn = "StreamARN",
                    .stream_status = "StreamStatus",
                    .stream_mode_details = "StreamModeDetails",
                    .retention_period_hours = "RetentionPeriodHours",
                    .stream_creation_timestamp = "StreamCreationTimestamp",
                    .enhanced_monitoring = "EnhancedMonitoring",
                    .encryption_type = "EncryptionType",
                    .key_id = "KeyId",
                    .open_shard_count = "OpenShardCount",
                    .consumer_count = "ConsumerCount",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_description_summary = "StreamDescriptionSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disable_enhanced_monitoring: struct {
    action_name: []const u8 = "DisableEnhancedMonitoring",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        shard_level_metrics: [][]const u8,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .shard_level_metrics = "ShardLevelMetrics",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_enhanced_monitoring) } {
            return .{ .service_metadata = service_metadata, .action = disable_enhanced_monitoring };
        }
    },
    Response: type = struct {
        stream_name: ?[]const u8 = null,
        current_shard_level_metrics: ?[][]const u8 = null,
        desired_shard_level_metrics: ?[][]const u8 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .current_shard_level_metrics = "CurrentShardLevelMetrics",
                .desired_shard_level_metrics = "DesiredShardLevelMetrics",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const enable_enhanced_monitoring: struct {
    action_name: []const u8 = "EnableEnhancedMonitoring",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        shard_level_metrics: [][]const u8,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .shard_level_metrics = "ShardLevelMetrics",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_enhanced_monitoring) } {
            return .{ .service_metadata = service_metadata, .action = enable_enhanced_monitoring };
        }
    },
    Response: type = struct {
        stream_name: ?[]const u8 = null,
        current_shard_level_metrics: ?[][]const u8 = null,
        desired_shard_level_metrics: ?[][]const u8 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .current_shard_level_metrics = "CurrentShardLevelMetrics",
                .desired_shard_level_metrics = "DesiredShardLevelMetrics",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const get_records: struct {
    action_name: []const u8 = "GetRecords",
    Request: type = struct {
        shard_iterator: []const u8,
        limit: ?i64 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shard_iterator = "ShardIterator",
                .limit = "Limit",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_records) } {
            return .{ .service_metadata = service_metadata, .action = get_records };
        }
    },
    Response: type = struct {
        records: []Record,
        next_shard_iterator: ?[]const u8 = null,
        millis_behind_latest: ?i64 = null,
        child_shards: ?[]ChildShard = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
                .next_shard_iterator = "NextShardIterator",
                .millis_behind_latest = "MillisBehindLatest",
                .child_shards = "ChildShards",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredIterator,
        InvalidArgument,
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSOptInRequired,
        KMSThrottling,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_resource_policy: struct {
    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_shard_iterator: struct {
    action_name: []const u8 = "GetShardIterator",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        shard_id: []const u8,
        shard_iterator_type: []const u8,
        starting_sequence_number: ?[]const u8 = null,
        timestamp: ?i64 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .shard_id = "ShardId",
                .shard_iterator_type = "ShardIteratorType",
                .starting_sequence_number = "StartingSequenceNumber",
                .timestamp = "Timestamp",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_shard_iterator) } {
            return .{ .service_metadata = service_metadata, .action = get_shard_iterator };
        }
    },
    Response: type = struct {
        shard_iterator: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shard_iterator = "ShardIterator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
    },
} = .{};
pub const increase_stream_retention_period: struct {
    action_name: []const u8 = "IncreaseStreamRetentionPeriod",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        retention_period_hours: i64,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .retention_period_hours = "RetentionPeriodHours",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(increase_stream_retention_period) } {
            return .{ .service_metadata = service_metadata, .action = increase_stream_retention_period };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const list_shards: struct {
    action_name: []const u8 = "ListShards",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        exclusive_start_shard_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        stream_creation_timestamp: ?i64 = null,
        shard_filter: ?struct {
            type: []const u8,
            shard_id: ?[]const u8 = null,
            timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .shard_id = "ShardId",
                    .timestamp = "Timestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .next_token = "NextToken",
                .exclusive_start_shard_id = "ExclusiveStartShardId",
                .max_results = "MaxResults",
                .stream_creation_timestamp = "StreamCreationTimestamp",
                .shard_filter = "ShardFilter",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_shards) } {
            return .{ .service_metadata = service_metadata, .action = list_shards };
        }
    },
    Response: type = struct {
        shards: ?[]Shard = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shards = "Shards",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredNextToken,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const list_stream_consumers: struct {
    action_name: []const u8 = "ListStreamConsumers",
    Request: type = struct {
        stream_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        stream_creation_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .stream_creation_timestamp = "StreamCreationTimestamp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_stream_consumers) } {
            return .{ .service_metadata = service_metadata, .action = list_stream_consumers };
        }
    },
    Response: type = struct {
        consumers: ?[]Consumer = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .consumers = "Consumers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredNextToken,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const list_streams: struct {
    action_name: []const u8 = "ListStreams",
    Request: type = struct {
        limit: ?i64 = null,
        exclusive_start_stream_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .exclusive_start_stream_name = "ExclusiveStartStreamName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_streams) } {
            return .{ .service_metadata = service_metadata, .action = list_streams };
        }
    },
    Response: type = struct {
        stream_names: [][]const u8,
        has_more_streams: bool,
        next_token: ?[]const u8 = null,
        stream_summaries: ?[]struct {
            stream_name: []const u8,
            stream_arn: []const u8,
            stream_status: []const u8,
            stream_mode_details: ?StreamModeDetails = null,
            stream_creation_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stream_name = "StreamName",
                    .stream_arn = "StreamARN",
                    .stream_status = "StreamStatus",
                    .stream_mode_details = "StreamModeDetails",
                    .stream_creation_timestamp = "StreamCreationTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_names = "StreamNames",
                .has_more_streams = "HasMoreStreams",
                .next_token = "NextToken",
                .stream_summaries = "StreamSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredNextToken,
        InvalidArgument,
        LimitExceeded,
    },
} = .{};
pub const list_tags_for_stream: struct {
    action_name: []const u8 = "ListTagsForStream",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        exclusive_start_tag_key: ?[]const u8 = null,
        limit: ?i64 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .exclusive_start_tag_key = "ExclusiveStartTagKey",
                .limit = "Limit",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_stream) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_stream };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: []const u8,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        has_more_tags: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .has_more_tags = "HasMoreTags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const merge_shards: struct {
    action_name: []const u8 = "MergeShards",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        shard_to_merge: []const u8,
        adjacent_shard_to_merge: []const u8,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .shard_to_merge = "ShardToMerge",
                .adjacent_shard_to_merge = "AdjacentShardToMerge",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_shards) } {
            return .{ .service_metadata = service_metadata, .action = merge_shards };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_record: struct {
    action_name: []const u8 = "PutRecord",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        data: []const u8,
        partition_key: []const u8,
        explicit_hash_key: ?[]const u8 = null,
        sequence_number_for_ordering: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .data = "Data",
                .partition_key = "PartitionKey",
                .explicit_hash_key = "ExplicitHashKey",
                .sequence_number_for_ordering = "SequenceNumberForOrdering",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_record) } {
            return .{ .service_metadata = service_metadata, .action = put_record };
        }
    },
    Response: type = struct {
        shard_id: []const u8,
        sequence_number: []const u8,
        encryption_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .shard_id = "ShardId",
                .sequence_number = "SequenceNumber",
                .encryption_type = "EncryptionType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSOptInRequired,
        KMSThrottling,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
    },
} = .{};
pub const put_records: struct {
    action_name: []const u8 = "PutRecords",
    Request: type = struct {
        records: []struct {
            data: []const u8,
            explicit_hash_key: ?[]const u8 = null,
            partition_key: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data = "Data",
                    .explicit_hash_key = "ExplicitHashKey",
                    .partition_key = "PartitionKey",
                };
                return @field(mappings, field_name);
            }
        },
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_records) } {
            return .{ .service_metadata = service_metadata, .action = put_records };
        }
    },
    Response: type = struct {
        failed_record_count: ?i64 = null,
        records: []struct {
            sequence_number: ?[]const u8 = null,
            shard_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sequence_number = "SequenceNumber",
                    .shard_id = "ShardId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        },
        encryption_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_record_count = "FailedRecordCount",
                .records = "Records",
                .encryption_type = "EncryptionType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSOptInRequired,
        KMSThrottling,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const register_stream_consumer: struct {
    action_name: []const u8 = "RegisterStreamConsumer",
    Request: type = struct {
        stream_arn: []const u8,
        consumer_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
                .consumer_name = "ConsumerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_stream_consumer) } {
            return .{ .service_metadata = service_metadata, .action = register_stream_consumer };
        }
    },
    Response: type = struct {
        consumer: Consumer,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .consumer = "Consumer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const remove_tags_from_stream: struct {
    action_name: []const u8 = "RemoveTagsFromStream",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        tag_keys: [][]const u8,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .tag_keys = "TagKeys",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_stream) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_stream };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const split_shard: struct {
    action_name: []const u8 = "SplitShard",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        shard_to_split: []const u8,
        new_starting_hash_key: []const u8,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .shard_to_split = "ShardToSplit",
                .new_starting_hash_key = "NewStartingHashKey",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(split_shard) } {
            return .{ .service_metadata = service_metadata, .action = split_shard };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_stream_encryption: struct {
    action_name: []const u8 = "StartStreamEncryption",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        encryption_type: []const u8,
        key_id: []const u8,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .encryption_type = "EncryptionType",
                .key_id = "KeyId",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_stream_encryption) } {
            return .{ .service_metadata = service_metadata, .action = start_stream_encryption };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSOptInRequired,
        KMSThrottling,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const stop_stream_encryption: struct {
    action_name: []const u8 = "StopStreamEncryption",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        encryption_type: []const u8,
        key_id: []const u8,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .encryption_type = "EncryptionType",
                .key_id = "KeyId",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_stream_encryption) } {
            return .{ .service_metadata = service_metadata, .action = stop_stream_encryption };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const subscribe_to_shard: struct {
    action_name: []const u8 = "SubscribeToShard",
    Request: type = struct {
        consumer_arn: []const u8,
        shard_id: []const u8,
        starting_position: struct {
            type: []const u8,
            sequence_number: ?[]const u8 = null,
            timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .sequence_number = "SequenceNumber",
                    .timestamp = "Timestamp",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .consumer_arn = "ConsumerARN",
                .shard_id = "ShardId",
                .starting_position = "StartingPosition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(subscribe_to_shard) } {
            return .{ .service_metadata = service_metadata, .action = subscribe_to_shard };
        }
    },
    Response: type = struct {
        event_stream: union {
            subscribe_to_shard_event: ?struct {
                records: []Record,
                continuation_sequence_number: []const u8,
                millis_behind_latest: i64,
                child_shards: ?[]ChildShard = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .records = "Records",
                        .continuation_sequence_number = "ContinuationSequenceNumber",
                        .millis_behind_latest = "MillisBehindLatest",
                        .child_shards = "ChildShards",
                    };
                    return @field(mappings, field_name);
                }
            },
            resource_not_found_exception: ?ResourceNotFoundException,
            resource_in_use_exception: ?ResourceInUseException,
            kms_disabled_exception: ?KMSDisabledException,
            kms_invalid_state_exception: ?KMSInvalidStateException,
            kms_access_denied_exception: ?KMSAccessDeniedException,
            kms_not_found_exception: ?KMSNotFoundException,
            kms_opt_in_required: ?KMSOptInRequired,
            kms_throttling_exception: ?KMSThrottlingException,
            internal_failure_exception: ?struct {
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .subscribe_to_shard_event = "SubscribeToShardEvent",
                    .resource_not_found_exception = "ResourceNotFoundException",
                    .resource_in_use_exception = "ResourceInUseException",
                    .kms_disabled_exception = "KMSDisabledException",
                    .kms_invalid_state_exception = "KMSInvalidStateException",
                    .kms_access_denied_exception = "KMSAccessDeniedException",
                    .kms_not_found_exception = "KMSNotFoundException",
                    .kms_opt_in_required = "KMSOptInRequired",
                    .kms_throttling_exception = "KMSThrottlingException",
                    .internal_failure_exception = "InternalFailureException",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_stream = "EventStream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_shard_count: struct {
    action_name: []const u8 = "UpdateShardCount",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        target_shard_count: i64,
        scaling_type: []const u8,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .target_shard_count = "TargetShardCount",
                .scaling_type = "ScalingType",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_shard_count) } {
            return .{ .service_metadata = service_metadata, .action = update_shard_count };
        }
    },
    Response: type = struct {
        stream_name: ?[]const u8 = null,
        current_shard_count: ?i64 = null,
        target_shard_count: ?i64 = null,
        stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .current_shard_count = "CurrentShardCount",
                .target_shard_count = "TargetShardCount",
                .stream_arn = "StreamARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_stream_mode: struct {
    action_name: []const u8 = "UpdateStreamMode",
    Request: type = struct {
        stream_arn: []const u8,
        stream_mode_details: StreamModeDetails,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_arn = "StreamARN",
                .stream_mode_details = "StreamModeDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_stream_mode) } {
            return .{ .service_metadata = service_metadata, .action = update_stream_mode };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArgument,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};

pub const StreamModeDetails = struct {
    stream_mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_mode = "StreamMode",
        };
        return @field(mappings, field_name);
    }
};

pub const KMSThrottlingException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const KMSOptInRequired = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const KMSNotFoundException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const KMSAccessDeniedException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const KMSInvalidStateException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const KMSDisabledException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceInUseException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceNotFoundException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ChildShard = struct {
    shard_id: []const u8,
    parent_shards: [][]const u8,
    hash_key_range: HashKeyRange,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shard_id = "ShardId",
            .parent_shards = "ParentShards",
            .hash_key_range = "HashKeyRange",
        };
        return @field(mappings, field_name);
    }
};

pub const HashKeyRange = struct {
    starting_hash_key: []const u8,
    ending_hash_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .starting_hash_key = "StartingHashKey",
            .ending_hash_key = "EndingHashKey",
        };
        return @field(mappings, field_name);
    }
};

pub const Record = struct {
    sequence_number: []const u8,
    approximate_arrival_timestamp: ?i64 = null,
    data: []const u8,
    partition_key: []const u8,
    encryption_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sequence_number = "SequenceNumber",
            .approximate_arrival_timestamp = "ApproximateArrivalTimestamp",
            .data = "Data",
            .partition_key = "PartitionKey",
            .encryption_type = "EncryptionType",
        };
        return @field(mappings, field_name);
    }
};

pub const Consumer = struct {
    consumer_name: []const u8,
    consumer_arn: []const u8,
    consumer_status: []const u8,
    consumer_creation_timestamp: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .consumer_name = "ConsumerName",
            .consumer_arn = "ConsumerARN",
            .consumer_status = "ConsumerStatus",
            .consumer_creation_timestamp = "ConsumerCreationTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const Shard = struct {
    shard_id: []const u8,
    parent_shard_id: ?[]const u8 = null,
    adjacent_parent_shard_id: ?[]const u8 = null,
    hash_key_range: HashKeyRange,
    sequence_number_range: SequenceNumberRange,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shard_id = "ShardId",
            .parent_shard_id = "ParentShardId",
            .adjacent_parent_shard_id = "AdjacentParentShardId",
            .hash_key_range = "HashKeyRange",
            .sequence_number_range = "SequenceNumberRange",
        };
        return @field(mappings, field_name);
    }
};

pub const SequenceNumberRange = struct {
    starting_sequence_number: []const u8,
    ending_sequence_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .starting_sequence_number = "StartingSequenceNumber",
            .ending_sequence_number = "EndingSequenceNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const EnhancedMetrics = struct {
    shard_level_metrics: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shard_level_metrics = "ShardLevelMetrics",
        };
        return @field(mappings, field_name);
    }
};
