const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-09-30";
pub const sdk_id: []const u8 = "Kinesis Video Archived Media";
pub const arn_namespace: ?[]const u8 = "kinesisvideo";
pub const endpoint_prefix: []const u8 = "kinesisvideo";
pub const sigv4_name: []const u8 = "kinesisvideo";
pub const name: []const u8 = "AWSAcuityReader";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-09-30",
    sdk_id: []const u8 = "Kinesis Video Archived Media",
    arn_namespace: ?[]const u8 = "kinesisvideo",
    endpoint_prefix: []const u8 = "kinesisvideo",
    sigv4_name: []const u8 = "kinesisvideo",
    name: []const u8 = "AWSAcuityReader",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_clip: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getClip",
        .success_code = 200,
    };

    action_name: []const u8 = "GetClip",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        clip_fragment_selector: struct {
            fragment_selector_type: []const u8,
            timestamp_range: struct {
                start_timestamp: i64,
                end_timestamp: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_timestamp = "StartTimestamp",
                        .end_timestamp = "EndTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fragment_selector_type = "FragmentSelectorType",
                    .timestamp_range = "TimestampRange",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .clip_fragment_selector = "ClipFragmentSelector",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_clip) } {
            return .{ .service_metadata = service_metadata, .action = get_clip };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        payload: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "ContentType",
                .payload = "Payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        InvalidCodecPrivateData,
        InvalidMediaFrame,
        MissingCodecPrivateData,
        NoDataRetention,
        NotAuthorized,
        ResourceNotFound,
        UnsupportedStreamMediaType,
    },
} = .{};
pub const get_dash_streaming_session_url: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getDASHStreamingSessionURL",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDASHStreamingSessionURL",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        playback_mode: ?[]const u8 = null,
        display_fragment_timestamp: ?[]const u8 = null,
        display_fragment_number: ?[]const u8 = null,
        dash_fragment_selector: ?struct {
            fragment_selector_type: ?[]const u8 = null,
            timestamp_range: ?struct {
                start_timestamp: ?i64 = null,
                end_timestamp: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_timestamp = "StartTimestamp",
                        .end_timestamp = "EndTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fragment_selector_type = "FragmentSelectorType",
                    .timestamp_range = "TimestampRange",
                };
                return @field(mappings, field_name);
            }
        } = null,
        expires: ?i64 = null,
        max_manifest_fragment_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .playback_mode = "PlaybackMode",
                .display_fragment_timestamp = "DisplayFragmentTimestamp",
                .display_fragment_number = "DisplayFragmentNumber",
                .dash_fragment_selector = "DASHFragmentSelector",
                .expires = "Expires",
                .max_manifest_fragment_results = "MaxManifestFragmentResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dash_streaming_session_url) } {
            return .{ .service_metadata = service_metadata, .action = get_dash_streaming_session_url };
        }
    },
    Response: type = struct {
        dash_streaming_session_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dash_streaming_session_url = "DASHStreamingSessionURL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        InvalidCodecPrivateData,
        MissingCodecPrivateData,
        NoDataRetention,
        NotAuthorized,
        ResourceNotFound,
        UnsupportedStreamMediaType,
    },
} = .{};
pub const get_hls_streaming_session_url: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getHLSStreamingSessionURL",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHLSStreamingSessionURL",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        playback_mode: ?[]const u8 = null,
        hls_fragment_selector: ?struct {
            fragment_selector_type: ?[]const u8 = null,
            timestamp_range: ?struct {
                start_timestamp: ?i64 = null,
                end_timestamp: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_timestamp = "StartTimestamp",
                        .end_timestamp = "EndTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fragment_selector_type = "FragmentSelectorType",
                    .timestamp_range = "TimestampRange",
                };
                return @field(mappings, field_name);
            }
        } = null,
        container_format: ?[]const u8 = null,
        discontinuity_mode: ?[]const u8 = null,
        display_fragment_timestamp: ?[]const u8 = null,
        expires: ?i64 = null,
        max_media_playlist_fragment_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .playback_mode = "PlaybackMode",
                .hls_fragment_selector = "HLSFragmentSelector",
                .container_format = "ContainerFormat",
                .discontinuity_mode = "DiscontinuityMode",
                .display_fragment_timestamp = "DisplayFragmentTimestamp",
                .expires = "Expires",
                .max_media_playlist_fragment_results = "MaxMediaPlaylistFragmentResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_hls_streaming_session_url) } {
            return .{ .service_metadata = service_metadata, .action = get_hls_streaming_session_url };
        }
    },
    Response: type = struct {
        hls_streaming_session_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hls_streaming_session_url = "HLSStreamingSessionURL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        InvalidCodecPrivateData,
        MissingCodecPrivateData,
        NoDataRetention,
        NotAuthorized,
        ResourceNotFound,
        UnsupportedStreamMediaType,
    },
} = .{};
pub const get_images: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getImages",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImages",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        image_selector_type: []const u8,
        start_timestamp: i64,
        end_timestamp: i64,
        sampling_interval: ?i64 = null,
        format: []const u8,
        format_config: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        width_pixels: ?i64 = null,
        height_pixels: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .image_selector_type = "ImageSelectorType",
                .start_timestamp = "StartTimestamp",
                .end_timestamp = "EndTimestamp",
                .sampling_interval = "SamplingInterval",
                .format = "Format",
                .format_config = "FormatConfig",
                .width_pixels = "WidthPixels",
                .height_pixels = "HeightPixels",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "format_config", field_name))
                return try serializeMap(self.format_config, self.fieldNameFor("format_config"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_images) } {
            return .{ .service_metadata = service_metadata, .action = get_images };
        }
    },
    Response: type = struct {
        images: ?[]struct {
            time_stamp: ?i64 = null,
            @"error": ?[]const u8 = null,
            image_content: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time_stamp = "TimeStamp",
                    .@"error" = "Error",
                    .image_content = "ImageContent",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .images = "Images",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NoDataRetention,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const get_media_for_fragment_list: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getMediaForFragmentList",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMediaForFragmentList",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        fragments: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .fragments = "Fragments",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_media_for_fragment_list) } {
            return .{ .service_metadata = service_metadata, .action = get_media_for_fragment_list };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        payload: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "ContentType",
                .payload = "Payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
pub const list_fragments: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listFragments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFragments",
    Request: type = struct {
        stream_name: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        fragment_selector: ?struct {
            fragment_selector_type: []const u8,
            timestamp_range: struct {
                start_timestamp: i64,
                end_timestamp: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_timestamp = "StartTimestamp",
                        .end_timestamp = "EndTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fragment_selector_type = "FragmentSelectorType",
                    .timestamp_range = "TimestampRange",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_name = "StreamName",
                .stream_arn = "StreamARN",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .fragment_selector = "FragmentSelector",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fragments) } {
            return .{ .service_metadata = service_metadata, .action = list_fragments };
        }
    },
    Response: type = struct {
        fragments: ?[]struct {
            fragment_number: ?[]const u8 = null,
            fragment_size_in_bytes: ?i64 = null,
            producer_timestamp: ?i64 = null,
            server_timestamp: ?i64 = null,
            fragment_length_in_milliseconds: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fragment_number = "FragmentNumber",
                    .fragment_size_in_bytes = "FragmentSizeInBytes",
                    .producer_timestamp = "ProducerTimestamp",
                    .server_timestamp = "ServerTimestamp",
                    .fragment_length_in_milliseconds = "FragmentLengthInMilliseconds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fragments = "Fragments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
