const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-04";
pub const sdk_id: []const u8 = "Kinesis Video Signaling";
pub const arn_namespace: ?[]const u8 = "kinesisvideo";
pub const endpoint_prefix: []const u8 = "kinesisvideo";
pub const sigv4_name: []const u8 = "kinesisvideo";
pub const name: []const u8 = "AWSAcuitySignalingService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-04",
    sdk_id: []const u8 = "Kinesis Video Signaling",
    arn_namespace: ?[]const u8 = "kinesisvideo",
    endpoint_prefix: []const u8 = "kinesisvideo",
    sigv4_name: []const u8 = "kinesisvideo",
    name: []const u8 = "AWSAcuitySignalingService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_ice_server_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/get-ice-server-config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIceServerConfig",
    Request: type = struct {
        channel_arn: []const u8,
        client_id: ?[]const u8 = null,
        service: ?[]const u8 = null,
        username: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelARN",
                .client_id = "ClientId",
                .service = "Service",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ice_server_config) } {
            return .{ .service_metadata = service_metadata, .action = get_ice_server_config };
        }
    },
    Response: type = struct {
        ice_server_list: ?[]struct {
            uris: ?[][]const u8 = null,
            username: ?[]const u8 = null,
            password: ?[]const u8 = null,
            ttl: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .uris = "Uris",
                    .username = "Username",
                    .password = "Password",
                    .ttl = "Ttl",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ice_server_list = "IceServerList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        InvalidClient,
        NotAuthorized,
        ResourceNotFound,
        SessionExpired,
    },
} = .{};
pub const send_alexa_offer_to_master: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/send-alexa-offer-to-master",
        .success_code = 200,
    };

    action_name: []const u8 = "SendAlexaOfferToMaster",
    Request: type = struct {
        channel_arn: []const u8,
        sender_client_id: []const u8,
        message_payload: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelARN",
                .sender_client_id = "SenderClientId",
                .message_payload = "MessagePayload",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_alexa_offer_to_master) } {
            return .{ .service_metadata = service_metadata, .action = send_alexa_offer_to_master };
        }
    },
    Response: type = struct {
        answer: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .answer = "Answer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClientLimitExceeded,
        InvalidArgument,
        NotAuthorized,
        ResourceNotFound,
    },
} = .{};
