const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-11-01";
pub const sdk_id: []const u8 = "KMS";
pub const arn_namespace: ?[]const u8 = "kms";
pub const endpoint_prefix: []const u8 = "kms";
pub const sigv4_name: []const u8 = "kms";
pub const name: []const u8 = "TrentService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2014-11-01",
    sdk_id: []const u8 = "KMS",
    arn_namespace: ?[]const u8 = "kms",
    endpoint_prefix: []const u8 = "kms",
    sigv4_name: []const u8 = "kms",
    name: []const u8 = "TrentService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const cancel_key_deletion: struct {
    action_name: []const u8 = "CancelKeyDeletion",
    Request: type = struct {
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_key_deletion) } {
            return .{ .service_metadata = service_metadata, .action = cancel_key_deletion };
        }
    },
    Response: type = struct {
        key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const connect_custom_key_store: struct {
    action_name: []const u8 = "ConnectCustomKeyStore",
    Request: type = struct {
        custom_key_store_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_key_store_id = "CustomKeyStoreId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(connect_custom_key_store) } {
            return .{ .service_metadata = service_metadata, .action = connect_custom_key_store };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmClusterInvalidConfiguration,
        CloudHsmClusterNotActive,
        CustomKeyStoreInvalidState,
        CustomKeyStoreNotFound,
        KMSInternal,
    },
} = .{};
pub const create_alias: struct {
    action_name: []const u8 = "CreateAlias",
    Request: type = struct {
        alias_name: []const u8,
        target_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_name = "AliasName",
                .target_key_id = "TargetKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_alias };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AlreadyExists,
        DependencyTimeout,
        InvalidAliasName,
        KMSInternal,
        KMSInvalidState,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const create_custom_key_store: struct {
    action_name: []const u8 = "CreateCustomKeyStore",
    Request: type = struct {
        custom_key_store_name: []const u8,
        cloud_hsm_cluster_id: ?[]const u8 = null,
        trust_anchor_certificate: ?[]const u8 = null,
        key_store_password: ?[]const u8 = null,
        custom_key_store_type: ?[]const u8 = null,
        xks_proxy_uri_endpoint: ?[]const u8 = null,
        xks_proxy_uri_path: ?[]const u8 = null,
        xks_proxy_vpc_endpoint_service_name: ?[]const u8 = null,
        xks_proxy_authentication_credential: ?XksProxyAuthenticationCredentialType = null,
        xks_proxy_connectivity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_key_store_name = "CustomKeyStoreName",
                .cloud_hsm_cluster_id = "CloudHsmClusterId",
                .trust_anchor_certificate = "TrustAnchorCertificate",
                .key_store_password = "KeyStorePassword",
                .custom_key_store_type = "CustomKeyStoreType",
                .xks_proxy_uri_endpoint = "XksProxyUriEndpoint",
                .xks_proxy_uri_path = "XksProxyUriPath",
                .xks_proxy_vpc_endpoint_service_name = "XksProxyVpcEndpointServiceName",
                .xks_proxy_authentication_credential = "XksProxyAuthenticationCredential",
                .xks_proxy_connectivity = "XksProxyConnectivity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_key_store) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_key_store };
        }
    },
    Response: type = struct {
        custom_key_store_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_key_store_id = "CustomKeyStoreId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmClusterInUse,
        CloudHsmClusterInvalidConfiguration,
        CloudHsmClusterNotActive,
        CloudHsmClusterNotFound,
        CustomKeyStoreNameInUse,
        IncorrectTrustAnchor,
        KMSInternal,
        LimitExceeded,
        XksProxyIncorrectAuthenticationCredential,
        XksProxyInvalidConfiguration,
        XksProxyInvalidResponse,
        XksProxyUriEndpointInUse,
        XksProxyUriInUse,
        XksProxyUriUnreachable,
        XksProxyVpcEndpointServiceInUse,
        XksProxyVpcEndpointServiceInvalidConfiguration,
        XksProxyVpcEndpointServiceNotFound,
    },
} = .{};
pub const create_grant: struct {
    action_name: []const u8 = "CreateGrant",
    Request: type = struct {
        key_id: []const u8,
        grantee_principal: []const u8,
        retiring_principal: ?[]const u8 = null,
        operations: [][]const u8,
        constraints: ?GrantConstraints = null,
        grant_tokens: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .grantee_principal = "GranteePrincipal",
                .retiring_principal = "RetiringPrincipal",
                .operations = "Operations",
                .constraints = "Constraints",
                .grant_tokens = "GrantTokens",
                .name = "Name",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_grant) } {
            return .{ .service_metadata = service_metadata, .action = create_grant };
        }
    },
    Response: type = struct {
        grant_token: ?[]const u8 = null,
        grant_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_token = "GrantToken",
                .grant_id = "GrantId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        InvalidArn,
        InvalidGrantToken,
        KMSInternal,
        KMSInvalidState,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const create_key: struct {
    action_name: []const u8 = "CreateKey",
    Request: type = struct {
        policy: ?[]const u8 = null,
        description: ?[]const u8 = null,
        key_usage: ?[]const u8 = null,
        customer_master_key_spec: ?[]const u8 = null,
        key_spec: ?[]const u8 = null,
        origin: ?[]const u8 = null,
        custom_key_store_id: ?[]const u8 = null,
        bypass_policy_lockout_safety_check: ?bool = null,
        tags: ?[]Tag = null,
        multi_region: ?bool = null,
        xks_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .description = "Description",
                .key_usage = "KeyUsage",
                .customer_master_key_spec = "CustomerMasterKeySpec",
                .key_spec = "KeySpec",
                .origin = "Origin",
                .custom_key_store_id = "CustomKeyStoreId",
                .bypass_policy_lockout_safety_check = "BypassPolicyLockoutSafetyCheck",
                .tags = "Tags",
                .multi_region = "MultiRegion",
                .xks_key_id = "XksKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_key) } {
            return .{ .service_metadata = service_metadata, .action = create_key };
        }
    },
    Response: type = struct {
        key_metadata: ?KeyMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_metadata = "KeyMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmClusterInvalidConfiguration,
        CustomKeyStoreInvalidState,
        CustomKeyStoreNotFound,
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        LimitExceeded,
        MalformedPolicyDocument,
        Tag,
        UnsupportedOperation,
        XksKeyAlreadyInUse,
        XksKeyInvalidConfiguration,
        XksKeyNotFound,
    },
} = .{};
pub const decrypt: struct {
    action_name: []const u8 = "Decrypt",
    Request: type = struct {
        ciphertext_blob: []const u8,
        encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        grant_tokens: ?[][]const u8 = null,
        key_id: ?[]const u8 = null,
        encryption_algorithm: ?[]const u8 = null,
        recipient: ?RecipientInfo = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ciphertext_blob = "CiphertextBlob",
                .encryption_context = "EncryptionContext",
                .grant_tokens = "GrantTokens",
                .key_id = "KeyId",
                .encryption_algorithm = "EncryptionAlgorithm",
                .recipient = "Recipient",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "encryption_context", field_name))
                return try serializeMap(self.encryption_context, self.fieldNameFor("encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decrypt) } {
            return .{ .service_metadata = service_metadata, .action = decrypt };
        }
    },
    Response: type = struct {
        key_id: ?[]const u8 = null,
        plaintext: ?[]const u8 = null,
        encryption_algorithm: ?[]const u8 = null,
        ciphertext_for_recipient: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .plaintext = "Plaintext",
                .encryption_algorithm = "EncryptionAlgorithm",
                .ciphertext_for_recipient = "CiphertextForRecipient",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        IncorrectKey,
        InvalidCiphertext,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const delete_alias: struct {
    action_name: []const u8 = "DeleteAlias",
    Request: type = struct {
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_alias };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const delete_custom_key_store: struct {
    action_name: []const u8 = "DeleteCustomKeyStore",
    Request: type = struct {
        custom_key_store_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_key_store_id = "CustomKeyStoreId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_key_store) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_key_store };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomKeyStoreHasCMKs,
        CustomKeyStoreInvalidState,
        CustomKeyStoreNotFound,
        KMSInternal,
    },
} = .{};
pub const delete_imported_key_material: struct {
    action_name: []const u8 = "DeleteImportedKeyMaterial",
    Request: type = struct {
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_imported_key_material) } {
            return .{ .service_metadata = service_metadata, .action = delete_imported_key_material };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_custom_key_stores: struct {
    action_name: []const u8 = "DescribeCustomKeyStores",
    Request: type = struct {
        custom_key_store_id: ?[]const u8 = null,
        custom_key_store_name: ?[]const u8 = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_key_store_id = "CustomKeyStoreId",
                .custom_key_store_name = "CustomKeyStoreName",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_key_stores) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_key_stores };
        }
    },
    Response: type = struct {
        custom_key_stores: ?[]struct {
            custom_key_store_id: ?[]const u8 = null,
            custom_key_store_name: ?[]const u8 = null,
            cloud_hsm_cluster_id: ?[]const u8 = null,
            trust_anchor_certificate: ?[]const u8 = null,
            connection_state: ?[]const u8 = null,
            connection_error_code: ?[]const u8 = null,
            creation_date: ?i64 = null,
            custom_key_store_type: ?[]const u8 = null,
            xks_proxy_configuration: ?struct {
                connectivity: ?[]const u8 = null,
                access_key_id: ?[]const u8 = null,
                uri_endpoint: ?[]const u8 = null,
                uri_path: ?[]const u8 = null,
                vpc_endpoint_service_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .connectivity = "Connectivity",
                        .access_key_id = "AccessKeyId",
                        .uri_endpoint = "UriEndpoint",
                        .uri_path = "UriPath",
                        .vpc_endpoint_service_name = "VpcEndpointServiceName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .custom_key_store_id = "CustomKeyStoreId",
                    .custom_key_store_name = "CustomKeyStoreName",
                    .cloud_hsm_cluster_id = "CloudHsmClusterId",
                    .trust_anchor_certificate = "TrustAnchorCertificate",
                    .connection_state = "ConnectionState",
                    .connection_error_code = "ConnectionErrorCode",
                    .creation_date = "CreationDate",
                    .custom_key_store_type = "CustomKeyStoreType",
                    .xks_proxy_configuration = "XksProxyConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_key_stores = "CustomKeyStores",
                .next_marker = "NextMarker",
                .truncated = "Truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomKeyStoreNotFound,
        InvalidMarker,
        KMSInternal,
    },
} = .{};
pub const describe_key: struct {
    action_name: []const u8 = "DescribeKey",
    Request: type = struct {
        key_id: []const u8,
        grant_tokens: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .grant_tokens = "GrantTokens",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_key) } {
            return .{ .service_metadata = service_metadata, .action = describe_key };
        }
    },
    Response: type = struct {
        key_metadata: ?KeyMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_metadata = "KeyMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        NotFound,
    },
} = .{};
pub const disable_key: struct {
    action_name: []const u8 = "DisableKey",
    Request: type = struct {
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_key) } {
            return .{ .service_metadata = service_metadata, .action = disable_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const disable_key_rotation: struct {
    action_name: []const u8 = "DisableKeyRotation",
    Request: type = struct {
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_key_rotation) } {
            return .{ .service_metadata = service_metadata, .action = disable_key_rotation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const disconnect_custom_key_store: struct {
    action_name: []const u8 = "DisconnectCustomKeyStore",
    Request: type = struct {
        custom_key_store_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_key_store_id = "CustomKeyStoreId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disconnect_custom_key_store) } {
            return .{ .service_metadata = service_metadata, .action = disconnect_custom_key_store };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomKeyStoreInvalidState,
        CustomKeyStoreNotFound,
        KMSInternal,
    },
} = .{};
pub const enable_key: struct {
    action_name: []const u8 = "EnableKey",
    Request: type = struct {
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_key) } {
            return .{ .service_metadata = service_metadata, .action = enable_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const enable_key_rotation: struct {
    action_name: []const u8 = "EnableKeyRotation",
    Request: type = struct {
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_key_rotation) } {
            return .{ .service_metadata = service_metadata, .action = enable_key_rotation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const encrypt: struct {
    action_name: []const u8 = "Encrypt",
    Request: type = struct {
        key_id: []const u8,
        plaintext: []const u8,
        encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        grant_tokens: ?[][]const u8 = null,
        encryption_algorithm: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .plaintext = "Plaintext",
                .encryption_context = "EncryptionContext",
                .grant_tokens = "GrantTokens",
                .encryption_algorithm = "EncryptionAlgorithm",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "encryption_context", field_name))
                return try serializeMap(self.encryption_context, self.fieldNameFor("encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(encrypt) } {
            return .{ .service_metadata = service_metadata, .action = encrypt };
        }
    },
    Response: type = struct {
        ciphertext_blob: ?[]const u8 = null,
        key_id: ?[]const u8 = null,
        encryption_algorithm: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ciphertext_blob = "CiphertextBlob",
                .key_id = "KeyId",
                .encryption_algorithm = "EncryptionAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const generate_data_key: struct {
    action_name: []const u8 = "GenerateDataKey",
    Request: type = struct {
        key_id: []const u8,
        encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        number_of_bytes: ?i64 = null,
        key_spec: ?[]const u8 = null,
        grant_tokens: ?[][]const u8 = null,
        recipient: ?RecipientInfo = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .encryption_context = "EncryptionContext",
                .number_of_bytes = "NumberOfBytes",
                .key_spec = "KeySpec",
                .grant_tokens = "GrantTokens",
                .recipient = "Recipient",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "encryption_context", field_name))
                return try serializeMap(self.encryption_context, self.fieldNameFor("encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_data_key) } {
            return .{ .service_metadata = service_metadata, .action = generate_data_key };
        }
    },
    Response: type = struct {
        ciphertext_blob: ?[]const u8 = null,
        plaintext: ?[]const u8 = null,
        key_id: ?[]const u8 = null,
        ciphertext_for_recipient: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ciphertext_blob = "CiphertextBlob",
                .plaintext = "Plaintext",
                .key_id = "KeyId",
                .ciphertext_for_recipient = "CiphertextForRecipient",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const generate_data_key_pair: struct {
    action_name: []const u8 = "GenerateDataKeyPair",
    Request: type = struct {
        encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        key_id: []const u8,
        key_pair_spec: []const u8,
        grant_tokens: ?[][]const u8 = null,
        recipient: ?RecipientInfo = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_context = "EncryptionContext",
                .key_id = "KeyId",
                .key_pair_spec = "KeyPairSpec",
                .grant_tokens = "GrantTokens",
                .recipient = "Recipient",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "encryption_context", field_name))
                return try serializeMap(self.encryption_context, self.fieldNameFor("encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_data_key_pair) } {
            return .{ .service_metadata = service_metadata, .action = generate_data_key_pair };
        }
    },
    Response: type = struct {
        private_key_ciphertext_blob: ?[]const u8 = null,
        private_key_plaintext: ?[]const u8 = null,
        public_key: ?[]const u8 = null,
        key_id: ?[]const u8 = null,
        key_pair_spec: ?[]const u8 = null,
        ciphertext_for_recipient: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .private_key_ciphertext_blob = "PrivateKeyCiphertextBlob",
                .private_key_plaintext = "PrivateKeyPlaintext",
                .public_key = "PublicKey",
                .key_id = "KeyId",
                .key_pair_spec = "KeyPairSpec",
                .ciphertext_for_recipient = "CiphertextForRecipient",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const generate_data_key_pair_without_plaintext: struct {
    action_name: []const u8 = "GenerateDataKeyPairWithoutPlaintext",
    Request: type = struct {
        encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        key_id: []const u8,
        key_pair_spec: []const u8,
        grant_tokens: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_context = "EncryptionContext",
                .key_id = "KeyId",
                .key_pair_spec = "KeyPairSpec",
                .grant_tokens = "GrantTokens",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "encryption_context", field_name))
                return try serializeMap(self.encryption_context, self.fieldNameFor("encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_data_key_pair_without_plaintext) } {
            return .{ .service_metadata = service_metadata, .action = generate_data_key_pair_without_plaintext };
        }
    },
    Response: type = struct {
        private_key_ciphertext_blob: ?[]const u8 = null,
        public_key: ?[]const u8 = null,
        key_id: ?[]const u8 = null,
        key_pair_spec: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .private_key_ciphertext_blob = "PrivateKeyCiphertextBlob",
                .public_key = "PublicKey",
                .key_id = "KeyId",
                .key_pair_spec = "KeyPairSpec",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const generate_data_key_without_plaintext: struct {
    action_name: []const u8 = "GenerateDataKeyWithoutPlaintext",
    Request: type = struct {
        key_id: []const u8,
        encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        key_spec: ?[]const u8 = null,
        number_of_bytes: ?i64 = null,
        grant_tokens: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .encryption_context = "EncryptionContext",
                .key_spec = "KeySpec",
                .number_of_bytes = "NumberOfBytes",
                .grant_tokens = "GrantTokens",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "encryption_context", field_name))
                return try serializeMap(self.encryption_context, self.fieldNameFor("encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_data_key_without_plaintext) } {
            return .{ .service_metadata = service_metadata, .action = generate_data_key_without_plaintext };
        }
    },
    Response: type = struct {
        ciphertext_blob: ?[]const u8 = null,
        key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ciphertext_blob = "CiphertextBlob",
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const generate_mac: struct {
    action_name: []const u8 = "GenerateMac",
    Request: type = struct {
        message: []const u8,
        key_id: []const u8,
        mac_algorithm: []const u8,
        grant_tokens: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
                .key_id = "KeyId",
                .mac_algorithm = "MacAlgorithm",
                .grant_tokens = "GrantTokens",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_mac) } {
            return .{ .service_metadata = service_metadata, .action = generate_mac };
        }
    },
    Response: type = struct {
        mac: ?[]const u8 = null,
        mac_algorithm: ?[]const u8 = null,
        key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mac = "Mac",
                .mac_algorithm = "MacAlgorithm",
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const generate_random: struct {
    action_name: []const u8 = "GenerateRandom",
    Request: type = struct {
        number_of_bytes: ?i64 = null,
        custom_key_store_id: ?[]const u8 = null,
        recipient: ?RecipientInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .number_of_bytes = "NumberOfBytes",
                .custom_key_store_id = "CustomKeyStoreId",
                .recipient = "Recipient",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_random) } {
            return .{ .service_metadata = service_metadata, .action = generate_random };
        }
    },
    Response: type = struct {
        plaintext: ?[]const u8 = null,
        ciphertext_for_recipient: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .plaintext = "Plaintext",
                .ciphertext_for_recipient = "CiphertextForRecipient",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomKeyStoreInvalidState,
        CustomKeyStoreNotFound,
        DependencyTimeout,
        KMSInternal,
        UnsupportedOperation,
    },
} = .{};
pub const get_key_policy: struct {
    action_name: []const u8 = "GetKeyPolicy",
    Request: type = struct {
        key_id: []const u8,
        policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .policy_name = "PolicyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_key_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_key_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const get_key_rotation_status: struct {
    action_name: []const u8 = "GetKeyRotationStatus",
    Request: type = struct {
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_key_rotation_status) } {
            return .{ .service_metadata = service_metadata, .action = get_key_rotation_status };
        }
    },
    Response: type = struct {
        key_rotation_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_rotation_enabled = "KeyRotationEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_parameters_for_import: struct {
    action_name: []const u8 = "GetParametersForImport",
    Request: type = struct {
        key_id: []const u8,
        wrapping_algorithm: []const u8,
        wrapping_key_spec: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .wrapping_algorithm = "WrappingAlgorithm",
                .wrapping_key_spec = "WrappingKeySpec",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_parameters_for_import) } {
            return .{ .service_metadata = service_metadata, .action = get_parameters_for_import };
        }
    },
    Response: type = struct {
        key_id: ?[]const u8 = null,
        import_token: ?[]const u8 = null,
        public_key: ?[]const u8 = null,
        parameters_valid_to: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .import_token = "ImportToken",
                .public_key = "PublicKey",
                .parameters_valid_to = "ParametersValidTo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_public_key: struct {
    action_name: []const u8 = "GetPublicKey",
    Request: type = struct {
        key_id: []const u8,
        grant_tokens: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .grant_tokens = "GrantTokens",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_public_key) } {
            return .{ .service_metadata = service_metadata, .action = get_public_key };
        }
    },
    Response: type = struct {
        key_id: ?[]const u8 = null,
        public_key: ?[]const u8 = null,
        customer_master_key_spec: ?[]const u8 = null,
        key_spec: ?[]const u8 = null,
        key_usage: ?[]const u8 = null,
        encryption_algorithms: ?[][]const u8 = null,
        signing_algorithms: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .public_key = "PublicKey",
                .customer_master_key_spec = "CustomerMasterKeySpec",
                .key_spec = "KeySpec",
                .key_usage = "KeyUsage",
                .encryption_algorithms = "EncryptionAlgorithms",
                .signing_algorithms = "SigningAlgorithms",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        InvalidArn,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const import_key_material: struct {
    action_name: []const u8 = "ImportKeyMaterial",
    Request: type = struct {
        key_id: []const u8,
        import_token: []const u8,
        encrypted_key_material: []const u8,
        valid_to: ?i64 = null,
        expiration_model: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .import_token = "ImportToken",
                .encrypted_key_material = "EncryptedKeyMaterial",
                .valid_to = "ValidTo",
                .expiration_model = "ExpirationModel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_key_material) } {
            return .{ .service_metadata = service_metadata, .action = import_key_material };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        ExpiredImportToken,
        IncorrectKeyMaterial,
        InvalidArn,
        InvalidCiphertext,
        InvalidImportToken,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const list_aliases: struct {
    action_name: []const u8 = "ListAliases",
    Request: type = struct {
        key_id: ?[]const u8 = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[]struct {
            alias_name: ?[]const u8 = null,
            alias_arn: ?[]const u8 = null,
            target_key_id: ?[]const u8 = null,
            creation_date: ?i64 = null,
            last_updated_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .alias_name = "AliasName",
                    .alias_arn = "AliasArn",
                    .target_key_id = "TargetKeyId",
                    .creation_date = "CreationDate",
                    .last_updated_date = "LastUpdatedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
                .next_marker = "NextMarker",
                .truncated = "Truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        InvalidMarker,
        KMSInternal,
        NotFound,
    },
} = .{};
pub const list_grants: struct {
    action_name: []const u8 = "ListGrants",
    Request: type = struct {
        limit: ?i64 = null,
        marker: ?[]const u8 = null,
        key_id: []const u8,
        grant_id: ?[]const u8 = null,
        grantee_principal: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .marker = "Marker",
                .key_id = "KeyId",
                .grant_id = "GrantId",
                .grantee_principal = "GranteePrincipal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_grants) } {
            return .{ .service_metadata = service_metadata, .action = list_grants };
        }
    },
    Response: type = struct {
        grants: ?[]GrantListEntry = null,
        next_marker: ?[]const u8 = null,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grants = "Grants",
                .next_marker = "NextMarker",
                .truncated = "Truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        InvalidGrantId,
        InvalidMarker,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const list_key_policies: struct {
    action_name: []const u8 = "ListKeyPolicies",
    Request: type = struct {
        key_id: []const u8,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_key_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_key_policies };
        }
    },
    Response: type = struct {
        policy_names: ?[][]const u8 = null,
        next_marker: ?[]const u8 = null,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_names = "PolicyNames",
                .next_marker = "NextMarker",
                .truncated = "Truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const list_keys: struct {
    action_name: []const u8 = "ListKeys",
    Request: type = struct {
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_keys };
        }
    },
    Response: type = struct {
        keys: ?[]struct {
            key_id: ?[]const u8 = null,
            key_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key_id = "KeyId",
                    .key_arn = "KeyArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keys = "Keys",
                .next_marker = "NextMarker",
                .truncated = "Truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidMarker,
        KMSInternal,
    },
} = .{};
pub const list_resource_tags: struct {
    action_name: []const u8 = "ListResourceTags",
    Request: type = struct {
        key_id: []const u8,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_tags };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_marker: ?[]const u8 = null,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_marker = "NextMarker",
                .truncated = "Truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidMarker,
        KMSInternal,
        NotFound,
    },
} = .{};
pub const list_retirable_grants: struct {
    action_name: []const u8 = "ListRetirableGrants",
    Request: type = struct {
        limit: ?i64 = null,
        marker: ?[]const u8 = null,
        retiring_principal: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .marker = "Marker",
                .retiring_principal = "RetiringPrincipal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_retirable_grants) } {
            return .{ .service_metadata = service_metadata, .action = list_retirable_grants };
        }
    },
    Response: type = struct {
        grants: ?[]GrantListEntry = null,
        next_marker: ?[]const u8 = null,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grants = "Grants",
                .next_marker = "NextMarker",
                .truncated = "Truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        InvalidMarker,
        KMSInternal,
        NotFound,
    },
} = .{};
pub const put_key_policy: struct {
    action_name: []const u8 = "PutKeyPolicy",
    Request: type = struct {
        key_id: []const u8,
        policy_name: []const u8,
        policy: []const u8,
        bypass_policy_lockout_safety_check: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .policy_name = "PolicyName",
                .policy = "Policy",
                .bypass_policy_lockout_safety_check = "BypassPolicyLockoutSafetyCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_key_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_key_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        LimitExceeded,
        MalformedPolicyDocument,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const re_encrypt: struct {
    action_name: []const u8 = "ReEncrypt",
    Request: type = struct {
        ciphertext_blob: []const u8,
        source_encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        source_key_id: ?[]const u8 = null,
        destination_key_id: []const u8,
        destination_encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        source_encryption_algorithm: ?[]const u8 = null,
        destination_encryption_algorithm: ?[]const u8 = null,
        grant_tokens: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ciphertext_blob = "CiphertextBlob",
                .source_encryption_context = "SourceEncryptionContext",
                .source_key_id = "SourceKeyId",
                .destination_key_id = "DestinationKeyId",
                .destination_encryption_context = "DestinationEncryptionContext",
                .source_encryption_algorithm = "SourceEncryptionAlgorithm",
                .destination_encryption_algorithm = "DestinationEncryptionAlgorithm",
                .grant_tokens = "GrantTokens",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "source_encryption_context", field_name))
                return try serializeMap(self.source_encryption_context, self.fieldNameFor("source_encryption_context"), options, out_stream);
            if (std.mem.eql(u8, "destination_encryption_context", field_name))
                return try serializeMap(self.destination_encryption_context, self.fieldNameFor("destination_encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(re_encrypt) } {
            return .{ .service_metadata = service_metadata, .action = re_encrypt };
        }
    },
    Response: type = struct {
        ciphertext_blob: ?[]const u8 = null,
        source_key_id: ?[]const u8 = null,
        key_id: ?[]const u8 = null,
        source_encryption_algorithm: ?[]const u8 = null,
        destination_encryption_algorithm: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ciphertext_blob = "CiphertextBlob",
                .source_key_id = "SourceKeyId",
                .key_id = "KeyId",
                .source_encryption_algorithm = "SourceEncryptionAlgorithm",
                .destination_encryption_algorithm = "DestinationEncryptionAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        IncorrectKey,
        InvalidCiphertext,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const replicate_key: struct {
    action_name: []const u8 = "ReplicateKey",
    Request: type = struct {
        key_id: []const u8,
        replica_region: []const u8,
        policy: ?[]const u8 = null,
        bypass_policy_lockout_safety_check: ?bool = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .replica_region = "ReplicaRegion",
                .policy = "Policy",
                .bypass_policy_lockout_safety_check = "BypassPolicyLockoutSafetyCheck",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replicate_key) } {
            return .{ .service_metadata = service_metadata, .action = replicate_key };
        }
    },
    Response: type = struct {
        replica_key_metadata: ?KeyMetadata = null,
        replica_policy: ?[]const u8 = null,
        replica_tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replica_key_metadata = "ReplicaKeyMetadata",
                .replica_policy = "ReplicaPolicy",
                .replica_tags = "ReplicaTags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        Disabled,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        LimitExceeded,
        MalformedPolicyDocument,
        NotFound,
        Tag,
        UnsupportedOperation,
    },
} = .{};
pub const retire_grant: struct {
    action_name: []const u8 = "RetireGrant",
    Request: type = struct {
        grant_token: ?[]const u8 = null,
        key_id: ?[]const u8 = null,
        grant_id: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_token = "GrantToken",
                .key_id = "KeyId",
                .grant_id = "GrantId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(retire_grant) } {
            return .{ .service_metadata = service_metadata, .action = retire_grant };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        DryRunOperation,
        InvalidArn,
        InvalidGrantId,
        InvalidGrantToken,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const revoke_grant: struct {
    action_name: []const u8 = "RevokeGrant",
    Request: type = struct {
        key_id: []const u8,
        grant_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .grant_id = "GrantId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_grant) } {
            return .{ .service_metadata = service_metadata, .action = revoke_grant };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        DryRunOperation,
        InvalidArn,
        InvalidGrantId,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const schedule_key_deletion: struct {
    action_name: []const u8 = "ScheduleKeyDeletion",
    Request: type = struct {
        key_id: []const u8,
        pending_window_in_days: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .pending_window_in_days = "PendingWindowInDays",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(schedule_key_deletion) } {
            return .{ .service_metadata = service_metadata, .action = schedule_key_deletion };
        }
    },
    Response: type = struct {
        key_id: ?[]const u8 = null,
        deletion_date: ?i64 = null,
        key_state: ?[]const u8 = null,
        pending_window_in_days: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .deletion_date = "DeletionDate",
                .key_state = "KeyState",
                .pending_window_in_days = "PendingWindowInDays",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const sign: struct {
    action_name: []const u8 = "Sign",
    Request: type = struct {
        key_id: []const u8,
        message: []const u8,
        message_type: ?[]const u8 = null,
        grant_tokens: ?[][]const u8 = null,
        signing_algorithm: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .message = "Message",
                .message_type = "MessageType",
                .grant_tokens = "GrantTokens",
                .signing_algorithm = "SigningAlgorithm",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(sign) } {
            return .{ .service_metadata = service_metadata, .action = sign };
        }
    },
    Response: type = struct {
        key_id: ?[]const u8 = null,
        signature: ?[]const u8 = null,
        signing_algorithm: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .signature = "Signature",
                .signing_algorithm = "SigningAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        key_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        LimitExceeded,
        NotFound,
        Tag,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        key_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        Tag,
    },
} = .{};
pub const update_alias: struct {
    action_name: []const u8 = "UpdateAlias",
    Request: type = struct {
        alias_name: []const u8,
        target_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_name = "AliasName",
                .target_key_id = "TargetKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_alias };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        KMSInternal,
        KMSInvalidState,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const update_custom_key_store: struct {
    action_name: []const u8 = "UpdateCustomKeyStore",
    Request: type = struct {
        custom_key_store_id: []const u8,
        new_custom_key_store_name: ?[]const u8 = null,
        key_store_password: ?[]const u8 = null,
        cloud_hsm_cluster_id: ?[]const u8 = null,
        xks_proxy_uri_endpoint: ?[]const u8 = null,
        xks_proxy_uri_path: ?[]const u8 = null,
        xks_proxy_vpc_endpoint_service_name: ?[]const u8 = null,
        xks_proxy_authentication_credential: ?XksProxyAuthenticationCredentialType = null,
        xks_proxy_connectivity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_key_store_id = "CustomKeyStoreId",
                .new_custom_key_store_name = "NewCustomKeyStoreName",
                .key_store_password = "KeyStorePassword",
                .cloud_hsm_cluster_id = "CloudHsmClusterId",
                .xks_proxy_uri_endpoint = "XksProxyUriEndpoint",
                .xks_proxy_uri_path = "XksProxyUriPath",
                .xks_proxy_vpc_endpoint_service_name = "XksProxyVpcEndpointServiceName",
                .xks_proxy_authentication_credential = "XksProxyAuthenticationCredential",
                .xks_proxy_connectivity = "XksProxyConnectivity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_custom_key_store) } {
            return .{ .service_metadata = service_metadata, .action = update_custom_key_store };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudHsmClusterInvalidConfiguration,
        CloudHsmClusterNotActive,
        CloudHsmClusterNotFound,
        CloudHsmClusterNotRelated,
        CustomKeyStoreInvalidState,
        CustomKeyStoreNameInUse,
        CustomKeyStoreNotFound,
        KMSInternal,
        XksProxyIncorrectAuthenticationCredential,
        XksProxyInvalidConfiguration,
        XksProxyInvalidResponse,
        XksProxyUriEndpointInUse,
        XksProxyUriInUse,
        XksProxyUriUnreachable,
        XksProxyVpcEndpointServiceInUse,
        XksProxyVpcEndpointServiceInvalidConfiguration,
        XksProxyVpcEndpointServiceNotFound,
    },
} = .{};
pub const update_key_description: struct {
    action_name: []const u8 = "UpdateKeyDescription",
    Request: type = struct {
        key_id: []const u8,
        description: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_key_description) } {
            return .{ .service_metadata = service_metadata, .action = update_key_description };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependencyTimeout,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const update_primary_region: struct {
    action_name: []const u8 = "UpdatePrimaryRegion",
    Request: type = struct {
        key_id: []const u8,
        primary_region: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .primary_region = "PrimaryRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_primary_region) } {
            return .{ .service_metadata = service_metadata, .action = update_primary_region };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Disabled,
        InvalidArn,
        KMSInternal,
        KMSInvalidState,
        NotFound,
        UnsupportedOperation,
    },
} = .{};
pub const verify: struct {
    action_name: []const u8 = "Verify",
    Request: type = struct {
        key_id: []const u8,
        message: []const u8,
        message_type: ?[]const u8 = null,
        signature: []const u8,
        signing_algorithm: []const u8,
        grant_tokens: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .message = "Message",
                .message_type = "MessageType",
                .signature = "Signature",
                .signing_algorithm = "SigningAlgorithm",
                .grant_tokens = "GrantTokens",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify) } {
            return .{ .service_metadata = service_metadata, .action = verify };
        }
    },
    Response: type = struct {
        key_id: ?[]const u8 = null,
        signature_valid: ?bool = null,
        signing_algorithm: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .signature_valid = "SignatureValid",
                .signing_algorithm = "SigningAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyTimeout,
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidSignature,
        KMSInvalidState,
        NotFound,
    },
} = .{};
pub const verify_mac: struct {
    action_name: []const u8 = "VerifyMac",
    Request: type = struct {
        message: []const u8,
        key_id: []const u8,
        mac_algorithm: []const u8,
        mac: []const u8,
        grant_tokens: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
                .key_id = "KeyId",
                .mac_algorithm = "MacAlgorithm",
                .mac = "Mac",
                .grant_tokens = "GrantTokens",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_mac) } {
            return .{ .service_metadata = service_metadata, .action = verify_mac };
        }
    },
    Response: type = struct {
        key_id: ?[]const u8 = null,
        mac_valid: ?bool = null,
        mac_algorithm: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .mac_valid = "MacValid",
                .mac_algorithm = "MacAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Disabled,
        DryRunOperation,
        InvalidGrantToken,
        InvalidKeyUsage,
        KeyUnavailable,
        KMSInternal,
        KMSInvalidMac,
        KMSInvalidState,
        NotFound,
    },
} = .{};

pub const XksProxyAuthenticationCredentialType = struct {
    access_key_id: []const u8,
    raw_secret_access_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_key_id = "AccessKeyId",
            .raw_secret_access_key = "RawSecretAccessKey",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    tag_key: []const u8,
    tag_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_key = "TagKey",
            .tag_value = "TagValue",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyMetadata = struct {
    aws_account_id: ?[]const u8 = null,
    key_id: []const u8,
    arn: ?[]const u8 = null,
    creation_date: ?i64 = null,
    enabled: ?bool = null,
    description: ?[]const u8 = null,
    key_usage: ?[]const u8 = null,
    key_state: ?[]const u8 = null,
    deletion_date: ?i64 = null,
    valid_to: ?i64 = null,
    origin: ?[]const u8 = null,
    custom_key_store_id: ?[]const u8 = null,
    cloud_hsm_cluster_id: ?[]const u8 = null,
    expiration_model: ?[]const u8 = null,
    key_manager: ?[]const u8 = null,
    customer_master_key_spec: ?[]const u8 = null,
    key_spec: ?[]const u8 = null,
    encryption_algorithms: ?[][]const u8 = null,
    signing_algorithms: ?[][]const u8 = null,
    multi_region: ?bool = null,
    multi_region_configuration: ?MultiRegionConfiguration = null,
    pending_deletion_window_in_days: ?i64 = null,
    mac_algorithms: ?[][]const u8 = null,
    xks_key_configuration: ?XksKeyConfigurationType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_account_id = "AWSAccountId",
            .key_id = "KeyId",
            .arn = "Arn",
            .creation_date = "CreationDate",
            .enabled = "Enabled",
            .description = "Description",
            .key_usage = "KeyUsage",
            .key_state = "KeyState",
            .deletion_date = "DeletionDate",
            .valid_to = "ValidTo",
            .origin = "Origin",
            .custom_key_store_id = "CustomKeyStoreId",
            .cloud_hsm_cluster_id = "CloudHsmClusterId",
            .expiration_model = "ExpirationModel",
            .key_manager = "KeyManager",
            .customer_master_key_spec = "CustomerMasterKeySpec",
            .key_spec = "KeySpec",
            .encryption_algorithms = "EncryptionAlgorithms",
            .signing_algorithms = "SigningAlgorithms",
            .multi_region = "MultiRegion",
            .multi_region_configuration = "MultiRegionConfiguration",
            .pending_deletion_window_in_days = "PendingDeletionWindowInDays",
            .mac_algorithms = "MacAlgorithms",
            .xks_key_configuration = "XksKeyConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const XksKeyConfigurationType = struct {
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiRegionConfiguration = struct {
    multi_region_key_type: ?[]const u8 = null,
    primary_key: ?MultiRegionKey = null,
    replica_keys: ?[]MultiRegionKey = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .multi_region_key_type = "MultiRegionKeyType",
            .primary_key = "PrimaryKey",
            .replica_keys = "ReplicaKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiRegionKey = struct {
    arn: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};

pub const GrantListEntry = struct {
    key_id: ?[]const u8 = null,
    grant_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    creation_date: ?i64 = null,
    grantee_principal: ?[]const u8 = null,
    retiring_principal: ?[]const u8 = null,
    issuing_account: ?[]const u8 = null,
    operations: ?[][]const u8 = null,
    constraints: ?GrantConstraints = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_id = "KeyId",
            .grant_id = "GrantId",
            .name = "Name",
            .creation_date = "CreationDate",
            .grantee_principal = "GranteePrincipal",
            .retiring_principal = "RetiringPrincipal",
            .issuing_account = "IssuingAccount",
            .operations = "Operations",
            .constraints = "Constraints",
        };
        return @field(mappings, field_name);
    }
};

pub const GrantConstraints = struct {
    encryption_context_subset: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    encryption_context_equals: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_context_subset = "EncryptionContextSubset",
            .encryption_context_equals = "EncryptionContextEquals",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "encryption_context_subset", field_name))
            return try serializeMap(self.encryption_context_subset, self.fieldNameFor("encryption_context_subset"), options, out_stream);
        if (std.mem.eql(u8, "encryption_context_equals", field_name))
            return try serializeMap(self.encryption_context_equals, self.fieldNameFor("encryption_context_equals"), options, out_stream);
        return false;
    }
};

pub const RecipientInfo = struct {
    key_encryption_algorithm: ?[]const u8 = null,
    attestation_document: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_encryption_algorithm = "KeyEncryptionAlgorithm",
            .attestation_document = "AttestationDocument",
        };
        return @field(mappings, field_name);
    }
};
